package com.tencent.soter.core.biometric;

import android.content.Context;
import android.os.CancellationSignal;
import android.os.Handler;
import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.soter.core.a;
import com.tencent.soter.core.biometric.FaceidManagerProxy.AuthenticationCallback;
import com.tencent.soter.core.c.d;
import java.util.HashMap;
import java.util.Map;

public class BiometricManagerCompat {
    static final Map<Integer, IBiometricManager> IMPL_PROVIDER = new HashMap();
    private static final String TAG = "Soter.BiometricManagerCompat";
    private Integer mBiometricType;
    private Context mContext;

    static class FaceidManagerImpl implements IBiometricManager {
        private static final String TAG = "Soter.BiometricManagerCompat.Faceid";

        static /* synthetic */ boolean access$300(AuthenticationCallback authenticationCallback, Context context) {
            AppMethodBeat.i(72908);
            boolean shouldInformTooManyTrial = shouldInformTooManyTrial(authenticationCallback, context);
            AppMethodBeat.o(72908);
            return shouldInformTooManyTrial;
        }

        static /* synthetic */ CryptoObject access$400(FaceidManagerProxy$CryptoObject faceidManagerProxy$CryptoObject) {
            AppMethodBeat.i(72909);
            CryptoObject unwrapCryptoObject = unwrapCryptoObject(faceidManagerProxy$CryptoObject);
            AppMethodBeat.o(72909);
            return unwrapCryptoObject;
        }

        static /* synthetic */ void access$500(AuthenticationCallback authenticationCallback) {
            AppMethodBeat.i(72910);
            informTooManyTrial(authenticationCallback);
            AppMethodBeat.o(72910);
        }

        public boolean hasEnrolledBiometric(Context context) {
            AppMethodBeat.i(72899);
            boolean hasEnrolledFaceids = FaceidManagerProxy.hasEnrolledFaceids(context);
            AppMethodBeat.o(72899);
            return hasEnrolledFaceids;
        }

        public boolean isHardwareDetected(Context context) {
            AppMethodBeat.i(72900);
            boolean isHardwareDetected = FaceidManagerProxy.isHardwareDetected(context);
            AppMethodBeat.o(72900);
            return isHardwareDetected;
        }

        public String getBiometricName(Context context) {
            AppMethodBeat.i(72901);
            String biometricName = FaceidManagerProxy.getBiometricName(context);
            AppMethodBeat.o(72901);
            return biometricName;
        }

        public void authenticate(Context context, CryptoObject cryptoObject, int i, CancellationSignal cancellationSignal, AuthenticationCallback authenticationCallback, Handler handler) {
            AppMethodBeat.i(72902);
            FaceidManagerProxy.authenticate(context, wrapCryptoObject(cryptoObject), i, cancellationSignal, wrapCallback(context, authenticationCallback), handler);
            AppMethodBeat.o(72902);
        }

        private static FaceidManagerProxy$CryptoObject wrapCryptoObject(CryptoObject cryptoObject) {
            AppMethodBeat.i(72903);
            FaceidManagerProxy$CryptoObject faceidManagerProxy$CryptoObject;
            if (cryptoObject == null) {
                AppMethodBeat.o(72903);
                return null;
            } else if (cryptoObject.getCipher() != null) {
                faceidManagerProxy$CryptoObject = new FaceidManagerProxy$CryptoObject(cryptoObject.getCipher());
                AppMethodBeat.o(72903);
                return faceidManagerProxy$CryptoObject;
            } else if (cryptoObject.getSignature() != null) {
                faceidManagerProxy$CryptoObject = new FaceidManagerProxy$CryptoObject(cryptoObject.getSignature());
                AppMethodBeat.o(72903);
                return faceidManagerProxy$CryptoObject;
            } else if (cryptoObject.getMac() != null) {
                faceidManagerProxy$CryptoObject = new FaceidManagerProxy$CryptoObject(cryptoObject.getMac());
                AppMethodBeat.o(72903);
                return faceidManagerProxy$CryptoObject;
            } else {
                AppMethodBeat.o(72903);
                return null;
            }
        }

        private static CryptoObject unwrapCryptoObject(FaceidManagerProxy$CryptoObject faceidManagerProxy$CryptoObject) {
            AppMethodBeat.i(72904);
            CryptoObject cryptoObject;
            if (faceidManagerProxy$CryptoObject == null) {
                AppMethodBeat.o(72904);
                return null;
            } else if (faceidManagerProxy$CryptoObject.getCipher() != null) {
                cryptoObject = new CryptoObject(faceidManagerProxy$CryptoObject.getCipher());
                AppMethodBeat.o(72904);
                return cryptoObject;
            } else if (faceidManagerProxy$CryptoObject.getSignature() != null) {
                cryptoObject = new CryptoObject(faceidManagerProxy$CryptoObject.getSignature());
                AppMethodBeat.o(72904);
                return cryptoObject;
            } else if (faceidManagerProxy$CryptoObject.getMac() != null) {
                cryptoObject = new CryptoObject(faceidManagerProxy$CryptoObject.getMac());
                AppMethodBeat.o(72904);
                return cryptoObject;
            } else {
                AppMethodBeat.o(72904);
                return null;
            }
        }

        private static AuthenticationCallback wrapCallback(Context context, AuthenticationCallback authenticationCallback) {
            AppMethodBeat.i(72905);
            1 1 = new 1(authenticationCallback, context);
            AppMethodBeat.o(72905);
            return 1;
        }

        private static boolean shouldInformTooManyTrial(AuthenticationCallback authenticationCallback, Context context) {
            AppMethodBeat.i(72906);
            if (SoterBiometricAntiBruteForceStrategy.isSystemHasAntiBruteForce()) {
                d.v(TAG, "soter: using system anti brute force strategy", new Object[0]);
                AppMethodBeat.o(72906);
                return false;
            } else if (SoterBiometricAntiBruteForceStrategy.isCurrentTweenTimeAvailable(context)) {
                if (!SoterBiometricAntiBruteForceStrategy.isCurrentFailTimeAvailable(context)) {
                    d.v(TAG, "soter: unfreeze former frozen status", new Object[0]);
                    SoterBiometricAntiBruteForceStrategy.unFreeze(context);
                }
                AppMethodBeat.o(72906);
                return false;
            } else if (SoterBiometricAntiBruteForceStrategy.isCurrentFailTimeAvailable(context)) {
                d.v(TAG, "soter: failure time available", new Object[0]);
                AppMethodBeat.o(72906);
                return false;
            } else {
                informTooManyTrial(authenticationCallback);
                AppMethodBeat.o(72906);
                return true;
            }
        }

        private static void informTooManyTrial(AuthenticationCallback authenticationCallback) {
            AppMethodBeat.i(72907);
            d.w(TAG, "soter: too many fail callback. inform it.", new Object[0]);
            authenticationCallback.onAuthenticationError(10308, "Too many failed times");
            AppMethodBeat.o(72907);
        }
    }

    public static BiometricManagerCompat from(Context context, Integer num) {
        AppMethodBeat.i(72926);
        BiometricManagerCompat biometricManagerCompat = new BiometricManagerCompat(context, num);
        AppMethodBeat.o(72926);
        return biometricManagerCompat;
    }

    private BiometricManagerCompat(Context context, Integer num) {
        this.mContext = context;
        this.mBiometricType = num;
    }

    static {
        Object fingerprintManagerImpl;
        AppMethodBeat.i(72934);
        if (a.dQN()) {
            fingerprintManagerImpl = new FingerprintManagerImpl();
        } else {
            fingerprintManagerImpl = new LegacyFingerprintManagerImpl();
        }
        IMPL_PROVIDER.put(Integer.valueOf(1), fingerprintManagerImpl);
        if (a.dQN() && isNativeSupportFaceid()) {
            IMPL_PROVIDER.put(Integer.valueOf(2), new FaceidManagerImpl());
        }
        AppMethodBeat.o(72934);
    }

    public static boolean isNativeSupportFaceid() {
        AppMethodBeat.i(72927);
        try {
            Class.forName("com.tencent.soter.core.biometric.SoterFaceManagerFactory");
            AppMethodBeat.o(72927);
            return true;
        } catch (Exception e) {
            AppMethodBeat.o(72927);
            return false;
        }
    }

    public boolean hasEnrolledBiometric() {
        AppMethodBeat.i(72928);
        IBiometricManager iBiometricManager = (IBiometricManager) IMPL_PROVIDER.get(this.mBiometricType);
        if (iBiometricManager == null) {
            d.i(TAG, "soter: Biometric provider not initialized type[" + this.mBiometricType + "]", new Object[0]);
            AppMethodBeat.o(72928);
            return false;
        }
        boolean hasEnrolledBiometric = iBiometricManager.hasEnrolledBiometric(this.mContext);
        AppMethodBeat.o(72928);
        return hasEnrolledBiometric;
    }

    public String getBiometricName() {
        AppMethodBeat.i(72929);
        IBiometricManager iBiometricManager = (IBiometricManager) IMPL_PROVIDER.get(this.mBiometricType);
        if (iBiometricManager == null) {
            d.i(TAG, "soter: Biometric provider not initialized type[" + this.mBiometricType + "]", new Object[0]);
            AppMethodBeat.o(72929);
            return null;
        }
        String biometricName = iBiometricManager.getBiometricName(this.mContext);
        AppMethodBeat.o(72929);
        return biometricName;
    }

    public boolean isHardwareDetected() {
        AppMethodBeat.i(72930);
        IBiometricManager iBiometricManager = (IBiometricManager) IMPL_PROVIDER.get(this.mBiometricType);
        if (iBiometricManager == null) {
            d.i(TAG, "soter: Biometric provider not initialized type[" + this.mBiometricType + "]", new Object[0]);
            AppMethodBeat.o(72930);
            return false;
        }
        boolean isHardwareDetected = iBiometricManager.isHardwareDetected(this.mContext);
        AppMethodBeat.o(72930);
        return isHardwareDetected;
    }

    public boolean isCurrentFailTimeAvailable() {
        AppMethodBeat.i(72931);
        boolean isCurrentFailTimeAvailable = SoterBiometricAntiBruteForceStrategy.isCurrentFailTimeAvailable(this.mContext);
        AppMethodBeat.o(72931);
        return isCurrentFailTimeAvailable;
    }

    public boolean isCurrentTweenTimeAvailable(Context context) {
        AppMethodBeat.i(72932);
        boolean isCurrentTweenTimeAvailable = SoterBiometricAntiBruteForceStrategy.isCurrentTweenTimeAvailable(this.mContext);
        AppMethodBeat.o(72932);
        return isCurrentTweenTimeAvailable;
    }

    public void authenticate(CryptoObject cryptoObject, int i, CancellationSignal cancellationSignal, AuthenticationCallback authenticationCallback, Handler handler) {
        AppMethodBeat.i(72933);
        IBiometricManager iBiometricManager = (IBiometricManager) IMPL_PROVIDER.get(this.mBiometricType);
        if (iBiometricManager == null) {
            d.i(TAG, "soter: Biometric provider not initialized type[" + this.mBiometricType + "]", new Object[0]);
            authenticationCallback.onAuthenticationCancelled();
        }
        iBiometricManager.authenticate(this.mContext, cryptoObject, i, cancellationSignal, authenticationCallback, handler);
        AppMethodBeat.o(72933);
    }
}
