package com.tencent.tmassistantsdk.downloadservice;

import android.os.Looper;
import android.text.TextUtils;
import com.google.firebase.analytics.FirebaseAnalytics$b;
import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.mm.ipcinvoker.l;
import com.tencent.mm.plugin.downloader.a.c;
import com.tencent.mm.sdk.platformtools.ab;
import com.tencent.smtt.sdk.TbsMediaPlayer$TbsMediaPlayerListener;
import com.tencent.tmassistantsdk.logreport.DownloadReportManager;
import com.tencent.tmassistantsdk.protocol.jce.DownloadChunkLogInfo;
import com.tencent.tmassistantsdk.storage.TMAssistantFile;
import com.tencent.tmassistantsdk.util.GlobalUtil;
import com.tencent.tmassistantsdk.util.TMLog;
import com.tencent.ytcommon.BuildConfig;
import java.io.IOException;
import java.net.SocketTimeoutException;
import java.net.URI;
import java.net.UnknownHostException;
import java.util.Map;
import java.util.Map.Entry;
import javax.net.ssl.SSLHandshakeException;
import org.apache.http.Header;
import org.apache.http.HttpEntity;
import org.apache.http.HttpResponse;
import org.apache.http.client.HttpClient;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.conn.ConnectTimeoutException;
import org.apache.http.conn.scheme.Scheme;
import org.apache.http.conn.ssl.SSLSocketFactory;

public class DownloadTask {
    public static final String TAG = "_DownloadTask";
    protected DownloadInfo mDownloadInfo = null;
    HttpClient mHttpClient = null;
    HttpGet mHttpGet = null;
    private boolean mIsRedirect = false;
    protected final byte[] mRecvBuf = new byte[4096];
    private String mRequestUrl;
    TMAssistantFile mSaveFile;
    protected boolean mStopTask = false;
    protected final int mTaskId = GlobalUtil.getMemUUID();
    private String startDownloadNetType = "wifi";

    static /* synthetic */ void access$000(DownloadTask downloadTask) {
        AppMethodBeat.i(75756);
        downloadTask.cancelInWorkThread();
        AppMethodBeat.o(75756);
    }

    public DownloadTask(DownloadInfo downloadInfo) {
        AppMethodBeat.i(75744);
        this.mDownloadInfo = downloadInfo;
        AppMethodBeat.o(75744);
    }

    public int getTaskId() {
        return this.mTaskId;
    }

    public void cancel() {
        AppMethodBeat.i(75745);
        TMLog.i(TAG, "DownloadTask::cancel url: " + this.mDownloadInfo.mURL);
        if (Thread.currentThread().getId() == Looper.getMainLooper().getThread().getId()) {
            l.post(new 1(this));
            AppMethodBeat.o(75745);
            return;
        }
        cancelInWorkThread();
        AppMethodBeat.o(75745);
    }

    private void cancelInWorkThread() {
        AppMethodBeat.i(75746);
        this.mStopTask = true;
        if (!(this.mHttpGet == null || this.mHttpGet.isAborted())) {
            this.mHttpGet.abort();
        }
        AppMethodBeat.o(75746);
    }

    public String getDownloadURI() {
        return this.mDownloadInfo.mURL;
    }

    public int getPriority() {
        return this.mDownloadInfo.mPriority;
    }

    public void exec(String str) {
        AppMethodBeat.i(75747);
        this.startDownloadNetType = DownloadHelper.getNetStatus();
        this.mDownloadInfo.mTaskIsRunning = true;
        this.mDownloadInfo.updateStatus(2, false);
        boolean z = false;
        boolean z2 = true;
        while (z2) {
            DownloadChunkLogInfo createNewChunkLogInfo = DownloadReportManager.getInstance().createNewChunkLogInfo((byte) 0);
            createNewChunkLogInfo.UUID = this.mDownloadInfo.mUUID;
            createNewChunkLogInfo.currentRetryCnt = (byte) this.mDownloadInfo.mRetryCnt;
            createNewChunkLogInfo.requestUrl = getDownloadURI();
            if (this.mStopTask) {
                break;
            }
            StopRequestException stopRequestException;
            boolean z3;
            try {
                Object Ij;
                if (!this.mIsRedirect || this.mRequestUrl == null || this.mRequestUrl.length() == 0) {
                    if (z) {
                        Ij = c.Ij(this.mDownloadInfo.mSecondaryUrl);
                    } else {
                        Ij = c.Ij(this.mDownloadInfo.mRequestURL);
                    }
                    this.mRequestUrl = Ij;
                } else {
                    Ij = this.mRequestUrl;
                }
                TMLog.i(TAG, "is redirect request: " + this.mIsRedirect);
                TMLog.i(TAG, "changeUrl = ".concat(String.valueOf(z)));
                TMLog.i(TAG, "url = ".concat(String.valueOf(Ij)));
                this.mIsRedirect = false;
                this.mHttpClient = HttpClientUtil.createHttpClient();
                HttpClientUtil.setProxy(this.mHttpClient);
                this.mHttpGet = new HttpGet();
                URI uri = new URI(Ij);
                this.mHttpGet.setURI(uri);
                setExtraHeaderParam(this.mHttpGet, this.mDownloadInfo.getHeaderParams());
                setRangeHeader(this.mHttpGet, createNewChunkLogInfo);
                if (uri.getScheme().equals("https")) {
                    SSLSocketFactory socketFactory = SSLSocketFactory.getSocketFactory();
                    socketFactory.setHostnameVerifier(SSLSocketFactory.BROWSER_COMPATIBLE_HOSTNAME_VERIFIER);
                    this.mHttpClient.getConnectionManager().getSchemeRegistry().register(new Scheme("https", socketFactory, 443));
                }
                TMLog.i(TAG, "start httpGet " + Thread.currentThread().getName());
                HttpResponse execute = this.mHttpClient.execute(this.mHttpGet);
                if (execute == null) {
                    stopRequestException = new StopRequestException(TbsMediaPlayer$TbsMediaPlayerListener.MEDIA_INFO_BUFFERING_START, "response is null! " + Thread.currentThread().getName());
                    AppMethodBeat.o(75747);
                    throw stopRequestException;
                }
                handleResponseCode(execute, createNewChunkLogInfo);
                if (this.mDownloadInfo.hasReceivedAllDataBytes()) {
                    z3 = false;
                } else {
                    z3 = true;
                }
                if (this.mHttpGet != null) {
                    if (!this.mHttpGet.isAborted()) {
                        this.mHttpGet.abort();
                    }
                    this.mHttpGet = null;
                }
                if (this.mHttpClient != null) {
                    this.mHttpClient.getConnectionManager().shutdown();
                    this.mHttpClient = null;
                }
                if (this.mSaveFile != null) {
                    this.mSaveFile.close();
                    this.mSaveFile = null;
                    z2 = z3;
                }
                z2 = z3;
            } catch (ConnectTimeoutException e) {
                if (this.mStopTask) {
                    z3 = false;
                } else {
                    TMLog.i(TAG, "ConnectTimeoutException " + Thread.currentThread().getName());
                    ab.printErrStackTrace(TAG, e, BuildConfig.FLAVOR, new Object[0]);
                    z3 = shouldRetryConnect();
                    if (!z3) {
                        this.mDownloadInfo.mDownloadFailedErrCode = 601;
                    }
                }
                if (this.mHttpGet != null) {
                    if (!this.mHttpGet.isAborted()) {
                        this.mHttpGet.abort();
                    }
                    this.mHttpGet = null;
                }
                if (this.mHttpClient != null) {
                    this.mHttpClient.getConnectionManager().shutdown();
                    this.mHttpClient = null;
                }
                if (this.mSaveFile != null) {
                    this.mSaveFile.close();
                    this.mSaveFile = null;
                    z2 = z3;
                }
            } catch (SocketTimeoutException e2) {
                if (this.mStopTask) {
                    z3 = false;
                } else {
                    TMLog.i(TAG, "SocketTimeoutException " + Thread.currentThread().getName());
                    ab.printErrStackTrace(TAG, e2, BuildConfig.FLAVOR, new Object[0]);
                    z3 = shouldRetryConnect();
                    if (!z3) {
                        this.mDownloadInfo.mDownloadFailedErrCode = 602;
                    }
                }
                if (this.mHttpGet != null) {
                    if (!this.mHttpGet.isAborted()) {
                        this.mHttpGet.abort();
                    }
                    this.mHttpGet = null;
                }
                if (this.mHttpClient != null) {
                    this.mHttpClient.getConnectionManager().shutdown();
                    this.mHttpClient = null;
                }
                if (this.mSaveFile != null) {
                    this.mSaveFile.close();
                    this.mSaveFile = null;
                    z2 = z3;
                }
            } catch (UnknownHostException e3) {
                if (this.mStopTask) {
                    z3 = false;
                } else {
                    TMLog.i(TAG, "UnknownHostException " + Thread.currentThread().getName());
                    ab.printErrStackTrace(TAG, e3, BuildConfig.FLAVOR, new Object[0]);
                    z3 = shouldRetryConnect();
                    if (!z3) {
                        this.mDownloadInfo.mDownloadFailedErrCode = 603;
                    }
                }
                if (this.mHttpGet != null) {
                    if (!this.mHttpGet.isAborted()) {
                        this.mHttpGet.abort();
                    }
                    this.mHttpGet = null;
                }
                if (this.mHttpClient != null) {
                    this.mHttpClient.getConnectionManager().shutdown();
                    this.mHttpClient = null;
                }
                if (this.mSaveFile != null) {
                    this.mSaveFile.close();
                    this.mSaveFile = null;
                    z2 = z3;
                }
            } catch (InterruptedException e4) {
                if (!this.mStopTask) {
                    TMLog.i(TAG, "InterruptedException " + Thread.currentThread().getName());
                    ab.printErrStackTrace(TAG, e4, BuildConfig.FLAVOR, new Object[0]);
                    this.mDownloadInfo.mDownloadFailedErrCode = 600;
                }
                if (this.mHttpGet != null) {
                    if (!this.mHttpGet.isAborted()) {
                        this.mHttpGet.abort();
                    }
                    this.mHttpGet = null;
                }
                if (this.mHttpClient != null) {
                    this.mHttpClient.getConnectionManager().shutdown();
                    this.mHttpClient = null;
                }
                if (this.mSaveFile != null) {
                    this.mSaveFile.close();
                    this.mSaveFile = null;
                    z2 = false;
                }
                z2 = false;
            } catch (SSLHandshakeException e5) {
                if (!this.mStopTask) {
                    TMLog.i(TAG, "SSLHandshakeException " + Thread.currentThread().getName());
                    ab.printErrStackTrace(TAG, e5, BuildConfig.FLAVOR, new Object[0]);
                    this.mDownloadInfo.mDownloadFailedErrCode = 607;
                }
                if (this.mHttpGet != null) {
                    if (!this.mHttpGet.isAborted()) {
                        this.mHttpGet.abort();
                    }
                    this.mHttpGet = null;
                }
                if (this.mHttpClient != null) {
                    this.mHttpClient.getConnectionManager().shutdown();
                    this.mHttpClient = null;
                }
                if (this.mSaveFile != null) {
                    this.mSaveFile.close();
                    this.mSaveFile = null;
                    z2 = false;
                }
                z2 = false;
            } catch (IOException e6) {
                if (this.mStopTask) {
                    z3 = false;
                } else {
                    TMLog.i(TAG, "IOException " + Thread.currentThread().getName());
                    ab.printErrStackTrace(TAG, e6, BuildConfig.FLAVOR, new Object[0]);
                    z3 = shouldRetryConnect();
                    if (!z3) {
                        this.mDownloadInfo.mDownloadFailedErrCode = 606;
                    }
                }
                if (this.mHttpGet != null) {
                    if (!this.mHttpGet.isAborted()) {
                        this.mHttpGet.abort();
                    }
                    this.mHttpGet = null;
                }
                if (this.mHttpClient != null) {
                    this.mHttpClient.getConnectionManager().shutdown();
                    this.mHttpClient = null;
                }
                if (this.mSaveFile != null) {
                    this.mSaveFile.close();
                    this.mSaveFile = null;
                    z2 = z3;
                }
            } catch (StopRequestException stopRequestException2) {
                if (this.mStopTask) {
                    z3 = z;
                    z2 = false;
                } else {
                    TMLog.i(TAG, "StopRequestException, errCode = " + stopRequestException2.mFinalErrCode + " " + Thread.currentThread().getName());
                    ab.printErrStackTrace(TAG, stopRequestException2, BuildConfig.FLAVOR, new Object[0]);
                    this.mDownloadInfo.mDownloadFailedErrCode = stopRequestException2.mFinalErrCode;
                    if (stopRequestException2.mFinalErrCode == TbsMediaPlayer$TbsMediaPlayerListener.MEDIA_INFO_NETWORK_BANDWIDTH || stopRequestException2.mFinalErrCode == 710 || stopRequestException2.mFinalErrCode == 711) {
                        z3 = z;
                        z2 = false;
                    } else if (704 == stopRequestException2.mFinalErrCode) {
                        this.mDownloadInfo.setTotalSize(0);
                        new TMAssistantFile(this.mDownloadInfo.mTempFileName, this.mDownloadInfo.mFileName).deleteTempFile();
                        z3 = z;
                        z2 = false;
                    } else if (705 != stopRequestException2.mFinalErrCode) {
                        z2 = shouldRetryConnect();
                        z3 = z;
                    } else if (z || !this.mDownloadInfo.hasRetryChance() || TextUtils.isEmpty(this.mDownloadInfo.mSecondaryUrl)) {
                        z3 = z;
                        z2 = false;
                    } else {
                        z3 = true;
                        z2 = true;
                    }
                }
                if (this.mHttpGet != null) {
                    if (!this.mHttpGet.isAborted()) {
                        this.mHttpGet.abort();
                    }
                    this.mHttpGet = null;
                }
                if (this.mHttpClient != null) {
                    this.mHttpClient.getConnectionManager().shutdown();
                    this.mHttpClient = null;
                }
                if (this.mSaveFile != null) {
                    this.mSaveFile.close();
                    this.mSaveFile = null;
                    z = z3;
                } else {
                    z = z3;
                }
            } catch (Throwable th) {
                if (this.mHttpGet != null) {
                    if (!this.mHttpGet.isAborted()) {
                        this.mHttpGet.abort();
                    }
                    this.mHttpGet = null;
                }
                if (this.mHttpClient != null) {
                    this.mHttpClient.getConnectionManager().shutdown();
                    this.mHttpClient = null;
                }
                if (this.mSaveFile != null) {
                    this.mSaveFile.close();
                    this.mSaveFile = null;
                }
                AppMethodBeat.o(75747);
            }
        }
        TMLog.i(TAG, "mStopTask = " + this.mStopTask + " " + Thread.currentThread().getName());
        if (this.mStopTask) {
            this.mDownloadInfo.mDownloadFailedErrCode = 0;
        } else {
            TMLog.i(TAG, "download finished, " + Thread.currentThread().getName() + ",finalstatus: " + this.mDownloadInfo.mStatus + " errCode: " + this.mDownloadInfo.mDownloadFailedErrCode);
            if (this.mDownloadInfo.hasReceivedAllDataBytes()) {
                this.mDownloadInfo.updateStatus(4, z);
            } else {
                this.mDownloadInfo.updateStatus(5, z);
            }
        }
        this.mDownloadInfo.mTaskIsRunning = false;
        AppMethodBeat.o(75747);
    }

    private boolean shouldRetryConnect() {
        boolean z = false;
        AppMethodBeat.i(75748);
        if (this.mStopTask) {
            TMLog.i(TAG, "mStopTask = " + this.mStopTask);
            AppMethodBeat.o(75748);
        } else {
            try {
                Thread.sleep(5000);
            } catch (InterruptedException e) {
            }
            if (!DownloadHelper.isNetworkConncted()) {
                int i = 0;
                while (!DownloadHelper.isNetworkConncted() && i < 5) {
                    i++;
                    try {
                        Thread.sleep(10000);
                    } catch (InterruptedException e2) {
                        this.mDownloadInfo.mDownloadFailedErrCode = 600;
                    }
                }
            }
            if (!DownloadHelper.isNetworkConncted()) {
                TMLog.i(TAG, "network unconnected");
                AppMethodBeat.o(75748);
            } else if (DownloadHelper.getNetStatus().equalsIgnoreCase("wifi") || DownloadHelper.getNetStatus().equalsIgnoreCase(this.startDownloadNetType)) {
                if (this.mDownloadInfo.hasRetryChance()) {
                    DownloadInfo downloadInfo = this.mDownloadInfo;
                    downloadInfo.mRetryCnt++;
                    this.mDownloadInfo.mRedirectCnt = 0;
                    try {
                        Thread.sleep(5000);
                        z = true;
                    } catch (InterruptedException e3) {
                        this.mDownloadInfo.mDownloadFailedErrCode = 600;
                    }
                }
                TMLog.i(TAG, "shouldRetryConnect(" + z + "), retryCnt = " + this.mDownloadInfo.mRetryCnt);
                AppMethodBeat.o(75748);
            } else {
                TMLog.i(TAG, "not equal netType, current: " + DownloadHelper.getNetStatus() + ", startNetType: " + this.startDownloadNetType);
                AppMethodBeat.o(75748);
            }
        }
        return z;
    }

    private void onDownloadError(Throwable th) {
        AppMethodBeat.i(75749);
        if (th != null) {
            ab.printErrStackTrace(TAG, th, BuildConfig.FLAVOR, new Object[0]);
        }
        AppMethodBeat.o(75749);
    }

    private void handleResponseCode(HttpResponse httpResponse, DownloadChunkLogInfo downloadChunkLogInfo) {
        AppMethodBeat.i(75750);
        int statusCode = httpResponse.getStatusLine().getStatusCode();
        TMLog.i(TAG, "httpResponseCode = " + statusCode + " " + Thread.currentThread().getName());
        downloadChunkLogInfo.readHeaderTime = System.currentTimeMillis();
        downloadChunkLogInfo.responseHttpCode = statusCode;
        if (statusCode == 200 || statusCode == 206) {
            this.mDownloadInfo.mRetryCnt = 0;
        }
        StopRequestException stopRequestException;
        StopRequestException stopRequestException2;
        switch (statusCode) {
            case 200:
                Header[] headers = httpResponse.getHeaders("Content-Type");
                if (headers != null && headers.length > 0) {
                    if (this.mDownloadInfo.mContentType.equals("resource/tm.android.unknown")) {
                        this.mDownloadInfo.mFileName = DownloadHelper.renameAPKFileName(this.mDownloadInfo.mFileName);
                    } else {
                        String value = headers[0].getValue();
                        if (TextUtils.isEmpty(value) || !value.startsWith("text")) {
                            renameApkFileName(httpResponse);
                        } else {
                            stopRequestException = new StopRequestException(708, "Return contenttype = text " + Thread.currentThread().getName());
                            AppMethodBeat.o(75750);
                            throw stopRequestException;
                        }
                    }
                }
                onReceivedResponseData(httpResponse, downloadChunkLogInfo);
                AppMethodBeat.o(75750);
                return;
            case 206:
                if (this.mDownloadInfo.mContentType.equals("resource/tm.android.unknown")) {
                    this.mDownloadInfo.mFileName = DownloadHelper.renameAPKFileName(this.mDownloadInfo.mFileName);
                } else {
                    renameApkFileName(httpResponse);
                }
                onReceivedResponseData(httpResponse, downloadChunkLogInfo);
                AppMethodBeat.o(75750);
                return;
            case 301:
            case 302:
            case 303:
            case 307:
                if (this.mDownloadInfo.mRedirectCnt > 5) {
                    TMLog.i(TAG, "mRedirectCnt = " + this.mDownloadInfo.mRedirectCnt + ",MAX_REDIRESTS = 5");
                    stopRequestException = new StopRequestException(709, "Redirect cnt many times.");
                    AppMethodBeat.o(75750);
                    throw stopRequestException;
                }
                Header firstHeader = httpResponse.getFirstHeader(FirebaseAnalytics$b.LOCATION);
                if (firstHeader != null) {
                    String value2 = firstHeader.getValue();
                    TMLog.i(TAG, "jumpURL = ".concat(String.valueOf(value2)));
                    if (DownloadHelper.isValidURL(value2)) {
                        this.mRequestUrl = DownloadHelper.correctURL(value2);
                        this.mIsRedirect = true;
                        DownloadInfo downloadInfo = this.mDownloadInfo;
                        downloadInfo.mRedirectCnt++;
                        AppMethodBeat.o(75750);
                        return;
                    }
                    StopRequestException stopRequestException3 = new StopRequestException(TbsMediaPlayer$TbsMediaPlayerListener.MEDIA_INFO_VIDEO_TRACK_LAGGING, "Jump url is not valid. httpResponseCode = " + statusCode + " url: " + value2);
                    AppMethodBeat.o(75750);
                    throw stopRequestException3;
                }
                TMLog.e(TAG, "location header is null. httpResponseCode = ".concat(String.valueOf(statusCode)));
                stopRequestException2 = new StopRequestException(TbsMediaPlayer$TbsMediaPlayerListener.MEDIA_INFO_BUFFERING_END, "location header is null. httpResponseCode = ".concat(String.valueOf(statusCode)));
                AppMethodBeat.o(75750);
                throw stopRequestException2;
            case 416:
                stopRequestException2 = new StopRequestException(statusCode, "HTTP response code error, code = ".concat(String.valueOf(statusCode)));
                AppMethodBeat.o(75750);
                throw stopRequestException2;
            case 500:
                stopRequestException2 = new StopRequestException(statusCode, "HTTP response code error, code = ".concat(String.valueOf(statusCode)));
                AppMethodBeat.o(75750);
                throw stopRequestException2;
            case 503:
                stopRequestException2 = new StopRequestException(statusCode, "HTTP response code error, code = ".concat(String.valueOf(statusCode)));
                AppMethodBeat.o(75750);
                throw stopRequestException2;
            default:
                stopRequestException2 = new StopRequestException(statusCode, "HTTP response code error, code = ".concat(String.valueOf(statusCode)));
                AppMethodBeat.o(75750);
                throw stopRequestException2;
        }
    }

    private boolean verifyTotalLen(HttpResponse httpResponse, HttpEntity httpEntity) {
        AppMethodBeat.i(75751);
        long contentLength;
        if (httpResponse.getStatusLine().getStatusCode() == 200) {
            contentLength = httpEntity.getContentLength();
            TMLog.i(TAG, "verifyTotalLen,totalLen = " + contentLength + "mRequestFileSize = " + this.mDownloadInfo.mRequestFileSize);
            if (contentLength == -1 || (this.mDownloadInfo.mRequestFileSize.longValue() > 0 && contentLength != this.mDownloadInfo.mRequestFileSize.longValue())) {
                AppMethodBeat.o(75751);
                return false;
            }
        } else if (httpResponse.getStatusLine().getStatusCode() == 206) {
            contentLength = ByteRange.getTotalSize(httpResponse.getFirstHeader("content-range").getValue());
            TMLog.i(TAG, "verifyTotalLen,totalLen = " + contentLength + "mRequestFileSize = " + this.mDownloadInfo.mRequestFileSize);
            if (contentLength == -1 || (this.mDownloadInfo.mRequestFileSize.longValue() > 0 && contentLength != this.mDownloadInfo.mRequestFileSize.longValue())) {
                AppMethodBeat.o(75751);
                return false;
            }
        }
        AppMethodBeat.o(75751);
        return true;
    }

    /* JADX WARNING: Removed duplicated region for block: B:84:0x033f  */
    /* JADX WARNING: Missing block: B:70:0x02c2, code skipped:
            if (com.tencent.tmassistantsdk.downloadservice.DownloadHelper.isSpaceEnough(com.tencent.tmassistantsdk.storage.TMAssistantFile.getSavePathRootDir(), r10.mDownloadInfo.getTotalSize()) == false) goto L_0x03a8;
     */
    /* JADX WARNING: Missing block: B:72:0x02c8, code skipped:
            if (com.tencent.tmassistantsdk.storage.TMAssistantFile.isSDCardExistAndCanWrite() == false) goto L_0x0353;
     */
    /* JADX WARNING: Missing block: B:73:0x02ca, code skipped:
            r0 = "write file failed, fileName: " + r10.mDownloadInfo.mFileName + " receivedSize: " + r10.mDownloadInfo.mReceivedBytes + " readedSize: " + r3 + " totalSize: " + r10.mDownloadInfo.getTotalSize();
            com.tencent.tmassistantsdk.util.TMLog.w(TAG, r0);
            r1 = new com.tencent.tmassistantsdk.downloadservice.StopRequestException(com.tencent.smtt.sdk.TbsMediaPlayer$TbsMediaPlayerListener.MEDIA_INFO_NETWORK_BANDWIDTH, r0);
            com.tencent.matrix.trace.core.AppMethodBeat.o(75752);
     */
    /* JADX WARNING: Missing block: B:74:0x031c, code skipped:
            throw r1;
     */
    /* JADX WARNING: Missing block: B:89:?, code skipped:
            r0 = "write file failed, no sdCard! fileName: " + r10.mDownloadInfo.mFileName + " receivedSize: " + r10.mDownloadInfo.mReceivedBytes + " readedSize: " + r3 + " totalSize: " + r10.mDownloadInfo.getTotalSize();
            com.tencent.tmassistantsdk.util.TMLog.w(TAG, r0);
            r1 = new com.tencent.tmassistantsdk.downloadservice.StopRequestException(711, r0);
            com.tencent.matrix.trace.core.AppMethodBeat.o(75752);
     */
    /* JADX WARNING: Missing block: B:90:0x03a5, code skipped:
            throw r1;
     */
    /* JADX WARNING: Missing block: B:93:0x03a8, code skipped:
            r0 = "write file failed, no enough space! fileName: " + r10.mDownloadInfo.mFileName + " receivedSize: " + r10.mDownloadInfo.mReceivedBytes + " readedSize: " + r3 + " totalSize: " + r10.mDownloadInfo.getTotalSize();
            com.tencent.tmassistantsdk.util.TMLog.w(TAG, r0);
            r1 = new com.tencent.tmassistantsdk.downloadservice.StopRequestException(710, r0);
            com.tencent.matrix.trace.core.AppMethodBeat.o(75752);
     */
    /* JADX WARNING: Missing block: B:94:0x03fa, code skipped:
            throw r1;
     */
    private void onReceivedResponseData(org.apache.http.HttpResponse r11, com.tencent.tmassistantsdk.protocol.jce.DownloadChunkLogInfo r12) {
        /*
        r10 = this;
        r0 = 75752; // 0x127e8 float:1.06151E-40 double:3.74265E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r0);
        r0 = r11.getEntity();
        r1 = r10.verifyTotalLen(r11, r0);
        if (r1 != 0) goto L_0x002a;
    L_0x0010:
        r0 = "_DownloadTask";
        r1 = "verifyTotalLen false";
        com.tencent.tmassistantsdk.util.TMLog.i(r0, r1);
        r0 = new com.tencent.tmassistantsdk.downloadservice.StopRequestException;
        r1 = 705; // 0x2c1 float:9.88E-43 double:3.483E-321;
        r2 = "totalLen is not match the requestSize";
        r0.<init>(r1, r2);
        r1 = 75752; // 0x127e8 float:1.06151E-40 double:3.74265E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r1);
        throw r0;
    L_0x002a:
        r1 = r10.mDownloadInfo;
        r2 = r1.getTotalSize();
        r4 = 0;
        r1 = (r2 > r4 ? 1 : (r2 == r4 ? 0 : -1));
        if (r1 != 0) goto L_0x016d;
    L_0x0036:
        r1 = r11.getStatusLine();
        r1 = r1.getStatusCode();
        r2 = 200; // 0xc8 float:2.8E-43 double:9.9E-322;
        if (r1 != r2) goto L_0x0108;
    L_0x0042:
        r1 = r10.mDownloadInfo;
        r2 = r0.getContentLength();
        r1.setTotalSize(r2);
        r1 = "_DownloadTask";
        r2 = new java.lang.StringBuilder;
        r3 = "HTTPCode 200, totalBytes:";
        r2.<init>(r3);
        r3 = r10.mDownloadInfo;
        r4 = r3.getTotalSize();
        r2 = r2.append(r4);
        r2 = r2.toString();
        com.tencent.tmassistantsdk.util.TMLog.i(r1, r2);
    L_0x0067:
        r1 = "_DownloadTask";
        r2 = new java.lang.StringBuilder;
        r3 = "first start downloadinfoTotalSize = ";
        r2.<init>(r3);
        r3 = r10.mDownloadInfo;
        r4 = r3.getTotalSize();
        r2 = r2.append(r4);
        r2 = r2.toString();
        com.tencent.tmassistantsdk.util.TMLog.w(r1, r2);
        r1 = "content-range";
        r1 = r11.getFirstHeader(r1);
        if (r1 == 0) goto L_0x00a8;
    L_0x008c:
        r1 = r1.getValue();
        r1 = com.tencent.tmassistantsdk.downloadservice.ByteRange.parseContentRange(r1);
        r2 = r1.getStart();
        r12.responseRangePosition = r2;
        r2 = r1.getEnd();
        r4 = r1.getStart();
        r2 = r2 - r4;
        r4 = 1;
        r2 = r2 + r4;
        r12.responseRangeLength = r2;
    L_0x00a8:
        r1 = r10.mDownloadInfo;
        r2 = r1.getTotalSize();
        r12.responseContentLength = r2;
    L_0x00b0:
        r1 = r10.mSaveFile;
        if (r1 != 0) goto L_0x00c3;
    L_0x00b4:
        r1 = new com.tencent.tmassistantsdk.storage.TMAssistantFile;
        r2 = r10.mDownloadInfo;
        r2 = r2.mTempFileName;
        r3 = r10.mDownloadInfo;
        r3 = r3.mFileName;
        r1.<init>(r2, r3);
        r10.mSaveFile = r1;
    L_0x00c3:
        r2 = 0;
        r7 = r0.getContent();	 Catch:{ SocketException -> 0x0453 }
        r0 = "_DownloadTask";
        r1 = new java.lang.StringBuilder;	 Catch:{ SocketException -> 0x0453 }
        r4 = "start write file, fileName: ";
        r1.<init>(r4);	 Catch:{ SocketException -> 0x0453 }
        r4 = r10.mDownloadInfo;	 Catch:{ SocketException -> 0x0453 }
        r4 = r4.mFileName;	 Catch:{ SocketException -> 0x0453 }
        r1 = r1.append(r4);	 Catch:{ SocketException -> 0x0453 }
        r1 = r1.toString();	 Catch:{ SocketException -> 0x0453 }
        com.tencent.tmassistantsdk.util.TMLog.i(r0, r1);	 Catch:{ SocketException -> 0x0453 }
        r8 = r2;
    L_0x00e4:
        r0 = r10.mRecvBuf;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r3 = r7.read(r0);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        if (r3 <= 0) goto L_0x00f3;
    L_0x00ec:
        r0 = r10.mStopTask;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        if (r0 == 0) goto L_0x028a;
    L_0x00f0:
        r7.close();	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
    L_0x00f3:
        r0 = r10.mSaveFile;
        if (r0 == 0) goto L_0x00ff;
    L_0x00f7:
        r0 = r10.mSaveFile;
        r0.close();
        r0 = 0;
        r10.mSaveFile = r0;
    L_0x00ff:
        r12.receiveDataSize = r8;
        r0 = 75752; // 0x127e8 float:1.06151E-40 double:3.74265E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r0);
        return;
    L_0x0108:
        r1 = r11.getStatusLine();
        r1 = r1.getStatusCode();
        r2 = 206; // 0xce float:2.89E-43 double:1.02E-321;
        if (r1 != r2) goto L_0x0146;
    L_0x0114:
        r1 = "content-range";
        r1 = r11.getFirstHeader(r1);
        r2 = r10.mDownloadInfo;
        r1 = r1.getValue();
        r4 = com.tencent.tmassistantsdk.downloadservice.ByteRange.getTotalSize(r1);
        r2.setTotalSize(r4);
        r1 = "_DownloadTask";
        r2 = new java.lang.StringBuilder;
        r3 = "HTTPCode 206, totalBytes:";
        r2.<init>(r3);
        r3 = r10.mDownloadInfo;
        r4 = r3.getTotalSize();
        r2 = r2.append(r4);
        r2 = r2.toString();
        com.tencent.tmassistantsdk.util.TMLog.i(r1, r2);
        goto L_0x0067;
    L_0x0146:
        r1 = "_DownloadTask";
        r2 = new java.lang.StringBuilder;
        r3 = "statusCode=";
        r2.<init>(r3);
        r3 = r11.getStatusLine();
        r3 = r3.getStatusCode();
        r2 = r2.append(r3);
        r3 = " onReceivedResponseData error.";
        r2 = r2.append(r3);
        r2 = r2.toString();
        com.tencent.tmassistantsdk.util.TMLog.w(r1, r2);
        goto L_0x0067;
    L_0x016d:
        r1 = r11.getStatusLine();
        r1 = r1.getStatusCode();
        r2 = 206; // 0xce float:2.89E-43 double:1.02E-321;
        if (r1 != r2) goto L_0x00b0;
    L_0x0179:
        r1 = "content-range";
        r1 = r11.getFirstHeader(r1);	 Catch:{ Throwable -> 0x022d }
        r2 = r1.getValue();	 Catch:{ Throwable -> 0x022d }
        r2 = com.tencent.tmassistantsdk.downloadservice.ByteRange.parseContentRange(r2);	 Catch:{ Throwable -> 0x022d }
        r3 = r1.getValue();	 Catch:{ Throwable -> 0x022d }
        r4 = com.tencent.tmassistantsdk.downloadservice.ByteRange.getTotalSize(r3);	 Catch:{ Throwable -> 0x022d }
        r6 = r2.getStart();	 Catch:{ Throwable -> 0x022d }
        r12.responseRangePosition = r6;	 Catch:{ Throwable -> 0x022d }
        r6 = r2.getEnd();	 Catch:{ Throwable -> 0x022d }
        r8 = r2.getStart();	 Catch:{ Throwable -> 0x022d }
        r6 = r6 - r8;
        r8 = 1;
        r6 = r6 + r8;
        r12.responseRangeLength = r6;	 Catch:{ Throwable -> 0x022d }
        r12.responseContentLength = r4;	 Catch:{ Throwable -> 0x022d }
        r3 = "_DownloadTask";
        r6 = new java.lang.StringBuilder;	 Catch:{ Throwable -> 0x022d }
        r7 = "totalSize = ";
        r6.<init>(r7);	 Catch:{ Throwable -> 0x022d }
        r6 = r6.append(r4);	 Catch:{ Throwable -> 0x022d }
        r7 = "  downloadinfoTotalSize = ";
        r6 = r6.append(r7);	 Catch:{ Throwable -> 0x022d }
        r7 = r10.mDownloadInfo;	 Catch:{ Throwable -> 0x022d }
        r8 = r7.getTotalSize();	 Catch:{ Throwable -> 0x022d }
        r6 = r6.append(r8);	 Catch:{ Throwable -> 0x022d }
        r6 = r6.toString();	 Catch:{ Throwable -> 0x022d }
        com.tencent.tmassistantsdk.util.TMLog.w(r3, r6);	 Catch:{ Throwable -> 0x022d }
        r3 = "_DownloadTask";
        r6 = new java.lang.StringBuilder;	 Catch:{ Throwable -> 0x022d }
        r7 = "mReceivedBytes = ";
        r6.<init>(r7);	 Catch:{ Throwable -> 0x022d }
        r7 = r10.mDownloadInfo;	 Catch:{ Throwable -> 0x022d }
        r8 = r7.mReceivedBytes;	 Catch:{ Throwable -> 0x022d }
        r6 = r6.append(r8);	 Catch:{ Throwable -> 0x022d }
        r6 = r6.toString();	 Catch:{ Throwable -> 0x022d }
        com.tencent.tmassistantsdk.util.TMLog.i(r3, r6);	 Catch:{ Throwable -> 0x022d }
        r3 = "_DownloadTask";
        r6 = new java.lang.StringBuilder;	 Catch:{ Throwable -> 0x022d }
        r7 = "start = ";
        r6.<init>(r7);	 Catch:{ Throwable -> 0x022d }
        r8 = r2.getStart();	 Catch:{ Throwable -> 0x022d }
        r6 = r6.append(r8);	 Catch:{ Throwable -> 0x022d }
        r7 = ", end = ";
        r6 = r6.append(r7);	 Catch:{ Throwable -> 0x022d }
        r8 = r2.getEnd();	 Catch:{ Throwable -> 0x022d }
        r6 = r6.append(r8);	 Catch:{ Throwable -> 0x022d }
        r6 = r6.toString();	 Catch:{ Throwable -> 0x022d }
        com.tencent.tmassistantsdk.util.TMLog.i(r3, r6);	 Catch:{ Throwable -> 0x022d }
        r2 = r2.getStart();	 Catch:{ Throwable -> 0x022d }
        r6 = r10.mDownloadInfo;	 Catch:{ Throwable -> 0x022d }
        r6 = r6.mReceivedBytes;	 Catch:{ Throwable -> 0x022d }
        r2 = (r2 > r6 ? 1 : (r2 == r6 ? 0 : -1));
        if (r2 == 0) goto L_0x0250;
    L_0x021c:
        r0 = new com.tencent.tmassistantsdk.downloadservice.StopRequestException;	 Catch:{ Throwable -> 0x022d }
        r1 = 706; // 0x2c2 float:9.9E-43 double:3.49E-321;
        r2 = "The received size is not equal with ByteRange.";
        r0.<init>(r1, r2);	 Catch:{ Throwable -> 0x022d }
        r1 = 75752; // 0x127e8 float:1.06151E-40 double:3.74265E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r1);	 Catch:{ Throwable -> 0x022d }
        throw r0;	 Catch:{ Throwable -> 0x022d }
    L_0x022d:
        r0 = move-exception;
        r1 = new com.tencent.tmassistantsdk.downloadservice.StopRequestException;	 Catch:{ all -> 0x023c }
        r2 = 704; // 0x2c0 float:9.87E-43 double:3.48E-321;
        r1.<init>(r2, r0);	 Catch:{ all -> 0x023c }
        r0 = 75752; // 0x127e8 float:1.06151E-40 double:3.74265E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r0);	 Catch:{ all -> 0x023c }
        throw r1;	 Catch:{ all -> 0x023c }
    L_0x023c:
        r0 = move-exception;
        r1 = r10.mSaveFile;
        if (r1 == 0) goto L_0x0249;
    L_0x0241:
        r1 = r10.mSaveFile;
        r1.close();
        r1 = 0;
        r10.mSaveFile = r1;
    L_0x0249:
        r1 = 75752; // 0x127e8 float:1.06151E-40 double:3.74265E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r1);
        throw r0;
    L_0x0250:
        r2 = r10.mDownloadInfo;	 Catch:{ Throwable -> 0x022d }
        r2 = r2.getTotalSize();	 Catch:{ Throwable -> 0x022d }
        r2 = (r4 > r2 ? 1 : (r4 == r2 ? 0 : -1));
        if (r2 == 0) goto L_0x026b;
    L_0x025a:
        r0 = new com.tencent.tmassistantsdk.downloadservice.StopRequestException;	 Catch:{ Throwable -> 0x022d }
        r1 = 705; // 0x2c1 float:9.88E-43 double:3.483E-321;
        r2 = "The total size is not equal with ByteRange.";
        r0.<init>(r1, r2);	 Catch:{ Throwable -> 0x022d }
        r1 = 75752; // 0x127e8 float:1.06151E-40 double:3.74265E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r1);	 Catch:{ Throwable -> 0x022d }
        throw r0;	 Catch:{ Throwable -> 0x022d }
    L_0x026b:
        r2 = "_DownloadTask";
        r3 = "response ByteRange: ";
        r1 = java.lang.String.valueOf(r1);	 Catch:{ Throwable -> 0x022d }
        r1 = r3.concat(r1);	 Catch:{ Throwable -> 0x022d }
        com.tencent.tmassistantsdk.util.TMLog.d(r2, r1);	 Catch:{ Throwable -> 0x022d }
        r1 = r10.mSaveFile;
        if (r1 == 0) goto L_0x00b0;
    L_0x0280:
        r1 = r10.mSaveFile;
        r1.close();
        r1 = 0;
        r10.mSaveFile = r1;
        goto L_0x00b0;
    L_0x028a:
        r0 = r10.mDownloadInfo;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r0 = r0.mReceivedBytes;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r4 = (long) r3;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r0 = r0 + r4;
        r2 = r10.mDownloadInfo;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r4 = r2.getTotalSize();	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r2 = (r0 > r4 ? 1 : (r0 == r4 ? 0 : -1));
        if (r2 > 0) goto L_0x0405;
    L_0x029a:
        r2 = r10.mDownloadInfo;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r4 = r2.getTotalSize();	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r0 = (r0 > r4 ? 1 : (r0 == r4 ? 0 : -1));
        if (r0 != 0) goto L_0x0350;
    L_0x02a4:
        r6 = 1;
    L_0x02a5:
        r0 = r10.mSaveFile;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = r10.mRecvBuf;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r2 = 0;
        r4 = r10.mDownloadInfo;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r4 = r4.mReceivedBytes;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r0 = r0.write(r1, r2, r3, r4, r6);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        if (r0 != 0) goto L_0x03fb;
    L_0x02b4:
        r0 = com.tencent.tmassistantsdk.storage.TMAssistantFile.getSavePathRootDir();	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = r10.mDownloadInfo;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r4 = r1.getTotalSize();	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r0 = com.tencent.tmassistantsdk.downloadservice.DownloadHelper.isSpaceEnough(r0, r4);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        if (r0 == 0) goto L_0x03a8;
    L_0x02c4:
        r0 = com.tencent.tmassistantsdk.storage.TMAssistantFile.isSDCardExistAndCanWrite();	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        if (r0 == 0) goto L_0x0353;
    L_0x02ca:
        r0 = new java.lang.StringBuilder;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = "write file failed, fileName: ";
        r0.<init>(r1);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = r10.mDownloadInfo;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = r1.mFileName;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r0 = r0.append(r1);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = " receivedSize: ";
        r0 = r0.append(r1);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = r10.mDownloadInfo;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r4 = r1.mReceivedBytes;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r0 = r0.append(r4);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = " readedSize: ";
        r0 = r0.append(r1);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r0 = r0.append(r3);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = " totalSize: ";
        r0 = r0.append(r1);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = r10.mDownloadInfo;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r2 = r1.getTotalSize();	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r0 = r0.append(r2);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r0 = r0.toString();	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = "_DownloadTask";
        com.tencent.tmassistantsdk.util.TMLog.w(r1, r0);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = new com.tencent.tmassistantsdk.downloadservice.StopRequestException;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r2 = 703; // 0x2bf float:9.85E-43 double:3.473E-321;
        r1.<init>(r2, r0);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r0 = 75752; // 0x127e8 float:1.06151E-40 double:3.74265E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r0);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        throw r1;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
    L_0x031d:
        r0 = move-exception;
        r2 = r8;
    L_0x031f:
        r1 = "_DownloadTask";
        r4 = "";
        r5 = 0;
        r5 = new java.lang.Object[r5];	 Catch:{ all -> 0x0339 }
        com.tencent.mm.sdk.platformtools.ab.printErrStackTrace(r1, r0, r4, r5);	 Catch:{ all -> 0x0339 }
        r1 = new com.tencent.tmassistantsdk.downloadservice.StopRequestException;	 Catch:{ all -> 0x0339 }
        r4 = 605; // 0x25d float:8.48E-43 double:2.99E-321;
        r1.<init>(r4, r0);	 Catch:{ all -> 0x0339 }
        r0 = 75752; // 0x127e8 float:1.06151E-40 double:3.74265E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r0);	 Catch:{ all -> 0x0339 }
        throw r1;	 Catch:{ all -> 0x0339 }
    L_0x0339:
        r0 = move-exception;
        r8 = r2;
    L_0x033b:
        r1 = r10.mSaveFile;
        if (r1 == 0) goto L_0x0347;
    L_0x033f:
        r1 = r10.mSaveFile;
        r1.close();
        r1 = 0;
        r10.mSaveFile = r1;
    L_0x0347:
        r12.receiveDataSize = r8;
        r1 = 75752; // 0x127e8 float:1.06151E-40 double:3.74265E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r1);
        throw r0;
    L_0x0350:
        r6 = 0;
        goto L_0x02a5;
    L_0x0353:
        r0 = new java.lang.StringBuilder;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = "write file failed, no sdCard! fileName: ";
        r0.<init>(r1);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = r10.mDownloadInfo;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = r1.mFileName;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r0 = r0.append(r1);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = " receivedSize: ";
        r0 = r0.append(r1);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = r10.mDownloadInfo;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r4 = r1.mReceivedBytes;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r0 = r0.append(r4);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = " readedSize: ";
        r0 = r0.append(r1);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r0 = r0.append(r3);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = " totalSize: ";
        r0 = r0.append(r1);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = r10.mDownloadInfo;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r2 = r1.getTotalSize();	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r0 = r0.append(r2);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r0 = r0.toString();	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = "_DownloadTask";
        com.tencent.tmassistantsdk.util.TMLog.w(r1, r0);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = new com.tencent.tmassistantsdk.downloadservice.StopRequestException;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r2 = 711; // 0x2c7 float:9.96E-43 double:3.513E-321;
        r1.<init>(r2, r0);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r0 = 75752; // 0x127e8 float:1.06151E-40 double:3.74265E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r0);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        throw r1;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
    L_0x03a6:
        r0 = move-exception;
        goto L_0x033b;
    L_0x03a8:
        r0 = new java.lang.StringBuilder;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = "write file failed, no enough space! fileName: ";
        r0.<init>(r1);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = r10.mDownloadInfo;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = r1.mFileName;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r0 = r0.append(r1);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = " receivedSize: ";
        r0 = r0.append(r1);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = r10.mDownloadInfo;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r4 = r1.mReceivedBytes;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r0 = r0.append(r4);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = " readedSize: ";
        r0 = r0.append(r1);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r0 = r0.append(r3);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = " totalSize: ";
        r0 = r0.append(r1);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = r10.mDownloadInfo;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r2 = r1.getTotalSize();	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r0 = r0.append(r2);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r0 = r0.toString();	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = "_DownloadTask";
        com.tencent.tmassistantsdk.util.TMLog.w(r1, r0);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = new com.tencent.tmassistantsdk.downloadservice.StopRequestException;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r2 = 710; // 0x2c6 float:9.95E-43 double:3.51E-321;
        r1.<init>(r2, r0);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r0 = 75752; // 0x127e8 float:1.06151E-40 double:3.74265E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r0);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        throw r1;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
    L_0x03fb:
        r0 = r10.mDownloadInfo;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r4 = (long) r3;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r0.updateReceivedSize(r4);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r0 = (long) r3;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r8 = r8 + r0;
        goto L_0x00e4;
    L_0x0405:
        r0 = "write file size too long.";
        r1 = "_DownloadTask";
        r2 = new java.lang.StringBuilder;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r4 = "write file size too long.\r\nreadedLen: ";
        r2.<init>(r4);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r2 = r2.append(r3);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r3 = "\r\nreceivedSize: ";
        r2 = r2.append(r3);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r3 = r10.mDownloadInfo;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r4 = r3.mReceivedBytes;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r2 = r2.append(r4);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r3 = "\r\ntotalSize: ";
        r2 = r2.append(r3);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r3 = r10.mDownloadInfo;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r4 = r3.getTotalSize();	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r2 = r2.append(r4);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r3 = "\r\nisTheEndData: false";
        r2 = r2.append(r3);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r2 = r2.toString();	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        com.tencent.tmassistantsdk.util.TMLog.w(r1, r2);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r1 = new com.tencent.tmassistantsdk.downloadservice.StopRequestException;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r2 = 703; // 0x2bf float:9.85E-43 double:3.473E-321;
        r1.<init>(r2, r0);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        r0 = 75752; // 0x127e8 float:1.06151E-40 double:3.74265E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r0);	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
        throw r1;	 Catch:{ SocketException -> 0x031d, all -> 0x03a6 }
    L_0x0453:
        r0 = move-exception;
        goto L_0x031f;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.tmassistantsdk.downloadservice.DownloadTask.onReceivedResponseData(org.apache.http.HttpResponse, com.tencent.tmassistantsdk.protocol.jce.DownloadChunkLogInfo):void");
    }

    private void setRangeHeader(HttpGet httpGet, DownloadChunkLogInfo downloadChunkLogInfo) {
        AppMethodBeat.i(75753);
        String netStatus = DownloadHelper.getNetStatus();
        this.mDownloadInfo.mNetType = netStatus;
        if (TextUtils.isEmpty(netStatus) || (!netStatus.contains("wap") && (!netStatus.contains("net") || this.mDownloadInfo.mRetryCnt <= 0))) {
            netStatus = "bytes=" + this.mDownloadInfo.mReceivedBytes + "-";
            httpGet.addHeader("range", netStatus);
            TMLog.d(TAG, "set range header: ".concat(String.valueOf(netStatus)));
            downloadChunkLogInfo.responseContentLength = this.mDownloadInfo.getTotalSize();
            downloadChunkLogInfo.requestRanagePosition = this.mDownloadInfo.mReceivedBytes;
            downloadChunkLogInfo.requestRanageSize = 0;
            AppMethodBeat.o(75753);
            return;
        }
        try {
            long j;
            int splitSizeInBytes = DownloadSetting.getSplitSizeInBytes(netStatus);
            long j2 = this.mDownloadInfo.mReceivedBytes;
            if (this.mDownloadInfo.getTotalSize() > 0) {
                j = (this.mDownloadInfo.mReceivedBytes + ((long) splitSizeInBytes)) - 1;
                if (j >= this.mDownloadInfo.getTotalSize()) {
                    j = this.mDownloadInfo.getTotalSize() - 1;
                }
            } else {
                j = (long) (splitSizeInBytes - 1);
            }
            netStatus = "bytes=" + j2 + "-" + j;
            httpGet.addHeader("range", netStatus);
            TMLog.d(TAG, "set range header: ".concat(String.valueOf(netStatus)));
            downloadChunkLogInfo.responseContentLength = this.mDownloadInfo.getTotalSize();
            downloadChunkLogInfo.requestRanagePosition = j2;
            downloadChunkLogInfo.requestRanageSize = (long) splitSizeInBytes;
            AppMethodBeat.o(75753);
        } catch (UnsupportedOperationException e) {
            ab.printErrStackTrace(TAG, e, BuildConfig.FLAVOR, new Object[0]);
            AppMethodBeat.o(75753);
        }
    }

    private void renameApkFileName(HttpResponse httpResponse) {
        AppMethodBeat.i(75754);
        if (httpResponse == null) {
            AppMethodBeat.o(75754);
            return;
        }
        if (this.mDownloadInfo.mContentType.equals("application/vnd.android.package-archive")) {
            CharSequence charSequence = null;
            Header[] headers = httpResponse.getHeaders("Content-Disposition");
            if (headers == null || headers.length <= 0) {
                charSequence = DownloadHelper.genAPKFileName(this.mDownloadInfo.mRequestURL);
            } else {
                String value = headers[0].getValue();
                TMLog.i(TAG, "headerFileName = ".concat(String.valueOf(value)));
                if (TextUtils.isEmpty(value) || !value.contains("filename=\"")) {
                    charSequence = DownloadHelper.genAPKFileName(this.mDownloadInfo.mRequestURL);
                } else {
                    value = value.substring(value.indexOf("filename=\"") + 10);
                    if (!TextUtils.isEmpty(value)) {
                        charSequence = value.substring(0, value.indexOf("\""));
                        TMLog.i(TAG, "header file Name =".concat(String.valueOf(charSequence)));
                    }
                }
            }
            if (!TextUtils.isEmpty(charSequence)) {
                this.mDownloadInfo.mFileName = DownloadHelper.correctFileName(DownloadHelper.decodeFileName(charSequence));
            }
        }
        AppMethodBeat.o(75754);
    }

    private void setExtraHeaderParam(HttpGet httpGet, Map<String, String> map) {
        AppMethodBeat.i(75755);
        if (!(httpGet == null || map == null || map.size() <= 0)) {
            for (Entry entry : map.entrySet()) {
                httpGet.addHeader((String) entry.getKey(), (String) entry.getValue());
            }
        }
        AppMethodBeat.o(75755);
    }
}
