package com.tencent.tmassistantsdk.openSDK;

import android.app.Application;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.content.pm.PackageManager.NameNotFoundException;
import android.net.Uri;
import android.text.TextUtils;
import com.google.android.gms.common.internal.ImagesContract;
import com.google.android.gms.common.util.CrashUtils.ErrorDialogData;
import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.mm.sdk.platformtools.ab;
import com.tencent.tmassistantsdk.channel.TMAssistantSDKChannel;
import com.tencent.tmassistantsdk.channel.TMAssistantSDKChannelDataItem;
import com.tencent.tmassistantsdk.downloadservice.NetworkMonitorReceiver;
import com.tencent.tmassistantsdk.logreport.DownloadReportManager;
import com.tencent.tmassistantsdk.logreport.GetSettingEngine;
import com.tencent.tmassistantsdk.logreport.LogReportManager;
import com.tencent.tmassistantsdk.openSDK.QQDownloader.AssistantStore.DownloadInfos;
import com.tencent.tmassistantsdk.protocol.jce.DownloadChunkLogInfo;
import com.tencent.tmassistantsdk.util.GlobalUtil;
import com.tencent.tmassistantsdk.util.TMLog;
import com.tencent.ytcommon.BuildConfig;
import java.io.File;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.Map.Entry;
import java.util.UUID;
import java.util.concurrent.ConcurrentHashMap;

public class TMQQDownloaderOpenSDK extends BaseQQDownloaderOpenSDK implements IDownloadStateChangedListener {
    public static final String AUTHORITY = "com.tencent.android.qqdownloader.provider";
    public static final Uri CONTENT_URI = DownloadInfos.CONTENT_URI;
    protected static final String TAG = "QQDownloaderOpenSDK";
    protected static TMQQDownloaderOpenSDK mInstance = null;
    Map<String, TMQQDownloaderOpenSDKParam> mDownloadParams;
    protected int sdkAPILevel;

    private TMQQDownloaderOpenSDK() {
        AppMethodBeat.i(75856);
        this.sdkAPILevel = 1;
        this.mDownloadParams = null;
        this.mDownloadParams = new ConcurrentHashMap();
        AppMethodBeat.o(75856);
    }

    public static synchronized TMQQDownloaderOpenSDK getInstance() {
        TMQQDownloaderOpenSDK tMQQDownloaderOpenSDK;
        synchronized (TMQQDownloaderOpenSDK.class) {
            AppMethodBeat.i(75857);
            if (mInstance == null) {
                mInstance = new TMQQDownloaderOpenSDK();
            }
            tMQQDownloaderOpenSDK = mInstance;
            AppMethodBeat.o(75857);
        }
        return tMQQDownloaderOpenSDK;
    }

    public void destroyQQDownloaderOpenSDK() {
        AppMethodBeat.i(75858);
        NetworkMonitorReceiver.getInstance().unregisterReceiver();
        GetSettingEngine.getInstance().cancleRequest();
        LogReportManager.getInstance().cancleReport();
        LogReportManager.getInstance().destory();
        if (this.mContext != null) {
            DownloadStateChangedReceiver.getInstance().unRegisteReceiver(this.mContext);
            DownloadStateChangedReceiver.getInstance().removeDownloadStateChangedListener(this);
        }
        GlobalUtil.getInstance().destroy();
        this.mContext = null;
        AppMethodBeat.o(75858);
    }

    public static boolean isExistActoin(long j) {
        AppMethodBeat.i(75859);
        if (j < 0) {
            AppMethodBeat.o(75859);
            return false;
        }
        ArrayList channelDataItemList = new TMAssistantSDKChannel().getChannelDataItemList();
        if (channelDataItemList != null && channelDataItemList.size() > 0) {
            Iterator it = channelDataItemList.iterator();
            while (it.hasNext()) {
                TMAssistantSDKChannelDataItem tMAssistantSDKChannelDataItem = (TMAssistantSDKChannelDataItem) it.next();
                if (((long) tMAssistantSDKChannelDataItem.mDBIdentity) == j && tMAssistantSDKChannelDataItem.mDataItemEndTime - tMAssistantSDKChannelDataItem.mDataItemStartTime <= 300000) {
                    AppMethodBeat.o(75859);
                    return true;
                }
            }
        }
        AppMethodBeat.o(75859);
        return false;
    }

    public int checkQQDownloaderInstalled(int i) {
        AppMethodBeat.i(75860);
        if (this.mContext == null) {
            Exception exception = new Exception("you must initial openSDK,by calling initQQDownloaderOpenSDK method!");
            AppMethodBeat.o(75860);
            throw exception;
        }
        String str = "com.tencent.android.qqdownloader";
        PackageManager packageManager = this.mContext.getPackageManager();
        if (packageManager != null) {
            try {
                if (packageManager.getPackageInfo(str, 0) != null) {
                    int qQDownloaderVersionCode = GlobalUtil.getInstance().getQQDownloaderVersionCode();
                    if (this.sdkAPILevel > GlobalUtil.getInstance().getQQDownloaderAPILevel()) {
                        AppMethodBeat.o(75860);
                        return 2;
                    } else if (i > qQDownloaderVersionCode) {
                        AppMethodBeat.o(75860);
                        return 2;
                    } else {
                        AppMethodBeat.o(75860);
                        return 0;
                    }
                }
                AppMethodBeat.o(75860);
                return 1;
            } catch (NameNotFoundException e) {
                ab.printErrStackTrace(TAG, e, BuildConfig.FLAVOR, new Object[0]);
            }
        }
        AppMethodBeat.o(75860);
        return 1;
    }

    public void startQQDownloader(Context context) {
        AppMethodBeat.i(75861);
        if (context != null) {
            Intent launchIntentForPackage = context.getPackageManager().getLaunchIntentForPackage("com.tencent.android.qqdownloader");
            if (context instanceof Application) {
                launchIntentForPackage.addFlags(ErrorDialogData.BINDER_CRASH);
            }
            context.startActivity(launchIntentForPackage);
        }
        AppMethodBeat.o(75861);
    }

    public void startToDownloadTaskList(Context context, TMQQDownloaderOpenSDKParam tMQQDownloaderOpenSDKParam, boolean z, boolean z2) {
        AppMethodBeat.i(75862);
        if (context == null) {
            Exception exception = new Exception("you must input an application or activity context!");
            AppMethodBeat.o(75862);
            throw exception;
        } else if (tMQQDownloaderOpenSDKParam == null) {
            AppMethodBeat.o(75862);
        } else {
            String uuid = UUID.randomUUID().toString();
            if (this.mDownloadParams != null) {
                this.mDownloadParams.put(uuid, tMQQDownloaderOpenSDKParam);
            }
            if (z) {
                DownloadChunkLogInfo createNewChunkLogInfo = DownloadReportManager.getInstance().createNewChunkLogInfo((byte) 1);
                createNewChunkLogInfo.UUID = uuid;
                createNewChunkLogInfo.requestUrl = BuildConfig.FLAVOR;
                createNewChunkLogInfo.via = tMQQDownloaderOpenSDKParam.via;
                createNewChunkLogInfo.appId = tMQQDownloaderOpenSDKParam.taskAppId;
                DownloadReportManager.getInstance().addLogData(createNewChunkLogInfo);
            }
            Map formatMapParams = super.formatMapParams(tMQQDownloaderOpenSDKParam, z, z2);
            formatMapParams.put("taskid", uuid);
            Intent intent = new Intent("android.intent.action.VIEW", Uri.parse(super.formatIntentUriPath(1, formatMapParams)));
            if (context instanceof Application) {
                intent.addFlags(ErrorDialogData.BINDER_CRASH);
            }
            context.startActivity(intent);
            AppMethodBeat.o(75862);
        }
    }

    public long addDownloadTaskFromTaskList(TMQQDownloaderOpenSDKParam tMQQDownloaderOpenSDKParam, boolean z, boolean z2) {
        AppMethodBeat.i(75863);
        if (!(this.mDownloadParams == null || tMQQDownloaderOpenSDKParam == null)) {
            this.mDownloadParams.put(UUID.randomUUID().toString(), tMQQDownloaderOpenSDKParam);
        }
        long buildAddDBData = super.buildAddDBData(tMQQDownloaderOpenSDKParam, z, z2, tMQQDownloaderOpenSDKParam.actionFlag, null, 1);
        AppMethodBeat.o(75863);
        return buildAddDBData;
    }

    public void startToAppDetail(Context context, TMQQDownloaderOpenSDKParam tMQQDownloaderOpenSDKParam, boolean z, boolean z2) {
        AppMethodBeat.i(75864);
        if (context == null) {
            Exception exception = new Exception("you must input an application or activity context!");
            AppMethodBeat.o(75864);
            throw exception;
        }
        String uuid = UUID.randomUUID().toString();
        if (this.mDownloadParams != null) {
            this.mDownloadParams.put(uuid, tMQQDownloaderOpenSDKParam);
        }
        if (z) {
            DownloadChunkLogInfo createNewChunkLogInfo = DownloadReportManager.getInstance().createNewChunkLogInfo((byte) 1);
            createNewChunkLogInfo.via = tMQQDownloaderOpenSDKParam.via;
            createNewChunkLogInfo.UUID = uuid;
            createNewChunkLogInfo.appId = tMQQDownloaderOpenSDKParam.taskAppId;
            createNewChunkLogInfo.resultState = 1;
            DownloadReportManager.getInstance().addLogData(createNewChunkLogInfo);
        }
        Map formatMapParams = super.formatMapParams(tMQQDownloaderOpenSDKParam, z, z2);
        formatMapParams.put("taskid", uuid);
        Intent intent = new Intent("android.intent.action.VIEW", Uri.parse(super.formatIntentUriPath(2, formatMapParams)));
        if (context instanceof Application) {
            intent.addFlags(ErrorDialogData.BINDER_CRASH);
        }
        context.startActivity(intent);
        AppMethodBeat.o(75864);
    }

    public long addDownloadTaskFromAppDetail(TMQQDownloaderOpenSDKParam tMQQDownloaderOpenSDKParam, boolean z, boolean z2) {
        AppMethodBeat.i(75865);
        if (!(this.mDownloadParams == null || tMQQDownloaderOpenSDKParam == null)) {
            this.mDownloadParams.put(UUID.randomUUID().toString(), tMQQDownloaderOpenSDKParam);
        }
        long buildAddDBData = super.buildAddDBData(tMQQDownloaderOpenSDKParam, z, z2, tMQQDownloaderOpenSDKParam.actionFlag, null, 2);
        AppMethodBeat.o(75865);
        return buildAddDBData;
    }

    public void startToAuthorized(Context context, TMQQDownloaderOpenSDKParam tMQQDownloaderOpenSDKParam, String str) {
        AppMethodBeat.i(75866);
        Exception exception;
        if (context == null) {
            exception = new Exception("you must input an application or activity context!");
            AppMethodBeat.o(75866);
            throw exception;
        } else if (tMQQDownloaderOpenSDKParam == null) {
            exception = new Exception("QQDownloaderParam param cann't be null!");
            AppMethodBeat.o(75866);
            throw exception;
        } else {
            String uuid = UUID.randomUUID().toString();
            if (this.mDownloadParams != null) {
                this.mDownloadParams.put(uuid, tMQQDownloaderOpenSDKParam);
            }
            DownloadChunkLogInfo createNewChunkLogInfo = DownloadReportManager.getInstance().createNewChunkLogInfo((byte) 1);
            createNewChunkLogInfo.via = tMQQDownloaderOpenSDKParam.via;
            createNewChunkLogInfo.UUID = uuid;
            createNewChunkLogInfo.appId = tMQQDownloaderOpenSDKParam.taskAppId;
            createNewChunkLogInfo.resultState = 1;
            DownloadReportManager.getInstance().addLogData(createNewChunkLogInfo);
            Map formatMapParams = super.formatMapParams(tMQQDownloaderOpenSDKParam, true, true);
            formatMapParams.put("verifytype", str);
            formatMapParams.put("taskid", uuid);
            Intent intent = new Intent("android.intent.action.VIEW", Uri.parse(super.formatIntentUriPath(3, formatMapParams)));
            if (context instanceof Application) {
                intent.addFlags(ErrorDialogData.BINDER_CRASH);
            }
            context.startActivity(intent);
            AppMethodBeat.o(75866);
        }
    }

    public void startToAuthorized(Context context, String str) {
        AppMethodBeat.i(75867);
        Intent intent = new Intent("android.intent.action.VIEW", Uri.parse(formatEncryptUrl(str)));
        if (context instanceof Application) {
            intent.addFlags(ErrorDialogData.BINDER_CRASH);
        }
        context.startActivity(intent);
        AppMethodBeat.o(75867);
    }

    public long addDownloadTaskFromAuthorize(TMQQDownloaderOpenSDKParam tMQQDownloaderOpenSDKParam, String str) {
        AppMethodBeat.i(75868);
        if (!(this.mDownloadParams == null || tMQQDownloaderOpenSDKParam == null)) {
            this.mDownloadParams.put(UUID.randomUUID().toString(), tMQQDownloaderOpenSDKParam);
        }
        long buildAddDBData = super.buildAddDBData(tMQQDownloaderOpenSDKParam, true, true, tMQQDownloaderOpenSDKParam.actionFlag, str, 3);
        AppMethodBeat.o(75868);
        return buildAddDBData;
    }

    public long addDownloadTaskFromAuthorize(String str) {
        AppMethodBeat.i(75869);
        String formatEncryptUrl = super.formatEncryptUrl(str);
        long currentTimeMillis = System.currentTimeMillis();
        long AddDataItem = this.sdkChannel.AddDataItem(this.hostPackageName, this.hostVersionCode, BuildConfig.FLAVOR, 0, formatEncryptUrl, currentTimeMillis, currentTimeMillis + 300000, 0, null);
        AppMethodBeat.o(75869);
        return AddDataItem;
    }

    /* JADX WARNING: Removed duplicated region for block: B:58:0x020a  */
    /* JADX WARNING: Removed duplicated region for block: B:58:0x020a  */
    /* JADX WARNING: Removed duplicated region for block: B:54:0x0202  */
    /* JADX WARNING: Removed duplicated region for block: B:61:0x0214 A:{Splitter:B:22:0x013a, ExcHandler: all (th java.lang.Throwable)} */
    /* JADX WARNING: Missing block: B:61:0x0214, code skipped:
            r2 = th;
     */
    public com.tencent.tmassistantsdk.downloadclient.TMAssistantDownloadTaskInfo getDownloadTaskState(com.tencent.tmassistantsdk.openSDK.TMQQDownloaderOpenSDKParam r18) {
        /*
        r17 = this;
        r2 = 75870; // 0x1285e float:1.06317E-40 double:3.7485E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r2);
        r0 = r17;
        r2 = r0.mContext;
        if (r2 != 0) goto L_0x001b;
    L_0x000c:
        r2 = new java.lang.Exception;
        r3 = "Context shouldn't be null !";
        r2.<init>(r3);
        r3 = 75870; // 0x1285e float:1.06317E-40 double:3.7485E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r3);
        throw r2;
    L_0x001b:
        if (r18 != 0) goto L_0x002c;
    L_0x001d:
        r2 = new java.lang.Exception;
        r3 = "QQDownloaderParam param cann't is null!";
        r2.<init>(r3);
        r3 = 75870; // 0x1285e float:1.06317E-40 double:3.7485E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r3);
        throw r2;
    L_0x002c:
        r0 = r17;
        r2 = r0.mContext;
        r2 = r2.getContentResolver();
        r12 = 0;
        r8 = 0;
        r3 = CONTENT_URI;	 Catch:{ Exception -> 0x01f1, all -> 0x0206 }
        r4 = 0;
        r5 = "packageName=? and versionCode=? and channelId=?";
        r6 = 3;
        r6 = new java.lang.String[r6];	 Catch:{ Exception -> 0x01f1, all -> 0x0206 }
        r7 = 0;
        r0 = r18;
        r9 = r0.taskPackageName;	 Catch:{ Exception -> 0x01f1, all -> 0x0206 }
        r6[r7] = r9;	 Catch:{ Exception -> 0x01f1, all -> 0x0206 }
        r7 = 1;
        r0 = r18;
        r9 = r0.taskVersion;	 Catch:{ Exception -> 0x01f1, all -> 0x0206 }
        r9 = java.lang.String.valueOf(r9);	 Catch:{ Exception -> 0x01f1, all -> 0x0206 }
        r6[r7] = r9;	 Catch:{ Exception -> 0x01f1, all -> 0x0206 }
        r7 = 2;
        r0 = r18;
        r9 = r0.channelId;	 Catch:{ Exception -> 0x01f1, all -> 0x0206 }
        r6[r7] = r9;	 Catch:{ Exception -> 0x01f1, all -> 0x0206 }
        r7 = 0;
        r11 = r2.query(r3, r4, r5, r6, r7);	 Catch:{ Exception -> 0x01f1, all -> 0x0206 }
        r2 = "QQDownloaderOpenSDK";
        r3 = new java.lang.StringBuilder;	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r4 = "getDownloadTaskState from qqdownloader , taskPackageName = ";
        r3.<init>(r4);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r0 = r18;
        r4 = r0.taskPackageName;	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r3 = r3.append(r4);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r4 = ", taskVersion=";
        r3 = r3.append(r4);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r0 = r18;
        r4 = r0.taskVersion;	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r4 = java.lang.String.valueOf(r4);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r3 = r3.append(r4);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r4 = ", channelId=";
        r3 = r3.append(r4);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r0 = r18;
        r4 = r0.channelId;	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r3 = r3.append(r4);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r3 = r3.toString();	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        com.tencent.tmassistantsdk.util.TMLog.d(r2, r3);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        if (r11 == 0) goto L_0x0222;
    L_0x009b:
        r2 = r11.moveToFirst();	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        if (r2 == 0) goto L_0x0222;
    L_0x00a1:
        r2 = "QQDownloaderOpenSDK";
        r3 = new java.lang.StringBuilder;	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r4 = "relate to qqdownloader , packageName = ";
        r3.<init>(r4);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r0 = r18;
        r4 = r0.taskPackageName;	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r3 = r3.append(r4);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r3 = r3.toString();	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        com.tencent.tmassistantsdk.util.TMLog.i(r2, r3);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r2 = "apkId";
        r2 = r11.getColumnIndex(r2);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r14 = r11.getLong(r2);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r2 = "apkUrl";
        r2 = r11.getColumnIndex(r2);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r2 = r11.getString(r2);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r2 = com.tencent.tmassistantsdk.util.GlobalUtil.String2List(r2);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r3 = 0;
        r3 = r2.get(r3);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r3 = (java.lang.String) r3;	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r2 = "filePath";
        r2 = r11.getColumnIndex(r2);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r4 = r11.getString(r2);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r2 = "received_length";
        r2 = r11.getColumnIndex(r2);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r6 = r11.getLong(r2);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r2 = "total_length";
        r2 = r11.getColumnIndex(r2);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r8 = r11.getLong(r2);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r10 = "application/vnd.android.package-archive";
        r2 = "state";
        r2 = r11.getColumnIndex(r2);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r2 = r11.getInt(r2);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r5 = com.tencent.tmassistantsdk.util.GlobalUtil.assistantState2SDKState(r2);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r2 = "QQDownloaderOpenSDK";
        r13 = "getDownloadTaskState state = ";
        r16 = java.lang.String.valueOf(r5);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r0 = r16;
        r13 = r13.concat(r0);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        com.tencent.tmassistantsdk.util.TMLog.i(r2, r13);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r2 = 4;
        if (r2 != r5) goto L_0x013a;
    L_0x0125:
        r0 = r17;
        r2 = r0.isFileExist(r4);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        if (r2 != 0) goto L_0x013a;
    L_0x012d:
        if (r11 == 0) goto L_0x0132;
    L_0x012f:
        r11.close();
    L_0x0132:
        r2 = 0;
        r3 = 75870; // 0x1285e float:1.06317E-40 double:3.7485E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r3);
    L_0x0139:
        return r2;
    L_0x013a:
        r2 = new com.tencent.tmassistantsdk.downloadclient.TMAssistantDownloadTaskInfo;	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r2.<init>(r3, r4, r5, r6, r8, r10);	 Catch:{ Exception -> 0x0219, all -> 0x0214 }
        r4 = 5;
        if (r5 == r4) goto L_0x0148;
    L_0x0142:
        r4 = 4;
        if (r5 == r4) goto L_0x0148;
    L_0x0145:
        r4 = 3;
        if (r5 != r4) goto L_0x0168;
    L_0x0148:
        r4 = com.tencent.tmassistantsdk.logreport.DownloadReportManager.getInstance();	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r6 = 1;
        r4 = r4.createNewChunkLogInfo(r6);	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r0 = r18;
        r6 = r0.via;	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r4.via = r6;	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r6 = java.lang.String.valueOf(r14);	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r4.appId = r6;	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r4.resultState = r5;	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r4.requestUrl = r3;	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r3 = com.tencent.tmassistantsdk.logreport.DownloadReportManager.getInstance();	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r3.addLogData(r4);	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
    L_0x0168:
        r0 = r17;
        r3 = r0.mDownloadParams;	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        if (r3 == 0) goto L_0x01e4;
    L_0x016e:
        r0 = r17;
        r3 = r0.mDownloadParams;	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r3 = r3.entrySet();	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r5 = r3.iterator();	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r4 = 0;
    L_0x017b:
        r3 = r5.hasNext();	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        if (r3 == 0) goto L_0x0220;
    L_0x0181:
        r3 = r5.next();	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r3 = (java.util.Map.Entry) r3;	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r3 = r3.getValue();	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r3 = (com.tencent.tmassistantsdk.openSDK.TMQQDownloaderOpenSDKParam) r3;	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        if (r3 == 0) goto L_0x017b;
    L_0x018f:
        r6 = r3.taskPackageName;	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r0 = r18;
        r7 = r0.taskPackageName;	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r6 = r6.equals(r7);	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        if (r6 == 0) goto L_0x017b;
    L_0x019b:
        r3 = r3.taskVersion;	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r0 = r18;
        r6 = r0.taskVersion;	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        if (r3 != r6) goto L_0x017b;
    L_0x01a3:
        r3 = 1;
    L_0x01a4:
        if (r3 != 0) goto L_0x01e4;
    L_0x01a6:
        r3 = "QQDownloaderOpenSDK";
        r4 = new java.lang.StringBuilder;	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r5 = "relate to qqdownloader , packageName = ";
        r4.<init>(r5);	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r0 = r18;
        r5 = r0.taskPackageName;	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r4 = r4.append(r5);	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r4 = r4.toString();	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        com.tencent.tmassistantsdk.util.TMLog.i(r3, r4);	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r3 = java.util.UUID.randomUUID();	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r3 = r3.toString();	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r4 = java.lang.String.valueOf(r14);	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r0 = r18;
        r0.taskApkId = r4;	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r0 = r17;
        r4 = r0.mDownloadParams;	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r0 = r18;
        r4.put(r3, r0);	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r0 = r17;
        r4 = r0.mContext;	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
        r0 = r17;
        r1 = r18;
        r0.relateToQQDownloader(r4, r1, r3);	 Catch:{ Exception -> 0x021d, all -> 0x0214 }
    L_0x01e4:
        if (r11 == 0) goto L_0x01e9;
    L_0x01e6:
        r11.close();
    L_0x01e9:
        r3 = 75870; // 0x1285e float:1.06317E-40 double:3.7485E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r3);
        goto L_0x0139;
    L_0x01f1:
        r3 = move-exception;
        r4 = r8;
        r2 = r12;
    L_0x01f4:
        r5 = "QQDownloaderOpenSDK";
        r6 = "";
        r7 = 0;
        r7 = new java.lang.Object[r7];	 Catch:{ all -> 0x0216 }
        com.tencent.mm.sdk.platformtools.ab.printErrStackTrace(r5, r3, r6, r7);	 Catch:{ all -> 0x0216 }
        if (r4 == 0) goto L_0x01e9;
    L_0x0202:
        r4.close();
        goto L_0x01e9;
    L_0x0206:
        r2 = move-exception;
        r11 = r8;
    L_0x0208:
        if (r11 == 0) goto L_0x020d;
    L_0x020a:
        r11.close();
    L_0x020d:
        r3 = 75870; // 0x1285e float:1.06317E-40 double:3.7485E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r3);
        throw r2;
    L_0x0214:
        r2 = move-exception;
        goto L_0x0208;
    L_0x0216:
        r2 = move-exception;
        r11 = r4;
        goto L_0x0208;
    L_0x0219:
        r3 = move-exception;
        r4 = r11;
        r2 = r12;
        goto L_0x01f4;
    L_0x021d:
        r3 = move-exception;
        r4 = r11;
        goto L_0x01f4;
    L_0x0220:
        r3 = r4;
        goto L_0x01a4;
    L_0x0222:
        r2 = r12;
        goto L_0x01e4;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.tmassistantsdk.openSDK.TMQQDownloaderOpenSDK.getDownloadTaskState(com.tencent.tmassistantsdk.openSDK.TMQQDownloaderOpenSDKParam):com.tencent.tmassistantsdk.downloadclient.TMAssistantDownloadTaskInfo");
    }

    private void relateToQQDownloader(Context context, TMQQDownloaderOpenSDKParam tMQQDownloaderOpenSDKParam, String str) {
        AppMethodBeat.i(75871);
        Map formatMapParams = super.formatMapParams(tMQQDownloaderOpenSDKParam, false, false);
        formatMapParams.put("taskid", str);
        String formatIntentUriPath = super.formatIntentUriPath(4, formatMapParams);
        Intent intent = new Intent("com.tencent.android.qqdownloader.action.RELATED");
        intent.setPackage("com.tencent.android.qqdownloader");
        intent.putExtra("command", "cmd_updatedownload");
        intent.putExtra("relatedurl", formatIntentUriPath);
        context.sendBroadcast(intent);
        AppMethodBeat.o(75871);
    }

    private boolean isFileExist(String str) {
        AppMethodBeat.i(75872);
        if (new File(str).exists()) {
            AppMethodBeat.o(75872);
            return true;
        }
        AppMethodBeat.o(75872);
        return false;
    }

    public void onDownloadStateChanged(TMQQDownloaderStateChangeParam tMQQDownloaderStateChangeParam) {
        AppMethodBeat.i(75873);
        TMQQDownloaderOpenSDKParam tMQQDownloaderOpenSDKParam = tMQQDownloaderStateChangeParam.param;
        int assistantState2SDKState = GlobalUtil.assistantState2SDKState(tMQQDownloaderStateChangeParam.state);
        int assistantErrorCode2SDKErrorCode = GlobalUtil.assistantErrorCode2SDKErrorCode(tMQQDownloaderStateChangeParam.errorCode);
        String str = tMQQDownloaderStateChangeParam.errorMsg;
        String str2 = tMQQDownloaderStateChangeParam.taskId;
        TMLog.i(TAG, "onDownloadStateChanged state = ".concat(String.valueOf(assistantState2SDKState)));
        TMQQDownloaderOpenSDKParam tMQQDownloaderOpenSDKParam2 = null;
        if (str2 != null && str2.trim().length() > 0) {
            tMQQDownloaderOpenSDKParam2 = (TMQQDownloaderOpenSDKParam) this.mDownloadParams.get(str2);
        }
        if (tMQQDownloaderOpenSDKParam2 != null) {
            onStateChanged(tMQQDownloaderOpenSDKParam2, assistantState2SDKState, assistantErrorCode2SDKErrorCode, str);
        } else {
            TMLog.i(TAG, "onDownloadStateChanged storeParam = null");
        }
        if (6 == assistantState2SDKState) {
            ArrayList arrayList = new ArrayList();
            for (Entry entry : this.mDownloadParams.entrySet()) {
                TMQQDownloaderOpenSDKParam tMQQDownloaderOpenSDKParam3 = (TMQQDownloaderOpenSDKParam) entry.getValue();
                String str3 = (String) entry.getKey();
                if (tMQQDownloaderOpenSDKParam3 != null && !TextUtils.isEmpty(tMQQDownloaderOpenSDKParam.taskPackageName) && tMQQDownloaderOpenSDKParam3.taskPackageName.equals(tMQQDownloaderOpenSDKParam.taskPackageName) && tMQQDownloaderOpenSDKParam3.taskVersion == tMQQDownloaderOpenSDKParam.taskVersion) {
                    arrayList.add(str3);
                }
            }
            Iterator it = arrayList.iterator();
            while (it.hasNext()) {
                this.mDownloadParams.remove((String) it.next());
            }
        }
        AppMethodBeat.o(75873);
    }

    public void initQQDownloaderOpenSDK(Context context) {
        AppMethodBeat.i(75874);
        this.mContext = context;
        this.hostPackageName = context.getPackageName();
        this.hostVersionCode = GlobalUtil.getAppVersionCode(this.mContext);
        GlobalUtil.getInstance().setContext(this.mContext);
        this.sdkAPILevel = 1;
        DownloadStateChangedReceiver.getInstance().registeReceiver(this.mContext);
        DownloadStateChangedReceiver.getInstance().addDownloadStateChangedListener(this);
        NetworkMonitorReceiver.getInstance().registerReceiver();
        GetSettingEngine.getInstance().sendRequest();
        LogReportManager.getInstance().reportLog();
        AppMethodBeat.o(75874);
    }

    public static String about() {
        return "TMQQDownloaderOpenSDK_2014_05_13_17_36_release_35169";
    }

    public void startToWebView(Context context, String str) {
        AppMethodBeat.i(75875);
        Exception exception;
        if (context == null) {
            exception = new Exception("you must input an application or activity context!");
            AppMethodBeat.o(75875);
            throw exception;
        } else if (TextUtils.isEmpty(str)) {
            exception = new Exception("param url shouldn't be null!");
            AppMethodBeat.o(75875);
            throw exception;
        } else {
            HashMap hashMap = new HashMap();
            hashMap.put(ImagesContract.URL, str);
            String formatIntentUriPath = super.formatIntentUriPath(5, hashMap);
            TMLog.i(TAG, "startToWebView finalPath:".concat(String.valueOf(formatIntentUriPath)));
            Intent intent = new Intent("android.intent.action.VIEW", Uri.parse(formatIntentUriPath));
            if (context instanceof Application) {
                intent.addFlags(ErrorDialogData.BINDER_CRASH);
            }
            context.startActivity(intent);
            AppMethodBeat.o(75875);
        }
    }
}
