package com.tencent.ttpic.baseutils;

import android.annotation.SuppressLint;
import android.content.Context;
import android.content.res.AssetManager;
import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.Bitmap.CompressFormat;
import android.graphics.Bitmap.Config;
import android.graphics.BitmapFactory;
import android.graphics.BitmapFactory.Options;
import android.graphics.Canvas;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.Point;
import android.graphics.PorterDuff.Mode;
import android.graphics.PorterDuffXfermode;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.Shader.TileMode;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.media.ExifInterface;
import android.net.Uri;
import android.os.Build.VERSION;
import android.os.Environment;
import android.text.TextUtils;
import android.view.View;
import com.tencent.matrix.trace.core.AppMethodBeat;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileDescriptor;
import java.io.IOException;
import java.io.InputStream;
import java.net.HttpURLConnection;
import java.net.URL;

@SuppressLint({"NewApi"})
public class BitmapUtils {
    public static final int JPEG_QUALITY = 99;
    public static final String RES_PREFIX_ASSETS = "assets://";
    public static final String RES_PREFIX_HTTP = "http://";
    public static final String RES_PREFIX_HTTPS = "https://";
    public static final String RES_PREFIX_STORAGE = "/";
    private static final String TAG = BitmapUtils.class.getSimpleName();

    static {
        AppMethodBeat.i(49652);
        AppMethodBeat.o(49652);
    }

    public static String getRealPath(String str) {
        AppMethodBeat.i(49599);
        if (TextUtils.isEmpty(str) || !str.startsWith("assets://")) {
            AppMethodBeat.o(49599);
            return str;
        }
        str = str.substring(9);
        AppMethodBeat.o(49599);
        return str;
    }

    public static boolean bmpIsExists(String str) {
        AppMethodBeat.i(49600);
        if (TextUtils.isEmpty(str)) {
            AppMethodBeat.o(49600);
            return false;
        } else if (str.startsWith("assets://") || new File(str).exists()) {
            AppMethodBeat.o(49600);
            return true;
        } else {
            AppMethodBeat.o(49600);
            return false;
        }
    }

    public static boolean isLegal(Bitmap bitmap) {
        AppMethodBeat.i(49601);
        if (bitmap == null || bitmap.isRecycled()) {
            AppMethodBeat.o(49601);
            return false;
        }
        AppMethodBeat.o(49601);
        return true;
    }

    public static boolean recycle(Bitmap bitmap) {
        AppMethodBeat.i(49602);
        if (bitmap == null || bitmap.isRecycled()) {
            AppMethodBeat.o(49602);
            return false;
        }
        bitmap.recycle();
        AppMethodBeat.o(49602);
        return true;
    }

    public static Bitmap copy(Bitmap bitmap, boolean z) {
        AppMethodBeat.i(49603);
        Bitmap bitmap2 = null;
        try {
            if (isLegal(bitmap)) {
                bitmap2 = bitmap.copy(bitmap.getConfig(), z);
            }
        } catch (OutOfMemoryError e) {
            LogUtils.e(TAG, "bitmap copy OOM!");
        }
        AppMethodBeat.o(49603);
        return bitmap2;
    }

    public static Bitmap convertToSRGB(Bitmap bitmap) {
        AppMethodBeat.i(49604);
        if (bitmap == null) {
            AppMethodBeat.o(49604);
            return null;
        }
        try {
            Bitmap createBitmap = Bitmap.createBitmap(bitmap.getWidth(), bitmap.getHeight(), bitmap.getConfig());
            new Canvas(createBitmap).drawBitmap(bitmap, 0.0f, 0.0f, new Paint());
            bitmap.recycle();
            AppMethodBeat.o(49604);
            return createBitmap;
        } catch (OutOfMemoryError e) {
            LogUtils.e(e);
            AppMethodBeat.o(49604);
            return bitmap;
        }
    }

    public static byte[] bmpToByteArray(Bitmap bitmap, boolean z) {
        AppMethodBeat.i(49605);
        if (isLegal(bitmap)) {
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            bitmap.compress(CompressFormat.JPEG, 80, byteArrayOutputStream);
            if (z) {
                bitmap.recycle();
            }
            byte[] toByteArray = byteArrayOutputStream.toByteArray();
            try {
                byteArrayOutputStream.close();
            } catch (Exception e) {
                LogUtils.e(e);
            }
            AppMethodBeat.o(49605);
            return toByteArray;
        }
        AppMethodBeat.o(49605);
        return null;
    }

    public static void fixBgRepeatY(View view) {
        AppMethodBeat.i(49606);
        Drawable background = view.getBackground();
        if (background != null && (background instanceof BitmapDrawable)) {
            BitmapDrawable bitmapDrawable = (BitmapDrawable) background;
            bitmapDrawable.mutate();
            bitmapDrawable.setTileModeY(TileMode.REPEAT);
        }
        AppMethodBeat.o(49606);
    }

    /* JADX WARNING: Removed duplicated region for block: B:24:0x004f A:{SYNTHETIC, Splitter:B:24:0x004f} */
    public static java.lang.String getBase64FromBitmap(android.graphics.Bitmap r5, int r6) {
        /*
        r4 = 49607; // 0xc1c7 float:6.9514E-41 double:2.4509E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r4);
        if (r5 != 0) goto L_0x0017;
    L_0x0008:
        r0 = TAG;
        r1 = "[getBase64FromBitmap] bitmap is null!";
        com.tencent.ttpic.baseutils.LogUtils.d(r0, r1);
        r0 = "";
        com.tencent.matrix.trace.core.AppMethodBeat.o(r4);
    L_0x0016:
        return r0;
    L_0x0017:
        r0 = "";
        r2 = 0;
        r1 = new java.io.ByteArrayOutputStream;	 Catch:{ Exception -> 0x003b, all -> 0x004b }
        r1.<init>();	 Catch:{ Exception -> 0x003b, all -> 0x004b }
        r2 = android.graphics.Bitmap.CompressFormat.JPEG;	 Catch:{ Exception -> 0x005d, all -> 0x005b }
        r3 = 100;
        r5.compress(r2, r3, r1);	 Catch:{ Exception -> 0x005d, all -> 0x005b }
        r2 = r1.toByteArray();	 Catch:{ Exception -> 0x005d, all -> 0x005b }
        r0 = android.util.Base64.encodeToString(r2, r6);	 Catch:{ Exception -> 0x005d, all -> 0x005b }
        r1.close();	 Catch:{ IOException -> 0x0036 }
    L_0x0032:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r4);
        goto L_0x0016;
    L_0x0036:
        r1 = move-exception;
        com.tencent.ttpic.baseutils.LogUtils.e(r1);
        goto L_0x0032;
    L_0x003b:
        r1 = move-exception;
        r1 = r2;
    L_0x003d:
        if (r1 == 0) goto L_0x0042;
    L_0x003f:
        r1.close();	 Catch:{ IOException -> 0x0046 }
    L_0x0042:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r4);
        goto L_0x0016;
    L_0x0046:
        r1 = move-exception;
        com.tencent.ttpic.baseutils.LogUtils.e(r1);
        goto L_0x0042;
    L_0x004b:
        r1 = move-exception;
        r1 = r2;
    L_0x004d:
        if (r1 == 0) goto L_0x0052;
    L_0x004f:
        r1.close();	 Catch:{ IOException -> 0x0056 }
    L_0x0052:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r4);
        goto L_0x0016;
    L_0x0056:
        r1 = move-exception;
        com.tencent.ttpic.baseutils.LogUtils.e(r1);
        goto L_0x0052;
    L_0x005b:
        r2 = move-exception;
        goto L_0x004d;
    L_0x005d:
        r2 = move-exception;
        goto L_0x003d;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.ttpic.baseutils.BitmapUtils.getBase64FromBitmap(android.graphics.Bitmap, int):java.lang.String");
    }

    @SuppressLint({"NewApi"})
    public static int getBitmapSizeInBytes(Bitmap bitmap) {
        AppMethodBeat.i(49608);
        if (bitmap == null) {
            AppMethodBeat.o(49608);
            return 0;
        }
        int allocationByteCount;
        if (VERSION.SDK_INT > 19) {
            try {
                allocationByteCount = bitmap.getAllocationByteCount();
                AppMethodBeat.o(49608);
                return allocationByteCount;
            } catch (NullPointerException e) {
            }
        }
        if (VERSION.SDK_INT >= 12) {
            allocationByteCount = bitmap.getByteCount();
            AppMethodBeat.o(49608);
            return allocationByteCount;
        }
        allocationByteCount = bitmap.getWidth() * bitmap.getRowBytes();
        AppMethodBeat.o(49608);
        return allocationByteCount;
    }

    public static Point getBitmapSize(Context context, String str) {
        AppMethodBeat.i(49609);
        Point bitmapSizeFromAssets;
        if (str.startsWith("assets://")) {
            bitmapSizeFromAssets = getBitmapSizeFromAssets(context, getRealPath(str));
            AppMethodBeat.o(49609);
            return bitmapSizeFromAssets;
        }
        bitmapSizeFromAssets = getBitmapSizeFromFile(str);
        AppMethodBeat.o(49609);
        return bitmapSizeFromAssets;
    }

    private static Point getBitmapSizeFromFile(String str) {
        AppMethodBeat.i(49610);
        Options options = new Options();
        options.inJustDecodeBounds = true;
        BitmapFactory.decodeFile(str, options);
        Point point = new Point(options.outWidth, options.outHeight);
        AppMethodBeat.o(49610);
        return point;
    }

    /* JADX WARNING: Removed duplicated region for block: B:20:0x004c A:{SYNTHETIC, Splitter:B:20:0x004c} */
    private static android.graphics.Point getBitmapSizeFromAssets(android.content.Context r6, java.lang.String r7) {
        /*
        r1 = 0;
        r2 = 0;
        r5 = 49611; // 0xc1cb float:6.952E-41 double:2.4511E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r5);
        r0 = new android.graphics.Point;
        r0.<init>(r2, r2);
        r2 = android.text.TextUtils.isEmpty(r7);
        if (r2 == 0) goto L_0x0017;
    L_0x0013:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
    L_0x0016:
        return r0;
    L_0x0017:
        r2 = r6.getAssets();
        r2 = r2.open(r7);	 Catch:{ IOException -> 0x003e, all -> 0x0048 }
        r3 = new android.graphics.BitmapFactory$Options;	 Catch:{ IOException -> 0x005b, all -> 0x0059 }
        r3.<init>();	 Catch:{ IOException -> 0x005b, all -> 0x0059 }
        r1 = 1;
        r3.inJustDecodeBounds = r1;	 Catch:{ IOException -> 0x005b, all -> 0x0059 }
        r1 = 0;
        android.graphics.BitmapFactory.decodeStream(r2, r1, r3);	 Catch:{ IOException -> 0x005b, all -> 0x0059 }
        r1 = new android.graphics.Point;	 Catch:{ IOException -> 0x005b, all -> 0x0059 }
        r4 = r3.outWidth;	 Catch:{ IOException -> 0x005b, all -> 0x0059 }
        r3 = r3.outHeight;	 Catch:{ IOException -> 0x005b, all -> 0x0059 }
        r1.<init>(r4, r3);	 Catch:{ IOException -> 0x005b, all -> 0x0059 }
        if (r2 == 0) goto L_0x0039;
    L_0x0036:
        r2.close();	 Catch:{ IOException -> 0x0053 }
    L_0x0039:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
        r0 = r1;
        goto L_0x0016;
    L_0x003e:
        r2 = move-exception;
    L_0x003f:
        if (r1 == 0) goto L_0x0044;
    L_0x0041:
        r1.close();	 Catch:{ IOException -> 0x0055 }
    L_0x0044:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
        goto L_0x0016;
    L_0x0048:
        r0 = move-exception;
        r2 = r1;
    L_0x004a:
        if (r2 == 0) goto L_0x004f;
    L_0x004c:
        r2.close();	 Catch:{ IOException -> 0x0057 }
    L_0x004f:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
        throw r0;
    L_0x0053:
        r0 = move-exception;
        goto L_0x0039;
    L_0x0055:
        r1 = move-exception;
        goto L_0x0044;
    L_0x0057:
        r1 = move-exception;
        goto L_0x004f;
    L_0x0059:
        r0 = move-exception;
        goto L_0x004a;
    L_0x005b:
        r1 = move-exception;
        r1 = r2;
        goto L_0x003f;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.ttpic.baseutils.BitmapUtils.getBitmapSizeFromAssets(android.content.Context, java.lang.String):android.graphics.Point");
    }

    public static int[] getImageSize(String str, int i, int i2) {
        int i3;
        AppMethodBeat.i(49612);
        Options options = new Options();
        options.inJustDecodeBounds = true;
        BitmapFactory.decodeFile(str, options);
        int i4 = 1;
        while (Math.pow(2.0d, (double) i4) < ((double) calculateInSampleSize(options, i, i2, true))) {
            i4++;
        }
        i4 = (int) Math.pow(2.0d, (double) (i4 - 1));
        int i5 = options.outWidth / i4;
        int i6 = options.outHeight / i4;
        i4 = getDegreeByExif(str);
        if (i4 == 90 || i4 == 270) {
            i4 = i6;
            i3 = i5;
        } else {
            i4 = i5;
            i3 = i6;
        }
        int[] iArr = new int[]{i4, i3};
        AppMethodBeat.o(49612);
        return iArr;
    }

    public static Options getBitmapOptionsFromFile(String str) {
        AppMethodBeat.i(49613);
        if (str == null) {
            AppMethodBeat.o(49613);
            return null;
        } else if (new File(str).exists()) {
            Options options = new Options();
            options.inJustDecodeBounds = true;
            BitmapFactory.decodeFile(str, options);
            AppMethodBeat.o(49613);
            return options;
        } else {
            AppMethodBeat.o(49613);
            return null;
        }
    }

    public static Options getBitmapOptionsFromResource(Resources resources, int i) {
        AppMethodBeat.i(49614);
        Options options = new Options();
        options.inJustDecodeBounds = true;
        BitmapFactory.decodeResource(resources, i, options);
        AppMethodBeat.o(49614);
        return options;
    }

    public static Options getBitmapOptionsFromAssets(Context context, String str) {
        InputStream open;
        AppMethodBeat.i(49615);
        AssetManager assets = context.getAssets();
        try {
            open = assets.open(str);
        } catch (IOException e) {
            try {
                open = assets.open(str.substring(0, str.lastIndexOf(46) + 1) + "webp");
            } catch (IOException e2) {
                LogUtils.e(TAG, e2);
                AppMethodBeat.o(49615);
                return null;
            }
        }
        Options options = new Options();
        options.inJustDecodeBounds = true;
        BitmapFactory.decodeStream(open, null, options);
        try {
            open.reset();
            if (open != null) {
                IOUtils.closeQuietly(open);
            }
        } catch (IOException e3) {
            LogUtils.e(TAG, e3);
            if (open != null) {
                IOUtils.closeQuietly(open);
            }
        } catch (Throwable th) {
            if (open != null) {
                IOUtils.closeQuietly(open);
            }
            AppMethodBeat.o(49615);
        }
        AppMethodBeat.o(49615);
        return options;
    }

    public static Options getBitmapOptionsFromUri(Context context, Uri uri) {
        String scheme;
        AppMethodBeat.i(49616);
        if (uri != null) {
            scheme = uri.getScheme();
        } else {
            scheme = null;
        }
        String substring;
        Options bitmapOptionsFromFile;
        if (scheme != null && scheme.toLowerCase().startsWith("file")) {
            substring = Uri.decode(uri.toString()).substring(7);
            LogUtils.v(TAG, "[getBitmapOptionsFromUri] file = ".concat(String.valueOf(substring)));
            bitmapOptionsFromFile = getBitmapOptionsFromFile(substring);
            AppMethodBeat.o(49616);
            return bitmapOptionsFromFile;
        } else if (uri == null) {
            AppMethodBeat.o(49616);
            return null;
        } else {
            substring = Uri.decode(uri.toString());
            LogUtils.v(TAG, "[getBitmapOptionsFromUri] in else , file = ".concat(String.valueOf(substring)));
            bitmapOptionsFromFile = getBitmapOptionsFromFile(substring);
            AppMethodBeat.o(49616);
            return bitmapOptionsFromFile;
        }
    }

    public static Bitmap createBitmap(Bitmap bitmap, int i, int i2, int i3, int i4, Matrix matrix) {
        Paint paint = null;
        AppMethodBeat.i(49617);
        if (bitmap == null || bitmap.isRecycled()) {
            AppMethodBeat.o(49617);
            return null;
        }
        Bitmap createBitmap;
        Canvas canvas = new Canvas();
        if (matrix == null || matrix.isIdentity()) {
            try {
                createBitmap = Bitmap.createBitmap(i3, i4, bitmap.getConfig());
            } catch (OutOfMemoryError e) {
                LogUtils.e(e);
                AppMethodBeat.o(49617);
                return null;
            } catch (NullPointerException e2) {
                LogUtils.e(e2);
                AppMethodBeat.o(49617);
                return null;
            }
        }
        RectF rectF = new RectF(0.0f, 0.0f, (float) i3, (float) i4);
        matrix.mapRect(rectF);
        try {
            createBitmap = Bitmap.createBitmap(Math.round(rectF.width()), Math.round(rectF.height()), bitmap.getConfig());
            canvas.translate(-rectF.left, -rectF.top);
            canvas.concat(matrix);
            paint = new Paint(2);
            if (!matrix.rectStaysRect()) {
                paint.setAntiAlias(true);
            }
        } catch (OutOfMemoryError e3) {
            LogUtils.e(e3);
            AppMethodBeat.o(49617);
            return null;
        }
        createBitmap.setDensity(bitmap.getDensity());
        canvas.setBitmap(createBitmap);
        canvas.drawBitmap(bitmap, new Rect(i, i2, i + i3, i2 + i4), new RectF(0.0f, 0.0f, (float) i3, (float) i4), paint);
        AppMethodBeat.o(49617);
        return createBitmap;
    }

    public static Bitmap scaleBitmap(Bitmap bitmap, float f, boolean z) {
        AppMethodBeat.i(49618);
        if (isLegal(bitmap)) {
            Matrix matrix = new Matrix();
            matrix.postScale(f, f);
            try {
                Bitmap createBitmap = Bitmap.createBitmap(bitmap, 0, 0, bitmap.getWidth(), bitmap.getHeight(), matrix, true);
                if (createBitmap != bitmap && z) {
                    recycle(bitmap);
                }
                bitmap = createBitmap;
            } catch (OutOfMemoryError e) {
            }
        } else {
            bitmap = null;
        }
        AppMethodBeat.o(49618);
        return bitmap;
    }

    public static void scaleBitmap(Bitmap bitmap, Canvas canvas, int i, int i2, double d, double d2, Point point, Paint paint) {
        AppMethodBeat.i(49619);
        if (isLegal(bitmap)) {
            Matrix matrix = new Matrix();
            int i3 = (int) (((double) i) - (((double) point.x) * d2));
            int i4 = (int) (((double) i2) - (((double) point.y) * d2));
            matrix.postScale((float) d2, (float) d2);
            if (!(i3 == 0 && i4 == 0)) {
                matrix.postTranslate((float) i3, (float) i4);
            }
            if (d != 0.0d) {
                matrix.postRotate((float) d, (float) i, (float) i2);
            }
            if (paint == null) {
                AppMethodBeat.o(49619);
                return;
            }
            canvas.drawBitmap(bitmap, matrix, paint);
            AppMethodBeat.o(49619);
            return;
        }
        AppMethodBeat.o(49619);
    }

    public static Bitmap rotateBitmap(Bitmap bitmap, int i) {
        AppMethodBeat.i(49620);
        if (bitmap != null) {
            Matrix matrix = new Matrix();
            matrix.setRotate((float) i, ((float) bitmap.getWidth()) / 2.0f, ((float) bitmap.getHeight()) / 2.0f);
            try {
                Bitmap createBitmap = Bitmap.createBitmap(bitmap, 0, 0, bitmap.getWidth(), bitmap.getHeight(), matrix, true);
                if (bitmap != createBitmap) {
                    bitmap.recycle();
                    bitmap = createBitmap;
                }
            } catch (OutOfMemoryError e) {
            }
        }
        AppMethodBeat.o(49620);
        return bitmap;
    }

    public static Bitmap flipBitmap(Bitmap bitmap, boolean z) {
        AppMethodBeat.i(49621);
        if (bitmap != null) {
            Matrix matrix = new Matrix();
            if (z) {
                matrix.setScale(1.0f, -1.0f);
            } else {
                matrix.setScale(-1.0f, 1.0f);
            }
            try {
                Bitmap createBitmap = Bitmap.createBitmap(bitmap, 0, 0, bitmap.getWidth(), bitmap.getHeight(), matrix, true);
                if (bitmap != createBitmap) {
                    bitmap.recycle();
                    bitmap = createBitmap;
                }
            } catch (OutOfMemoryError e) {
                LogUtils.e(TAG, "OutOfMemoryError. ".concat(String.valueOf(e)));
            }
        }
        AppMethodBeat.o(49621);
        return bitmap;
    }

    public static Bitmap roundRectBitmap(Bitmap bitmap, int i) {
        AppMethodBeat.i(49622);
        Paint paint = new Paint();
        paint.setAntiAlias(true);
        paint.setFilterBitmap(true);
        int width = bitmap.getWidth();
        int height = bitmap.getHeight();
        RectF rectF = new RectF(0.0f, 0.0f, (float) width, (float) height);
        Rect rect = new Rect(0, 0, width, height);
        Canvas canvas = new Canvas(bitmap);
        paint.setXfermode(null);
        canvas.drawRoundRect(rectF, (float) i, (float) i, paint);
        paint.setXfermode(new PorterDuffXfermode(Mode.SRC_IN));
        canvas.drawBitmap(bitmap, rect, rectF, paint);
        AppMethodBeat.o(49622);
        return bitmap;
    }

    public static Bitmap decodeSampleBitmap(Context context, String str, int i, int i2) {
        AppMethodBeat.i(49623);
        Bitmap decodeSampledBitmapFromAssets;
        if (TextUtils.isEmpty(str)) {
            AppMethodBeat.o(49623);
            return null;
        } else if (str.startsWith("assets://")) {
            decodeSampledBitmapFromAssets = decodeSampledBitmapFromAssets(context, getRealPath(str), i, i2);
            AppMethodBeat.o(49623);
            return decodeSampledBitmapFromAssets;
        } else if (bmpIsExists(str)) {
            decodeSampledBitmapFromAssets = decodeSampledBitmapFromFile(str, i, i2);
            AppMethodBeat.o(49623);
            return decodeSampledBitmapFromAssets;
        } else {
            AppMethodBeat.o(49623);
            return null;
        }
    }

    public static Bitmap decodeSampleBitmap(Context context, String str, int i) {
        AppMethodBeat.i(49624);
        Bitmap decodeSampleBitmapFromAssets;
        if (TextUtils.isEmpty(str)) {
            AppMethodBeat.o(49624);
            return null;
        } else if (str.startsWith("assets://")) {
            decodeSampleBitmapFromAssets = decodeSampleBitmapFromAssets(context, getRealPath(str), i);
            AppMethodBeat.o(49624);
            return decodeSampleBitmapFromAssets;
        } else if (bmpIsExists(str)) {
            decodeSampleBitmapFromAssets = decodeSampledBitmapFromFile(str, i);
            AppMethodBeat.o(49624);
            return decodeSampleBitmapFromAssets;
        } else {
            AppMethodBeat.o(49624);
            return null;
        }
    }

    public static Bitmap decodeSampledBitmapFromFile(String str, int i, int i2) {
        AppMethodBeat.i(49625);
        Options options = new Options();
        options.inJustDecodeBounds = true;
        BitmapFactory.decodeFile(str, options);
        options.inSampleSize = calculateInSampleSizeNew(options, i, i2, true);
        options.inJustDecodeBounds = false;
        ApiHelper.hasHoneycomb();
        Bitmap bitmap = null;
        try {
            bitmap = BitmapFactory.decodeFile(str, options);
        } catch (OutOfMemoryError e) {
            options.inSampleSize <<= 1;
            try {
                bitmap = BitmapFactory.decodeFile(str, options);
            } catch (OutOfMemoryError e2) {
                LogUtils.e(e2);
            }
        }
        AppMethodBeat.o(49625);
        return bitmap;
    }

    public static Bitmap decodeSampledBitmapFromFile(String str, int i) {
        AppMethodBeat.i(49626);
        Options options = new Options();
        options.inSampleSize = i;
        options.inJustDecodeBounds = false;
        Bitmap bitmap = null;
        try {
            bitmap = BitmapFactory.decodeFile(str, options);
        } catch (OutOfMemoryError e) {
            options.inSampleSize <<= 1;
            try {
                bitmap = BitmapFactory.decodeFile(str, options);
            } catch (OutOfMemoryError e2) {
            }
        }
        AppMethodBeat.o(49626);
        return bitmap;
    }

    public static Bitmap decodeSampledBitmapFromFileCheckExif(String str, int i, int i2) {
        AppMethodBeat.i(49627);
        Options options = new Options();
        options.inJustDecodeBounds = true;
        BitmapFactory.decodeFile(str, options);
        options.inSampleSize = calculateInSampleSizeNew(options, i, i2, true);
        options.inJustDecodeBounds = false;
        int degreeByExif = getDegreeByExif(str) % 360;
        Bitmap bitmap = null;
        try {
            bitmap = BitmapFactory.decodeFile(str, options);
            if (degreeByExif != 0) {
                bitmap = rotateBitmap(bitmap, degreeByExif);
            }
        } catch (OutOfMemoryError e) {
            options.inSampleSize <<= 1;
            try {
                bitmap = BitmapFactory.decodeFile(str, options);
                if (degreeByExif != 0) {
                    bitmap = rotateBitmap(bitmap, degreeByExif);
                }
            } catch (OutOfMemoryError e2) {
                LogUtils.e(e2);
            }
        }
        AppMethodBeat.o(49627);
        return bitmap;
    }

    public static int getDegreeByExif(String str) {
        int i = 0;
        AppMethodBeat.i(49628);
        if (TextUtils.isEmpty(str)) {
            AppMethodBeat.o(49628);
        } else {
            try {
                i = getDegreeByOrientation(new ExifInterface(str).getAttributeInt("Orientation", 0));
                AppMethodBeat.o(49628);
            } catch (Exception e) {
                AppMethodBeat.o(49628);
            }
        }
        return i;
    }

    public static int getDegreeByOrientation(int i) {
        switch (i) {
            case 3:
                return 180;
            case 6:
                return 90;
            case 8:
                return 270;
            default:
                return 0;
        }
    }

    public static Bitmap decodeSampledBitmapFromResource(Resources resources, int i, int i2, int i3) {
        AppMethodBeat.i(49629);
        Options options = new Options();
        options.inJustDecodeBounds = true;
        BitmapFactory.decodeResource(resources, i, options);
        options.inSampleSize = calculateInSampleSizeNew(options, i2, i3, true);
        options.inJustDecodeBounds = false;
        Bitmap bitmap = null;
        try {
            bitmap = BitmapFactory.decodeResource(resources, i, options);
        } catch (Exception e) {
            LogUtils.e(e);
        } catch (OutOfMemoryError e2) {
            LogUtils.e(e2);
            try {
                options.inSampleSize *= 2;
                bitmap = BitmapFactory.decodeResource(resources, i, options);
            } catch (OutOfMemoryError e3) {
            }
        }
        AppMethodBeat.o(49629);
        return bitmap;
    }

    public static Bitmap decodeSampledBitmapFromDescriptor(FileDescriptor fileDescriptor, int i, int i2, boolean z) {
        Bitmap bitmap = null;
        AppMethodBeat.i(49630);
        Options options = new Options();
        options.inJustDecodeBounds = true;
        BitmapFactory.decodeFileDescriptor(fileDescriptor, bitmap, options);
        options.inSampleSize = calculateInSampleSizeNew(options, i, i2, true);
        options.inJustDecodeBounds = false;
        try {
            bitmap = BitmapFactory.decodeFileDescriptor(fileDescriptor, null, options);
        } catch (OutOfMemoryError e) {
            options.inSampleSize <<= 1;
            try {
                bitmap = BitmapFactory.decodeFileDescriptor(fileDescriptor, null, options);
            } catch (OutOfMemoryError e2) {
                LogUtils.e(e);
            }
        } catch (Exception e3) {
        }
        AppMethodBeat.o(49630);
        return bitmap;
    }

    public static Bitmap decodeSampledBitmapFromAssets(Context context, String str, int i, int i2) {
        AppMethodBeat.i(49631);
        if (TextUtils.isEmpty(str)) {
            AppMethodBeat.o(49631);
            return null;
        }
        InputStream open;
        Bitmap decodeStream;
        AssetManager assets = context.getAssets();
        try {
            open = assets.open(str);
        } catch (IOException e) {
            try {
                open = assets.open(str.substring(0, str.lastIndexOf(46) + 1) + "webp");
            } catch (IOException e2) {
                LogUtils.e(TAG, e2);
                AppMethodBeat.o(49631);
                return null;
            }
        }
        Options options = new Options();
        options.inJustDecodeBounds = true;
        BitmapFactory.decodeStream(open, null, options);
        options.inSampleSize = calculateInSampleSizeNew(options, i, i2, true);
        options.inJustDecodeBounds = false;
        try {
            open.reset();
            decodeStream = BitmapFactory.decodeStream(open, null, options);
        } catch (IOException e3) {
            LogUtils.e(TAG, e3);
            decodeStream = null;
        } catch (OutOfMemoryError e4) {
            options.inSampleSize <<= 1;
            try {
                open.reset();
                decodeStream = BitmapFactory.decodeStream(open, null, options);
            } catch (IOException | OutOfMemoryError e5) {
                LogUtils.e(TAG, e5);
                decodeStream = null;
            }
        }
        IOUtils.closeQuietly(open);
        AppMethodBeat.o(49631);
        return decodeStream;
    }

    public static Bitmap decodeSampleBitmapFromAssets(Context context, String str, int i) {
        Bitmap bitmap = null;
        AppMethodBeat.i(49632);
        if (TextUtils.isEmpty(str)) {
            AppMethodBeat.o(49632);
        } else {
            try {
                InputStream open = context.getAssets().open(str);
                Options options = new Options();
                options.inJustDecodeBounds = false;
                options.inSampleSize = i;
                try {
                    bitmap = BitmapFactory.decodeStream(open, null, options);
                    if (open != null) {
                        try {
                            open.close();
                        } catch (IOException e) {
                        }
                    }
                } catch (Exception e2) {
                    if (open != null) {
                        try {
                            open.close();
                        } catch (IOException e3) {
                        }
                    }
                } catch (OutOfMemoryError e4) {
                    options.inSampleSize <<= 1;
                    try {
                        open.reset();
                        bitmap = BitmapFactory.decodeStream(open, null, options);
                    } catch (IOException | OutOfMemoryError e5) {
                    }
                    if (open != null) {
                        try {
                            open.close();
                        } catch (IOException e6) {
                        }
                    }
                } catch (Throwable th) {
                    if (open != null) {
                        try {
                            open.close();
                        } catch (IOException e7) {
                        }
                    }
                    AppMethodBeat.o(49632);
                }
                AppMethodBeat.o(49632);
            } catch (IOException e8) {
                AppMethodBeat.o(49632);
            }
        }
        return bitmap;
    }

    public static Bitmap decodeSampledBitmapFromUri(Uri uri, int i, int i2) {
        String scheme;
        Throwable e;
        Bitmap bitmap;
        AppMethodBeat.i(49633);
        if (uri != null) {
            try {
                scheme = uri.getScheme();
            } catch (Exception e2) {
                e = e2;
                bitmap = null;
            }
        } else {
            scheme = null;
        }
        if (scheme != null && scheme.toLowerCase().startsWith("file")) {
            scheme = Uri.decode(uri.toString()).substring(7);
            LogUtils.v(TAG, "decodeSampledBitmapFromUri(), file = ".concat(String.valueOf(scheme)));
            bitmap = decodeSampledBitmapFromFileCheckExif(scheme, i, i2);
        } else if (uri != null) {
            scheme = Uri.decode(uri.toString());
            LogUtils.v(TAG, "decodeSampledBitmapFromUri() in else , file = ".concat(String.valueOf(scheme)));
            bitmap = decodeSampledBitmapFromFileCheckExif(scheme, i, i2);
        } else {
            bitmap = null;
        }
        if (bitmap != null) {
            try {
                LogUtils.v(TAG, "decodeSampledBitmapFromUri(), width = " + bitmap.getWidth() + ", height = " + bitmap.getHeight());
            } catch (Exception e3) {
                e = e3;
                try {
                    LogUtils.e(e);
                    IOUtils.closeQuietly(null);
                    IOUtils.closeQuietly(null);
                    AppMethodBeat.o(49633);
                    return bitmap;
                } catch (Throwable th) {
                    IOUtils.closeQuietly(null);
                    IOUtils.closeQuietly(null);
                    AppMethodBeat.o(49633);
                }
            }
        }
        IOUtils.closeQuietly(null);
        IOUtils.closeQuietly(null);
        AppMethodBeat.o(49633);
        return bitmap;
    }

    public static Bitmap getBitmapFromURL(String str) {
        AppMethodBeat.i(49634);
        try {
            HttpURLConnection httpURLConnection = (HttpURLConnection) new URL(str).openConnection();
            httpURLConnection.setDoInput(true);
            httpURLConnection.connect();
            Bitmap decodeStream = BitmapFactory.decodeStream(httpURLConnection.getInputStream());
            AppMethodBeat.o(49634);
            return decodeStream;
        } catch (IOException e) {
            AppMethodBeat.o(49634);
            return null;
        }
    }

    /* JADX WARNING: Unknown top exception splitter block from list: {B:18:0x004a=Splitter:B:18:0x004a, B:14:0x003d=Splitter:B:14:0x003d} */
    public static com.tencent.ttpic.baseutils.BitmapUtils.SAVE_STATUS saveBitmap(android.graphics.Bitmap r5, java.lang.String r6) {
        /*
        r4 = 49635; // 0xc1e3 float:6.9553E-41 double:2.4523E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r4);
        r1 = 0;
        r0 = new java.io.File;	 Catch:{ Exception -> 0x003c, OutOfMemoryError -> 0x0049 }
        r0.<init>(r6);	 Catch:{ Exception -> 0x003c, OutOfMemoryError -> 0x0049 }
        r2 = r0.getParentFile();	 Catch:{ Exception -> 0x003c, OutOfMemoryError -> 0x0049 }
        r3 = r2.exists();	 Catch:{ Exception -> 0x003c, OutOfMemoryError -> 0x0049 }
        if (r3 != 0) goto L_0x0019;
    L_0x0016:
        r2.mkdirs();	 Catch:{ Exception -> 0x003c, OutOfMemoryError -> 0x0049 }
    L_0x0019:
        r2 = r0.exists();	 Catch:{ Exception -> 0x003c, OutOfMemoryError -> 0x0049 }
        if (r2 != 0) goto L_0x0022;
    L_0x001f:
        r0.createNewFile();	 Catch:{ Exception -> 0x003c, OutOfMemoryError -> 0x0049 }
    L_0x0022:
        r2 = new java.io.FileOutputStream;	 Catch:{ Exception -> 0x003c, OutOfMemoryError -> 0x0049 }
        r2.<init>(r6);	 Catch:{ Exception -> 0x003c, OutOfMemoryError -> 0x0049 }
        if (r5 == 0) goto L_0x0033;
    L_0x0029:
        r0 = android.graphics.Bitmap.CompressFormat.JPEG;	 Catch:{ Exception -> 0x0064, OutOfMemoryError -> 0x0061, all -> 0x005e }
        r1 = 99;
        r5.compress(r0, r1, r2);	 Catch:{ Exception -> 0x0064, OutOfMemoryError -> 0x0061, all -> 0x005e }
        r2.flush();	 Catch:{ Exception -> 0x0064, OutOfMemoryError -> 0x0061, all -> 0x005e }
    L_0x0033:
        com.tencent.ttpic.baseutils.IOUtils.closeQuietly(r2);
        r0 = com.tencent.ttpic.baseutils.BitmapUtils.SAVE_STATUS.SAVE_SUCCESS;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r4);
    L_0x003b:
        return r0;
    L_0x003c:
        r0 = move-exception;
    L_0x003d:
        com.tencent.ttpic.baseutils.LogUtils.e(r0);	 Catch:{ all -> 0x0056 }
        r0 = com.tencent.ttpic.baseutils.BitmapUtils.SAVE_STATUS.SAVE_FAILED;	 Catch:{ all -> 0x0056 }
        com.tencent.ttpic.baseutils.IOUtils.closeQuietly(r1);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r4);
        goto L_0x003b;
    L_0x0049:
        r0 = move-exception;
    L_0x004a:
        com.tencent.ttpic.baseutils.LogUtils.e(r0);	 Catch:{ all -> 0x0056 }
        r0 = com.tencent.ttpic.baseutils.BitmapUtils.SAVE_STATUS.SAVE_OOM;	 Catch:{ all -> 0x0056 }
        com.tencent.ttpic.baseutils.IOUtils.closeQuietly(r1);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r4);
        goto L_0x003b;
    L_0x0056:
        r0 = move-exception;
    L_0x0057:
        com.tencent.ttpic.baseutils.IOUtils.closeQuietly(r1);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r4);
        throw r0;
    L_0x005e:
        r0 = move-exception;
        r1 = r2;
        goto L_0x0057;
    L_0x0061:
        r0 = move-exception;
        r1 = r2;
        goto L_0x004a;
    L_0x0064:
        r0 = move-exception;
        r1 = r2;
        goto L_0x003d;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.ttpic.baseutils.BitmapUtils.saveBitmap(android.graphics.Bitmap, java.lang.String):com.tencent.ttpic.baseutils.BitmapUtils$SAVE_STATUS");
    }

    /* JADX WARNING: Removed duplicated region for block: B:39:0x0093  */
    /* JADX WARNING: Removed duplicated region for block: B:23:0x0050  */
    /* JADX WARNING: Removed duplicated region for block: B:36:0x008b A:{Splitter:B:7:0x0016, ExcHandler: all (th java.lang.Throwable)} */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing block: B:31:0x0080, code skipped:
            r2 = e;
     */
    /* JADX WARNING: Missing block: B:32:0x0081, code skipped:
            r3 = null;
            r4 = null;
     */
    /* JADX WARNING: Missing block: B:36:0x008b, code skipped:
            r0 = th;
     */
    public static java.io.File saveBitmap(android.content.Context r6, android.graphics.Bitmap r7, java.lang.String r8, java.lang.String r9, android.graphics.Bitmap.CompressFormat r10, java.lang.String r11) {
        /*
        r1 = 0;
        r5 = 49636; // 0xc1e4 float:6.9555E-41 double:2.45234E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r5);
        if (r8 != 0) goto L_0x0055;
    L_0x0009:
        if (r6 == 0) goto L_0x0015;
    L_0x000b:
        r0 = r6.getCacheDir();
        if (r0 == 0) goto L_0x0015;
    L_0x0011:
        r8 = r0.getAbsolutePath();
    L_0x0015:
        r0 = 0;
        r2 = android.graphics.Bitmap.CompressFormat.PNG;	 Catch:{ Exception -> 0x0080, all -> 0x008b }
        if (r10 != r2) goto L_0x006b;
    L_0x001a:
        r2 = new java.lang.StringBuilder;	 Catch:{ Exception -> 0x0080, all -> 0x008b }
        r2.<init>();	 Catch:{ Exception -> 0x0080, all -> 0x008b }
        r2 = r2.append(r9);	 Catch:{ Exception -> 0x0080, all -> 0x008b }
        r3 = ".png";
        r2 = r2.append(r3);	 Catch:{ Exception -> 0x0080, all -> 0x008b }
        r2 = r2.toString();	 Catch:{ Exception -> 0x0080, all -> 0x008b }
    L_0x002e:
        r4 = new java.io.File;	 Catch:{ Exception -> 0x0080, all -> 0x008b }
        r4.<init>(r8, r2);	 Catch:{ Exception -> 0x0080, all -> 0x008b }
        r3 = new java.io.FileOutputStream;	 Catch:{ Exception -> 0x009b, all -> 0x008b }
        r3.<init>(r4);	 Catch:{ Exception -> 0x009b, all -> 0x008b }
        r2 = android.graphics.Bitmap.CompressFormat.JPEG;	 Catch:{ Exception -> 0x009e }
        if (r10 != r2) goto L_0x0044;
    L_0x003c:
        if (r11 == 0) goto L_0x0044;
    L_0x003e:
        r2 = r11.length();	 Catch:{ Exception -> 0x009e }
        if (r2 > 0) goto L_0x004a;
    L_0x0044:
        r2 = 99;
        r0 = r7.compress(r10, r2, r3);	 Catch:{ Exception -> 0x009e }
    L_0x004a:
        com.tencent.ttpic.baseutils.IOUtils.closeQuietly(r3);
        r2 = r4;
    L_0x004e:
        if (r0 == 0) goto L_0x0093;
    L_0x0050:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
        r0 = r2;
    L_0x0054:
        return r0;
    L_0x0055:
        r0 = new java.io.File;
        r0.<init>(r8);
        r2 = r0.isDirectory();
        if (r2 != 0) goto L_0x0015;
    L_0x0060:
        r0 = r0.mkdirs();
        if (r0 != 0) goto L_0x0015;
    L_0x0066:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
        r0 = r1;
        goto L_0x0054;
    L_0x006b:
        r2 = new java.lang.StringBuilder;	 Catch:{ Exception -> 0x0080, all -> 0x008b }
        r2.<init>();	 Catch:{ Exception -> 0x0080, all -> 0x008b }
        r2 = r2.append(r9);	 Catch:{ Exception -> 0x0080, all -> 0x008b }
        r3 = ".jpg";
        r2 = r2.append(r3);	 Catch:{ Exception -> 0x0080, all -> 0x008b }
        r2 = r2.toString();	 Catch:{ Exception -> 0x0080, all -> 0x008b }
        goto L_0x002e;
    L_0x0080:
        r2 = move-exception;
        r3 = r1;
        r4 = r1;
    L_0x0083:
        com.tencent.ttpic.baseutils.LogUtils.e(r2);	 Catch:{ all -> 0x0098 }
        com.tencent.ttpic.baseutils.IOUtils.closeQuietly(r3);
        r2 = r4;
        goto L_0x004e;
    L_0x008b:
        r0 = move-exception;
    L_0x008c:
        com.tencent.ttpic.baseutils.IOUtils.closeQuietly(r1);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
        throw r0;
    L_0x0093:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
        r0 = r1;
        goto L_0x0054;
    L_0x0098:
        r0 = move-exception;
        r1 = r3;
        goto L_0x008c;
    L_0x009b:
        r2 = move-exception;
        r3 = r1;
        goto L_0x0083;
    L_0x009e:
        r2 = move-exception;
        goto L_0x0083;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.ttpic.baseutils.BitmapUtils.saveBitmap(android.content.Context, android.graphics.Bitmap, java.lang.String, java.lang.String, android.graphics.Bitmap$CompressFormat, java.lang.String):java.io.File");
    }

    /* JADX WARNING: Unknown top exception splitter block from list: {B:18:0x004a=Splitter:B:18:0x004a, B:14:0x003d=Splitter:B:14:0x003d} */
    public static com.tencent.ttpic.baseutils.BitmapUtils.SAVE_STATUS saveBitmap2PNG(android.graphics.Bitmap r5, java.lang.String r6) {
        /*
        r4 = 49637; // 0xc1e5 float:6.9556E-41 double:2.4524E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r4);
        r1 = 0;
        r0 = new java.io.File;	 Catch:{ Exception -> 0x003c, OutOfMemoryError -> 0x0049 }
        r0.<init>(r6);	 Catch:{ Exception -> 0x003c, OutOfMemoryError -> 0x0049 }
        r2 = r0.getParentFile();	 Catch:{ Exception -> 0x003c, OutOfMemoryError -> 0x0049 }
        r3 = r2.exists();	 Catch:{ Exception -> 0x003c, OutOfMemoryError -> 0x0049 }
        if (r3 != 0) goto L_0x0019;
    L_0x0016:
        r2.mkdirs();	 Catch:{ Exception -> 0x003c, OutOfMemoryError -> 0x0049 }
    L_0x0019:
        r2 = r0.exists();	 Catch:{ Exception -> 0x003c, OutOfMemoryError -> 0x0049 }
        if (r2 != 0) goto L_0x0022;
    L_0x001f:
        r0.createNewFile();	 Catch:{ Exception -> 0x003c, OutOfMemoryError -> 0x0049 }
    L_0x0022:
        r2 = new java.io.FileOutputStream;	 Catch:{ Exception -> 0x003c, OutOfMemoryError -> 0x0049 }
        r2.<init>(r6);	 Catch:{ Exception -> 0x003c, OutOfMemoryError -> 0x0049 }
        if (r5 == 0) goto L_0x0033;
    L_0x0029:
        r0 = android.graphics.Bitmap.CompressFormat.PNG;	 Catch:{ Exception -> 0x0064, OutOfMemoryError -> 0x0061, all -> 0x005e }
        r1 = 99;
        r5.compress(r0, r1, r2);	 Catch:{ Exception -> 0x0064, OutOfMemoryError -> 0x0061, all -> 0x005e }
        r2.flush();	 Catch:{ Exception -> 0x0064, OutOfMemoryError -> 0x0061, all -> 0x005e }
    L_0x0033:
        com.tencent.ttpic.baseutils.IOUtils.closeQuietly(r2);
        r0 = com.tencent.ttpic.baseutils.BitmapUtils.SAVE_STATUS.SAVE_SUCCESS;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r4);
    L_0x003b:
        return r0;
    L_0x003c:
        r0 = move-exception;
    L_0x003d:
        com.tencent.ttpic.baseutils.LogUtils.e(r0);	 Catch:{ all -> 0x0056 }
        r0 = com.tencent.ttpic.baseutils.BitmapUtils.SAVE_STATUS.SAVE_FAILED;	 Catch:{ all -> 0x0056 }
        com.tencent.ttpic.baseutils.IOUtils.closeQuietly(r1);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r4);
        goto L_0x003b;
    L_0x0049:
        r0 = move-exception;
    L_0x004a:
        com.tencent.ttpic.baseutils.LogUtils.e(r0);	 Catch:{ all -> 0x0056 }
        r0 = com.tencent.ttpic.baseutils.BitmapUtils.SAVE_STATUS.SAVE_OOM;	 Catch:{ all -> 0x0056 }
        com.tencent.ttpic.baseutils.IOUtils.closeQuietly(r1);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r4);
        goto L_0x003b;
    L_0x0056:
        r0 = move-exception;
    L_0x0057:
        com.tencent.ttpic.baseutils.IOUtils.closeQuietly(r1);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r4);
        throw r0;
    L_0x005e:
        r0 = move-exception;
        r1 = r2;
        goto L_0x0057;
    L_0x0061:
        r0 = move-exception;
        r1 = r2;
        goto L_0x004a;
    L_0x0064:
        r0 = move-exception;
        r1 = r2;
        goto L_0x003d;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.ttpic.baseutils.BitmapUtils.saveBitmap2PNG(android.graphics.Bitmap, java.lang.String):com.tencent.ttpic.baseutils.BitmapUtils$SAVE_STATUS");
    }

    public static Bitmap correctImageToFitIn(Bitmap bitmap, int i, int i2) {
        AppMethodBeat.i(49638);
        Bitmap bitmap2 = null;
        if (bitmap != null) {
            int width = bitmap.getWidth();
            int height = bitmap.getHeight();
            if (width <= i && height <= i2) {
                bitmap2 = Bitmap.createScaledBitmap(bitmap, width, height, true);
            } else if ((((double) i2) * 1.0d) / ((double) height) > (((double) i) * 1.0d) / ((double) width)) {
                bitmap2 = Bitmap.createScaledBitmap(bitmap, i, (int) (((double) height) * ((((double) i) * 1.0d) / ((double) width))), true);
            } else {
                bitmap2 = Bitmap.createScaledBitmap(bitmap, (int) (((double) width) * ((((double) i2) * 1.0d) / ((double) height))), i2, true);
            }
        }
        AppMethodBeat.o(49638);
        return bitmap2;
    }

    public static Bitmap scaleBitmapUnderLimit(Bitmap bitmap, int i) {
        Object obj = null;
        AppMethodBeat.i(49639);
        float f = 1.0f;
        Bitmap bitmap2 = bitmap;
        while (obj == null) {
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            try {
                bitmap2 = scaleBitmap(bitmap2, f, false);
                bitmap2.compress(CompressFormat.JPEG, 85, byteArrayOutputStream);
                if (byteArrayOutputStream.toByteArray().length <= i) {
                    obj = 1;
                }
                f *= 0.7f;
            } catch (OutOfMemoryError e) {
                if (bitmap2.getHeight() < 10 || bitmap2.getWidth() < 10) {
                    obj = 1;
                }
                f *= 0.7f;
            } catch (Throwable th) {
                AppMethodBeat.o(49639);
            }
        }
        AppMethodBeat.o(49639);
        return bitmap2;
    }

    public static Bitmap decodeBitmapFromFileForShare(String str, int i, int i2, int[] iArr) {
        Bitmap bitmap = null;
        int i3 = 1;
        AppMethodBeat.i(49640);
        LogUtils.d(TAG, "decodeBitmapFromFileForShare(%s, %d, %d, %s)", new Object[]{str, Integer.valueOf(i), Integer.valueOf(i2), iArr});
        if (TextUtils.isEmpty(str)) {
            AppMethodBeat.o(49640);
        } else if (new File(str).exists()) {
            int degreeByExif = getDegreeByExif(str);
            try {
                Options options = new Options();
                options.inJustDecodeBounds = true;
                BitmapFactory.decodeFile(str, options);
                Size size = new Size(options.outWidth, options.outHeight);
                LogUtils.v(TAG, "decodeBitmapFromFileForShare(), outer width = " + options.outWidth + ", height = " + options.outHeight);
                if (iArr != null && iArr.length == 2) {
                    iArr[0] = options.outWidth;
                    iArr[1] = options.outHeight;
                }
                boolean shouldResize = shouldResize(size, i, i2);
                if (shouldResize) {
                    size = calcNewSize(size, i, i2);
                }
                options.inJustDecodeBounds = false;
                if (shouldResize) {
                    i3 = calculateInSampleSizeNew(options, size.width, size.height, true);
                }
                LogUtils.v(TAG, "decodeBitmapFromFileForShare(), inSampleSize = ".concat(String.valueOf(i3)));
                options.inSampleSize = i3;
                Bitmap decodeFile = BitmapFactory.decodeFile(str, options);
                if (degreeByExif != 0) {
                    decodeFile = rotateBitmap(decodeFile, degreeByExif);
                }
                if (decodeFile != null) {
                    bitmap = getFinalBitmap(decodeFile, i, i2);
                    AppMethodBeat.o(49640);
                } else {
                    AppMethodBeat.o(49640);
                }
            } catch (Exception e) {
                LogUtils.e(e);
                AppMethodBeat.o(49640);
            } catch (OutOfMemoryError e2) {
                LogUtils.e(e2);
                AppMethodBeat.o(49640);
            }
        } else {
            AppMethodBeat.o(49640);
        }
        return bitmap;
    }

    public static Bitmap decodeBitmapFromFileExtForShare(String str, int i, int i2, int i3) {
        Bitmap bitmap = null;
        AppMethodBeat.i(49641);
        LogUtils.d(TAG, "decodeBitmapFromFileExtForShare(%s, %d, %d, %d)", new Object[]{str, Integer.valueOf(i), Integer.valueOf(i2), Integer.valueOf(i3)});
        if (TextUtils.isEmpty(str)) {
            AppMethodBeat.o(49641);
            return null;
        } else if (new File(str).exists()) {
            Bitmap bitmap2;
            int degreeByExif = getDegreeByExif(str);
            int i4;
            int i5;
            if (i < i2) {
                i4 = i;
                i5 = i2;
            } else {
                i4 = i2;
                i5 = i;
            }
            Options options = new Options();
            options.inJustDecodeBounds = true;
            BitmapFactory.decodeFile(str, options);
            int i6 = options.outWidth > options.outHeight ? options.outWidth : options.outHeight;
            int i7 = options.outWidth < options.outHeight ? options.outWidth : options.outHeight;
            options.inJustDecodeBounds = false;
            options.inSampleSize = 1;
            do {
                try {
                    bitmap = BitmapFactory.decodeFile(str, options);
                } catch (OutOfMemoryError e) {
                    options.inSampleSize *= 2;
                    LogUtils.w(TAG, "[decodeBitmapFromFileExtForShare] " + e.getMessage());
                }
                if (bitmap != null || (i6 / options.inSampleSize < i5 && i7 / options.inSampleSize < i4)) {
                    if (bitmap != null || degreeByExif == 0) {
                        bitmap2 = bitmap;
                    } else {
                        bitmap2 = rotateBitmap(bitmap, degreeByExif);
                    }
                }
            } while (options.inSampleSize <= i3);
            if (bitmap != null) {
            }
            bitmap2 = bitmap;
            AppMethodBeat.o(49641);
            return bitmap2;
        } else {
            AppMethodBeat.o(49641);
            return null;
        }
    }

    public static String compressImage(String str, Options options, int i, int i2) {
        AppMethodBeat.i(49642);
        try {
            String compressImageFile = compressImageFile(str, getScaledOpt(options, i, i2), new File(Environment.getExternalStorageDirectory().getAbsolutePath() + File.separatorChar + "Pitu"));
            AppMethodBeat.o(49642);
            return compressImageFile;
        } catch (Exception e) {
            LogUtils.e(e);
            AppMethodBeat.o(49642);
            return null;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:40:0x00b2 A:{SYNTHETIC, Splitter:B:40:0x00b2} */
    /* JADX WARNING: Removed duplicated region for block: B:34:0x00a7 A:{SYNTHETIC, Splitter:B:34:0x00a7} */
    private static java.lang.String compressImageFile(java.lang.String r7, android.graphics.BitmapFactory.Options r8, java.io.File r9) {
        /*
        r5 = 1;
        r0 = 0;
        r6 = 49643; // 0xc1eb float:6.9565E-41 double:2.4527E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r6);
        r1 = TAG;
        r2 = "compressImageFile(%s, %s, %s)";
        r3 = 3;
        r3 = new java.lang.Object[r3];
        r4 = 0;
        r3[r4] = r7;
        r3[r5] = r8;
        r4 = 2;
        r5 = r9.getAbsolutePath();
        r3[r4] = r5;
        com.tencent.ttpic.baseutils.LogUtils.d(r1, r2, r3);
        r1 = r9.exists();
        if (r1 != 0) goto L_0x0028;
    L_0x0025:
        r9.mkdirs();
    L_0x0028:
        r1 = new java.lang.StringBuilder;
        r1.<init>();
        r2 = r9.getAbsolutePath();
        r1 = r1.append(r2);
        r2 = java.io.File.separator;
        r1 = r1.append(r2);
        r2 = "topic_thumb_temp_";
        r1 = r1.append(r2);
        r2 = new java.util.Date;
        r2.<init>();
        r2 = r2.getTime();
        r1 = r1.append(r2);
        r1 = r1.toString();
        r3 = new java.io.File;
        r3.<init>(r1);
        r2 = r3.exists();	 Catch:{ Exception -> 0x00a0, all -> 0x00ae }
        if (r2 != 0) goto L_0x0061;
    L_0x005e:
        r3.createNewFile();	 Catch:{ Exception -> 0x00a0, all -> 0x00ae }
    L_0x0061:
        r2 = new java.io.FileOutputStream;	 Catch:{ Exception -> 0x00a0, all -> 0x00ae }
        r2.<init>(r3);	 Catch:{ Exception -> 0x00a0, all -> 0x00ae }
        r3 = r8.outMimeType;	 Catch:{ Exception -> 0x00c4 }
        r3 = IsSupportImgType(r3);	 Catch:{ Exception -> 0x00c4 }
        if (r3 != 0) goto L_0x0088;
    L_0x006e:
        r3 = android.graphics.Bitmap.Config.RGB_565;	 Catch:{ Exception -> 0x00c4 }
        r8.inPreferredConfig = r3;	 Catch:{ Exception -> 0x00c4 }
        r3 = 1;
        r8.inPurgeable = r3;	 Catch:{ Exception -> 0x00c4 }
        r3 = 1;
        r8.inInputShareable = r3;	 Catch:{ Exception -> 0x00c4 }
        r3 = android.graphics.BitmapFactory.decodeFile(r7, r8);	 Catch:{ OutOfMemoryError -> 0x0093 }
    L_0x007c:
        if (r3 == 0) goto L_0x0099;
    L_0x007e:
        r4 = android.graphics.Bitmap.CompressFormat.JPEG;	 Catch:{ Exception -> 0x00c4 }
        r5 = 90;
        r3.compress(r4, r5, r2);	 Catch:{ Exception -> 0x00c4 }
        r3.recycle();	 Catch:{ Exception -> 0x00c4 }
    L_0x0088:
        r2.close();	 Catch:{ Exception -> 0x00c4 }
        r2.close();	 Catch:{ IOException -> 0x00bb }
    L_0x008e:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r6);
        r0 = r1;
    L_0x0092:
        return r0;
    L_0x0093:
        r3 = move-exception;
        com.tencent.ttpic.baseutils.LogUtils.e(r3);	 Catch:{ Exception -> 0x00c4 }
        r3 = r0;
        goto L_0x007c;
    L_0x0099:
        r2.close();	 Catch:{ IOException -> 0x00b9 }
    L_0x009c:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r6);
        goto L_0x0092;
    L_0x00a0:
        r1 = move-exception;
        r2 = r0;
    L_0x00a2:
        com.tencent.ttpic.baseutils.LogUtils.e(r1);	 Catch:{ all -> 0x00c1 }
        if (r2 == 0) goto L_0x00aa;
    L_0x00a7:
        r2.close();	 Catch:{ IOException -> 0x00bd }
    L_0x00aa:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r6);
        goto L_0x0092;
    L_0x00ae:
        r1 = move-exception;
        r2 = r0;
    L_0x00b0:
        if (r2 == 0) goto L_0x00b5;
    L_0x00b2:
        r2.close();	 Catch:{ IOException -> 0x00bf }
    L_0x00b5:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r6);
        throw r1;
    L_0x00b9:
        r1 = move-exception;
        goto L_0x009c;
    L_0x00bb:
        r0 = move-exception;
        goto L_0x008e;
    L_0x00bd:
        r1 = move-exception;
        goto L_0x00aa;
    L_0x00bf:
        r0 = move-exception;
        goto L_0x00b5;
    L_0x00c1:
        r0 = move-exception;
        r1 = r0;
        goto L_0x00b0;
    L_0x00c4:
        r1 = move-exception;
        goto L_0x00a2;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.ttpic.baseutils.BitmapUtils.compressImageFile(java.lang.String, android.graphics.BitmapFactory$Options, java.io.File):java.lang.String");
    }

    private static Options getScaledOpt(Options options, int i, int i2) {
        AppMethodBeat.i(49644);
        Options options2 = new Options();
        options2.inSampleSize = calculateInSampleSizeNew(options, i, i2, false);
        options2.inJustDecodeBounds = false;
        AppMethodBeat.o(49644);
        return options2;
    }

    private static boolean IsSupportImgType(String str) {
        AppMethodBeat.i(49645);
        boolean z = false;
        if (str != null && (str.equalsIgnoreCase("image/jpeg") || str.equalsIgnoreCase("image/png") || str.equalsIgnoreCase("image/gif"))) {
            z = true;
        }
        AppMethodBeat.o(49645);
        return z;
    }

    private static boolean shouldResize(Size size, int i, int i2) {
        int i3;
        int i4;
        if (((double) (((float) size.height) / ((float) size.width))) >= 1.0d) {
            i4 = size.height;
            i3 = size.width;
        } else {
            i4 = size.width;
            i3 = size.height;
        }
        if (i3 >= i || i4 >= i2) {
            return true;
        }
        return false;
    }

    private static Size calcNewSize(Size size, int i, int i2) {
        int i3;
        int i4;
        AppMethodBeat.i(49646);
        if (((double) (((float) size.height) / ((float) size.width))) >= 1.0d) {
            i3 = size.height;
            i4 = size.width;
        } else {
            i3 = size.width;
            i4 = size.height;
        }
        Size newSize = getNewSize(i4, i3, i, i2);
        AppMethodBeat.o(49646);
        return newSize;
    }

    private static Size getNewSize(int i, int i2, int i3, int i4) {
        AppMethodBeat.i(49647);
        float min = Math.min(((float) i3) / ((float) i), ((float) i4) / ((float) i2));
        Size size;
        if (((double) min) < 1.0d) {
            size = new Size((int) (((float) i) * min), (int) (min * ((float) i2)));
            AppMethodBeat.o(49647);
            return size;
        }
        size = new Size(i, i2);
        AppMethodBeat.o(49647);
        return size;
    }

    private static Bitmap getFinalBitmap(Bitmap bitmap, int i, int i2) {
        AppMethodBeat.i(49648);
        int max = Math.max(bitmap.getWidth(), bitmap.getHeight());
        int min = Math.min(bitmap.getWidth(), bitmap.getHeight());
        if (max > i2 || min > i) {
            float min2 = Math.min(((float) i2) / ((float) max), ((float) i) / ((float) min));
            Matrix matrix = new Matrix();
            matrix.setScale(min2, min2);
            Bitmap createBitmap = Bitmap.createBitmap((int) (((float) bitmap.getWidth()) * min2), (int) (min2 * ((float) bitmap.getHeight())), Config.ARGB_8888);
            Paint paint = new Paint();
            paint.setAntiAlias(true);
            paint.setDither(true);
            paint.setFilterBitmap(true);
            new Canvas(createBitmap).drawBitmap(bitmap, matrix, paint);
            recycle(bitmap);
            AppMethodBeat.o(49648);
            return createBitmap;
        }
        AppMethodBeat.o(49648);
        return bitmap;
    }

    public static void drawRepeatBitmap(Bitmap bitmap, Rect rect, Rect rect2, Canvas canvas, float f, Paint paint) {
        AppMethodBeat.i(49649);
        int i = rect2.top;
        int i2 = rect2.bottom;
        int i3 = rect2.left;
        int i4 = rect2.right;
        int width = (int) (((((float) rect2.width()) / f) / ((float) rect.width())) + 1.0f);
        int height = (int) (((((float) rect2.height()) / f) / ((float) rect.height())) + 1.0f);
        canvas.save();
        canvas.clipRect(rect2);
        for (int i5 = 0; i5 < height; i5++) {
            for (int i6 = 0; i6 < width; i6++) {
                rect2.set((int) (((float) i3) + (((float) (rect.width() * i6)) * f)), (int) (((float) i) + (((float) (rect.height() * i5)) * f)), (int) ((((float) i3) + (((float) (rect.width() * i6)) * f)) + (((float) rect.width()) * f)), (int) ((((float) i) + (((float) (rect.height() * i5)) * f)) + (((float) rect.height()) * f)));
                canvas.drawBitmap(bitmap, rect, rect2, paint);
            }
        }
        canvas.restore();
        rect2.set(i3, i, i4, i2);
        AppMethodBeat.o(49649);
    }

    public static int calculateInSampleSize(Options options, int i, int i2, boolean z) {
        AppMethodBeat.i(49650);
        int i3 = options.outHeight;
        int i4 = options.outWidth;
        int i5 = 1;
        if ((i2 > 0 && i3 > i2) || (i > 0 && i4 > i)) {
            i5 = Math.round(((float) i3) / ((float) i2));
            int round = Math.round(((float) i4) / ((float) i));
            if (!z) {
                if (i5 >= round) {
                    round = i5;
                }
                i5 = round;
            } else if (i5 >= round) {
                i5 = round;
            }
            float f = (float) (i4 * i3);
            float f2 = (float) ((i * i2) * 2);
            if (ApiHelper.hasNougat()) {
                while (f / ((float) (i5 * i5)) >= f2) {
                    i5++;
                }
                if (z && (((double) (i4 / i5)) > ((double) i) * 1.5d || ((double) (i3 / i5)) > ((double) i2) * 1.5d)) {
                    i5 = i4 / i;
                    round = i3 / i2;
                    if (i5 <= round) {
                        i5 = round;
                    }
                }
            } else {
                while (f / ((float) (i5 * i5)) > f2) {
                    i5++;
                }
                if (isPowerOf2(i5)) {
                    round = i5;
                } else {
                    round = i5;
                    while (round > 2 && !isPowerOf2(round)) {
                        round--;
                    }
                }
                if (z && (((double) (i4 / round)) > ((double) i) * 1.5d || ((double) (i3 / round)) > ((double) i2) * 1.5d)) {
                    i5 = round * 2;
                }
            }
        }
        LogUtils.d(TAG, "[calculateInSampleSize] source size = " + i4 + " * " + i3 + ", request size = " + i + " * " + i2 + ", inSampleSize = " + i5 + ", preferLarge = " + z);
        AppMethodBeat.o(49650);
        return i5;
    }

    public static int calculateInSampleSizeNew(Options options, int i, int i2, boolean z) {
        AppMethodBeat.i(49651);
        int i3 = options.outHeight;
        int i4 = options.outWidth;
        float max = (float) Math.max(i4, i3);
        float min = (float) Math.min(i4, i3);
        float max2 = (float) Math.max(i, i2);
        if (((float) Math.min(i, i2)) <= 0.0f || max <= max2) {
            AppMethodBeat.o(49651);
            return 1;
        }
        if (max / min > 2.0f) {
            float f = (float) (i3 * i4);
            max = (float) (i * i2);
            if (ApiHelper.hasNougat()) {
                i3 = 1;
                while (f / ((float) (i3 * i3)) >= max) {
                    i3++;
                }
                if (z && i3 > 1) {
                    i3--;
                }
            } else {
                i3 = 1;
                while (f / ((float) (i3 * i3)) >= max) {
                    i3 *= 2;
                }
                if (z && i3 > 1) {
                    i3 /= 2;
                }
            }
        } else if (ApiHelper.hasNougat()) {
            i3 = 1;
            while (max / ((float) i3) >= max2) {
                i3++;
            }
            if (z && i3 > 1) {
                i3--;
            }
        } else {
            i3 = 1;
            while (max / ((float) i3) >= max2) {
                i3 *= 2;
            }
            if (z && i3 > 1) {
                i3 /= 2;
            }
        }
        AppMethodBeat.o(49651);
        return i3;
    }

    private static boolean isPowerOf2(int i) {
        return ((i + -1) & i) == 0;
    }
}
