package com.tencent.ttpic.baseutils;

import android.content.Context;
import android.content.res.AssetManager;
import android.os.AsyncTask;
import android.text.TextUtils;
import android.util.Base64OutputStream;
import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.ytcommon.BuildConfig;
import java.io.BufferedOutputStream;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.ByteArrayOutputStream;
import java.io.Closeable;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.Reader;
import java.io.Writer;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;

public class FileUtils {
    public static final String PIC_POSTFIX_JPEG = ".jpg";
    public static final String PIC_POSTFIX_PNG = ".png";
    public static final String PIC_POSTFIX_WEBP = ".webp";
    public static final String RES_PREFIX_ASSETS = "assets://";
    public static final String RES_PREFIX_HTTP = "http://";
    public static final String RES_PREFIX_HTTPS = "https://";
    public static final String RES_PREFIX_STORAGE = "/";
    public static final AssetFileComparator SIMPLE_ASSET_COMPARATOR = new 2();
    private static final String TAG = FileUtils.class.getSimpleName();

    static /* synthetic */ long access$000(Context context, String str) {
        AppMethodBeat.i(49715);
        long assetLength = getAssetLength(context, str);
        AppMethodBeat.o(49715);
        return assetLength;
    }

    static {
        AppMethodBeat.i(49716);
        AppMethodBeat.o(49716);
    }

    public static String checkPhoto(String str) {
        AppMethodBeat.i(49678);
        if (TextUtils.isEmpty(str)) {
            AppMethodBeat.o(49678);
            return null;
        } else if (new File(str).exists()) {
            AppMethodBeat.o(49678);
            return str;
        } else {
            if (str.substring(str.lastIndexOf("/")).lastIndexOf(".") == -1) {
                String str2 = str + PIC_POSTFIX_JPEG;
                if (new File(str2).exists()) {
                    AppMethodBeat.o(49678);
                    return str2;
                }
                str2 = str + PIC_POSTFIX_PNG;
                if (new File(str2).exists()) {
                    AppMethodBeat.o(49678);
                    return str2;
                }
            }
            AppMethodBeat.o(49678);
            return str;
        }
    }

    public static String checkAssetsPhoto(Context context, String str) {
        InputStream inputStream = null;
        AppMethodBeat.i(49679);
        if (TextUtils.isEmpty(str)) {
            AppMethodBeat.o(49679);
            return inputStream;
        }
        AssetManager assets = context.getAssets();
        try {
            inputStream = assets.open(str);
            return str;
        } catch (IOException e) {
            IOUtils.closeQuietly(inputStream);
            if (str.lastIndexOf(".") != -1) {
                str = str.substring(0, str.lastIndexOf(46) + 1) + "webp";
                try {
                    inputStream = assets.open(str);
                    return str;
                } catch (IOException e2) {
                    IOUtils.closeQuietly(inputStream);
                    AppMethodBeat.o(49679);
                    return inputStream;
                } catch (Throwable th) {
                    IOUtils.closeQuietly(inputStream);
                    AppMethodBeat.o(49679);
                }
            }
            String str2 = str + PIC_POSTFIX_JPEG;
            try {
                inputStream = assets.open(str2);
                return str2;
            } catch (IOException e3) {
                IOUtils.closeQuietly(inputStream);
                str2 = str + PIC_POSTFIX_WEBP;
                try {
                    inputStream = assets.open(str2);
                    return str2;
                } catch (IOException e4) {
                    IOUtils.closeQuietly(inputStream);
                    str = str + PIC_POSTFIX_PNG;
                    try {
                        inputStream = assets.open(str);
                        return str;
                    } catch (IOException e5) {
                        return inputStream;
                    } finally {
                        IOUtils.closeQuietly(inputStream);
                        AppMethodBeat.o(49679);
                    }
                } catch (Throwable th2) {
                    IOUtils.closeQuietly(inputStream);
                    AppMethodBeat.o(49679);
                }
            } finally {
                IOUtils.closeQuietly(inputStream);
                AppMethodBeat.o(49679);
            }
        } finally {
            IOUtils.closeQuietly(inputStream);
            AppMethodBeat.o(49679);
        }
    }

    public static boolean isDirectoryWritable(String str) {
        boolean z = false;
        AppMethodBeat.i(49680);
        File file = new File(str);
        if (!file.exists() || file.isDirectory()) {
            if (!file.exists()) {
                file.mkdirs();
            }
            if (file.isDirectory()) {
                try {
                    z = file.canWrite();
                    AppMethodBeat.o(49680);
                } catch (Exception e) {
                }
            }
            AppMethodBeat.o(49680);
        } else {
            AppMethodBeat.o(49680);
        }
        return z;
    }

    public static String getRealPath(String str) {
        AppMethodBeat.i(49681);
        if (TextUtils.isEmpty(str) || !str.startsWith("assets://")) {
            AppMethodBeat.o(49681);
            return str;
        }
        str = str.substring(9);
        AppMethodBeat.o(49681);
        return str;
    }

    public static String getFileNameByPath(String str) {
        AppMethodBeat.i(49682);
        LogUtils.v(TAG, "[getFileNameByPath] path = ".concat(String.valueOf(str)));
        Object obj = null;
        if (!TextUtils.isEmpty(str)) {
            int indexOf = str.indexOf(".");
            int lastIndexOf = str.lastIndexOf("/");
            if (lastIndexOf >= 0 && indexOf > lastIndexOf) {
                obj = str.substring(lastIndexOf + 1, indexOf);
            }
        }
        LogUtils.v(TAG, "[getFileNameByPath] return title = ".concat(String.valueOf(obj)));
        AppMethodBeat.o(49682);
        return obj;
    }

    public static String getFileNameFromUrl(String str) {
        AppMethodBeat.i(49683);
        if (str == null) {
            AppMethodBeat.o(49683);
            return null;
        }
        int lastIndexOf = str.lastIndexOf("/");
        if (lastIndexOf == -1) {
            AppMethodBeat.o(49683);
            return null;
        } else if (lastIndexOf == str.length() - 1) {
            AppMethodBeat.o(49683);
            return null;
        } else {
            String substring = str.substring(lastIndexOf + 1);
            AppMethodBeat.o(49683);
            return substring;
        }
    }

    public static String getFileSuffixFromUrl(String str) {
        AppMethodBeat.i(49684);
        if (str == null) {
            AppMethodBeat.o(49684);
            return null;
        }
        int lastIndexOf = str.lastIndexOf(".");
        if (lastIndexOf == -1) {
            AppMethodBeat.o(49684);
            return null;
        } else if (lastIndexOf == str.length() - 1) {
            AppMethodBeat.o(49684);
            return null;
        } else {
            String substring = str.substring(lastIndexOf + 1);
            AppMethodBeat.o(49684);
            return substring;
        }
    }

    public static void save(File file, String str) {
        Writer bufferedWriter;
        Throwable e;
        AppMethodBeat.i(49685);
        OutputStream fileOutputStream;
        try {
            fileOutputStream = new FileOutputStream(file);
            try {
                bufferedWriter = new BufferedWriter(new OutputStreamWriter(fileOutputStream, "UTF-8"));
            } catch (Exception e2) {
                e = e2;
                bufferedWriter = null;
                try {
                    LogUtils.e(e);
                    IOUtils.closeQuietly(fileOutputStream);
                    IOUtils.closeQuietly(bufferedWriter);
                    AppMethodBeat.o(49685);
                } catch (Throwable th) {
                    e = th;
                    IOUtils.closeQuietly(fileOutputStream);
                    IOUtils.closeQuietly(bufferedWriter);
                    AppMethodBeat.o(49685);
                    throw e;
                }
            } catch (Throwable th2) {
                e = th2;
                bufferedWriter = null;
                IOUtils.closeQuietly(fileOutputStream);
                IOUtils.closeQuietly(bufferedWriter);
                AppMethodBeat.o(49685);
                throw e;
            }
            try {
                bufferedWriter.write(str);
                IOUtils.closeQuietly(fileOutputStream);
                IOUtils.closeQuietly(bufferedWriter);
                AppMethodBeat.o(49685);
            } catch (Exception e3) {
                e = e3;
                LogUtils.e(e);
                IOUtils.closeQuietly(fileOutputStream);
                IOUtils.closeQuietly(bufferedWriter);
                AppMethodBeat.o(49685);
            }
        } catch (Exception e4) {
            e = e4;
            bufferedWriter = null;
            fileOutputStream = null;
            LogUtils.e(e);
            IOUtils.closeQuietly(fileOutputStream);
            IOUtils.closeQuietly(bufferedWriter);
            AppMethodBeat.o(49685);
        } catch (Throwable th3) {
            e = th3;
            bufferedWriter = null;
            fileOutputStream = null;
            IOUtils.closeQuietly(fileOutputStream);
            IOUtils.closeQuietly(bufferedWriter);
            AppMethodBeat.o(49685);
            throw e;
        }
    }

    public static String load(Context context, String str, String str2) {
        AppMethodBeat.i(49686);
        String str3;
        if (TextUtils.isEmpty(str) || TextUtils.isEmpty(str2)) {
            str3 = BuildConfig.FLAVOR;
            AppMethodBeat.o(49686);
            return str3;
        } else if (str.startsWith("assets://")) {
            str3 = loadAssetsString(context, getRealPath(str) + File.separator + str2);
            AppMethodBeat.o(49686);
            return str3;
        } else {
            str3 = load(new File(str + File.separator + str2));
            AppMethodBeat.o(49686);
            return str3;
        }
    }

    private static String load(File file) {
        InputStream inputStream;
        Throwable th;
        AppMethodBeat.i(49687);
        InputStream fileInputStream;
        try {
            fileInputStream = new FileInputStream(file);
            try {
                byte[] bArr = new byte[((int) file.length())];
                fileInputStream.read(bArr);
                String str = new String(bArr, "UTF-8");
                IOUtils.closeQuietly(fileInputStream);
                AppMethodBeat.o(49687);
                return str;
            } catch (FileNotFoundException e) {
                inputStream = fileInputStream;
                IOUtils.closeQuietly(inputStream);
                AppMethodBeat.o(49687);
                return null;
            } catch (Exception e2) {
                IOUtils.closeQuietly(fileInputStream);
                AppMethodBeat.o(49687);
                return null;
            } catch (Throwable th2) {
                th = th2;
                IOUtils.closeQuietly(fileInputStream);
                AppMethodBeat.o(49687);
                throw th;
            }
        } catch (FileNotFoundException e3) {
            inputStream = null;
            IOUtils.closeQuietly(inputStream);
            AppMethodBeat.o(49687);
            return null;
        } catch (Exception e4) {
            fileInputStream = null;
            IOUtils.closeQuietly(fileInputStream);
            AppMethodBeat.o(49687);
            return null;
        } catch (Throwable th3) {
            th = th3;
            fileInputStream = null;
            IOUtils.closeQuietly(fileInputStream);
            AppMethodBeat.o(49687);
            throw th;
        }
    }

    public static String loadAssetsString(Context context, String str) {
        String stringBuilder;
        Throwable th;
        Reader reader;
        AppMethodBeat.i(49688);
        StringBuilder stringBuilder2 = new StringBuilder();
        InputStream open;
        Reader bufferedReader;
        try {
            open = context.getAssets().open(str);
            try {
                bufferedReader = new BufferedReader(new InputStreamReader(open, "UTF-8"));
                while (true) {
                    try {
                        String readLine = bufferedReader.readLine();
                        if (readLine == null) {
                            break;
                        }
                        stringBuilder2.append(readLine);
                        stringBuilder2.append(IOUtils.LINE_SEPARATOR_UNIX);
                    } catch (IOException e) {
                        IOUtils.closeQuietly(bufferedReader);
                        IOUtils.closeQuietly(open);
                        stringBuilder = stringBuilder2.toString();
                        AppMethodBeat.o(49688);
                        return stringBuilder;
                    } catch (Throwable th2) {
                        th = th2;
                        reader = bufferedReader;
                        IOUtils.closeQuietly(reader);
                        IOUtils.closeQuietly(open);
                        AppMethodBeat.o(49688);
                        throw th;
                    }
                }
                IOUtils.closeQuietly(bufferedReader);
                IOUtils.closeQuietly(open);
            } catch (IOException e2) {
                bufferedReader = null;
                IOUtils.closeQuietly(bufferedReader);
                IOUtils.closeQuietly(open);
                stringBuilder = stringBuilder2.toString();
                AppMethodBeat.o(49688);
                return stringBuilder;
            } catch (Throwable th3) {
                th = th3;
                reader = null;
                IOUtils.closeQuietly(reader);
                IOUtils.closeQuietly(open);
                AppMethodBeat.o(49688);
                throw th;
            }
        } catch (IOException e3) {
            bufferedReader = null;
            open = null;
        } catch (Throwable th32) {
            th = th32;
            reader = null;
            open = null;
            IOUtils.closeQuietly(reader);
            IOUtils.closeQuietly(open);
            AppMethodBeat.o(49688);
            throw th;
        }
        stringBuilder = stringBuilder2.toString();
        AppMethodBeat.o(49688);
        return stringBuilder;
    }

    public static String loadRawResourceString(Context context, int i) {
        AppMethodBeat.i(49689);
        Reader inputStreamReader = new InputStreamReader(context.getResources().openRawResource(i));
        Reader bufferedReader = new BufferedReader(inputStreamReader);
        StringBuilder stringBuilder = new StringBuilder();
        while (true) {
            try {
                String readLine = bufferedReader.readLine();
                if (readLine != null) {
                    stringBuilder.append(readLine);
                    stringBuilder.append(10);
                } else {
                    IOUtils.closeQuietly(inputStreamReader);
                    IOUtils.closeQuietly(bufferedReader);
                    String stringBuilder2 = stringBuilder.toString();
                    AppMethodBeat.o(49689);
                    return stringBuilder2;
                }
            } catch (IOException e) {
                IOUtils.closeQuietly(inputStreamReader);
                IOUtils.closeQuietly(bufferedReader);
                AppMethodBeat.o(49689);
                return null;
            } catch (Throwable th) {
                IOUtils.closeQuietly(inputStreamReader);
                IOUtils.closeQuietly(bufferedReader);
                AppMethodBeat.o(49689);
            }
        }
    }

    public static boolean copyAssets(Context context, String str, String str2) {
        AppMethodBeat.i(49690);
        boolean copyAssets = copyAssets(context, str, str2, SIMPLE_ASSET_COMPARATOR);
        AppMethodBeat.o(49690);
        return copyAssets;
    }

    public static boolean copyAssets(Context context, String str, String str2, AssetFileComparator assetFileComparator) {
        AppMethodBeat.i(49691);
        boolean performCopyAssetsFile = performCopyAssetsFile(context, str, str2, assetFileComparator);
        AppMethodBeat.o(49691);
        return performCopyAssetsFile;
    }

    private static boolean performCopyAssetsFile(Context context, String str, String str2, AssetFileComparator assetFileComparator) {
        Closeable closeable;
        Throwable th;
        Closeable closeable2;
        boolean z = false;
        Closeable closeable3 = null;
        AppMethodBeat.i(49692);
        if (TextUtils.isEmpty(str) || TextUtils.isEmpty(str2)) {
            AppMethodBeat.o(49692);
            return false;
        }
        AssetManager assets = context.getAssets();
        File file = new File(str2);
        Closeable open;
        Closeable bufferedOutputStream;
        try {
            if (file.exists()) {
                if (assetFileComparator != null && assetFileComparator.equals(context, str, file)) {
                    closeSilently(null);
                    closeSilently(null);
                    AppMethodBeat.o(49692);
                    return true;
                } else if (file.isDirectory()) {
                    delete(file);
                }
            }
            File parentFile = file.getParentFile();
            if (parentFile.isFile()) {
                delete(parentFile);
            }
            if (parentFile.exists() || parentFile.mkdirs()) {
                open = assets.open(str);
                try {
                    if (open.available() > 0) {
                        bufferedOutputStream = new BufferedOutputStream(new FileOutputStream(file));
                        try {
                            byte[] bArr = new byte[1024];
                            while (true) {
                                int read = open.read(bArr);
                                if (read <= 0) {
                                    break;
                                }
                                bufferedOutputStream.write(bArr, 0, read);
                            }
                            closeable3 = bufferedOutputStream;
                            z = true;
                        } catch (Throwable th2) {
                            th = th2;
                            closeable2 = bufferedOutputStream;
                            closeSilently(open);
                            closeSilently(closeable2);
                            AppMethodBeat.o(49692);
                            throw th;
                        }
                    }
                    closeSilently(open);
                    closeSilently(closeable3);
                } catch (Throwable th3) {
                    th = th3;
                    closeable2 = null;
                    closeSilently(open);
                    closeSilently(closeable2);
                    AppMethodBeat.o(49692);
                    throw th;
                }
                AppMethodBeat.o(49692);
                return z;
            }
            closeSilently(null);
            closeSilently(null);
            AppMethodBeat.o(49692);
            return false;
        } catch (Throwable th32) {
            th = th32;
            closeable2 = null;
            open = null;
            closeSilently(open);
            closeSilently(closeable2);
            AppMethodBeat.o(49692);
            throw th;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:22:0x0037 A:{SYNTHETIC, Splitter:B:22:0x0037} */
    private static long getAssetLength(android.content.Context r5, java.lang.String r6) {
        /*
        r1 = 0;
        r4 = 49693; // 0xc21d float:6.9635E-41 double:2.45516E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r4);
        r3 = r5.getAssets();
        r2 = r3.openFd(r6);	 Catch:{ IOException -> 0x001c, all -> 0x0033 }
        r0 = r2.getLength();	 Catch:{ IOException -> 0x005e, all -> 0x005c }
        if (r2 == 0) goto L_0x0018;
    L_0x0015:
        r2.close();	 Catch:{ IOException -> 0x0051 }
    L_0x0018:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r4);
    L_0x001b:
        return r0;
    L_0x001c:
        r0 = move-exception;
        r0 = r1;
    L_0x001e:
        if (r0 == 0) goto L_0x0023;
    L_0x0020:
        r0.close();	 Catch:{ IOException -> 0x0053 }
    L_0x0023:
        r2 = r3.open(r6);	 Catch:{ IOException -> 0x003e, all -> 0x0048 }
        r0 = r2.available();	 Catch:{ IOException -> 0x0059, all -> 0x0057 }
        r0 = (long) r0;
        closeSilently(r2);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r4);
        goto L_0x001b;
    L_0x0033:
        r0 = move-exception;
        r2 = r1;
    L_0x0035:
        if (r2 == 0) goto L_0x003a;
    L_0x0037:
        r2.close();	 Catch:{ IOException -> 0x0055 }
    L_0x003a:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r4);
        throw r0;
    L_0x003e:
        r0 = move-exception;
    L_0x003f:
        closeSilently(r1);
        r0 = -1;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r4);
        goto L_0x001b;
    L_0x0048:
        r0 = move-exception;
        r2 = r1;
    L_0x004a:
        closeSilently(r2);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r4);
        throw r0;
    L_0x0051:
        r2 = move-exception;
        goto L_0x0018;
    L_0x0053:
        r0 = move-exception;
        goto L_0x0023;
    L_0x0055:
        r1 = move-exception;
        goto L_0x003a;
    L_0x0057:
        r0 = move-exception;
        goto L_0x004a;
    L_0x0059:
        r0 = move-exception;
        r1 = r2;
        goto L_0x003f;
    L_0x005c:
        r0 = move-exception;
        goto L_0x0035;
    L_0x005e:
        r0 = move-exception;
        r0 = r2;
        goto L_0x001e;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.ttpic.baseutils.FileUtils.getAssetLength(android.content.Context, java.lang.String):long");
    }

    /* JADX WARNING: Removed duplicated region for block: B:15:0x0030 A:{Catch:{ IOException -> 0x003a }} */
    /* JADX WARNING: Removed duplicated region for block: B:24:0x0047 A:{Catch:{ IOException -> 0x0051 }} */
    public static void copyRaw(android.content.Context r6, int r7, java.lang.String r8) {
        /*
        r5 = 49694; // 0xc21e float:6.9636E-41 double:2.4552E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r5);
        r0 = r6.getResources();
        r4 = r0.openRawResource(r7);
        r1 = 0;
        r0 = new java.io.FileOutputStream;	 Catch:{ Exception -> 0x0029, all -> 0x003f }
        r0.<init>(r8);	 Catch:{ Exception -> 0x0029, all -> 0x003f }
        copyFile(r4, r0);	 Catch:{ Exception -> 0x0057, all -> 0x0053 }
        r4.close();	 Catch:{ IOException -> 0x0024 }
        r0.flush();	 Catch:{ IOException -> 0x0024 }
        r0.close();	 Catch:{ IOException -> 0x0024 }
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
    L_0x0023:
        return;
    L_0x0024:
        r0 = move-exception;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
        goto L_0x0023;
    L_0x0029:
        r0 = move-exception;
        r0 = r1;
    L_0x002b:
        r4.close();	 Catch:{ IOException -> 0x003a }
        if (r0 == 0) goto L_0x0036;
    L_0x0030:
        r0.flush();	 Catch:{ IOException -> 0x003a }
        r0.close();	 Catch:{ IOException -> 0x003a }
    L_0x0036:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
        goto L_0x0023;
    L_0x003a:
        r0 = move-exception;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
        goto L_0x0023;
    L_0x003f:
        r0 = move-exception;
        r2 = r0;
        r3 = r1;
    L_0x0042:
        r4.close();	 Catch:{ IOException -> 0x0051 }
        if (r3 == 0) goto L_0x004d;
    L_0x0047:
        r3.flush();	 Catch:{ IOException -> 0x0051 }
        r3.close();	 Catch:{ IOException -> 0x0051 }
    L_0x004d:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
        throw r2;
    L_0x0051:
        r0 = move-exception;
        goto L_0x004d;
    L_0x0053:
        r1 = move-exception;
        r2 = r1;
        r3 = r0;
        goto L_0x0042;
    L_0x0057:
        r1 = move-exception;
        goto L_0x002b;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.ttpic.baseutils.FileUtils.copyRaw(android.content.Context, int, java.lang.String):void");
    }

    public static void clearDir(File file) {
        AppMethodBeat.i(49695);
        if (file != null && file.exists() && file.isDirectory()) {
            File[] listFiles = file.listFiles();
            if (listFiles == null) {
                AppMethodBeat.o(49695);
                return;
            }
            for (File file2 : listFiles) {
                if (file2.isDirectory()) {
                    clearDir(file2);
                } else {
                    file2.delete();
                }
            }
            file.delete();
            AppMethodBeat.o(49695);
            return;
        }
        AppMethodBeat.o(49695);
    }

    public static void clearDirs(File[] fileArr) {
        AppMethodBeat.i(49696);
        if (fileArr == null) {
            AppMethodBeat.o(49696);
            return;
        }
        for (File clearDir : fileArr) {
            clearDir(clearDir);
        }
        AppMethodBeat.o(49696);
    }

    public static boolean exists(String str) {
        AppMethodBeat.i(49697);
        if (TextUtils.isEmpty(str)) {
            AppMethodBeat.o(49697);
            return false;
        } else if (str.indexOf("assets") >= 0 || new File(str).exists()) {
            AppMethodBeat.o(49697);
            return true;
        } else {
            AppMethodBeat.o(49697);
            return false;
        }
    }

    public static boolean Move(File file, String str) {
        AppMethodBeat.i(49698);
        boolean renameTo = file.renameTo(new File(new File(str), file.getName()));
        AppMethodBeat.o(49698);
        return renameTo;
    }

    public static void delete(String str) {
        AppMethodBeat.i(49699);
        if (TextUtils.isEmpty(str)) {
            AppMethodBeat.o(49699);
            return;
        }
        delete(new File(str));
        AppMethodBeat.o(49699);
    }

    public static void delete(File file) {
        AppMethodBeat.i(49700);
        if (file.isFile()) {
            file.delete();
            AppMethodBeat.o(49700);
            return;
        }
        if (file.isDirectory()) {
            File[] listFiles = file.listFiles();
            if (listFiles == null || listFiles.length == 0) {
                file.delete();
                AppMethodBeat.o(49700);
                return;
            }
            for (File delete : listFiles) {
                delete(delete);
            }
            file.delete();
        }
        AppMethodBeat.o(49700);
    }

    public static void delete(File file, boolean z) {
        AppMethodBeat.i(49701);
        if (file == null || !file.exists()) {
            AppMethodBeat.o(49701);
        } else if (file.isFile()) {
            file.delete();
            AppMethodBeat.o(49701);
        } else {
            File[] listFiles = file.listFiles();
            if (listFiles == null) {
                AppMethodBeat.o(49701);
                return;
            }
            for (File delete : listFiles) {
                delete(delete, z);
            }
            if (!z) {
                file.delete();
            }
            AppMethodBeat.o(49701);
        }
    }

    public static void deleteFiles(String str, String str2) {
        AppMethodBeat.i(49702);
        if (TextUtils.isEmpty(str)) {
            AppMethodBeat.o(49702);
            return;
        }
        File[] listFiles = new File(str).listFiles(new 1(str2));
        if (listFiles != null) {
            for (File delete : listFiles) {
                delete.delete();
            }
        }
        AppMethodBeat.o(49702);
    }

    public static void deleteAllFilesOfDir(File file) {
        AppMethodBeat.i(49703);
        if (!file.exists()) {
            AppMethodBeat.o(49703);
        } else if (file.isFile()) {
            file.delete();
            AppMethodBeat.o(49703);
        } else {
            File[] listFiles = file.listFiles();
            if (listFiles != null) {
                for (File deleteAllFilesOfDir : listFiles) {
                    deleteAllFilesOfDir(deleteAllFilesOfDir);
                }
            }
            file.delete();
            AppMethodBeat.o(49703);
        }
    }

    private static void closeSilently(Closeable closeable) {
        AppMethodBeat.i(49704);
        if (closeable != null) {
            try {
                closeable.close();
                AppMethodBeat.o(49704);
                return;
            } catch (Throwable th) {
            }
        }
        AppMethodBeat.o(49704);
    }

    /* JADX WARNING: Removed duplicated region for block: B:16:0x0044 A:{SYNTHETIC, Splitter:B:16:0x0044} */
    /* JADX WARNING: Removed duplicated region for block: B:19:0x0049 A:{SYNTHETIC, Splitter:B:19:0x0049} */
    /* JADX WARNING: Removed duplicated region for block: B:31:0x0065 A:{SYNTHETIC, Splitter:B:31:0x0065} */
    /* JADX WARNING: Removed duplicated region for block: B:34:0x006a A:{SYNTHETIC, Splitter:B:34:0x006a} */
    /* JADX WARNING: Removed duplicated region for block: B:48:0x0089 A:{SYNTHETIC, Splitter:B:48:0x0089} */
    /* JADX WARNING: Removed duplicated region for block: B:57:0x009a A:{SYNTHETIC, Splitter:B:57:0x009a} */
    /* JADX WARNING: Removed duplicated region for block: B:31:0x0065 A:{SYNTHETIC, Splitter:B:31:0x0065} */
    /* JADX WARNING: Removed duplicated region for block: B:34:0x006a A:{SYNTHETIC, Splitter:B:34:0x006a} */
    public static java.lang.String readTxtFile(android.content.Context r6, java.lang.String r7) {
        /*
        r0 = 0;
        r5 = 49705; // 0xc229 float:6.9652E-41 double:2.45575E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r5);
        r1 = android.text.TextUtils.isEmpty(r7);
        if (r1 == 0) goto L_0x0011;
    L_0x000d:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
    L_0x0010:
        return r0;
    L_0x0011:
        r3 = new java.lang.StringBuilder;
        r3.<init>();
        r1 = "assets://";
        r1 = r7.startsWith(r1);
        if (r1 == 0) goto L_0x0071;
    L_0x001f:
        r1 = r6.getAssets();	 Catch:{ IOException -> 0x00bb, all -> 0x005f }
        r2 = 9;
        r2 = r7.substring(r2);	 Catch:{ IOException -> 0x00bb, all -> 0x005f }
        r2 = r1.open(r2);	 Catch:{ IOException -> 0x00bb, all -> 0x005f }
        r1 = new java.io.BufferedReader;	 Catch:{ IOException -> 0x00bf, all -> 0x00b3 }
        r4 = new java.io.InputStreamReader;	 Catch:{ IOException -> 0x00bf, all -> 0x00b3 }
        r4.<init>(r2);	 Catch:{ IOException -> 0x00bf, all -> 0x00b3 }
        r1.<init>(r4);	 Catch:{ IOException -> 0x00bf, all -> 0x00b3 }
    L_0x0037:
        r0 = r1.readLine();	 Catch:{ IOException -> 0x0041, all -> 0x00b7 }
        if (r0 == 0) goto L_0x0054;
    L_0x003d:
        r3.append(r0);	 Catch:{ IOException -> 0x0041, all -> 0x00b7 }
        goto L_0x0037;
    L_0x0041:
        r0 = move-exception;
    L_0x0042:
        if (r1 == 0) goto L_0x0047;
    L_0x0044:
        r1.close();	 Catch:{ IOException -> 0x00a3 }
    L_0x0047:
        if (r2 == 0) goto L_0x004c;
    L_0x0049:
        r2.close();	 Catch:{ IOException -> 0x00a5 }
    L_0x004c:
        r0 = r3.toString();
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
        goto L_0x0010;
    L_0x0054:
        r1.close();	 Catch:{ IOException -> 0x00a1 }
    L_0x0057:
        if (r2 == 0) goto L_0x004c;
    L_0x0059:
        r2.close();	 Catch:{ IOException -> 0x005d }
        goto L_0x004c;
    L_0x005d:
        r0 = move-exception;
        goto L_0x004c;
    L_0x005f:
        r1 = move-exception;
        r3 = r1;
        r4 = r0;
        r2 = r0;
    L_0x0063:
        if (r4 == 0) goto L_0x0068;
    L_0x0065:
        r4.close();	 Catch:{ IOException -> 0x00a7 }
    L_0x0068:
        if (r2 == 0) goto L_0x006d;
    L_0x006a:
        r2.close();	 Catch:{ IOException -> 0x00a9 }
    L_0x006d:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
        throw r3;
    L_0x0071:
        r1 = new java.io.BufferedReader;	 Catch:{ IOException -> 0x00b1, all -> 0x0095 }
        r2 = new java.io.FileReader;	 Catch:{ IOException -> 0x00b1, all -> 0x0095 }
        r2.<init>(r7);	 Catch:{ IOException -> 0x00b1, all -> 0x0095 }
        r1.<init>(r2);	 Catch:{ IOException -> 0x00b1, all -> 0x0095 }
    L_0x007b:
        r0 = r1.readLine();	 Catch:{ IOException -> 0x0085, all -> 0x00ad }
        if (r0 == 0) goto L_0x008f;
    L_0x0081:
        r3.append(r0);	 Catch:{ IOException -> 0x0085, all -> 0x00ad }
        goto L_0x007b;
    L_0x0085:
        r0 = move-exception;
        r0 = r1;
    L_0x0087:
        if (r0 == 0) goto L_0x004c;
    L_0x0089:
        r0.close();	 Catch:{ IOException -> 0x008d }
        goto L_0x004c;
    L_0x008d:
        r0 = move-exception;
        goto L_0x004c;
    L_0x008f:
        r1.close();	 Catch:{ IOException -> 0x0093 }
        goto L_0x004c;
    L_0x0093:
        r0 = move-exception;
        goto L_0x004c;
    L_0x0095:
        r1 = move-exception;
        r2 = r1;
        r3 = r0;
    L_0x0098:
        if (r3 == 0) goto L_0x009d;
    L_0x009a:
        r3.close();	 Catch:{ IOException -> 0x00ab }
    L_0x009d:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
        throw r2;
    L_0x00a1:
        r0 = move-exception;
        goto L_0x0057;
    L_0x00a3:
        r0 = move-exception;
        goto L_0x0047;
    L_0x00a5:
        r0 = move-exception;
        goto L_0x004c;
    L_0x00a7:
        r0 = move-exception;
        goto L_0x0068;
    L_0x00a9:
        r0 = move-exception;
        goto L_0x006d;
    L_0x00ab:
        r0 = move-exception;
        goto L_0x009d;
    L_0x00ad:
        r0 = move-exception;
        r2 = r0;
        r3 = r1;
        goto L_0x0098;
    L_0x00b1:
        r1 = move-exception;
        goto L_0x0087;
    L_0x00b3:
        r1 = move-exception;
        r3 = r1;
        r4 = r0;
        goto L_0x0063;
    L_0x00b7:
        r0 = move-exception;
        r3 = r0;
        r4 = r1;
        goto L_0x0063;
    L_0x00bb:
        r1 = move-exception;
        r1 = r0;
        r2 = r0;
        goto L_0x0042;
    L_0x00bf:
        r1 = move-exception;
        r1 = r0;
        goto L_0x0042;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.ttpic.baseutils.FileUtils.readTxtFile(android.content.Context, java.lang.String):java.lang.String");
    }

    public static String getSHA1(String str) {
        String str2 = null;
        AppMethodBeat.i(49706);
        if (new File(str).exists()) {
            try {
                int read;
                MessageDigest instance = MessageDigest.getInstance("SHA-1");
                FileInputStream fileInputStream = new FileInputStream(str);
                byte[] bArr = new byte[4096];
                while (true) {
                    read = fileInputStream.read(bArr);
                    if (read == -1) {
                        break;
                    }
                    instance.update(bArr, 0, read);
                }
                fileInputStream.close();
                StringBuilder stringBuilder = new StringBuilder();
                for (byte b : instance.digest()) {
                    int i = b & 255;
                    stringBuilder.append(i < 16 ? "0" : BuildConfig.FLAVOR);
                    stringBuilder.append(Integer.toHexString(i).toLowerCase());
                }
                str2 = stringBuilder.toString();
                AppMethodBeat.o(49706);
            } catch (Exception e) {
                AppMethodBeat.o(49706);
            }
        } else {
            AppMethodBeat.o(49706);
        }
        return str2;
    }

    public static String getMD5(String str, String str2) {
        String str3 = null;
        AppMethodBeat.i(49707);
        if (new File(str).exists()) {
            try {
                int read;
                MessageDigest instance = MessageDigest.getInstance("MD5");
                FileInputStream fileInputStream = new FileInputStream(str);
                byte[] bArr = new byte[4096];
                while (true) {
                    read = fileInputStream.read(bArr);
                    if (read == -1) {
                        break;
                    }
                    instance.update(bArr, 0, read);
                }
                instance.update(str2.getBytes());
                fileInputStream.close();
                StringBuilder stringBuilder = new StringBuilder();
                for (byte b : instance.digest()) {
                    int i = b & 255;
                    stringBuilder.append(i < 16 ? "0" : BuildConfig.FLAVOR);
                    stringBuilder.append(Integer.toHexString(i).toLowerCase());
                }
                str3 = stringBuilder.toString();
                AppMethodBeat.o(49707);
            } catch (Exception e) {
                AppMethodBeat.o(49707);
            }
        } else {
            AppMethodBeat.o(49707);
        }
        return str3;
    }

    public static String md5ForBase64Data(String str) {
        int i = 0;
        AppMethodBeat.i(49708);
        char[] cArr = new char[]{'r', 'D', 'z', 'o', 'i', 'e', '5', 'e', '3', 'o', 'n', 'g', 'f', 'z', '1', 'l'};
        StringBuffer stringBuffer = new StringBuffer(str);
        for (int i2 = 0; i2 < 16; i2++) {
            stringBuffer.append(cArr[i2]);
        }
        String stringBuffer2;
        try {
            MessageDigest instance = MessageDigest.getInstance("MD5");
            instance.update(stringBuffer.toString().getBytes());
            byte[] digest = instance.digest();
            StringBuffer stringBuffer3 = new StringBuffer();
            int length = digest.length;
            while (i < length) {
                stringBuffer3.append(String.format("%02x", new Object[]{Integer.valueOf(digest[i] & 255)}));
                i++;
            }
            stringBuffer2 = stringBuffer3.toString();
            AppMethodBeat.o(49708);
            return stringBuffer2;
        } catch (NoSuchAlgorithmException e) {
            stringBuffer2 = BuildConfig.FLAVOR;
            AppMethodBeat.o(49708);
            return stringBuffer2;
        }
    }

    public static String toBase64(String str) {
        String str2;
        AppMethodBeat.i(49709);
        try {
            FileInputStream fileInputStream = new FileInputStream(new File(str));
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            Base64OutputStream base64OutputStream = new Base64OutputStream(byteArrayOutputStream, 2);
            byte[] bArr = new byte[4096];
            while (true) {
                int read = fileInputStream.read(bArr);
                if (read < 0) {
                    break;
                }
                base64OutputStream.write(bArr, 0, read);
            }
            base64OutputStream.flush();
            base64OutputStream.close();
            str2 = new String(byteArrayOutputStream.toByteArray(), "UTF-8");
            try {
                byteArrayOutputStream.close();
                fileInputStream.close();
            } catch (Exception e) {
            }
        } catch (Exception e2) {
            str2 = null;
        }
        AppMethodBeat.o(49709);
        return str2;
    }

    public static boolean copyFile(String str, String str2) {
        InputStream fileInputStream;
        OutputStream fileOutputStream;
        Throwable e;
        Throwable th;
        AppMethodBeat.i(49710);
        try {
            if (new File(str).exists()) {
                fileInputStream = new FileInputStream(str);
                try {
                    fileOutputStream = new FileOutputStream(str2);
                } catch (Exception e2) {
                    e = e2;
                    fileOutputStream = null;
                    try {
                        LogUtils.e(e);
                        IOUtils.closeQuietly(fileInputStream);
                        IOUtils.closeQuietly(fileOutputStream);
                        AppMethodBeat.o(49710);
                        return false;
                    } catch (Throwable th2) {
                        th = th2;
                        IOUtils.closeQuietly(fileInputStream);
                        IOUtils.closeQuietly(fileOutputStream);
                        AppMethodBeat.o(49710);
                        throw th;
                    }
                } catch (Throwable th3) {
                    th = th3;
                    fileOutputStream = null;
                    IOUtils.closeQuietly(fileInputStream);
                    IOUtils.closeQuietly(fileOutputStream);
                    AppMethodBeat.o(49710);
                    throw th;
                }
                try {
                    byte[] bArr = new byte[4096];
                    while (true) {
                        int read = fileInputStream.read(bArr);
                        if (read > 0) {
                            fileOutputStream.write(bArr, 0, read);
                        } else {
                            IOUtils.closeQuietly(fileInputStream);
                            IOUtils.closeQuietly(fileOutputStream);
                            AppMethodBeat.o(49710);
                            return true;
                        }
                    }
                } catch (Exception e3) {
                    e = e3;
                    LogUtils.e(e);
                    IOUtils.closeQuietly(fileInputStream);
                    IOUtils.closeQuietly(fileOutputStream);
                    AppMethodBeat.o(49710);
                    return false;
                }
            }
            IOUtils.closeQuietly(null);
            IOUtils.closeQuietly(null);
            AppMethodBeat.o(49710);
            return false;
        } catch (Exception e4) {
            e = e4;
            fileOutputStream = null;
            fileInputStream = null;
        } catch (Throwable th4) {
            th = th4;
            fileOutputStream = null;
            fileInputStream = null;
            IOUtils.closeQuietly(fileInputStream);
            IOUtils.closeQuietly(fileOutputStream);
            AppMethodBeat.o(49710);
            throw th;
        }
    }

    public static boolean copyFile(InputStream inputStream, OutputStream outputStream) {
        AppMethodBeat.i(49711);
        if (inputStream == null || outputStream == null) {
            AppMethodBeat.o(49711);
            return false;
        }
        try {
            byte[] bArr = new byte[4096];
            while (true) {
                int read = inputStream.read(bArr);
                if (read <= 0) {
                    break;
                }
                outputStream.write(bArr, 0, read);
            }
            outputStream.flush();
        } catch (Exception e) {
            LogUtils.e(e);
        }
        AppMethodBeat.o(49711);
        return true;
    }

    public static boolean copyFile(InputStream inputStream, String str) {
        Throwable th;
        AppMethodBeat.i(49712);
        OutputStream fileOutputStream;
        try {
            fileOutputStream = new FileOutputStream(str);
            try {
                byte[] bArr = new byte[4096];
                while (true) {
                    int read = inputStream.read(bArr);
                    if (read > 0) {
                        fileOutputStream.write(bArr, 0, read);
                    } else {
                        IOUtils.closeQuietly(inputStream);
                        IOUtils.closeQuietly(fileOutputStream);
                        AppMethodBeat.o(49712);
                        return true;
                    }
                }
            } catch (Exception e) {
                IOUtils.closeQuietly(inputStream);
                IOUtils.closeQuietly(fileOutputStream);
                AppMethodBeat.o(49712);
                return false;
            } catch (Throwable th2) {
                th = th2;
                IOUtils.closeQuietly(inputStream);
                IOUtils.closeQuietly(fileOutputStream);
                AppMethodBeat.o(49712);
                throw th;
            }
        } catch (Exception e2) {
            fileOutputStream = null;
            IOUtils.closeQuietly(inputStream);
            IOUtils.closeQuietly(fileOutputStream);
            AppMethodBeat.o(49712);
            return false;
        } catch (Throwable th3) {
            th = th3;
            fileOutputStream = null;
            IOUtils.closeQuietly(inputStream);
            IOUtils.closeQuietly(fileOutputStream);
            AppMethodBeat.o(49712);
            throw th;
        }
    }

    public static void asyncCopyFile(InputStream inputStream, String str, OnFileCopyListener onFileCopyListener) {
        AppMethodBeat.i(49713);
        FileCopyTask fileCopyTask = new FileCopyTask(inputStream, str);
        fileCopyTask.setOnFileCopyListener(onFileCopyListener);
        fileCopyTask.executeOnExecutor(AsyncTask.SERIAL_EXECUTOR, new String[0]);
        AppMethodBeat.o(49713);
    }

    public static String readTextFileFromRaw(Context context, int i) {
        AppMethodBeat.i(49714);
        BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(context.getResources().openRawResource(i)));
        StringBuilder stringBuilder = new StringBuilder();
        while (true) {
            try {
                String readLine = bufferedReader.readLine();
                if (readLine != null) {
                    stringBuilder.append(readLine);
                    stringBuilder.append(10);
                } else {
                    String stringBuilder2 = stringBuilder.toString();
                    AppMethodBeat.o(49714);
                    return stringBuilder2;
                }
            } catch (IOException e) {
                AppMethodBeat.o(49714);
                return null;
            }
        }
    }
}
