package com.tencent.ttpic.thread;

import android.annotation.TargetApi;
import android.graphics.Bitmap;
import android.opengl.EGLContext;
import android.os.Handler;
import android.os.HandlerThread;
import com.tencent.filter.BaseFilter;
import com.tencent.filter.GLSLRender;
import com.tencent.filter.h;
import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.ttpic.fabby.FabbyManager;
import com.tencent.ttpic.filter.ExpFilter;
import com.tencent.ttpic.filter.FabbyExtractFilter;
import com.tencent.ttpic.filter.FabbyStrokeFilter;
import com.tencent.ttpic.filter.SimpleGaussionFilter;
import com.tencent.ttpic.gles.EglCore;
import com.tencent.ttpic.gles.GLSegSharedData;
import com.tencent.ttpic.gles.OffscreenSurface;
import com.tencent.ttpic.gles.SegmentDataPipe;

@TargetApi(18)
public class SegmentGLThread {
    private static final int SEGMENT_HEIGHT;
    private static final int SEGMENT_WIDTH = 16;
    private ExpFilter expFilter = new ExpFilter();
    private FabbyExtractFilter fabbyExtractFilter = new FabbyExtractFilter();
    private FabbyStrokeFilter fabbyStrokeFilter = new FabbyStrokeFilter();
    private BaseFilter mCopyFilter = new BaseFilter(GLSLRender.bJB);
    private h mCopyFrame;
    private EglCore mCore;
    private Handler mHandler;
    private boolean mIsInitReady;
    private OnSegDataReadyListener mListener;
    private Bitmap mMaskBitmap;
    private Bitmap mMaskBitmapHorizon;
    private OffscreenSurface mOffscreenSurface;
    private boolean mRunOnCpuForce;
    private Bitmap mSegBitmap;
    private Bitmap mSegBitmapHorizon;
    private h mSegFrame;
    private SimpleGaussionFilter mSimpleBlurFilter = new SimpleGaussionFilter();
    private h mTempFrame;
    private int[] mTempTexId = new int[2];
    private GLSegSharedData sharedData;

    static /* synthetic */ void access$1200(SegmentGLThread segmentGLThread, int i) {
        AppMethodBeat.i(83788);
        segmentGLThread.setAllRenderMode(i);
        AppMethodBeat.o(83788);
    }

    static {
        int i = 16;
        boolean z = FabbyManager.USE_SMALL_IMAGE;
        if (!FabbyManager.USE_SMALL_IMAGE) {
            i = 32;
        }
        SEGMENT_HEIGHT = i;
    }

    public SegmentGLThread(EGLContext eGLContext) {
        AppMethodBeat.i(83779);
        HandlerThread handlerThread = new HandlerThread("SegmentGLThread");
        handlerThread.start();
        this.mHandler = new Handler(handlerThread.getLooper());
        this.mHandler.post(new 1(this, eGLContext));
        AppMethodBeat.o(83779);
    }

    public void setOnDataReadyListener(OnSegDataReadyListener onSegDataReadyListener) {
        this.mListener = onSegDataReadyListener;
    }

    public boolean isInitReady() {
        return this.mIsInitReady;
    }

    public void postSegJob(h hVar, boolean z) {
        AppMethodBeat.i(83780);
        if (this.mHandler == null) {
            AppMethodBeat.o(83780);
            return;
        }
        this.mHandler.post(new 2(this, z, hVar));
        AppMethodBeat.o(83780);
    }

    public SegmentDataPipe getCurrentDataPipe() {
        AppMethodBeat.i(83781);
        if (this.sharedData == null) {
            AppMethodBeat.o(83781);
            return null;
        }
        SegmentDataPipe currentTexturePile = this.sharedData.getCurrentTexturePile();
        AppMethodBeat.o(83781);
        return currentTexturePile;
    }

    public void destroy() {
        AppMethodBeat.i(83782);
        if (this.mHandler != null) {
            this.mHandler.post(new 3(this));
        }
        AppMethodBeat.o(83782);
    }

    public boolean needWait() {
        AppMethodBeat.i(83783);
        if (this.sharedData == null) {
            AppMethodBeat.o(83783);
            return true;
        }
        for (SegmentDataPipe segmentDataPipe : this.sharedData.mTexturePile) {
            if (segmentDataPipe.isBusy() || segmentDataPipe.isReady()) {
                AppMethodBeat.o(83783);
                return true;
            }
        }
        AppMethodBeat.o(83783);
        return false;
    }

    private void setAllRenderMode(int i) {
        AppMethodBeat.i(83784);
        this.fabbyExtractFilter.setRenderMode(i);
        this.fabbyStrokeFilter.setRenderMode(i);
        this.expFilter.setRenderMode(i);
        this.mCopyFilter.setRenderMode(i);
        AppMethodBeat.o(83784);
    }

    public void reset() {
        AppMethodBeat.i(83785);
        if (this.mHandler != null) {
            this.mHandler.post(new 4(this));
        }
        AppMethodBeat.o(83785);
    }

    public void initSegLig() {
        AppMethodBeat.i(83786);
        if (this.mHandler != null) {
            this.mHandler.post(new 5(this));
        }
        AppMethodBeat.o(83786);
    }

    public void clearSegLig() {
        AppMethodBeat.i(83787);
        if (this.mHandler != null) {
            this.mHandler.post(new 6(this));
        }
        AppMethodBeat.o(83787);
    }
}
