package com.facebook.appevents.codeless;

import android.os.Handler;
import android.text.TextUtils;
import android.view.View;
import android.view.View.AccessibilityDelegate;
import android.view.View.OnTouchListener;
import android.view.ViewGroup;
import android.view.ViewParent;
import android.view.ViewTreeObserver;
import android.view.ViewTreeObserver.OnGlobalLayoutListener;
import android.view.ViewTreeObserver.OnScrollChangedListener;
import com.facebook.FacebookException;
import com.facebook.FacebookSdk;
import com.facebook.appevents.codeless.CodelessLoggingEventListener.AutoLoggingAccessibilityDelegate;
import com.facebook.appevents.codeless.CodelessMatcher.MatchedView;
import com.facebook.appevents.codeless.RCTCodelessLoggingEventListener.AutoLoggingOnTouchListener;
import com.facebook.appevents.codeless.internal.EventBinding;
import com.facebook.appevents.codeless.internal.PathComponent;
import com.facebook.appevents.codeless.internal.PathComponent.MatchBitmaskType;
import com.facebook.appevents.codeless.internal.ViewHierarchy;
import com.facebook.internal.FetchedAppSettings;
import com.facebook.internal.FetchedAppSettingsManager;
import com.tencent.matrix.trace.core.AppMethodBeat;
import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

protected class CodelessMatcher$ViewMatcher implements OnGlobalLayoutListener, OnScrollChangedListener, Runnable {
    private final String activityName;
    private HashMap<String, String> delegateMap;
    private List<EventBinding> eventBindings;
    private final Handler handler;
    private WeakReference<View> rootView;

    public CodelessMatcher$ViewMatcher(View view, Handler handler, HashMap<String, String> hashMap, String str) {
        AppMethodBeat.i(72050);
        this.rootView = new WeakReference(view);
        this.handler = handler;
        this.delegateMap = hashMap;
        this.activityName = str;
        this.handler.postDelayed(this, 200);
        AppMethodBeat.o(72050);
    }

    public void run() {
        AppMethodBeat.i(72051);
        FetchedAppSettings appSettingsWithoutQuery = FetchedAppSettingsManager.getAppSettingsWithoutQuery(FacebookSdk.getApplicationId());
        if (appSettingsWithoutQuery == null || !appSettingsWithoutQuery.getCodelessEventsEnabled()) {
            AppMethodBeat.o(72051);
            return;
        }
        this.eventBindings = EventBinding.parseArray(appSettingsWithoutQuery.getEventBindings());
        if (this.eventBindings != null) {
            View view = (View) this.rootView.get();
            if (view == null) {
                AppMethodBeat.o(72051);
                return;
            }
            ViewTreeObserver viewTreeObserver = view.getViewTreeObserver();
            if (viewTreeObserver.isAlive()) {
                viewTreeObserver.addOnGlobalLayoutListener(this);
                viewTreeObserver.addOnScrollChangedListener(this);
            }
            startMatch();
        }
        AppMethodBeat.o(72051);
    }

    public void onGlobalLayout() {
        AppMethodBeat.i(72052);
        startMatch();
        AppMethodBeat.o(72052);
    }

    public void onScrollChanged() {
        AppMethodBeat.i(72053);
        startMatch();
        AppMethodBeat.o(72053);
    }

    private void startMatch() {
        AppMethodBeat.i(72054);
        if (this.eventBindings != null && this.rootView.get() != null) {
            int i = 0;
            while (true) {
                int i2 = i;
                if (i2 >= this.eventBindings.size()) {
                    break;
                }
                findView((EventBinding) this.eventBindings.get(i2), (View) this.rootView.get());
                i = i2 + 1;
            }
        }
        AppMethodBeat.o(72054);
    }

    public void findView(EventBinding eventBinding, View view) {
        AppMethodBeat.i(72055);
        if (eventBinding == null || view == null) {
            AppMethodBeat.o(72055);
        } else if (TextUtils.isEmpty(eventBinding.getActivityName()) || eventBinding.getActivityName().equals(this.activityName)) {
            List viewPath = eventBinding.getViewPath();
            if (viewPath.size() > 25) {
                AppMethodBeat.o(72055);
                return;
            }
            for (MatchedView attachListener : findViewByPath(eventBinding, view, viewPath, 0, -1, this.activityName)) {
                attachListener(attachListener, view, eventBinding);
            }
            AppMethodBeat.o(72055);
        } else {
            AppMethodBeat.o(72055);
        }
    }

    public static List<MatchedView> findViewByPath(EventBinding eventBinding, View view, List<PathComponent> list, int i, int i2, String str) {
        int i3 = 0;
        AppMethodBeat.i(72056);
        String str2 = str + "." + String.valueOf(i2);
        ArrayList arrayList = new ArrayList();
        if (view == null) {
            AppMethodBeat.o(72056);
            return arrayList;
        }
        List findVisibleChildren;
        int size;
        if (i >= list.size()) {
            arrayList.add(new MatchedView(view, str2));
        } else {
            PathComponent pathComponent = (PathComponent) list.get(i);
            if (pathComponent.className.equals("..")) {
                ViewParent parent = view.getParent();
                if (parent instanceof ViewGroup) {
                    findVisibleChildren = findVisibleChildren((ViewGroup) parent);
                    size = findVisibleChildren.size();
                    while (i3 < size) {
                        arrayList.addAll(findViewByPath(eventBinding, (View) findVisibleChildren.get(i3), list, i + 1, i3, str2));
                        i3++;
                    }
                }
                AppMethodBeat.o(72056);
                return arrayList;
            } else if (pathComponent.className.equals(".")) {
                arrayList.add(new MatchedView(view, str2));
                AppMethodBeat.o(72056);
                return arrayList;
            } else if (!isTheSameView(view, pathComponent, i2)) {
                AppMethodBeat.o(72056);
                return arrayList;
            } else if (i == list.size() - 1) {
                arrayList.add(new MatchedView(view, str2));
            }
        }
        if (view instanceof ViewGroup) {
            findVisibleChildren = findVisibleChildren((ViewGroup) view);
            size = findVisibleChildren.size();
            while (i3 < size) {
                arrayList.addAll(findViewByPath(eventBinding, (View) findVisibleChildren.get(i3), list, i + 1, i3, str2));
                i3++;
            }
        }
        AppMethodBeat.o(72056);
        return arrayList;
    }

    private static boolean isTheSameView(View view, PathComponent pathComponent, int i) {
        AppMethodBeat.i(72057);
        if (pathComponent.index == -1 || i == pathComponent.index) {
            if (!view.getClass().getCanonicalName().equals(pathComponent.className)) {
                if (pathComponent.className.matches(".*android\\..*")) {
                    String[] split = pathComponent.className.split("\\.");
                    if (split.length > 0) {
                        if (!view.getClass().getSimpleName().equals(split[split.length - 1])) {
                            AppMethodBeat.o(72057);
                            return false;
                        }
                    }
                    AppMethodBeat.o(72057);
                    return false;
                }
                AppMethodBeat.o(72057);
                return false;
            }
            if ((pathComponent.matchBitmask & MatchBitmaskType.ID.getValue()) > 0 && pathComponent.id != view.getId()) {
                AppMethodBeat.o(72057);
                return false;
            } else if ((pathComponent.matchBitmask & MatchBitmaskType.TEXT.getValue()) <= 0 || pathComponent.text.equals(ViewHierarchy.getTextOfView(view))) {
                String str;
                Object obj;
                if ((pathComponent.matchBitmask & MatchBitmaskType.DESCRIPTION.getValue()) > 0) {
                    str = pathComponent.description;
                    if (view.getContentDescription() == null) {
                        obj = "";
                    } else {
                        obj = String.valueOf(view.getContentDescription());
                    }
                    if (!str.equals(obj)) {
                        AppMethodBeat.o(72057);
                        return false;
                    }
                }
                if ((pathComponent.matchBitmask & MatchBitmaskType.HINT.getValue()) <= 0 || pathComponent.hint.equals(ViewHierarchy.getHintOfView(view))) {
                    if ((pathComponent.matchBitmask & MatchBitmaskType.TAG.getValue()) > 0) {
                        str = pathComponent.tag;
                        if (view.getTag() == null) {
                            obj = "";
                        } else {
                            obj = String.valueOf(view.getTag());
                        }
                        if (!str.equals(obj)) {
                            AppMethodBeat.o(72057);
                            return false;
                        }
                    }
                    AppMethodBeat.o(72057);
                    return true;
                }
                AppMethodBeat.o(72057);
                return false;
            } else {
                AppMethodBeat.o(72057);
                return false;
            }
        }
        AppMethodBeat.o(72057);
        return false;
    }

    private static List<View> findVisibleChildren(ViewGroup viewGroup) {
        AppMethodBeat.i(72058);
        ArrayList arrayList = new ArrayList();
        int childCount = viewGroup.getChildCount();
        for (int i = 0; i < childCount; i++) {
            View childAt = viewGroup.getChildAt(i);
            if (childAt.getVisibility() == 0) {
                arrayList.add(childAt);
            }
        }
        AppMethodBeat.o(72058);
        return arrayList;
    }

    private void attachListener(MatchedView matchedView, View view, EventBinding eventBinding) {
        AppMethodBeat.i(72059);
        if (eventBinding == null) {
            AppMethodBeat.o(72059);
            return;
        }
        try {
            View view2 = matchedView.getView();
            if (view2 == null) {
                AppMethodBeat.o(72059);
            } else if (ViewHierarchy.isRCTButton(view2)) {
                attachRCTListener(matchedView, view, eventBinding);
                AppMethodBeat.o(72059);
            } else {
                Object obj;
                String viewMapKey = matchedView.getViewMapKey();
                AccessibilityDelegate existingDelegate = ViewHierarchy.getExistingDelegate(view2);
                Object obj2 = existingDelegate != null ? 1 : null;
                if (obj2 == null || !(existingDelegate instanceof AutoLoggingAccessibilityDelegate)) {
                    obj = null;
                } else {
                    obj = 1;
                }
                Object obj3;
                if (obj == null || !((AutoLoggingAccessibilityDelegate) existingDelegate).getSupportCodelessLogging()) {
                    obj3 = null;
                } else {
                    obj3 = 1;
                }
                if (!this.delegateMap.containsKey(viewMapKey) && (obj2 == null || obj == null || obj3 == null)) {
                    view2.setAccessibilityDelegate(CodelessLoggingEventListener.getAccessibilityDelegate(eventBinding, view, view2));
                    this.delegateMap.put(viewMapKey, eventBinding.getEventName());
                }
                AppMethodBeat.o(72059);
            }
        } catch (FacebookException e) {
            CodelessMatcher.access$100();
            AppMethodBeat.o(72059);
        }
    }

    private void attachRCTListener(MatchedView matchedView, View view, EventBinding eventBinding) {
        AppMethodBeat.i(72060);
        if (eventBinding == null) {
            AppMethodBeat.o(72060);
            return;
        }
        View view2 = matchedView.getView();
        if (view2 == null || !ViewHierarchy.isRCTButton(view2)) {
            AppMethodBeat.o(72060);
            return;
        }
        Object obj;
        String viewMapKey = matchedView.getViewMapKey();
        OnTouchListener existingOnTouchListener = ViewHierarchy.getExistingOnTouchListener(view2);
        Object obj2 = existingOnTouchListener != null ? 1 : null;
        if (obj2 == null || !(existingOnTouchListener instanceof AutoLoggingOnTouchListener)) {
            obj = null;
        } else {
            obj = 1;
        }
        Object obj3;
        if (obj == null || !((AutoLoggingOnTouchListener) existingOnTouchListener).getSupportCodelessLogging()) {
            obj3 = null;
        } else {
            obj3 = 1;
        }
        if (!this.delegateMap.containsKey(viewMapKey) && (obj2 == null || obj == null || obj3 == null)) {
            view2.setOnTouchListener(RCTCodelessLoggingEventListener.getOnTouchListener(eventBinding, view, view2));
            this.delegateMap.put(viewMapKey, eventBinding.getEventName());
        }
        AppMethodBeat.o(72060);
    }
}
