package com.facebook.login;

import android.app.AlertDialog.Builder;
import android.app.Dialog;
import android.content.DialogInterface;
import android.content.DialogInterface.OnClickListener;
import android.graphics.drawable.BitmapDrawable;
import android.os.Bundle;
import android.support.v4.app.DialogFragment;
import android.text.Html;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.TextView;
import com.facebook.AccessToken;
import com.facebook.AccessTokenSource;
import com.facebook.FacebookActivity;
import com.facebook.FacebookException;
import com.facebook.FacebookSdk;
import com.facebook.GraphRequest;
import com.facebook.GraphRequestAsyncTask;
import com.facebook.HttpMethod;
import com.facebook.appevents.AppEventsLogger;
import com.facebook.devicerequests.internal.DeviceRequestsHelper;
import com.facebook.internal.ServerProtocol;
import com.facebook.internal.Utility.PermissionsPair;
import com.facebook.internal.Validate;
import com.facebook.login.LoginClient.Request;
import com.tencent.matrix.trace.core.AppMethodBeat;
import java.util.Date;
import java.util.concurrent.ScheduledFuture;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.atomic.AtomicBoolean;

public class DeviceAuthDialog extends DialogFragment {
    private static final String DEVICE_LOGIN_ENDPOINT = "device/login";
    private static final String DEVICE_LOGIN_STATUS_ENDPOINT = "device/login_status";
    private static final int LOGIN_ERROR_SUBCODE_AUTHORIZATION_DECLINED = 1349173;
    private static final int LOGIN_ERROR_SUBCODE_AUTHORIZATION_PENDING = 1349174;
    private static final int LOGIN_ERROR_SUBCODE_CODE_EXPIRED = 1349152;
    private static final int LOGIN_ERROR_SUBCODE_EXCESSIVE_POLLING = 1349172;
    private static final String REQUEST_STATE_KEY = "request_state";
    private AtomicBoolean completed = new AtomicBoolean();
    private TextView confirmationCode;
    private volatile GraphRequestAsyncTask currentGraphRequestPoll;
    private volatile RequestState currentRequestState;
    private DeviceAuthMethodHandler deviceAuthMethodHandler;
    private Dialog dialog;
    private TextView instructions;
    private boolean isBeingDestroyed = false;
    private boolean isRetry = false;
    private Request mRequest = null;
    private View progressBar;
    private volatile ScheduledFuture scheduledPoll;

    public DeviceAuthDialog() {
        AppMethodBeat.i(96726);
        AppMethodBeat.o(96726);
    }

    static /* synthetic */ void access$100(DeviceAuthDialog deviceAuthDialog, RequestState requestState) {
        AppMethodBeat.i(96743);
        deviceAuthDialog.setCurrentRequestState(requestState);
        AppMethodBeat.o(96743);
    }

    static /* synthetic */ void access$1100(DeviceAuthDialog deviceAuthDialog, String str, PermissionsPair permissionsPair, String str2, String str3, Date date, Date date2) {
        AppMethodBeat.i(96748);
        deviceAuthDialog.presentConfirmation(str, permissionsPair, str2, str3, date, date2);
        AppMethodBeat.o(96748);
    }

    static /* synthetic */ void access$200(DeviceAuthDialog deviceAuthDialog) {
        AppMethodBeat.i(96744);
        deviceAuthDialog.poll();
        AppMethodBeat.o(96744);
    }

    static /* synthetic */ void access$400(DeviceAuthDialog deviceAuthDialog) {
        AppMethodBeat.i(96745);
        deviceAuthDialog.schedulePoll();
        AppMethodBeat.o(96745);
    }

    static /* synthetic */ void access$700(DeviceAuthDialog deviceAuthDialog, String str, Long l, Long l2) {
        AppMethodBeat.i(96746);
        deviceAuthDialog.onSuccess(str, l, l2);
        AppMethodBeat.o(96746);
    }

    static /* synthetic */ void access$900(DeviceAuthDialog deviceAuthDialog, String str, PermissionsPair permissionsPair, String str2, Date date, Date date2) {
        AppMethodBeat.i(96747);
        deviceAuthDialog.completeLogin(str, permissionsPair, str2, date, date2);
        AppMethodBeat.o(96747);
    }

    public View onCreateView(LayoutInflater layoutInflater, ViewGroup viewGroup, Bundle bundle) {
        AppMethodBeat.i(96727);
        View onCreateView = super.onCreateView(layoutInflater, viewGroup, bundle);
        this.deviceAuthMethodHandler = (DeviceAuthMethodHandler) ((LoginFragment) ((FacebookActivity) getActivity()).getCurrentFragment()).getLoginClient().getCurrentHandler();
        if (bundle != null) {
            RequestState requestState = (RequestState) bundle.getParcelable(REQUEST_STATE_KEY);
            if (requestState != null) {
                setCurrentRequestState(requestState);
            }
        }
        AppMethodBeat.o(96727);
        return onCreateView;
    }

    public Dialog onCreateDialog(Bundle bundle) {
        AppMethodBeat.i(96728);
        this.dialog = new Dialog(getActivity(), 2131493845);
        boolean z = DeviceRequestsHelper.isAvailable() && !this.isRetry;
        this.dialog.setContentView(initializeContentView(z));
        Dialog dialog = this.dialog;
        AppMethodBeat.o(96728);
        return dialog;
    }

    public void onDismiss(DialogInterface dialogInterface) {
        AppMethodBeat.i(96729);
        super.onDismiss(dialogInterface);
        if (!this.isBeingDestroyed) {
            onCancel();
        }
        AppMethodBeat.o(96729);
    }

    public void onSaveInstanceState(Bundle bundle) {
        AppMethodBeat.i(96730);
        super.onSaveInstanceState(bundle);
        if (this.currentRequestState != null) {
            bundle.putParcelable(REQUEST_STATE_KEY, this.currentRequestState);
        }
        AppMethodBeat.o(96730);
    }

    public void onDestroy() {
        AppMethodBeat.i(96731);
        this.isBeingDestroyed = true;
        this.completed.set(true);
        super.onDestroy();
        if (this.currentGraphRequestPoll != null) {
            this.currentGraphRequestPoll.cancel(true);
        }
        if (this.scheduledPoll != null) {
            this.scheduledPoll.cancel(true);
        }
        AppMethodBeat.o(96731);
    }

    public void startLogin(Request request) {
        AppMethodBeat.i(96732);
        this.mRequest = request;
        Bundle bundle = new Bundle();
        bundle.putString(ServerProtocol.DIALOG_PARAM_SCOPE, TextUtils.join(",", request.getPermissions()));
        String deviceRedirectUriString = request.getDeviceRedirectUriString();
        if (deviceRedirectUriString != null) {
            bundle.putString(ServerProtocol.DIALOG_PARAM_REDIRECT_URI, deviceRedirectUriString);
        }
        deviceRedirectUriString = request.getDeviceAuthTargetUserId();
        if (deviceRedirectUriString != null) {
            bundle.putString("target_user_id", deviceRedirectUriString);
        }
        bundle.putString("access_token", Validate.hasAppID() + "|" + Validate.hasClientToken());
        bundle.putString("device_info", DeviceRequestsHelper.getDeviceInfo());
        new GraphRequest(null, DEVICE_LOGIN_ENDPOINT, bundle, HttpMethod.POST, new 1(this)).executeAsync();
        AppMethodBeat.o(96732);
    }

    private void setCurrentRequestState(RequestState requestState) {
        AppMethodBeat.i(96733);
        this.currentRequestState = requestState;
        this.confirmationCode.setText(requestState.getUserCode());
        this.instructions.setCompoundDrawablesWithIntrinsicBounds(null, new BitmapDrawable(getResources(), DeviceRequestsHelper.generateQRCode(requestState.getAuthorizationUri())), null, null);
        this.confirmationCode.setVisibility(0);
        this.progressBar.setVisibility(8);
        if (!this.isRetry && DeviceRequestsHelper.startAdvertisementService(requestState.getUserCode())) {
            AppEventsLogger.newLogger(getContext()).logSdkEvent("fb_smart_login_service", null, null);
        }
        if (requestState.withinLastRefreshWindow()) {
            schedulePoll();
            AppMethodBeat.o(96733);
            return;
        }
        poll();
        AppMethodBeat.o(96733);
    }

    /* Access modifiers changed, original: protected */
    public View initializeContentView(boolean z) {
        AppMethodBeat.i(96734);
        View inflate = getActivity().getLayoutInflater().inflate(getLayoutResId(z), null);
        this.progressBar = inflate.findViewById(2131821099);
        this.confirmationCode = (TextView) inflate.findViewById(2131822893);
        ((Button) inflate.findViewById(2131822895)).setOnClickListener(new 2(this));
        this.instructions = (TextView) inflate.findViewById(2131822894);
        this.instructions.setText(Html.fromHtml(getString(2131296295)));
        AppMethodBeat.o(96734);
        return inflate;
    }

    /* Access modifiers changed, original: protected */
    public int getLayoutResId(boolean z) {
        return z ? 2130969170 : 2130969168;
    }

    private void poll() {
        AppMethodBeat.i(96735);
        this.currentRequestState.setLastPoll(new Date().getTime());
        this.currentGraphRequestPoll = getPollRequest().executeAsync();
        AppMethodBeat.o(96735);
    }

    private void schedulePoll() {
        AppMethodBeat.i(96736);
        this.scheduledPoll = DeviceAuthMethodHandler.getBackgroundExecutor().schedule(new 3(this), this.currentRequestState.getInterval(), TimeUnit.SECONDS);
        AppMethodBeat.o(96736);
    }

    private GraphRequest getPollRequest() {
        AppMethodBeat.i(96737);
        Bundle bundle = new Bundle();
        bundle.putString("code", this.currentRequestState.getRequestCode());
        GraphRequest graphRequest = new GraphRequest(null, DEVICE_LOGIN_STATUS_ENDPOINT, bundle, HttpMethod.POST, new 4(this));
        AppMethodBeat.o(96737);
        return graphRequest;
    }

    private void presentConfirmation(String str, PermissionsPair permissionsPair, String str2, String str3, Date date, Date date2) {
        AppMethodBeat.i(96738);
        String string = getResources().getString(2131296316);
        String string2 = getResources().getString(2131296315);
        String string3 = getResources().getString(2131296314);
        String format = String.format(string2, new Object[]{str3});
        Builder builder = new Builder(getContext());
        final String str4 = str;
        final PermissionsPair permissionsPair2 = permissionsPair;
        final String str5 = str2;
        final Date date3 = date;
        final Date date4 = date2;
        builder.setMessage(string).setCancelable(true).setNegativeButton(format, new OnClickListener() {
            public void onClick(DialogInterface dialogInterface, int i) {
                AppMethodBeat.i(96716);
                DeviceAuthDialog.access$900(DeviceAuthDialog.this, str4, permissionsPair2, str5, date3, date4);
                AppMethodBeat.o(96716);
            }
        }).setPositiveButton(string3, new OnClickListener() {
            public void onClick(DialogInterface dialogInterface, int i) {
                AppMethodBeat.i(96715);
                DeviceAuthDialog.this.dialog.setContentView(DeviceAuthDialog.this.initializeContentView(false));
                DeviceAuthDialog.this.startLogin(DeviceAuthDialog.this.mRequest);
                AppMethodBeat.o(96715);
            }
        });
        builder.create().show();
        AppMethodBeat.o(96738);
    }

    private void onSuccess(String str, Long l, Long l2) {
        AppMethodBeat.i(96739);
        Bundle bundle = new Bundle();
        bundle.putString(GraphRequest.FIELDS_PARAM, "id,permissions,name");
        Date date = l.longValue() != 0 ? new Date(new Date().getTime() + (l.longValue() * 1000)) : null;
        Date date2 = (l2.longValue() == 0 || l2 == null) ? null : new Date(l2.longValue() * 1000);
        new GraphRequest(new AccessToken(str, FacebookSdk.getApplicationId(), "0", null, null, null, date, null, date2), "me", bundle, HttpMethod.GET, new 7(this, str, date, date2)).executeAsync();
        AppMethodBeat.o(96739);
    }

    private void completeLogin(String str, PermissionsPair permissionsPair, String str2, Date date, Date date2) {
        AppMethodBeat.i(96740);
        this.deviceAuthMethodHandler.onSuccess(str2, FacebookSdk.getApplicationId(), str, permissionsPair.getGrantedPermissions(), permissionsPair.getDeclinedPermissions(), AccessTokenSource.DEVICE_AUTH, date, null, date2);
        this.dialog.dismiss();
        AppMethodBeat.o(96740);
    }

    /* Access modifiers changed, original: protected */
    public void onError(FacebookException facebookException) {
        AppMethodBeat.i(96741);
        if (this.completed.compareAndSet(false, true)) {
            if (this.currentRequestState != null) {
                DeviceRequestsHelper.cleanUpAdvertisementService(this.currentRequestState.getUserCode());
            }
            this.deviceAuthMethodHandler.onError(facebookException);
            this.dialog.dismiss();
            AppMethodBeat.o(96741);
            return;
        }
        AppMethodBeat.o(96741);
    }

    /* Access modifiers changed, original: protected */
    public void onCancel() {
        AppMethodBeat.i(96742);
        if (this.completed.compareAndSet(false, true)) {
            if (this.currentRequestState != null) {
                DeviceRequestsHelper.cleanUpAdvertisementService(this.currentRequestState.getUserCode());
            }
            if (this.deviceAuthMethodHandler != null) {
                this.deviceAuthMethodHandler.onCancel();
            }
            this.dialog.dismiss();
            AppMethodBeat.o(96742);
            return;
        }
        AppMethodBeat.o(96742);
    }
}
