package com.google.android.gms.internal.measurement;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteDatabaseLockedException;
import android.database.sqlite.SQLiteException;
import android.database.sqlite.SQLiteFullException;
import android.os.Parcel;
import android.os.SystemClock;
import com.google.android.gms.common.util.Clock;
import com.google.android.gms.common.util.VisibleForTesting;
import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.ttpic.util.VideoMaterialUtil;

public final class zzfc extends zzhh {
    private final zzfd zzaig = new zzfd(this, getContext(), "google_app_measurement_local.db");
    private boolean zzaih;

    zzfc(zzgl zzgl) {
        super(zzgl);
        AppMethodBeat.i(68802);
        AppMethodBeat.o(68802);
    }

    @VisibleForTesting
    private final SQLiteDatabase getWritableDatabase() {
        AppMethodBeat.i(68809);
        if (this.zzaih) {
            AppMethodBeat.o(68809);
            return null;
        }
        SQLiteDatabase writableDatabase = this.zzaig.getWritableDatabase();
        if (writableDatabase == null) {
            this.zzaih = true;
            AppMethodBeat.o(68809);
            return null;
        }
        AppMethodBeat.o(68809);
        return writableDatabase;
    }

    private final boolean zza(int i, byte[] bArr) {
        AppMethodBeat.i(68804);
        zzab();
        if (this.zzaih) {
            AppMethodBeat.o(68804);
            return false;
        }
        ContentValues contentValues = new ContentValues();
        contentValues.put(VideoMaterialUtil.CRAZYFACE_LAYER_TYPE, Integer.valueOf(i));
        contentValues.put("entry", bArr);
        int i2 = 5;
        int i3 = 0;
        while (true) {
            int i4 = i3;
            if (i4 < 5) {
                SQLiteDatabase sQLiteDatabase = null;
                Cursor cursor = null;
                try {
                    sQLiteDatabase = getWritableDatabase();
                    if (sQLiteDatabase == null) {
                        this.zzaih = true;
                        if (sQLiteDatabase != null) {
                            sQLiteDatabase.close();
                        }
                        AppMethodBeat.o(68804);
                        return false;
                    }
                    sQLiteDatabase.beginTransaction();
                    long j = 0;
                    cursor = sQLiteDatabase.rawQuery("select count(1) from messages", null);
                    if (cursor != null && cursor.moveToFirst()) {
                        j = cursor.getLong(0);
                    }
                    if (j >= 100000) {
                        zzge().zzim().log("Data loss, local db full");
                        j = (100000 - j) + 1;
                        long delete = (long) sQLiteDatabase.delete("messages", "rowid in (select rowid from messages order by rowid asc limit ?)", new String[]{Long.toString(j)});
                        if (delete != j) {
                            zzge().zzim().zzd("Different delete count than expected in local db. expected, received, difference", Long.valueOf(j), Long.valueOf(delete), Long.valueOf(j - delete));
                        }
                    }
                    sQLiteDatabase.insertOrThrow("messages", null, contentValues);
                    sQLiteDatabase.setTransactionSuccessful();
                    sQLiteDatabase.endTransaction();
                    if (cursor != null) {
                        cursor.close();
                    }
                    if (sQLiteDatabase != null) {
                        sQLiteDatabase.close();
                    }
                    AppMethodBeat.o(68804);
                    return true;
                } catch (SQLiteFullException e) {
                    zzge().zzim().zzg("Error writing entry to local database", e);
                    this.zzaih = true;
                    if (cursor != null) {
                        cursor.close();
                    }
                    if (sQLiteDatabase != null) {
                        sQLiteDatabase.close();
                    }
                } catch (SQLiteDatabaseLockedException e2) {
                    SystemClock.sleep((long) i2);
                    i2 += 20;
                    if (cursor != null) {
                        cursor.close();
                    }
                    if (sQLiteDatabase != null) {
                        sQLiteDatabase.close();
                    }
                } catch (SQLiteException e3) {
                    if (sQLiteDatabase != null) {
                        if (sQLiteDatabase.inTransaction()) {
                            sQLiteDatabase.endTransaction();
                        }
                    }
                    zzge().zzim().zzg("Error writing entry to local database", e3);
                    this.zzaih = true;
                    if (cursor != null) {
                        cursor.close();
                    }
                    if (sQLiteDatabase != null) {
                        sQLiteDatabase.close();
                    }
                } catch (Throwable th) {
                    if (cursor != null) {
                        cursor.close();
                    }
                    if (sQLiteDatabase != null) {
                        sQLiteDatabase.close();
                    }
                    AppMethodBeat.o(68804);
                }
            } else {
                zzge().zzip().log("Failed to write entry to local database");
                AppMethodBeat.o(68804);
                return false;
            }
            i3 = i4 + 1;
        }
    }

    public final /* bridge */ /* synthetic */ Context getContext() {
        AppMethodBeat.i(68820);
        Context context = super.getContext();
        AppMethodBeat.o(68820);
        return context;
    }

    public final void resetAnalyticsData() {
        AppMethodBeat.i(68803);
        zzab();
        try {
            int delete = getWritableDatabase().delete("messages", null, null) + 0;
            if (delete > 0) {
                zzge().zzit().zzg("Reset local analytics data. records", Integer.valueOf(delete));
            }
            AppMethodBeat.o(68803);
        } catch (SQLiteException e) {
            zzge().zzim().zzg("Error resetting local analytics data. error", e);
            AppMethodBeat.o(68803);
        }
    }

    public final boolean zza(zzeu zzeu) {
        AppMethodBeat.i(68805);
        Parcel obtain = Parcel.obtain();
        zzeu.writeToParcel(obtain, 0);
        byte[] marshall = obtain.marshall();
        obtain.recycle();
        if (marshall.length > 131072) {
            zzge().zzip().log("Event is too long for local database. Sending event directly to service");
            AppMethodBeat.o(68805);
            return false;
        }
        boolean zza = zza(0, marshall);
        AppMethodBeat.o(68805);
        return zza;
    }

    public final boolean zza(zzjx zzjx) {
        AppMethodBeat.i(68806);
        Parcel obtain = Parcel.obtain();
        zzjx.writeToParcel(obtain, 0);
        byte[] marshall = obtain.marshall();
        obtain.recycle();
        if (marshall.length > 131072) {
            zzge().zzip().log("User property too long for local database. Sending directly to service");
            AppMethodBeat.o(68806);
            return false;
        }
        boolean zza = zza(1, marshall);
        AppMethodBeat.o(68806);
        return zza;
    }

    public final /* bridge */ /* synthetic */ void zzab() {
        AppMethodBeat.i(68812);
        super.zzab();
        AppMethodBeat.o(68812);
    }

    public final /* bridge */ /* synthetic */ Clock zzbt() {
        AppMethodBeat.i(68819);
        Clock zzbt = super.zzbt();
        AppMethodBeat.o(68819);
        return zzbt;
    }

    public final boolean zzc(zzed zzed) {
        AppMethodBeat.i(68807);
        zzgb();
        byte[] zza = zzka.zza(zzed);
        if (zza.length > 131072) {
            zzge().zzip().log("Conditional user property too long for local database. Sending directly to service");
            AppMethodBeat.o(68807);
            return false;
        }
        boolean zza2 = zza(2, zza);
        AppMethodBeat.o(68807);
        return zza2;
    }

    public final /* bridge */ /* synthetic */ void zzfr() {
        AppMethodBeat.i(68810);
        super.zzfr();
        AppMethodBeat.o(68810);
    }

    public final /* bridge */ /* synthetic */ void zzfs() {
        AppMethodBeat.i(68811);
        super.zzfs();
        AppMethodBeat.o(68811);
    }

    public final /* bridge */ /* synthetic */ zzdu zzft() {
        AppMethodBeat.i(68813);
        zzdu zzft = super.zzft();
        AppMethodBeat.o(68813);
        return zzft;
    }

    public final /* bridge */ /* synthetic */ zzhk zzfu() {
        AppMethodBeat.i(68814);
        zzhk zzfu = super.zzfu();
        AppMethodBeat.o(68814);
        return zzfu;
    }

    public final /* bridge */ /* synthetic */ zzfb zzfv() {
        AppMethodBeat.i(68815);
        zzfb zzfv = super.zzfv();
        AppMethodBeat.o(68815);
        return zzfv;
    }

    public final /* bridge */ /* synthetic */ zzeo zzfw() {
        AppMethodBeat.i(68816);
        zzeo zzfw = super.zzfw();
        AppMethodBeat.o(68816);
        return zzfw;
    }

    public final /* bridge */ /* synthetic */ zzii zzfx() {
        AppMethodBeat.i(68817);
        zzii zzfx = super.zzfx();
        AppMethodBeat.o(68817);
        return zzfx;
    }

    public final /* bridge */ /* synthetic */ zzif zzfy() {
        AppMethodBeat.i(68818);
        zzif zzfy = super.zzfy();
        AppMethodBeat.o(68818);
        return zzfy;
    }

    public final /* bridge */ /* synthetic */ zzfc zzfz() {
        AppMethodBeat.i(68821);
        zzfc zzfz = super.zzfz();
        AppMethodBeat.o(68821);
        return zzfz;
    }

    public final /* bridge */ /* synthetic */ zzfe zzga() {
        AppMethodBeat.i(68822);
        zzfe zzga = super.zzga();
        AppMethodBeat.o(68822);
        return zzga;
    }

    public final /* bridge */ /* synthetic */ zzka zzgb() {
        AppMethodBeat.i(68823);
        zzka zzgb = super.zzgb();
        AppMethodBeat.o(68823);
        return zzgb;
    }

    public final /* bridge */ /* synthetic */ zzjh zzgc() {
        AppMethodBeat.i(68824);
        zzjh zzgc = super.zzgc();
        AppMethodBeat.o(68824);
        return zzgc;
    }

    public final /* bridge */ /* synthetic */ zzgg zzgd() {
        AppMethodBeat.i(68825);
        zzgg zzgd = super.zzgd();
        AppMethodBeat.o(68825);
        return zzgd;
    }

    public final /* bridge */ /* synthetic */ zzfg zzge() {
        AppMethodBeat.i(68826);
        zzfg zzge = super.zzge();
        AppMethodBeat.o(68826);
        return zzge;
    }

    public final /* bridge */ /* synthetic */ zzfr zzgf() {
        AppMethodBeat.i(68827);
        zzfr zzgf = super.zzgf();
        AppMethodBeat.o(68827);
        return zzgf;
    }

    public final /* bridge */ /* synthetic */ zzef zzgg() {
        AppMethodBeat.i(68828);
        zzef zzgg = super.zzgg();
        AppMethodBeat.o(68828);
        return zzgg;
    }

    /* Access modifiers changed, original: protected|final */
    public final boolean zzhf() {
        return false;
    }

    /* JADX WARNING: Removed duplicated region for block: B:58:0x00f5  */
    /* JADX WARNING: Removed duplicated region for block: B:158:0x00d2 A:{SYNTHETIC} */
    /* JADX WARNING: Removed duplicated region for block: B:60:0x00fa  */
    /* JADX WARNING: Removed duplicated region for block: B:68:0x010d A:{SYNTHETIC, Splitter:B:68:0x010d} */
    /* JADX WARNING: Removed duplicated region for block: B:74:0x0129  */
    /* JADX WARNING: Removed duplicated region for block: B:76:0x012e  */
    /* JADX WARNING: Removed duplicated region for block: B:92:0x015a  */
    /* JADX WARNING: Removed duplicated region for block: B:94:0x015f  */
    /* JADX WARNING: Removed duplicated region for block: B:58:0x00f5  */
    /* JADX WARNING: Removed duplicated region for block: B:60:0x00fa  */
    /* JADX WARNING: Removed duplicated region for block: B:158:0x00d2 A:{SYNTHETIC} */
    /* JADX WARNING: Removed duplicated region for block: B:68:0x010d A:{SYNTHETIC, Splitter:B:68:0x010d} */
    /* JADX WARNING: Removed duplicated region for block: B:74:0x0129  */
    /* JADX WARNING: Removed duplicated region for block: B:76:0x012e  */
    /* JADX WARNING: Removed duplicated region for block: B:92:0x015a  */
    /* JADX WARNING: Removed duplicated region for block: B:94:0x015f  */
    /* JADX WARNING: Removed duplicated region for block: B:92:0x015a  */
    /* JADX WARNING: Removed duplicated region for block: B:94:0x015f  */
    public final java.util.List<com.google.android.gms.common.internal.safeparcel.AbstractSafeParcelable> zzp(int r14) {
        /*
        r13 = this;
        r0 = 68808; // 0x10cc8 float:9.642E-41 double:3.39957E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r0);
        r13.zzab();
        r0 = r13.zzaih;
        if (r0 == 0) goto L_0x0015;
    L_0x000d:
        r0 = 0;
        r1 = 68808; // 0x10cc8 float:9.642E-41 double:3.39957E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r1);
    L_0x0014:
        return r0;
    L_0x0015:
        r10 = new java.util.ArrayList;
        r10.<init>();
        r0 = r13.getContext();
        r1 = "google_app_measurement_local.db";
        r0 = r0.getDatabasePath(r1);
        r0 = r0.exists();
        if (r0 != 0) goto L_0x0033;
    L_0x002b:
        r0 = 68808; // 0x10cc8 float:9.642E-41 double:3.39957E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r0);
        r0 = r10;
        goto L_0x0014;
    L_0x0033:
        r9 = 5;
        r0 = 0;
        r12 = r0;
    L_0x0036:
        r0 = 5;
        if (r12 >= r0) goto L_0x021b;
    L_0x0039:
        r3 = 0;
        r11 = 0;
        r0 = r13.getWritableDatabase();	 Catch:{ SQLiteFullException -> 0x0253, SQLiteDatabaseLockedException -> 0x024a, SQLiteException -> 0x0240, all -> 0x0232 }
        if (r0 != 0) goto L_0x0051;
    L_0x0041:
        r1 = 1;
        r13.zzaih = r1;	 Catch:{ SQLiteFullException -> 0x0258, SQLiteDatabaseLockedException -> 0x024e, SQLiteException -> 0x0245, all -> 0x0237 }
        if (r0 == 0) goto L_0x0049;
    L_0x0046:
        r0.close();
    L_0x0049:
        r0 = 0;
        r1 = 68808; // 0x10cc8 float:9.642E-41 double:3.39957E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r1);
        goto L_0x0014;
    L_0x0051:
        r0.beginTransaction();	 Catch:{ SQLiteFullException -> 0x0258, SQLiteDatabaseLockedException -> 0x024e, SQLiteException -> 0x0245, all -> 0x0237 }
        r1 = "messages";
        r2 = 3;
        r2 = new java.lang.String[r2];	 Catch:{ SQLiteFullException -> 0x0258, SQLiteDatabaseLockedException -> 0x024e, SQLiteException -> 0x0245, all -> 0x0237 }
        r3 = 0;
        r4 = "rowid";
        r2[r3] = r4;	 Catch:{ SQLiteFullException -> 0x0258, SQLiteDatabaseLockedException -> 0x024e, SQLiteException -> 0x0245, all -> 0x0237 }
        r3 = 1;
        r4 = "type";
        r2[r3] = r4;	 Catch:{ SQLiteFullException -> 0x0258, SQLiteDatabaseLockedException -> 0x024e, SQLiteException -> 0x0245, all -> 0x0237 }
        r3 = 2;
        r4 = "entry";
        r2[r3] = r4;	 Catch:{ SQLiteFullException -> 0x0258, SQLiteDatabaseLockedException -> 0x024e, SQLiteException -> 0x0245, all -> 0x0237 }
        r3 = 0;
        r4 = 0;
        r5 = 0;
        r6 = 0;
        r7 = "rowid asc";
        r8 = 100;
        r8 = java.lang.Integer.toString(r8);	 Catch:{ SQLiteFullException -> 0x0258, SQLiteDatabaseLockedException -> 0x024e, SQLiteException -> 0x0245, all -> 0x0237 }
        r2 = r0.query(r1, r2, r3, r4, r5, r6, r7, r8);	 Catch:{ SQLiteFullException -> 0x0258, SQLiteDatabaseLockedException -> 0x024e, SQLiteException -> 0x0245, all -> 0x0237 }
        r4 = -1;
    L_0x007f:
        r1 = r2.moveToNext();	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        if (r1 == 0) goto L_0x01da;
    L_0x0085:
        r1 = 0;
        r4 = r2.getLong(r1);	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        r1 = 1;
        r1 = r2.getInt(r1);	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        r3 = 2;
        r6 = r2.getBlob(r3);	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        if (r1 != 0) goto L_0x0133;
    L_0x0096:
        r3 = android.os.Parcel.obtain();	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        r1 = 0;
        r7 = r6.length;	 Catch:{ ParseException -> 0x00d8 }
        r3.unmarshall(r6, r1, r7);	 Catch:{ ParseException -> 0x00d8 }
        r1 = 0;
        r3.setDataPosition(r1);	 Catch:{ ParseException -> 0x00d8 }
        r1 = com.google.android.gms.internal.measurement.zzeu.CREATOR;	 Catch:{ ParseException -> 0x00d8 }
        r1 = r1.createFromParcel(r3);	 Catch:{ ParseException -> 0x00d8 }
        r1 = (com.google.android.gms.internal.measurement.zzeu) r1;	 Catch:{ ParseException -> 0x00d8 }
        r3.recycle();	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        if (r1 == 0) goto L_0x007f;
    L_0x00b0:
        r10.add(r1);	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        goto L_0x007f;
    L_0x00b4:
        r1 = move-exception;
        r3 = r0;
    L_0x00b6:
        r0 = r13.zzge();	 Catch:{ all -> 0x023c }
        r0 = r0.zzim();	 Catch:{ all -> 0x023c }
        r4 = "Error reading entries from local database";
        r0.zzg(r4, r1);	 Catch:{ all -> 0x023c }
        r0 = 1;
        r13.zzaih = r0;	 Catch:{ all -> 0x023c }
        if (r2 == 0) goto L_0x00cc;
    L_0x00c9:
        r2.close();
    L_0x00cc:
        if (r3 == 0) goto L_0x025d;
    L_0x00ce:
        r3.close();
        r0 = r9;
    L_0x00d2:
        r1 = r12 + 1;
        r12 = r1;
        r9 = r0;
        goto L_0x0036;
    L_0x00d8:
        r1 = move-exception;
        r1 = r13.zzge();	 Catch:{ all -> 0x00fe }
        r1 = r1.zzim();	 Catch:{ all -> 0x00fe }
        r6 = "Failed to load event from local database";
        r1.log(r6);	 Catch:{ all -> 0x00fe }
        r3.recycle();	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        goto L_0x007f;
    L_0x00eb:
        r1 = move-exception;
        r3 = r0;
    L_0x00ed:
        r0 = (long) r9;
        android.os.SystemClock.sleep(r0);	 Catch:{ all -> 0x023c }
        r0 = r9 + 20;
        if (r2 == 0) goto L_0x00f8;
    L_0x00f5:
        r2.close();
    L_0x00f8:
        if (r3 == 0) goto L_0x00d2;
    L_0x00fa:
        r3.close();
        goto L_0x00d2;
    L_0x00fe:
        r1 = move-exception;
        r3.recycle();	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        r3 = 68808; // 0x10cc8 float:9.642E-41 double:3.39957E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r3);	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        throw r1;	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
    L_0x0109:
        r1 = move-exception;
        r3 = r0;
    L_0x010b:
        if (r3 == 0) goto L_0x0116;
    L_0x010d:
        r0 = r3.inTransaction();	 Catch:{ all -> 0x023c }
        if (r0 == 0) goto L_0x0116;
    L_0x0113:
        r3.endTransaction();	 Catch:{ all -> 0x023c }
    L_0x0116:
        r0 = r13.zzge();	 Catch:{ all -> 0x023c }
        r0 = r0.zzim();	 Catch:{ all -> 0x023c }
        r4 = "Error reading entries from local database";
        r0.zzg(r4, r1);	 Catch:{ all -> 0x023c }
        r0 = 1;
        r13.zzaih = r0;	 Catch:{ all -> 0x023c }
        if (r2 == 0) goto L_0x012c;
    L_0x0129:
        r2.close();
    L_0x012c:
        if (r3 == 0) goto L_0x025d;
    L_0x012e:
        r3.close();
        r0 = r9;
        goto L_0x00d2;
    L_0x0133:
        r3 = 1;
        if (r1 != r3) goto L_0x0188;
    L_0x0136:
        r7 = android.os.Parcel.obtain();	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        r3 = 0;
        r1 = 0;
        r8 = r6.length;	 Catch:{ ParseException -> 0x0169 }
        r7.unmarshall(r6, r1, r8);	 Catch:{ ParseException -> 0x0169 }
        r1 = 0;
        r7.setDataPosition(r1);	 Catch:{ ParseException -> 0x0169 }
        r1 = com.google.android.gms.internal.measurement.zzjx.CREATOR;	 Catch:{ ParseException -> 0x0169 }
        r1 = r1.createFromParcel(r7);	 Catch:{ ParseException -> 0x0169 }
        r1 = (com.google.android.gms.internal.measurement.zzjx) r1;	 Catch:{ ParseException -> 0x0169 }
        r7.recycle();	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
    L_0x014f:
        if (r1 == 0) goto L_0x007f;
    L_0x0151:
        r10.add(r1);	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        goto L_0x007f;
    L_0x0156:
        r1 = move-exception;
        r3 = r0;
    L_0x0158:
        if (r2 == 0) goto L_0x015d;
    L_0x015a:
        r2.close();
    L_0x015d:
        if (r3 == 0) goto L_0x0162;
    L_0x015f:
        r3.close();
    L_0x0162:
        r0 = 68808; // 0x10cc8 float:9.642E-41 double:3.39957E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r0);
        throw r1;
    L_0x0169:
        r1 = move-exception;
        r1 = r13.zzge();	 Catch:{ all -> 0x017d }
        r1 = r1.zzim();	 Catch:{ all -> 0x017d }
        r6 = "Failed to load user property from local database";
        r1.log(r6);	 Catch:{ all -> 0x017d }
        r7.recycle();	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        r1 = r3;
        goto L_0x014f;
    L_0x017d:
        r1 = move-exception;
        r7.recycle();	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        r3 = 68808; // 0x10cc8 float:9.642E-41 double:3.39957E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r3);	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        throw r1;	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
    L_0x0188:
        r3 = 2;
        if (r1 != r3) goto L_0x01ca;
    L_0x018b:
        r7 = android.os.Parcel.obtain();	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        r3 = 0;
        r1 = 0;
        r8 = r6.length;	 Catch:{ ParseException -> 0x01ab }
        r7.unmarshall(r6, r1, r8);	 Catch:{ ParseException -> 0x01ab }
        r1 = 0;
        r7.setDataPosition(r1);	 Catch:{ ParseException -> 0x01ab }
        r1 = com.google.android.gms.internal.measurement.zzed.CREATOR;	 Catch:{ ParseException -> 0x01ab }
        r1 = r1.createFromParcel(r7);	 Catch:{ ParseException -> 0x01ab }
        r1 = (com.google.android.gms.internal.measurement.zzed) r1;	 Catch:{ ParseException -> 0x01ab }
        r7.recycle();	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
    L_0x01a4:
        if (r1 == 0) goto L_0x007f;
    L_0x01a6:
        r10.add(r1);	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        goto L_0x007f;
    L_0x01ab:
        r1 = move-exception;
        r1 = r13.zzge();	 Catch:{ all -> 0x01bf }
        r1 = r1.zzim();	 Catch:{ all -> 0x01bf }
        r6 = "Failed to load user property from local database";
        r1.log(r6);	 Catch:{ all -> 0x01bf }
        r7.recycle();	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        r1 = r3;
        goto L_0x01a4;
    L_0x01bf:
        r1 = move-exception;
        r7.recycle();	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        r3 = 68808; // 0x10cc8 float:9.642E-41 double:3.39957E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r3);	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        throw r1;	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
    L_0x01ca:
        r1 = r13.zzge();	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        r1 = r1.zzim();	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        r3 = "Unknown record type in local database";
        r1.log(r3);	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        goto L_0x007f;
    L_0x01da:
        r1 = "messages";
        r3 = "rowid <= ?";
        r6 = 1;
        r6 = new java.lang.String[r6];	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        r7 = 0;
        r4 = java.lang.Long.toString(r4);	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        r6[r7] = r4;	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        r1 = r0.delete(r1, r3, r6);	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        r3 = r10.size();	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        if (r1 >= r3) goto L_0x0202;
    L_0x01f4:
        r1 = r13.zzge();	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        r1 = r1.zzim();	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        r3 = "Fewer entries removed from local database than expected";
        r1.log(r3);	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
    L_0x0202:
        r0.setTransactionSuccessful();	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        r0.endTransaction();	 Catch:{ SQLiteFullException -> 0x00b4, SQLiteDatabaseLockedException -> 0x00eb, SQLiteException -> 0x0109, all -> 0x0156 }
        if (r2 == 0) goto L_0x020d;
    L_0x020a:
        r2.close();
    L_0x020d:
        if (r0 == 0) goto L_0x0212;
    L_0x020f:
        r0.close();
    L_0x0212:
        r0 = 68808; // 0x10cc8 float:9.642E-41 double:3.39957E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r0);
        r0 = r10;
        goto L_0x0014;
    L_0x021b:
        r0 = r13.zzge();
        r0 = r0.zzip();
        r1 = "Failed to read events from database in reasonable time";
        r0.log(r1);
        r0 = 0;
        r1 = 68808; // 0x10cc8 float:9.642E-41 double:3.39957E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r1);
        goto L_0x0014;
    L_0x0232:
        r0 = move-exception;
        r1 = r0;
        r2 = r11;
        goto L_0x0158;
    L_0x0237:
        r1 = move-exception;
        r2 = r11;
        r3 = r0;
        goto L_0x0158;
    L_0x023c:
        r0 = move-exception;
        r1 = r0;
        goto L_0x0158;
    L_0x0240:
        r0 = move-exception;
        r1 = r0;
        r2 = r11;
        goto L_0x010b;
    L_0x0245:
        r1 = move-exception;
        r2 = r11;
        r3 = r0;
        goto L_0x010b;
    L_0x024a:
        r0 = move-exception;
        r2 = r11;
        goto L_0x00ed;
    L_0x024e:
        r1 = move-exception;
        r2 = r11;
        r3 = r0;
        goto L_0x00ed;
    L_0x0253:
        r0 = move-exception;
        r1 = r0;
        r2 = r11;
        goto L_0x00b6;
    L_0x0258:
        r1 = move-exception;
        r2 = r11;
        r3 = r0;
        goto L_0x00b6;
    L_0x025d:
        r0 = r9;
        goto L_0x00d2;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.google.android.gms.internal.measurement.zzfc.zzp(int):java.util.List");
    }
}
