package com.tencent.qqmusic.mediaplayer;

import android.media.AudioTrack;
import android.text.TextUtils;
import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.qqmusic.mediaplayer.AudioFormat.AudioType;
import com.tencent.qqmusic.mediaplayer.codec.BaseDecoder;
import com.tencent.qqmusic.mediaplayer.codec.IAudioRecognition;
import com.tencent.qqmusic.mediaplayer.codec.NativeDecoder;
import com.tencent.qqmusic.mediaplayer.util.Logger;
import java.io.IOException;
import java.util.HashMap;
import java.util.Iterator;

public class AudioRecognition {
    private static final int READ_FILE_HEADER_SIZE = 64;
    private static String TAG = "AudioRecognition";
    private static HashMap<String, AudioType> mGuessFormatResultCache = new HashMap();
    private static HashMap<String, AudioType> mRecognitionResultCache = new HashMap();

    static {
        AppMethodBeat.i(128376);
        AppMethodBeat.o(128376);
    }

    public static AudioType recognitionAudioFormatByExtensions(String str) {
        AppMethodBeat.i(128370);
        AudioType audioType;
        if (TextUtils.isEmpty(str)) {
            AppMethodBeat.o(128370);
            return null;
        } else if (mRecognitionResultCache.containsKey(str)) {
            audioType = (AudioType) mRecognitionResultCache.get(str);
            Logger.w(TAG, "Get from cache " + audioType + ",filepath = " + str + ",retType = " + audioType);
            AppMethodBeat.o(128370);
            return audioType;
        } else {
            audioType = guessFormat(str);
            if (!AudioFormat.isAudioType(audioType)) {
                Logger.i(TAG, "recognitionAudioFormatByExtensions guessAudioType = null,so recognitionAudioFormatExactly filepath = ".concat(String.valueOf(str)));
                try {
                    audioType = recognitionAudioFormatExactly(str);
                } catch (IOException e) {
                    Logger.e(TAG, e);
                }
            }
            Logger.i(TAG, "recognitionAudioFormatByExtensions filepath = " + str + ",guessAudioType = " + audioType);
            AppMethodBeat.o(128370);
            return audioType;
        }
    }

    public static AudioType guessFormat(String str) {
        AppMethodBeat.i(128371);
        AudioType guessAudioType;
        if (mGuessFormatResultCache == null || !mGuessFormatResultCache.containsKey(str)) {
            Iterator it = MediaCodecFactory.getSupportAudioType().iterator();
            while (it.hasNext()) {
                IAudioRecognition createDecoderByType = MediaCodecFactory.createDecoderByType((AudioType) it.next());
                if (createDecoderByType != null) {
                    guessAudioType = createDecoderByType.guessAudioType(str);
                    if (AudioFormat.isAudioType(guessAudioType)) {
                        mGuessFormatResultCache.put(str, guessAudioType);
                        AppMethodBeat.o(128371);
                        return guessAudioType;
                    }
                }
            }
            guessAudioType = AudioType.UNSUPPORT;
            AppMethodBeat.o(128371);
            return guessAudioType;
        }
        guessAudioType = (AudioType) mGuessFormatResultCache.get(str);
        AppMethodBeat.o(128371);
        return guessAudioType;
    }

    public static NativeDecoder getDecoderFormFile(String str) {
        AppMethodBeat.i(128372);
        if (TextUtils.isEmpty(str)) {
            AppMethodBeat.o(128372);
            return null;
        }
        NativeDecoder nativeDecoder = new NativeDecoder();
        nativeDecoder.init(str, false);
        AppMethodBeat.o(128372);
        return nativeDecoder;
    }

    public static int getAudioBitDept(BaseDecoder baseDecoder, AudioInformation audioInformation) {
        int i = 0;
        AppMethodBeat.i(128373);
        int i2 = audioInformation.getAudioType() == AudioType.FLAC ? 1 : 0;
        if (i2 != 0) {
            try {
                i = (int) baseDecoder.getMinBufferSize();
            } catch (Throwable th) {
                Logger.e(TAG, th);
            }
        }
        int minBufferSize = AudioTrack.getMinBufferSize((int) audioInformation.getSampleRate(), audioInformation.getChannels(), 2);
        i2 = i2 == 0 ? minBufferSize % 2048 != 0 ? ((minBufferSize / 2048) + 1) * 2048 : minBufferSize : i;
        i = baseDecoder.decodeData(i2, new byte[i2]);
        if (i <= 0) {
            i2 *= 2;
        } else {
            i2 = i;
        }
        i2 = calcBitDept((long) i2, baseDecoder.getCurrentTime(), audioInformation.getChannels(), audioInformation.getSampleRate());
        AppMethodBeat.o(128373);
        return i2;
    }

    public static int calcBitDept(long j, long j2, int i, long j3) {
        AppMethodBeat.i(128374);
        if (0 == j2 || i == 0) {
            AppMethodBeat.o(128374);
            return 0;
        }
        double d = (double) ((1000.0f * ((float) j)) / ((float) ((((long) i) * j2) * j3)));
        int round = (int) Math.round(d);
        Logger.i(TAG, "byteNumbers = " + j + ",time = " + j2 + ",channels = " + i + ",sampleRate = " + j3 + ",bitDept = " + d);
        AppMethodBeat.o(128374);
        return round;
    }

    /* JADX WARNING: Removed duplicated region for block: B:35:0x00f7  */
    /* JADX WARNING: Removed duplicated region for block: B:68:0x01b7  */
    /* JADX WARNING: Removed duplicated region for block: B:43:0x014f  */
    /* JADX WARNING: Removed duplicated region for block: B:74:0x01f4  */
    /* JADX WARNING: Removed duplicated region for block: B:52:0x0189 A:{SYNTHETIC, Splitter:B:52:0x0189} */
    /* JADX WARNING: Removed duplicated region for block: B:35:0x00f7  */
    /* JADX WARNING: Removed duplicated region for block: B:43:0x014f  */
    /* JADX WARNING: Removed duplicated region for block: B:68:0x01b7  */
    /* JADX WARNING: Removed duplicated region for block: B:52:0x0189 A:{SYNTHETIC, Splitter:B:52:0x0189} */
    /* JADX WARNING: Removed duplicated region for block: B:74:0x01f4  */
    /* JADX WARNING: Removed duplicated region for block: B:35:0x00f7  */
    /* JADX WARNING: Removed duplicated region for block: B:68:0x01b7  */
    /* JADX WARNING: Removed duplicated region for block: B:43:0x014f  */
    /* JADX WARNING: Removed duplicated region for block: B:60:0x019c A:{SYNTHETIC, Splitter:B:60:0x019c} */
    public static com.tencent.qqmusic.mediaplayer.AudioFormat.AudioType recognitionAudioFormatExactly(java.lang.String r14) {
        /*
        r9 = 64;
        r2 = 0;
        r8 = 0;
        r13 = 128375; // 0x1f577 float:1.79892E-40 double:6.34257E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r13);
        if (r14 != 0) goto L_0x0011;
    L_0x000c:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r13);
        r0 = r2;
    L_0x0010:
        return r0;
    L_0x0011:
        r0 = mGuessFormatResultCache;
        r0.remove(r14);
        r0 = TAG;
        r1 = "recognitionAudioFormatExactly  path = ";
        r3 = java.lang.String.valueOf(r14);
        r1 = r1.concat(r3);
        com.tencent.qqmusic.mediaplayer.util.Logger.i(r0, r1);
        r0 = new java.io.File;
        r0.<init>(r14);
        r1 = r0.exists();
        if (r1 != 0) goto L_0x0045;
    L_0x0031:
        r0 = new java.io.FileNotFoundException;
        r1 = "File not found :";
        r2 = java.lang.String.valueOf(r14);
        r1 = r1.concat(r2);
        r0.<init>(r1);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r13);
        throw r0;
    L_0x0045:
        r1 = r0.canRead();
        if (r1 != 0) goto L_0x005f;
    L_0x004b:
        r0 = new java.io.IOException;
        r1 = "Can not read file :";
        r2 = java.lang.String.valueOf(r14);
        r1 = r1.concat(r2);
        r0.<init>(r1);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r13);
        throw r0;
    L_0x005f:
        r1 = TAG;
        r3 = new java.lang.StringBuilder;
        r4 = "recognitionAudioFormatExactly file length = ";
        r3.<init>(r4);
        r4 = r0.length();
        r0 = r3.append(r4);
        r0 = r0.toString();
        com.tencent.qqmusic.mediaplayer.util.Logger.i(r1, r0);
        r4 = java.lang.System.currentTimeMillis();
        r6 = guessFormat(r14);
        r7 = com.tencent.qqmusic.mediaplayer.MediaCodecFactory.getSupportAudioType();
        if (r6 == 0) goto L_0x00a4;
    L_0x0086:
        r0 = r7.contains(r6);
        if (r0 == 0) goto L_0x00a4;
    L_0x008c:
        r7.remove(r6);
        r7.add(r8, r6);
        r0 = com.tencent.qqmusic.mediaplayer.AudioFormat.AudioType.MP3;
        r0 = r0.equals(r6);
        if (r0 == 0) goto L_0x00a4;
    L_0x009a:
        r0 = com.tencent.qqmusic.mediaplayer.AudioFormat.AudioType.FLAC;
        r7.remove(r0);
        r0 = com.tencent.qqmusic.mediaplayer.AudioFormat.AudioType.FLAC;
        r7.add(r8, r0);
    L_0x00a4:
        r3 = new java.io.FileInputStream;	 Catch:{ Exception -> 0x017f, all -> 0x0198 }
        r3.<init>(r14);	 Catch:{ Exception -> 0x017f, all -> 0x0198 }
        r0 = 1024; // 0x400 float:1.435E-42 double:5.06E-321;
        r1 = com.tencent.qqmusic.mediaplayer.CacheBytesManager.getStatic(r0);	 Catch:{ Exception -> 0x01ec }
        r8 = r3.read(r1);	 Catch:{ Exception -> 0x01ec }
        if (r8 < r9) goto L_0x01f7;
    L_0x00b5:
        r0 = 64;
        r0 = new byte[r0];	 Catch:{ Exception -> 0x01ec }
        r9 = 0;
        r10 = 0;
        r11 = 64;
        java.lang.System.arraycopy(r1, r9, r0, r10, r11);	 Catch:{ Exception -> 0x01ef }
    L_0x00c0:
        com.tencent.qqmusic.mediaplayer.CacheBytesManager.recycle(r1);	 Catch:{ Exception -> 0x01ef }
        r9 = TAG;	 Catch:{ Exception -> 0x01ef }
        r10 = new java.lang.StringBuilder;	 Catch:{ Exception -> 0x01ef }
        r11 = "recognitionAudioFormatExactly header = ";
        r10.<init>(r11);	 Catch:{ Exception -> 0x01ef }
        r11 = new java.lang.String;	 Catch:{ Exception -> 0x01ef }
        r12 = 0;
        r11.<init>(r1, r12, r8);	 Catch:{ Exception -> 0x01ef }
        r1 = r10.append(r11);	 Catch:{ Exception -> 0x01ef }
        r8 = ",path = ";
        r1 = r1.append(r8);	 Catch:{ Exception -> 0x01ef }
        r1 = r1.append(r14);	 Catch:{ Exception -> 0x01ef }
        r1 = r1.toString();	 Catch:{ Exception -> 0x01ef }
        com.tencent.qqmusic.mediaplayer.util.Logger.i(r9, r1);	 Catch:{ Exception -> 0x01ef }
        r3.close();	 Catch:{ Exception -> 0x0176 }
        r1 = r0;
    L_0x00ed:
        r3 = r7.iterator();
    L_0x00f1:
        r0 = r3.hasNext();
        if (r0 == 0) goto L_0x01f1;
    L_0x00f7:
        r0 = r3.next();
        r0 = (com.tencent.qqmusic.mediaplayer.AudioFormat.AudioType) r0;
        r0 = com.tencent.qqmusic.mediaplayer.MediaCodecFactory.createDecoderByType(r0);
        if (r0 == 0) goto L_0x00f1;
    L_0x0103:
        r0 = r0.getAudioType(r14, r1);	 Catch:{ SoNotFindException -> 0x01aa }
    L_0x0107:
        r7 = com.tencent.qqmusic.mediaplayer.AudioFormat.isAudioType(r0);
        if (r7 == 0) goto L_0x00f1;
    L_0x010d:
        r1 = TAG;
        r2 = new java.lang.StringBuilder;
        r3 = "soft recognition  = ";
        r2.<init>(r3);
        r2 = r2.append(r0);
        r3 = ",file path = ";
        r2 = r2.append(r3);
        r2 = r2.append(r14);
        r3 = ",recognition time = ";
        r2 = r2.append(r3);
        r8 = java.lang.System.currentTimeMillis();
        r4 = r8 - r4;
        r2 = r2.append(r4);
        r3 = ",guess file format = ";
        r2 = r2.append(r3);
        r3 = r0.equals(r6);
        r2 = r2.append(r3);
        r2 = r2.toString();
        com.tencent.qqmusic.mediaplayer.util.Logger.w(r1, r2);
    L_0x014d:
        if (r0 != 0) goto L_0x01b7;
    L_0x014f:
        r0 = com.tencent.qqmusic.mediaplayer.AudioFormat.AudioType.UNSUPPORT;
    L_0x0151:
        r1 = TAG;
        r2 = new java.lang.StringBuilder;
        r3 = "recognitionAudioFormatExactly checkFilePath = ";
        r2.<init>(r3);
        r2 = r2.append(r14);
        r3 = ",retType = ";
        r2 = r2.append(r3);
        r2 = r2.append(r0);
        r2 = r2.toString();
        com.tencent.qqmusic.mediaplayer.util.Logger.i(r1, r2);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r13);
        goto L_0x0010;
    L_0x0176:
        r1 = move-exception;
        r3 = TAG;
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r3, r1);
        r1 = r0;
        goto L_0x00ed;
    L_0x017f:
        r1 = move-exception;
        r0 = r2;
        r3 = r2;
    L_0x0182:
        r8 = TAG;	 Catch:{ all -> 0x01ea }
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r8, r1);	 Catch:{ all -> 0x01ea }
        if (r3 == 0) goto L_0x01f4;
    L_0x0189:
        r3.close();	 Catch:{ Exception -> 0x018f }
        r1 = r0;
        goto L_0x00ed;
    L_0x018f:
        r1 = move-exception;
        r3 = TAG;
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r3, r1);
        r1 = r0;
        goto L_0x00ed;
    L_0x0198:
        r0 = move-exception;
        r3 = r2;
    L_0x019a:
        if (r3 == 0) goto L_0x019f;
    L_0x019c:
        r3.close();	 Catch:{ Exception -> 0x01a3 }
    L_0x019f:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r13);
        throw r0;
    L_0x01a3:
        r1 = move-exception;
        r2 = TAG;
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r2, r1);
        goto L_0x019f;
    L_0x01aa:
        r0 = move-exception;
        r7 = TAG;
        r8 = "so not find!";
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r7, r8, r0);
        r0 = com.tencent.qqmusic.mediaplayer.AudioFormat.AudioType.UNSUPPORT;
        goto L_0x0107;
    L_0x01b7:
        r1 = TAG;
        r2 = new java.lang.StringBuilder;
        r3 = "[recognitionAudioFormatExactly] add to cache, file path checkFilePath = [";
        r2.<init>(r3);
        r2 = r2.append(r14);
        r3 = "]. retType = [";
        r2 = r2.append(r3);
        r2 = r2.append(r0);
        r3 = "].";
        r2 = r2.append(r3);
        r2 = r2.toString();
        com.tencent.qqmusic.mediaplayer.util.Logger.i(r1, r2);
        r1 = mRecognitionResultCache;
        r1.put(r14, r0);
        r1 = mGuessFormatResultCache;
        r1.put(r14, r0);
        goto L_0x0151;
    L_0x01ea:
        r0 = move-exception;
        goto L_0x019a;
    L_0x01ec:
        r1 = move-exception;
        r0 = r2;
        goto L_0x0182;
    L_0x01ef:
        r1 = move-exception;
        goto L_0x0182;
    L_0x01f1:
        r0 = r2;
        goto L_0x014d;
    L_0x01f4:
        r1 = r0;
        goto L_0x00ed;
    L_0x01f7:
        r0 = r2;
        goto L_0x00c0;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.qqmusic.mediaplayer.AudioRecognition.recognitionAudioFormatExactly(java.lang.String):com.tencent.qqmusic.mediaplayer.AudioFormat$AudioType");
    }
}
