package com.tencent.rtmp.sharp.jni;

import android.annotation.TargetApi;
import android.content.Context;
import android.media.AudioManager;
import android.media.AudioRecord;
import android.media.AudioTrack;
import android.os.Build;
import android.os.Build.VERSION;
import android.os.Environment;
import android.os.Process;
import com.google.android.gms.auth.api.credentials.CredentialsApi;
import com.tencent.matrix.trace.core.AppMethodBeat;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.locks.Condition;
import java.util.concurrent.locks.ReentrantLock;

@TargetApi(16)
public class AudioDeviceInterface {
    private static boolean _dumpEnable = false;
    private static boolean _logEnable = true;
    private TraeAudioSession _as = null;
    private AudioManager _audioManager = null;
    private AudioRecord _audioRecord = null;
    private boolean _audioRouteChanged = false;
    private int _audioSource = 0;
    private int _audioSourcePolicy = -1;
    private int _audioStreamTypePolicy = -1;
    private AudioTrack _audioTrack = null;
    private int _bufferedPlaySamples = 0;
    private int _bufferedRecSamples = 0;
    private int _channelOutType = 4;
    private String _connectedDev = "DEVICE_NONE";
    private Context _context = null;
    private boolean _doPlayInit = true;
    private boolean _doRecInit = true;
    private TraeAudioSession _init_as = null;
    private boolean _isPlaying = false;
    private boolean _isRecording = false;
    private int _modePolicy = -1;
    private ByteBuffer _playBuffer;
    private final ReentrantLock _playLock = new ReentrantLock();
    private int _playPosition = 0;
    private int _playSamplerate = 8000;
    private File _play_dump = null;
    private FileOutputStream _play_out = null;
    private boolean _preDone = false;
    private Condition _precon = this._prelock.newCondition();
    private ReentrantLock _prelock = new ReentrantLock();
    private ByteBuffer _recBuffer;
    private final ReentrantLock _recLock = new ReentrantLock();
    private File _rec_dump = null;
    private FileOutputStream _rec_out = null;
    private int _sceneModeKey = 0;
    private int _sessionId = 0;
    private int _streamType = 0;
    private byte[] _tempBufPlay;
    private byte[] _tempBufRec;
    private int switchState = 0;
    private boolean usingJava = true;

    static /* synthetic */ void access$400(AudioDeviceInterface audioDeviceInterface, String str) {
        AppMethodBeat.i(65788);
        audioDeviceInterface.onOutputChanage(str);
        AppMethodBeat.o(65788);
    }

    public AudioDeviceInterface() {
        AppMethodBeat.i(65760);
        try {
            this._playBuffer = ByteBuffer.allocateDirect(1920);
            this._recBuffer = ByteBuffer.allocateDirect(1920);
        } catch (Exception e) {
            if (QLog.isColorLevel()) {
                QLog.w("TRAE", 2, e.getMessage());
            }
        }
        this._tempBufPlay = new byte[1920];
        this._tempBufRec = new byte[1920];
        int i = VERSION.SDK_INT;
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "AudioDeviceInterface apiLevel:".concat(String.valueOf(i)));
        }
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, " SDK_INT:" + VERSION.SDK_INT);
        }
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "manufacture:" + Build.MANUFACTURER);
        }
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "MODEL:" + Build.MODEL);
        }
        AppMethodBeat.o(65760);
    }

    public void setContext(Context context) {
        this._context = context;
    }

    private int getLowlatencySamplerate() {
        AppMethodBeat.i(65761);
        if (this._context == null || VERSION.SDK_INT < 9) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "getLowlatencySamplerate err, _context:" + this._context + " api:" + VERSION.SDK_INT);
            }
            AppMethodBeat.o(65761);
        } else {
            boolean hasSystemFeature = this._context.getPackageManager().hasSystemFeature("android.hardware.audio.low_latency");
            if (QLog.isColorLevel()) {
                QLog.w("TRAE", 2, "LOW_LATENCY:" + (hasSystemFeature ? "Y" : "N"));
            }
            if (VERSION.SDK_INT < 17) {
                if (QLog.isColorLevel()) {
                    QLog.e("TRAE", 2, "API Level too low not support PROPERTY_OUTPUT_SAMPLE_RATE");
                }
                AppMethodBeat.o(65761);
            } else {
                if (QLog.isColorLevel()) {
                    QLog.e("TRAE", 2, "getLowlatencySamplerate not support right now!");
                }
                AppMethodBeat.o(65761);
            }
        }
        return 0;
    }

    private int getLowlatencyFramesPerBuffer() {
        AppMethodBeat.i(65762);
        if (this._context == null || VERSION.SDK_INT < 9) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "getLowlatencySamplerate err, _context:" + this._context + " api:" + VERSION.SDK_INT);
            }
            AppMethodBeat.o(65762);
        } else {
            boolean hasSystemFeature = this._context.getPackageManager().hasSystemFeature("android.hardware.audio.low_latency");
            if (QLog.isColorLevel()) {
                QLog.w("TRAE", 2, "LOW_LATENCY:" + (hasSystemFeature ? "Y" : "N"));
            }
            if (VERSION.SDK_INT < 17) {
                if (QLog.isColorLevel()) {
                    QLog.e("TRAE", 2, "API Level too low not support PROPERTY_OUTPUT_SAMPLE_RATE");
                }
                AppMethodBeat.o(65762);
            } else {
                AppMethodBeat.o(65762);
            }
        }
        return 0;
    }

    @TargetApi(16)
    private int getAudioSessionId(AudioRecord audioRecord) {
        return 0;
    }

    private int InitSetting(int i, int i2, int i3, int i4) {
        AppMethodBeat.i(65763);
        this._audioSourcePolicy = i;
        this._audioStreamTypePolicy = i2;
        this._modePolicy = i3;
        this._sceneModeKey = i4;
        if (this._sceneModeKey == 1 || this._sceneModeKey == 2 || this._sceneModeKey == 3) {
            TraeAudioManager.IsMusicScene = true;
        } else {
            TraeAudioManager.IsMusicScene = false;
        }
        TraeAudioManager.IsUpdateSceneFlag = true;
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "InitSetting: _audioSourcePolicy:" + this._audioSourcePolicy + " _audioStreamTypePolicy:" + this._audioStreamTypePolicy + " _modePolicy:" + this._modePolicy + " sceneModeKey:" + i4);
        }
        AppMethodBeat.o(65763);
        return 0;
    }

    private int InitRecording(int i, int i2) {
        AppMethodBeat.i(65764);
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "InitRecording entry:".concat(String.valueOf(i)));
        }
        if (this._isRecording || this._audioRecord != null || i2 > 2) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "InitRecording _isRecording:" + this._isRecording);
            }
            AppMethodBeat.o(65764);
            return -1;
        }
        int i3;
        int i4 = 16;
        if (i2 == 2) {
            i4 = 12;
        }
        int minBufferSize = AudioRecord.getMinBufferSize(i, i4, 2);
        int i5 = (((i * 20) * i2) * 2) / CredentialsApi.ACTIVITY_RESULT_ADD_ACCOUNT;
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "InitRecording: min rec buf size is " + minBufferSize + " sr:" + getLowlatencySamplerate() + " fp" + getLowlatencyFramesPerBuffer() + " 20msFZ:" + i5);
        }
        this._bufferedRecSamples = (i * 5) / 200;
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "  rough rec delay set to " + this._bufferedRecSamples);
        }
        if (this._audioRecord != null) {
            this._audioRecord.release();
            this._audioRecord = null;
        }
        int[] iArr = new int[]{0, 1, 5, 0};
        iArr[0] = TraeAudioManager.getAudioSource(this._audioSourcePolicy);
        int i6 = minBufferSize;
        for (int i7 = 0; i7 < 4 && this._audioRecord == null; i7++) {
            this._audioSource = iArr[i7];
            i3 = 1;
            while (true) {
                int i8 = i3;
                if (i8 > 2) {
                    break;
                }
                i6 = minBufferSize * i8;
                if (i6 >= i5 * 4 || i8 >= 2) {
                    try {
                        this._audioRecord = new AudioRecord(this._audioSource, i, i4, 2, i6);
                        if (this._audioRecord.getState() == 1) {
                            break;
                        }
                        if (QLog.isColorLevel()) {
                            QLog.w("TRAE", 2, "InitRecording:  rec not initialized,try agine,  minbufsize:" + i6 + " sr:" + i + " as:" + this._audioSource);
                        }
                        this._audioRecord.release();
                        this._audioRecord = null;
                    } catch (Exception e) {
                        if (QLog.isColorLevel()) {
                            QLog.w("TRAE", 2, e.getMessage() + " _audioRecord:" + this._audioRecord);
                        }
                        if (this._audioRecord != null) {
                            this._audioRecord.release();
                        }
                        this._audioRecord = null;
                    }
                }
                i3 = i8 + 1;
            }
        }
        if (this._audioRecord == null) {
            if (QLog.isColorLevel()) {
                QLog.w("TRAE", 2, "InitRecording fail!!!");
            }
            AppMethodBeat.o(65764);
            return -1;
        }
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, " [Config] InitRecording: audioSession:" + this._sessionId + " audioSource:" + this._audioSource + " rec sample rate set to " + i + " recBufSize:" + i6);
        }
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "InitRecording exit");
        }
        i3 = this._bufferedRecSamples;
        AppMethodBeat.o(65764);
        return i3;
    }

    private int InitPlayback(int i, int i2) {
        AppMethodBeat.i(65765);
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "InitPlayback entry: sampleRate ".concat(String.valueOf(i)));
        }
        if (this._isPlaying || this._audioTrack != null || i2 > 2) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "InitPlayback _isPlaying:" + this._isPlaying);
            }
            AppMethodBeat.o(65765);
            return -1;
        }
        int i3;
        if (this._audioManager == null) {
            try {
                this._audioManager = (AudioManager) this._context.getSystemService("audio");
            } catch (Exception e) {
                if (QLog.isColorLevel()) {
                    QLog.w("TRAE", 2, e.getMessage());
                }
                AppMethodBeat.o(65765);
                return -1;
            }
        }
        if (i2 == 2) {
            this._channelOutType = 12;
        } else {
            this._channelOutType = 4;
        }
        this._playSamplerate = i;
        int minBufferSize = AudioTrack.getMinBufferSize(i, this._channelOutType, 2);
        if (this._channelOutType == 12) {
            if (QLog.isColorLevel()) {
                QLog.w("TRAE", 2, "InitPlayback, _channelOutType stero");
            } else if (this._channelOutType == 4 && QLog.isColorLevel()) {
                QLog.w("TRAE", 2, "InitPlayback, _channelOutType Mono");
            }
        }
        int i4 = (((i * 20) * 1) * 2) / CredentialsApi.ACTIVITY_RESULT_ADD_ACCOUNT;
        if (this._channelOutType == 12) {
            i3 = i4 * 2;
        } else {
            i3 = i4;
        }
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "InitPlayback: minPlayBufSize:" + minBufferSize + " 20msFz:" + i3);
        }
        this._bufferedPlaySamples = 0;
        if (this._audioTrack != null) {
            this._audioTrack.release();
            this._audioTrack = null;
        }
        int[] iArr = new int[]{0, 0, 3, 1};
        this._streamType = TraeAudioManager.getAudioStreamType(this._audioStreamTypePolicy);
        if (this._audioRouteChanged) {
            if (QLog.isColorLevel()) {
                QLog.w("TRAE", 2, "_audioRouteChanged:" + this._audioRouteChanged + " _streamType:" + this._streamType);
            }
            if (this._audioManager.getMode() == 0 && this._connectedDev.equals("DEVICE_SPEAKERPHONE")) {
                this._streamType = 3;
            } else {
                this._streamType = 0;
            }
            this._audioRouteChanged = false;
        }
        iArr[0] = this._streamType;
        int i5 = minBufferSize;
        for (int i6 = 0; i6 < 4 && this._audioTrack == null; i6++) {
            this._streamType = iArr[i6];
            if (QLog.isColorLevel()) {
                QLog.w("TRAE", 2, "InitPlayback: min play buf size is " + minBufferSize + " hw_sr:" + AudioTrack.getNativeOutputSampleRate(this._streamType));
            }
            i4 = 1;
            while (true) {
                int i7 = i4;
                if (i7 > 2) {
                    break;
                }
                i5 = minBufferSize * i7;
                if (i5 >= i3 * 4 || i7 >= 2) {
                    try {
                        this._audioTrack = new AudioTrack(this._streamType, this._playSamplerate, this._channelOutType, 2, i5, 1);
                        if (this._audioTrack.getState() == 1) {
                            break;
                        }
                        if (QLog.isColorLevel()) {
                            QLog.w("TRAE", 2, "InitPlayback: play not initialized playBufSize:" + i5 + " sr:" + this._playSamplerate);
                        }
                        this._audioTrack.release();
                        this._audioTrack = null;
                    } catch (Exception e2) {
                        if (QLog.isColorLevel()) {
                            QLog.w("TRAE", 2, e2.getMessage() + " _audioTrack:" + this._audioTrack);
                        }
                        if (this._audioTrack != null) {
                            this._audioTrack.release();
                        }
                        this._audioTrack = null;
                    }
                }
                i4 = i7 + 1;
            }
        }
        if (this._audioTrack == null) {
            if (QLog.isColorLevel()) {
                QLog.w("TRAE", 2, "InitPlayback fail!!!");
            }
            AppMethodBeat.o(65765);
            return -1;
        }
        if (!(this._as == null || this._audioManager == null)) {
            this._as.voiceCallAudioParamChanged(this._audioManager.getMode(), this._streamType);
        }
        this._playPosition = this._audioTrack.getPlaybackHeadPosition();
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "InitPlayback exit: streamType:" + this._streamType + " samplerate:" + this._playSamplerate + " _playPosition:" + this._playPosition + " playBufSize:" + i5);
        }
        AudioManager audioManager = this._audioManager;
        if (this._connectedDev.equals("DEVICE_BLUETOOTHHEADSET")) {
            i4 = 6;
        } else {
            i4 = this._audioTrack.getStreamType();
        }
        TraeAudioManager.forceVolumeControlStream(audioManager, i4);
        AppMethodBeat.o(65765);
        return 0;
    }

    private String getDumpFilePath(String str, int i) {
        AppMethodBeat.i(65766);
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "manufacture:" + Build.MANUFACTURER);
        }
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "MODEL:" + Build.MODEL);
        }
        String str2 = Environment.getExternalStorageDirectory().getPath() + "/MF-" + Build.MANUFACTURER + "-M-" + Build.MODEL + "-as-" + TraeAudioManager.getAudioSource(this._audioSourcePolicy) + "-st-" + this._streamType + "-m-" + i + "-" + str;
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "dump:".concat(String.valueOf(str2)));
        }
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "dump replace:" + str2.replace(" ", "_"));
        }
        str2 = str2.replace(" ", "_");
        AppMethodBeat.o(65766);
        return str2;
    }

    private int StartRecording() {
        int i = -1;
        AppMethodBeat.i(65767);
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "StartRecording entry");
        }
        if (this._isRecording) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "StartRecording _isRecording:" + this._isRecording);
            }
            AppMethodBeat.o(65767);
            return -1;
        } else if (this._audioRecord == null) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "StartRecording _audioRecord:" + this._audioRecord);
            }
            AppMethodBeat.o(65767);
            return -1;
        } else {
            try {
                this._audioRecord.startRecording();
                if (_dumpEnable) {
                    String str = "jnirecord.pcm";
                    if (this._audioManager != null) {
                        i = this._audioManager.getMode();
                    }
                    this._rec_dump = new File(getDumpFilePath(str, i));
                    try {
                        this._rec_out = new FileOutputStream(this._rec_dump);
                    } catch (FileNotFoundException e) {
                    }
                }
                this._isRecording = true;
                if (QLog.isColorLevel()) {
                    QLog.w("TRAE", 2, "StartRecording ok");
                }
                AppMethodBeat.o(65767);
                return 0;
            } catch (IllegalStateException e2) {
                if (QLog.isColorLevel()) {
                    QLog.e("TRAE", 2, "StartRecording fail");
                }
                AppMethodBeat.o(65767);
                return -1;
            }
        }
    }

    private int StartPlayback() {
        int i = -1;
        AppMethodBeat.i(65768);
        if (this._isPlaying) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "StartPlayback _isPlaying");
            }
            AppMethodBeat.o(65768);
            return -1;
        } else if (this._audioTrack == null) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "StartPlayback _audioTrack:" + this._audioTrack);
            }
            AppMethodBeat.o(65768);
            return -1;
        } else {
            try {
                this._audioTrack.play();
                if (_dumpEnable) {
                    String str = "jniplay.pcm";
                    if (this._audioManager != null) {
                        i = this._audioManager.getMode();
                    }
                    this._play_dump = new File(getDumpFilePath(str, i));
                    try {
                        this._play_out = new FileOutputStream(this._play_dump);
                    } catch (FileNotFoundException e) {
                    }
                }
                this._isPlaying = true;
                if (QLog.isColorLevel()) {
                    QLog.w("TRAE", 2, "StartPlayback ok");
                }
                AppMethodBeat.o(65768);
                return 0;
            } catch (IllegalStateException e2) {
                if (QLog.isColorLevel()) {
                    QLog.e("TRAE", 2, "StartPlayback fail");
                }
                AppMethodBeat.o(65768);
                return -1;
            }
        }
    }

    private int StopRecording() {
        AppMethodBeat.i(65769);
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "StopRecording entry");
        }
        if (this._audioRecord == null) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "UnintRecord:" + this._audioRecord);
            }
            AppMethodBeat.o(65769);
            return -1;
        }
        this._recLock.lock();
        try {
            if (this._audioRecord.getRecordingState() == 3) {
                if (QLog.isColorLevel()) {
                    QLog.w("TRAE", 2, "StopRecording stop... state:" + this._audioRecord.getRecordingState());
                }
                this._audioRecord.stop();
            }
            if (QLog.isColorLevel()) {
                QLog.w("TRAE", 2, "StopRecording releaseing... state:" + this._audioRecord.getRecordingState());
            }
            this._audioRecord.release();
            this._audioRecord = null;
            this._isRecording = false;
            this._recLock.unlock();
            if (QLog.isColorLevel()) {
                QLog.w("TRAE", 2, "StopRecording exit ok");
            }
            AppMethodBeat.o(65769);
            return 0;
        } catch (IllegalStateException e) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "StopRecording  err");
            }
            this._recLock.unlock();
            AppMethodBeat.o(65769);
            return -1;
        } catch (Throwable th) {
            this._recLock.unlock();
            AppMethodBeat.o(65769);
        }
    }

    private int StopPlayback() {
        AppMethodBeat.i(65770);
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "StopPlayback entry _isPlaying:" + this._isPlaying);
        }
        if (this._audioTrack == null) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "StopPlayback _isPlaying:" + this._isPlaying + " " + this._audioTrack);
            }
            AppMethodBeat.o(65770);
            return -1;
        }
        this._playLock.lock();
        try {
            if (this._audioTrack.getPlayState() == 3) {
                if (QLog.isColorLevel()) {
                    QLog.w("TRAE", 2, "StopPlayback stoping...");
                }
                this._audioTrack.stop();
                if (QLog.isColorLevel()) {
                    QLog.w("TRAE", 2, "StopPlayback flushing... state:" + this._audioTrack.getPlayState());
                }
                this._audioTrack.flush();
            }
            if (QLog.isColorLevel()) {
                QLog.w("TRAE", 2, "StopPlayback releaseing... state:" + this._audioTrack.getPlayState());
            }
            this._audioTrack.release();
            this._audioTrack = null;
            this._isPlaying = false;
            this._playLock.unlock();
            if (QLog.isColorLevel()) {
                QLog.w("TRAE", 2, "StopPlayback exit ok");
            }
            AppMethodBeat.o(65770);
            return 0;
        } catch (IllegalStateException e) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "StopPlayback err");
            }
            this._playLock.unlock();
            AppMethodBeat.o(65770);
            return -1;
        } catch (Throwable th) {
            this._playLock.unlock();
            AppMethodBeat.o(65770);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:101:0x0242 A:{Catch:{ all -> 0x02a5 }} */
    private int PlayAudio(int r15) {
        /*
        r14 = this;
        r0 = 65771; // 0x100eb float:9.2165E-41 double:3.2495E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r0);
        r2 = 0;
        r0 = r14._isPlaying;
        if (r0 != 0) goto L_0x0048;
    L_0x000b:
        r0 = 1;
    L_0x000c:
        r1 = r14._audioTrack;
        if (r1 != 0) goto L_0x004a;
    L_0x0010:
        r1 = 1;
    L_0x0011:
        r0 = r0 | r1;
        if (r0 == 0) goto L_0x004c;
    L_0x0014:
        r0 = com.tencent.rtmp.sharp.jni.QLog.isColorLevel();
        if (r0 == 0) goto L_0x0040;
    L_0x001a:
        r0 = "TRAE";
        r1 = 2;
        r2 = new java.lang.StringBuilder;
        r3 = "PlayAudio: _isPlaying ";
        r2.<init>(r3);
        r3 = r14._isPlaying;
        r2 = r2.append(r3);
        r3 = " ";
        r2 = r2.append(r3);
        r3 = r14._audioTrack;
        r2 = r2.append(r3);
        r2 = r2.toString();
        com.tencent.rtmp.sharp.jni.QLog.e(r0, r1, r2);
    L_0x0040:
        r15 = -1;
        r0 = 65771; // 0x100eb float:9.2165E-41 double:3.2495E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r0);
    L_0x0047:
        return r15;
    L_0x0048:
        r0 = 0;
        goto L_0x000c;
    L_0x004a:
        r1 = 0;
        goto L_0x0011;
    L_0x004c:
        r0 = r14._playLock;
        r0.lock();
        r0 = r14._audioTrack;	 Catch:{ Exception -> 0x0239 }
        if (r0 != 0) goto L_0x0062;
    L_0x0055:
        r0 = r14._playLock;
        r0.unlock();
        r15 = -2;
        r0 = 65771; // 0x100eb float:9.2165E-41 double:3.2495E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r0);
        goto L_0x0047;
    L_0x0062:
        r0 = r14._doPlayInit;	 Catch:{ Exception -> 0x0239 }
        r1 = 1;
        if (r0 != r1) goto L_0x006f;
    L_0x0067:
        r0 = -19;
        android.os.Process.setThreadPriority(r0);	 Catch:{ Exception -> 0x0215 }
    L_0x006c:
        r0 = 0;
        r14._doPlayInit = r0;	 Catch:{ Exception -> 0x0239 }
    L_0x006f:
        r0 = _dumpEnable;	 Catch:{ Exception -> 0x0239 }
        if (r0 == 0) goto L_0x0080;
    L_0x0073:
        r0 = r14._play_out;	 Catch:{ Exception -> 0x0239 }
        if (r0 == 0) goto L_0x0080;
    L_0x0077:
        r0 = r14._play_out;	 Catch:{ IOException -> 0x0413 }
        r1 = r14._tempBufPlay;	 Catch:{ IOException -> 0x0413 }
        r3 = 0;
        r4 = 0;
        r0.write(r1, r3, r4);	 Catch:{ IOException -> 0x0413 }
    L_0x0080:
        r0 = r14._audioRouteChanged;	 Catch:{ Exception -> 0x0239 }
        if (r0 != 0) goto L_0x026a;
    L_0x0084:
        r0 = 0;
    L_0x0085:
        r1 = r14._playBuffer;	 Catch:{ Exception -> 0x0239 }
        r3 = r14._tempBufPlay;	 Catch:{ Exception -> 0x0239 }
        r1.get(r3);	 Catch:{ Exception -> 0x0239 }
        if (r0 == 0) goto L_0x036c;
    L_0x008e:
        r0 = r14._playBuffer;	 Catch:{ Exception -> 0x02cb }
        r0.rewind();	 Catch:{ Exception -> 0x02cb }
        r10 = android.os.SystemClock.elapsedRealtime();	 Catch:{ Exception -> 0x02cb }
        r0 = com.tencent.rtmp.sharp.jni.QLog.isColorLevel();	 Catch:{ Exception -> 0x02cb }
        if (r0 == 0) goto L_0x00c7;
    L_0x009d:
        r0 = "TRAE";
        r1 = 2;
        r2 = new java.lang.StringBuilder;	 Catch:{ Exception -> 0x02cb }
        r3 = " track resting: _streamType:";
        r2.<init>(r3);	 Catch:{ Exception -> 0x02cb }
        r3 = r14._streamType;	 Catch:{ Exception -> 0x02cb }
        r2 = r2.append(r3);	 Catch:{ Exception -> 0x02cb }
        r3 = " at.st:";
        r2 = r2.append(r3);	 Catch:{ Exception -> 0x02cb }
        r3 = r14._audioTrack;	 Catch:{ Exception -> 0x02cb }
        r3 = r3.getStreamType();	 Catch:{ Exception -> 0x02cb }
        r2 = r2.append(r3);	 Catch:{ Exception -> 0x02cb }
        r2 = r2.toString();	 Catch:{ Exception -> 0x02cb }
        com.tencent.rtmp.sharp.jni.QLog.w(r0, r1, r2);	 Catch:{ Exception -> 0x02cb }
    L_0x00c7:
        r0 = r14._audioTrack;	 Catch:{ Exception -> 0x02cb }
        r0 = r0.getPlayState();	 Catch:{ Exception -> 0x02cb }
        r1 = 3;
        if (r0 != r1) goto L_0x0138;
    L_0x00d0:
        r0 = com.tencent.rtmp.sharp.jni.QLog.isColorLevel();	 Catch:{ IllegalStateException -> 0x02b8 }
        if (r0 == 0) goto L_0x00e0;
    L_0x00d6:
        r0 = "TRAE";
        r1 = 2;
        r2 = "StopPlayback stoping...";
        com.tencent.rtmp.sharp.jni.QLog.w(r0, r1, r2);	 Catch:{ IllegalStateException -> 0x02b8 }
    L_0x00e0:
        r0 = r14._audioTrack;	 Catch:{ IllegalStateException -> 0x02b8 }
        r0.stop();	 Catch:{ IllegalStateException -> 0x02b8 }
        r0 = r14._audioTrack;	 Catch:{ IllegalStateException -> 0x02b8 }
        r0.flush();	 Catch:{ IllegalStateException -> 0x02b8 }
        r0 = com.tencent.rtmp.sharp.jni.QLog.isColorLevel();	 Catch:{ IllegalStateException -> 0x02b8 }
        if (r0 == 0) goto L_0x010d;
    L_0x00f0:
        r0 = "TRAE";
        r1 = 2;
        r2 = new java.lang.StringBuilder;	 Catch:{ IllegalStateException -> 0x02b8 }
        r3 = "StopPlayback flushing... state:";
        r2.<init>(r3);	 Catch:{ IllegalStateException -> 0x02b8 }
        r3 = r14._audioTrack;	 Catch:{ IllegalStateException -> 0x02b8 }
        r3 = r3.getPlayState();	 Catch:{ IllegalStateException -> 0x02b8 }
        r2 = r2.append(r3);	 Catch:{ IllegalStateException -> 0x02b8 }
        r2 = r2.toString();	 Catch:{ IllegalStateException -> 0x02b8 }
        com.tencent.rtmp.sharp.jni.QLog.w(r0, r1, r2);	 Catch:{ IllegalStateException -> 0x02b8 }
    L_0x010d:
        r0 = r14._audioTrack;	 Catch:{ IllegalStateException -> 0x02b8 }
        r0.release();	 Catch:{ IllegalStateException -> 0x02b8 }
        r0 = com.tencent.rtmp.sharp.jni.QLog.isColorLevel();	 Catch:{ IllegalStateException -> 0x02b8 }
        if (r0 == 0) goto L_0x0135;
    L_0x0118:
        r0 = "TRAE";
        r1 = 2;
        r2 = new java.lang.StringBuilder;	 Catch:{ IllegalStateException -> 0x02b8 }
        r3 = "StopPlayback releaseing... state:";
        r2.<init>(r3);	 Catch:{ IllegalStateException -> 0x02b8 }
        r3 = r14._audioTrack;	 Catch:{ IllegalStateException -> 0x02b8 }
        r3 = r3.getPlayState();	 Catch:{ IllegalStateException -> 0x02b8 }
        r2 = r2.append(r3);	 Catch:{ IllegalStateException -> 0x02b8 }
        r2 = r2.toString();	 Catch:{ IllegalStateException -> 0x02b8 }
        com.tencent.rtmp.sharp.jni.QLog.w(r0, r1, r2);	 Catch:{ IllegalStateException -> 0x02b8 }
    L_0x0135:
        r0 = 0;
        r14._audioTrack = r0;	 Catch:{ IllegalStateException -> 0x02b8 }
    L_0x0138:
        r0 = r14._playSamplerate;	 Catch:{ Exception -> 0x02cb }
        r1 = r14._channelOutType;	 Catch:{ Exception -> 0x02cb }
        r2 = 2;
        r12 = android.media.AudioTrack.getMinBufferSize(r0, r1, r2);	 Catch:{ Exception -> 0x02cb }
        r0 = 4;
        r13 = new int[r0];	 Catch:{ Exception -> 0x02cb }
        r13 = {0, 0, 3, 1};	 Catch:{ Exception -> 0x02cb }
        r0 = 0;
        r1 = r14._streamType;	 Catch:{ Exception -> 0x02cb }
        r13[r0] = r1;	 Catch:{ Exception -> 0x02cb }
        r0 = r14._playSamplerate;	 Catch:{ Exception -> 0x02cb }
        r0 = r0 * 20;
        r0 = r0 * 1;
        r0 = r0 * 2;
        r0 = r0 / 1000;
        r1 = r14._channelOutType;	 Catch:{ Exception -> 0x02cb }
        r2 = 12;
        if (r1 != r2) goto L_0x0416;
    L_0x015c:
        r0 = r0 * 2;
        r7 = r0;
    L_0x015f:
        r0 = 0;
        r9 = r0;
    L_0x0161:
        r0 = 4;
        if (r9 >= r0) goto L_0x030e;
    L_0x0164:
        r0 = r14._audioTrack;	 Catch:{ Exception -> 0x02cb }
        if (r0 != 0) goto L_0x030e;
    L_0x0168:
        r0 = r13[r9];	 Catch:{ Exception -> 0x02cb }
        r14._streamType = r0;	 Catch:{ Exception -> 0x02cb }
        r0 = com.tencent.rtmp.sharp.jni.QLog.isColorLevel();	 Catch:{ Exception -> 0x02cb }
        if (r0 == 0) goto L_0x019a;
    L_0x0172:
        r0 = "TRAE";
        r1 = 2;
        r2 = new java.lang.StringBuilder;	 Catch:{ Exception -> 0x02cb }
        r3 = "InitPlayback: min play buf size is ";
        r2.<init>(r3);	 Catch:{ Exception -> 0x02cb }
        r2 = r2.append(r12);	 Catch:{ Exception -> 0x02cb }
        r3 = " hw_sr:";
        r2 = r2.append(r3);	 Catch:{ Exception -> 0x02cb }
        r3 = r14._streamType;	 Catch:{ Exception -> 0x02cb }
        r3 = android.media.AudioTrack.getNativeOutputSampleRate(r3);	 Catch:{ Exception -> 0x02cb }
        r2 = r2.append(r3);	 Catch:{ Exception -> 0x02cb }
        r2 = r2.toString();	 Catch:{ Exception -> 0x02cb }
        com.tencent.rtmp.sharp.jni.QLog.w(r0, r1, r2);	 Catch:{ Exception -> 0x02cb }
    L_0x019a:
        r0 = 1;
        r8 = r0;
    L_0x019c:
        r0 = 2;
        if (r8 > r0) goto L_0x0309;
    L_0x019f:
        r5 = r12 * r8;
        r0 = r7 * 4;
        if (r5 >= r0) goto L_0x01a8;
    L_0x01a5:
        r0 = 2;
        if (r8 < r0) goto L_0x0211;
    L_0x01a8:
        r0 = new android.media.AudioTrack;	 Catch:{ Exception -> 0x02cf }
        r1 = r14._streamType;	 Catch:{ Exception -> 0x02cf }
        r2 = r14._playSamplerate;	 Catch:{ Exception -> 0x02cf }
        r3 = r14._channelOutType;	 Catch:{ Exception -> 0x02cf }
        r4 = 2;
        r6 = 1;
        r0.<init>(r1, r2, r3, r4, r5, r6);	 Catch:{ Exception -> 0x02cf }
        r14._audioTrack = r0;	 Catch:{ Exception -> 0x02cf }
        r0 = com.tencent.rtmp.sharp.jni.QLog.isColorLevel();	 Catch:{ Exception -> 0x02cb }
        if (r0 == 0) goto L_0x01d6;
    L_0x01bd:
        r0 = "TRAE";
        r1 = 2;
        r2 = new java.lang.StringBuilder;	 Catch:{ Exception -> 0x02cb }
        r3 = " _audioTrack:";
        r2.<init>(r3);	 Catch:{ Exception -> 0x02cb }
        r3 = r14._audioTrack;	 Catch:{ Exception -> 0x02cb }
        r2 = r2.append(r3);	 Catch:{ Exception -> 0x02cb }
        r2 = r2.toString();	 Catch:{ Exception -> 0x02cb }
        com.tencent.rtmp.sharp.jni.QLog.w(r0, r1, r2);	 Catch:{ Exception -> 0x02cb }
    L_0x01d6:
        r0 = r14._audioTrack;	 Catch:{ Exception -> 0x02cb }
        r0 = r0.getState();	 Catch:{ Exception -> 0x02cb }
        r1 = 1;
        if (r0 == r1) goto L_0x0309;
    L_0x01df:
        r0 = com.tencent.rtmp.sharp.jni.QLog.isColorLevel();	 Catch:{ Exception -> 0x02cb }
        if (r0 == 0) goto L_0x0209;
    L_0x01e5:
        r0 = "TRAE";
        r1 = 2;
        r2 = new java.lang.StringBuilder;	 Catch:{ Exception -> 0x02cb }
        r3 = "InitPlayback: play not initialized playBufSize:";
        r2.<init>(r3);	 Catch:{ Exception -> 0x02cb }
        r2 = r2.append(r5);	 Catch:{ Exception -> 0x02cb }
        r3 = " sr:";
        r2 = r2.append(r3);	 Catch:{ Exception -> 0x02cb }
        r3 = r14._playSamplerate;	 Catch:{ Exception -> 0x02cb }
        r2 = r2.append(r3);	 Catch:{ Exception -> 0x02cb }
        r2 = r2.toString();	 Catch:{ Exception -> 0x02cb }
        com.tencent.rtmp.sharp.jni.QLog.w(r0, r1, r2);	 Catch:{ Exception -> 0x02cb }
    L_0x0209:
        r0 = r14._audioTrack;	 Catch:{ Exception -> 0x02cb }
        r0.release();	 Catch:{ Exception -> 0x02cb }
        r0 = 0;
        r14._audioTrack = r0;	 Catch:{ Exception -> 0x02cb }
    L_0x0211:
        r0 = r8 + 1;
        r8 = r0;
        goto L_0x019c;
    L_0x0215:
        r0 = move-exception;
        r1 = com.tencent.rtmp.sharp.jni.QLog.isColorLevel();	 Catch:{ Exception -> 0x0239 }
        if (r1 == 0) goto L_0x006c;
    L_0x021c:
        r1 = "TRAE";
        r3 = 2;
        r4 = new java.lang.StringBuilder;	 Catch:{ Exception -> 0x0239 }
        r5 = "Set play thread priority failed: ";
        r4.<init>(r5);	 Catch:{ Exception -> 0x0239 }
        r0 = r0.getMessage();	 Catch:{ Exception -> 0x0239 }
        r0 = r4.append(r0);	 Catch:{ Exception -> 0x0239 }
        r0 = r0.toString();	 Catch:{ Exception -> 0x0239 }
        com.tencent.rtmp.sharp.jni.QLog.w(r1, r3, r0);	 Catch:{ Exception -> 0x0239 }
        goto L_0x006c;
    L_0x0239:
        r0 = move-exception;
        r1 = r0;
        r15 = r2;
    L_0x023c:
        r0 = com.tencent.rtmp.sharp.jni.QLog.isColorLevel();	 Catch:{ all -> 0x02a5 }
        if (r0 == 0) goto L_0x025d;
    L_0x0242:
        r0 = "TRAE";
        r2 = 2;
        r3 = new java.lang.StringBuilder;	 Catch:{ all -> 0x02a5 }
        r4 = "PlayAudio Exception: ";
        r3.<init>(r4);	 Catch:{ all -> 0x02a5 }
        r1 = r1.getMessage();	 Catch:{ all -> 0x02a5 }
        r1 = r3.append(r1);	 Catch:{ all -> 0x02a5 }
        r1 = r1.toString();	 Catch:{ all -> 0x02a5 }
        com.tencent.rtmp.sharp.jni.QLog.e(r0, r2, r1);	 Catch:{ all -> 0x02a5 }
    L_0x025d:
        r0 = r14._playLock;
        r0.unlock();
    L_0x0262:
        r0 = 65771; // 0x100eb float:9.2165E-41 double:3.2495E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r0);
        goto L_0x0047;
    L_0x026a:
        r0 = r14._audioManager;	 Catch:{ Exception -> 0x0239 }
        if (r0 != 0) goto L_0x027f;
    L_0x026e:
        r0 = r14._context;	 Catch:{ Exception -> 0x0239 }
        if (r0 == 0) goto L_0x027f;
    L_0x0272:
        r0 = r14._context;	 Catch:{ Exception -> 0x0239 }
        r1 = "audio";
        r0 = r0.getSystemService(r1);	 Catch:{ Exception -> 0x0239 }
        r0 = (android.media.AudioManager) r0;	 Catch:{ Exception -> 0x0239 }
        r14._audioManager = r0;	 Catch:{ Exception -> 0x0239 }
    L_0x027f:
        r0 = r14._audioManager;	 Catch:{ Exception -> 0x0239 }
        r0 = r0.getMode();	 Catch:{ Exception -> 0x0239 }
        if (r0 != 0) goto L_0x02b2;
    L_0x0287:
        r0 = r14._connectedDev;	 Catch:{ Exception -> 0x0239 }
        r1 = "DEVICE_SPEAKERPHONE";
        r0 = r0.equals(r1);	 Catch:{ Exception -> 0x0239 }
        if (r0 == 0) goto L_0x02b2;
    L_0x0292:
        r0 = 3;
        r14._streamType = r0;	 Catch:{ Exception -> 0x0239 }
    L_0x0295:
        r0 = r14._streamType;	 Catch:{ Exception -> 0x0239 }
        r1 = r14._audioTrack;	 Catch:{ Exception -> 0x0239 }
        r1 = r1.getStreamType();	 Catch:{ Exception -> 0x0239 }
        if (r0 != r1) goto L_0x02b6;
    L_0x029f:
        r0 = 0;
    L_0x02a0:
        r1 = 0;
        r14._audioRouteChanged = r1;	 Catch:{ Exception -> 0x0239 }
        goto L_0x0085;
    L_0x02a5:
        r0 = move-exception;
        r1 = r14._playLock;
        r1.unlock();
        r1 = 65771; // 0x100eb float:9.2165E-41 double:3.2495E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r1);
        throw r0;
    L_0x02b2:
        r0 = 0;
        r14._streamType = r0;	 Catch:{ Exception -> 0x0239 }
        goto L_0x0295;
    L_0x02b6:
        r0 = 1;
        goto L_0x02a0;
    L_0x02b8:
        r0 = move-exception;
        r0 = com.tencent.rtmp.sharp.jni.QLog.isColorLevel();	 Catch:{ Exception -> 0x02cb }
        if (r0 == 0) goto L_0x0138;
    L_0x02bf:
        r0 = "TRAE";
        r1 = 2;
        r2 = "StopPlayback err";
        com.tencent.rtmp.sharp.jni.QLog.e(r0, r1, r2);	 Catch:{ Exception -> 0x02cb }
        goto L_0x0138;
    L_0x02cb:
        r0 = move-exception;
        r1 = r0;
        goto L_0x023c;
    L_0x02cf:
        r0 = move-exception;
        r1 = com.tencent.rtmp.sharp.jni.QLog.isColorLevel();	 Catch:{ Exception -> 0x02cb }
        if (r1 == 0) goto L_0x02fb;
    L_0x02d6:
        r1 = "TRAE";
        r2 = 2;
        r3 = new java.lang.StringBuilder;	 Catch:{ Exception -> 0x02cb }
        r3.<init>();	 Catch:{ Exception -> 0x02cb }
        r0 = r0.getMessage();	 Catch:{ Exception -> 0x02cb }
        r0 = r3.append(r0);	 Catch:{ Exception -> 0x02cb }
        r3 = " _audioTrack:";
        r0 = r0.append(r3);	 Catch:{ Exception -> 0x02cb }
        r3 = r14._audioTrack;	 Catch:{ Exception -> 0x02cb }
        r0 = r0.append(r3);	 Catch:{ Exception -> 0x02cb }
        r0 = r0.toString();	 Catch:{ Exception -> 0x02cb }
        com.tencent.rtmp.sharp.jni.QLog.w(r1, r2, r0);	 Catch:{ Exception -> 0x02cb }
    L_0x02fb:
        r0 = r14._audioTrack;	 Catch:{ Exception -> 0x02cb }
        if (r0 == 0) goto L_0x0304;
    L_0x02ff:
        r0 = r14._audioTrack;	 Catch:{ Exception -> 0x02cb }
        r0.release();	 Catch:{ Exception -> 0x02cb }
    L_0x0304:
        r0 = 0;
        r14._audioTrack = r0;	 Catch:{ Exception -> 0x02cb }
        goto L_0x0211;
    L_0x0309:
        r0 = r9 + 1;
        r9 = r0;
        goto L_0x0161;
    L_0x030e:
        r0 = r14._audioTrack;	 Catch:{ Exception -> 0x02cb }
        if (r0 == 0) goto L_0x0335;
    L_0x0312:
        r0 = r14._audioTrack;	 Catch:{ Exception -> 0x0410 }
        r0.play();	 Catch:{ Exception -> 0x0410 }
        r0 = r14._as;	 Catch:{ Exception -> 0x0410 }
        r1 = r14._audioManager;	 Catch:{ Exception -> 0x0410 }
        r1 = r1.getMode();	 Catch:{ Exception -> 0x0410 }
        r2 = r14._streamType;	 Catch:{ Exception -> 0x0410 }
        r0.voiceCallAudioParamChanged(r1, r2);	 Catch:{ Exception -> 0x0410 }
        r1 = r14._audioManager;	 Catch:{ Exception -> 0x0410 }
        r0 = r14._connectedDev;	 Catch:{ Exception -> 0x0410 }
        r2 = "DEVICE_BLUETOOTHHEADSET";
        r0 = r0.equals(r2);	 Catch:{ Exception -> 0x0410 }
        if (r0 == 0) goto L_0x0365;
    L_0x0331:
        r0 = 6;
    L_0x0332:
        com.tencent.rtmp.sharp.jni.TraeAudioManager.forceVolumeControlStream(r1, r0);	 Catch:{ Exception -> 0x0410 }
    L_0x0335:
        r0 = com.tencent.rtmp.sharp.jni.QLog.isColorLevel();	 Catch:{ Exception -> 0x02cb }
        if (r0 == 0) goto L_0x035e;
    L_0x033b:
        r0 = "TRAE";
        r1 = 2;
        r2 = new java.lang.StringBuilder;	 Catch:{ Exception -> 0x02cb }
        r3 = "  track reset used:";
        r2.<init>(r3);	 Catch:{ Exception -> 0x02cb }
        r4 = android.os.SystemClock.elapsedRealtime();	 Catch:{ Exception -> 0x02cb }
        r4 = r4 - r10;
        r2 = r2.append(r4);	 Catch:{ Exception -> 0x02cb }
        r3 = "ms";
        r2 = r2.append(r3);	 Catch:{ Exception -> 0x02cb }
        r2 = r2.toString();	 Catch:{ Exception -> 0x02cb }
        com.tencent.rtmp.sharp.jni.QLog.e(r0, r1, r2);	 Catch:{ Exception -> 0x02cb }
    L_0x035e:
        r0 = r14._playLock;
        r0.unlock();
        goto L_0x0262;
    L_0x0365:
        r0 = r14._audioTrack;	 Catch:{ Exception -> 0x0410 }
        r0 = r0.getStreamType();	 Catch:{ Exception -> 0x0410 }
        goto L_0x0332;
    L_0x036c:
        r0 = r14._audioTrack;	 Catch:{ Exception -> 0x0239 }
        r1 = r14._tempBufPlay;	 Catch:{ Exception -> 0x0239 }
        r3 = 0;
        r0 = r0.write(r1, r3, r15);	 Catch:{ Exception -> 0x0239 }
        r1 = r14._playBuffer;	 Catch:{ Exception -> 0x040c }
        r1.rewind();	 Catch:{ Exception -> 0x040c }
        if (r0 >= 0) goto L_0x03b9;
    L_0x037c:
        r1 = com.tencent.rtmp.sharp.jni.QLog.isColorLevel();	 Catch:{ Exception -> 0x040c }
        if (r1 == 0) goto L_0x03ab;
    L_0x0382:
        r1 = "TRAE";
        r2 = 2;
        r3 = new java.lang.StringBuilder;	 Catch:{ Exception -> 0x040c }
        r4 = "Could not write data from sc (write = ";
        r3.<init>(r4);	 Catch:{ Exception -> 0x040c }
        r3 = r3.append(r0);	 Catch:{ Exception -> 0x040c }
        r4 = ", length = ";
        r3 = r3.append(r4);	 Catch:{ Exception -> 0x040c }
        r3 = r3.append(r15);	 Catch:{ Exception -> 0x040c }
        r4 = ")";
        r3 = r3.append(r4);	 Catch:{ Exception -> 0x040c }
        r3 = r3.toString();	 Catch:{ Exception -> 0x040c }
        com.tencent.rtmp.sharp.jni.QLog.e(r1, r2, r3);	 Catch:{ Exception -> 0x040c }
    L_0x03ab:
        r0 = r14._playLock;
        r0.unlock();
        r15 = -1;
        r0 = 65771; // 0x100eb float:9.2165E-41 double:3.2495E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r0);
        goto L_0x0047;
    L_0x03b9:
        if (r0 == r15) goto L_0x03ea;
    L_0x03bb:
        r1 = com.tencent.rtmp.sharp.jni.QLog.isColorLevel();	 Catch:{ Exception -> 0x040c }
        if (r1 == 0) goto L_0x03ea;
    L_0x03c1:
        r1 = "TRAE";
        r2 = 2;
        r3 = new java.lang.StringBuilder;	 Catch:{ Exception -> 0x040c }
        r4 = "Could not write all data from sc (write = ";
        r3.<init>(r4);	 Catch:{ Exception -> 0x040c }
        r3 = r3.append(r0);	 Catch:{ Exception -> 0x040c }
        r4 = ", length = ";
        r3 = r3.append(r4);	 Catch:{ Exception -> 0x040c }
        r3 = r3.append(r15);	 Catch:{ Exception -> 0x040c }
        r4 = ")";
        r3 = r3.append(r4);	 Catch:{ Exception -> 0x040c }
        r3 = r3.toString();	 Catch:{ Exception -> 0x040c }
        com.tencent.rtmp.sharp.jni.QLog.e(r1, r2, r3);	 Catch:{ Exception -> 0x040c }
    L_0x03ea:
        r1 = r14._bufferedPlaySamples;	 Catch:{ Exception -> 0x040c }
        r2 = r0 >> 1;
        r1 = r1 + r2;
        r14._bufferedPlaySamples = r1;	 Catch:{ Exception -> 0x040c }
        r1 = r14._audioTrack;	 Catch:{ Exception -> 0x040c }
        r1 = r1.getPlaybackHeadPosition();	 Catch:{ Exception -> 0x040c }
        r2 = r14._playPosition;	 Catch:{ Exception -> 0x040c }
        if (r1 >= r2) goto L_0x03fe;
    L_0x03fb:
        r2 = 0;
        r14._playPosition = r2;	 Catch:{ Exception -> 0x040c }
    L_0x03fe:
        r2 = r14._bufferedPlaySamples;	 Catch:{ Exception -> 0x040c }
        r3 = r14._playPosition;	 Catch:{ Exception -> 0x040c }
        r3 = r1 - r3;
        r2 = r2 - r3;
        r14._bufferedPlaySamples = r2;	 Catch:{ Exception -> 0x040c }
        r14._playPosition = r1;	 Catch:{ Exception -> 0x040c }
        r15 = r0;
        goto L_0x035e;
    L_0x040c:
        r1 = move-exception;
        r15 = r0;
        goto L_0x023c;
    L_0x0410:
        r0 = move-exception;
        goto L_0x0335;
    L_0x0413:
        r0 = move-exception;
        goto L_0x0080;
    L_0x0416:
        r7 = r0;
        goto L_0x015f;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.rtmp.sharp.jni.AudioDeviceInterface.PlayAudio(int):int");
    }

    private int OpenslesNeedResetAudioTrack(boolean z) {
        AppMethodBeat.i(65772);
        try {
            if (TraeAudioManager.isCloseSystemAPM(this._modePolicy)) {
                if (this._audioRouteChanged || z) {
                    if (this._audioManager == null && this._context != null) {
                        this._audioManager = (AudioManager) this._context.getSystemService("audio");
                    }
                    if (this._audioManager == null) {
                        AppMethodBeat.o(65772);
                        return 0;
                    }
                    if (this._audioManager.getMode() == 0 && this._connectedDev.equals("DEVICE_SPEAKERPHONE")) {
                        this._audioStreamTypePolicy = 3;
                    } else {
                        this._audioStreamTypePolicy = 0;
                    }
                    this._audioRouteChanged = false;
                }
                int i = this._audioStreamTypePolicy;
                AppMethodBeat.o(65772);
                return i;
            }
            AppMethodBeat.o(65772);
            return -1;
        } catch (Exception e) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "PlayAudio Exception: " + e.getMessage());
            }
        } catch (Throwable th) {
            AppMethodBeat.o(65772);
        }
    }

    private int RecordAudio(int i) {
        int i2 = 0;
        AppMethodBeat.i(65773);
        if (this._isRecording) {
            this._recLock.lock();
            try {
                if (this._audioRecord == null) {
                    this._recLock.unlock();
                    AppMethodBeat.o(65773);
                    return -2;
                }
                if (this._doRecInit) {
                    try {
                        Process.setThreadPriority(-19);
                    } catch (Exception e) {
                        if (QLog.isColorLevel()) {
                            QLog.w("TRAE", 2, "Set rec thread priority failed: " + e.getMessage());
                        }
                    }
                    this._doRecInit = false;
                }
                this._recBuffer.rewind();
                i2 = this._audioRecord.read(this._tempBufRec, 0, i);
                if (i2 < 0) {
                    if (QLog.isColorLevel()) {
                        QLog.e("TRAE", 2, "Could not read data from sc (read = " + i2 + ", length = " + i + ")");
                    }
                    this._recLock.unlock();
                    AppMethodBeat.o(65773);
                    return -1;
                }
                this._recBuffer.put(this._tempBufRec, 0, i2);
                if (_dumpEnable && this._rec_out != null) {
                    try {
                        this._rec_out.write(this._tempBufRec, 0, i2);
                    } catch (IOException e2) {
                    }
                }
                if (i2 != i) {
                    if (QLog.isColorLevel()) {
                        QLog.e("TRAE", 2, "Could not read all data from sc (read = " + i2 + ", length = " + i + ")");
                    }
                    this._recLock.unlock();
                    AppMethodBeat.o(65773);
                    return -1;
                }
                this._recLock.unlock();
                AppMethodBeat.o(65773);
                return i2;
            } catch (Exception e3) {
                if (QLog.isColorLevel()) {
                    QLog.e("TRAE", 2, "RecordAudio Exception: " + e3.getMessage());
                }
                this._recLock.unlock();
            } catch (Throwable th) {
                this._recLock.unlock();
                AppMethodBeat.o(65773);
            }
        } else {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "RecordAudio: _isRecording " + this._isRecording);
            }
            AppMethodBeat.o(65773);
            return -1;
        }
    }

    private int SetPlayoutVolume(int i) {
        AppMethodBeat.i(65774);
        if (this._audioManager == null && this._context != null) {
            this._audioManager = (AudioManager) this._context.getSystemService("audio");
        }
        int i2 = -1;
        if (this._audioManager != null) {
            this._audioManager.setStreamVolume(0, i, 0);
            i2 = 0;
        }
        AppMethodBeat.o(65774);
        return i2;
    }

    private int GetPlayoutVolume() {
        AppMethodBeat.i(65775);
        if (this._audioManager == null && this._context != null) {
            this._audioManager = (AudioManager) this._context.getSystemService("audio");
        }
        int i = -1;
        if (this._audioManager != null) {
            i = this._audioManager.getStreamVolume(0);
        }
        AppMethodBeat.o(65775);
        return i;
    }

    public static String getTraceInfo() {
        AppMethodBeat.i(65776);
        StringBuffer stringBuffer = new StringBuffer();
        StackTraceElement[] stackTrace = new Throwable().getStackTrace();
        stringBuffer.append(stackTrace[2].getClassName()).append(".").append(stackTrace[2].getMethodName()).append(": ").append(stackTrace[2].getLineNumber());
        String stringBuffer2 = stringBuffer.toString();
        AppMethodBeat.o(65776);
        return stringBuffer2;
    }

    public static final void LogTraceEntry(String str) {
        AppMethodBeat.i(65777);
        if (_logEnable) {
            String str2 = getTraceInfo() + " entry:" + str;
            if (QLog.isColorLevel()) {
                QLog.w("TRAE", 2, str2);
            }
            AppMethodBeat.o(65777);
            return;
        }
        AppMethodBeat.o(65777);
    }

    public static final void LogTraceExit() {
        AppMethodBeat.i(65778);
        if (_logEnable) {
            String str = getTraceInfo() + " exit";
            if (QLog.isColorLevel()) {
                QLog.w("TRAE", 2, str);
            }
            AppMethodBeat.o(65778);
            return;
        }
        AppMethodBeat.o(65778);
    }

    private void onOutputChanage(String str) {
        AppMethodBeat.i(65779);
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, " onOutputChanage:".concat(String.valueOf(str)));
        }
        setAudioRouteSwitchState(str);
        if (!TraeAudioManager.isCloseSystemAPM(this._modePolicy)) {
            AppMethodBeat.o(65779);
        } else if (this._sceneModeKey == 1 || this._sceneModeKey == 2 || this._sceneModeKey == 3) {
            AppMethodBeat.o(65779);
        } else {
            String str2;
            String str3;
            this._connectedDev = str;
            if (QLog.isColorLevel()) {
                str2 = "TRAE";
                StringBuilder append = new StringBuilder(" onOutputChanage:").append(str);
                if (this._audioManager == null) {
                    str3 = " am==null";
                } else {
                    str3 = " mode:" + this._audioManager.getMode();
                }
                append = append.append(str3).append(" st:").append(this._streamType);
                if (this._audioTrack == null) {
                    str3 = "_audioTrack==null";
                } else {
                    str3 = " at.st:" + this._audioTrack.getStreamType();
                }
                QLog.w(str2, 2, append.append(str3).toString());
            }
            try {
                if (this._audioManager == null) {
                    this._audioManager = (AudioManager) this._context.getSystemService("audio");
                }
                if (QLog.isColorLevel()) {
                    str2 = "TRAE";
                    StringBuilder append2 = new StringBuilder(" curr mode:").append(str);
                    if (this._audioManager == null) {
                        str3 = "am==null";
                    } else {
                        str3 = " mode:" + this._audioManager.getMode();
                    }
                    QLog.w(str2, 2, append2.append(str3).toString());
                }
                if (this._audioManager != null && this._connectedDev.equals("DEVICE_SPEAKERPHONE")) {
                    this._audioManager.setMode(0);
                }
            } catch (Exception e) {
                if (QLog.isColorLevel()) {
                    QLog.w("TRAE", 2, e.getMessage());
                }
            }
            this._audioRouteChanged = true;
            AppMethodBeat.o(65779);
        }
    }

    public int call_preprocess() {
        AppMethodBeat.i(65780);
        LogTraceEntry("");
        this.switchState = 0;
        this._streamType = TraeAudioManager.getAudioStreamType(this._audioStreamTypePolicy);
        if (this._as == null) {
            QLog.e("TRAE", 2, "TraeAudioSession-LeakCheck init: call_preprocess");
        }
        this._as = new TraeAudioSession(this._context, new 1(this));
        this._preDone = false;
        if (this._as != null) {
            this._prelock.lock();
            try {
                this._as.voiceCallPreprocess(this._modePolicy, this._streamType);
                this._as.connectHighestPriorityDevice();
                int i = 7;
                while (true) {
                    int i2 = i - 1;
                    if (i <= 0) {
                        break;
                    }
                    try {
                        if (this._preDone) {
                            break;
                        }
                        this._precon.await(1, TimeUnit.SECONDS);
                        if (QLog.isColorLevel()) {
                            QLog.e("TRAE", 2, "call_preprocess waiting...  as:" + this._as);
                            i = i2;
                        } else {
                            i = i2;
                        }
                    } catch (InterruptedException e) {
                    }
                }
                if (QLog.isColorLevel()) {
                    QLog.e("TRAE", 2, "call_preprocess done!");
                }
                this._as.getConnectedDevice();
                this._prelock.unlock();
            } catch (Throwable th) {
                this._prelock.unlock();
                AppMethodBeat.o(65780);
            }
        }
        LogTraceExit();
        AppMethodBeat.o(65780);
        return 0;
    }

    public int call_postprocess() {
        AppMethodBeat.i(65781);
        LogTraceEntry("");
        this.switchState = 0;
        if (this._as != null) {
            this._as.voiceCallPostprocess();
            this._as.release();
            this._as = null;
            QLog.e("TRAE", 2, "TraeAudioSession-LeakCheck release: call_postprocess");
        }
        TraeAudioManager.IsUpdateSceneFlag = false;
        LogTraceExit();
        AppMethodBeat.o(65781);
        return 0;
    }

    public int call_preprocess_media() {
        AppMethodBeat.i(65782);
        LogTraceEntry("");
        this.switchState = 0;
        if (this._as == null) {
            QLog.e("TRAE", 2, "TraeAudioSession-LeakCheck init: call_preprocess_media");
        }
        this._as = new TraeAudioSession(this._context, new 2(this));
        if (this._as != null) {
            try {
                if (this._audioManager == null) {
                    this._audioManager = (AudioManager) this._context.getSystemService("audio");
                }
                if (this._audioManager != null) {
                    if (this._audioManager.getMode() == 2) {
                        int i = 5;
                        while (true) {
                            int i2 = i - 1;
                            if (i <= 0 || this._audioManager.getMode() != 2) {
                                break;
                            }
                            if (QLog.isColorLevel()) {
                                QLog.e("TRAE", 2, "media call_preprocess waiting...  mode:" + this._audioManager.getMode());
                            }
                            Thread.sleep(500);
                            i = i2;
                        }
                    }
                    if (this._audioManager.getMode() != 0) {
                        this._audioManager.setMode(0);
                    }
                }
                this._as.connectHighestPriorityDevice();
                this._as.getConnectedDevice();
                if (QLog.isColorLevel()) {
                    QLog.e("TRAE", 2, "call_preprocess done!");
                }
            } catch (InterruptedException e) {
            }
        }
        LogTraceExit();
        AppMethodBeat.o(65782);
        return 0;
    }

    public int call_postprocess_media() {
        AppMethodBeat.i(65783);
        LogTraceEntry("");
        this.switchState = 0;
        if (this._as != null) {
            this._as.release();
            this._as = null;
            QLog.e("TRAE", 2, "TraeAudioSession-LeakCheck release: call_postprocess_media");
        }
        TraeAudioManager.IsUpdateSceneFlag = false;
        LogTraceExit();
        AppMethodBeat.o(65783);
        return 0;
    }

    public void setJavaInterface(int i) {
        AppMethodBeat.i(65784);
        if (i == 0) {
            this.usingJava = false;
        } else {
            this.usingJava = true;
        }
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "setJavaInterface flg:".concat(String.valueOf(i)));
        }
        AppMethodBeat.o(65784);
    }

    private void setAudioRouteSwitchState(String str) {
        AppMethodBeat.i(65785);
        if (str.equals("DEVICE_EARPHONE")) {
            this.switchState = 1;
            AppMethodBeat.o(65785);
        } else if (str.equals("DEVICE_SPEAKERPHONE")) {
            this.switchState = 2;
            AppMethodBeat.o(65785);
        } else if (str.equals("DEVICE_WIREDHEADSET")) {
            this.switchState = 3;
            AppMethodBeat.o(65785);
        } else if (str.equals("DEVICE_BLUETOOTHHEADSET")) {
            this.switchState = 4;
            AppMethodBeat.o(65785);
        } else {
            this.switchState = 0;
            AppMethodBeat.o(65785);
        }
    }

    public int getAudioRouteSwitchState() {
        return this.switchState;
    }

    private void initTRAEAudioManager() {
        AppMethodBeat.i(65786);
        if (this._context != null) {
            TraeAudioManager.init(this._context);
            if (this._init_as == null) {
                QLog.e("TRAE", 2, "TraeAudioSession-LeakCheck init: initTRAEAudioManager");
                this._init_as = new TraeAudioSession(this._context, null);
            }
            if (QLog.isColorLevel()) {
                QLog.w("TRAE", 2, "initTRAEAudioManager , TraeAudioSession startService");
            }
            this._init_as.startService("DEVICE_SPEAKERPHONE;DEVICE_WIREDHEADSET;DEVICE_BLUETOOTHHEADSET;");
        }
        AppMethodBeat.o(65786);
    }

    private int getAndroidSdkVersion() {
        return VERSION.SDK_INT;
    }

    private void uninitTRAEAudioManager() {
        AppMethodBeat.i(65787);
        if (this._context != null) {
            if (this._init_as != null) {
                if (QLog.isColorLevel()) {
                    QLog.w("TRAE", 2, "uninitTRAEAudioManager , stopService");
                }
                this._init_as.stopService();
                this._init_as.release();
                this._init_as = null;
                QLog.e("TRAE", 2, "TraeAudioSession-LeakCheck release: uninitTRAEAudioManager");
            }
            if (QLog.isColorLevel()) {
                QLog.w("TRAE", 2, "uninitTRAEAudioManager , stopService");
            }
            TraeAudioManager.uninit();
            AppMethodBeat.o(65787);
            return;
        }
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "uninitTRAEAudioManager , context null");
        }
        AppMethodBeat.o(65787);
    }
}
