package com.tencent.ttpic.view;

import android.content.Context;
import android.util.AttributeSet;
import android.view.SurfaceHolder;
import android.view.SurfaceHolder.Callback2;
import android.view.SurfaceView;
import com.tencent.matrix.trace.core.AppMethodBeat;
import java.lang.ref.WeakReference;
import javax.microedition.khronos.egl.EGL10;
import javax.microedition.khronos.egl.EGLConfig;
import javax.microedition.khronos.egl.EGLDisplay;
import javax.microedition.khronos.opengles.GL;
import javax.microedition.khronos.opengles.GL10;

public class GLSurfaceView extends SurfaceView implements Callback2 {
    public static final int DEBUG_CHECK_GL_ERROR = 1;
    public static final int DEBUG_LOG_GL_CALLS = 2;
    private static final boolean LOG_ATTACH_DETACH = false;
    private static final boolean LOG_EGL = false;
    private static final boolean LOG_PAUSE_RESUME = false;
    private static final boolean LOG_RENDERER = false;
    private static final boolean LOG_RENDERER_DRAW_FRAME = false;
    private static final boolean LOG_SURFACE = false;
    private static final boolean LOG_THREADS = false;
    public static final int RENDERMODE_CONTINUOUSLY = 1;
    public static final int RENDERMODE_WHEN_DIRTY = 0;
    private static final String TAG = "GLSurfaceView";
    private static final GLThreadManager sGLThreadManager = new GLThreadManager(null);
    private int mDebugFlags;
    private boolean mDetached;
    private EGLConfigChooser mEGLConfigChooser;
    private int mEGLContextClientVersion;
    private EGLContextFactory mEGLContextFactory;
    private EGLWindowSurfaceFactory mEGLWindowSurfaceFactory;
    private GLThread mGLThread;
    private GLWrapper mGLWrapper;
    private boolean mPreserveEGLContextOnPause;
    private Renderer mRenderer;
    private final WeakReference<GLSurfaceView> mThisWeakRef = new WeakReference(this);

    public interface EGLConfigChooser {
        EGLConfig chooseConfig(EGL10 egl10, EGLDisplay eGLDisplay);
    }

    public interface GLWrapper {
        GL wrap(GL gl);
    }

    public interface Renderer {
        void onDrawFrame(GL10 gl10);

        void onSurfaceChanged(GL10 gl10, int i, int i2);

        void onSurfaceCreated(GL10 gl10, EGLConfig eGLConfig);
    }

    public GLSurfaceView(Context context) {
        super(context);
        AppMethodBeat.i(84472);
        init();
        AppMethodBeat.o(84472);
    }

    public GLSurfaceView(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
        AppMethodBeat.i(84473);
        init();
        AppMethodBeat.o(84473);
    }

    /* Access modifiers changed, original: protected */
    public void finalize() {
        AppMethodBeat.i(84474);
        try {
            if (this.mGLThread != null) {
                this.mGLThread.requestExitAndWait();
            }
            super.finalize();
            AppMethodBeat.o(84474);
        } catch (Throwable th) {
            super.finalize();
            AppMethodBeat.o(84474);
        }
    }

    private void init() {
        AppMethodBeat.i(84475);
        getHolder().addCallback(this);
        AppMethodBeat.o(84475);
    }

    public void setGLWrapper(GLWrapper gLWrapper) {
        this.mGLWrapper = gLWrapper;
    }

    public void setDebugFlags(int i) {
        this.mDebugFlags = i;
    }

    public int getDebugFlags() {
        return this.mDebugFlags;
    }

    public void setPreserveEGLContextOnPause(boolean z) {
        this.mPreserveEGLContextOnPause = z;
    }

    public boolean getPreserveEGLContextOnPause() {
        return this.mPreserveEGLContextOnPause;
    }

    public void setRenderer(Renderer renderer) {
        AppMethodBeat.i(84476);
        checkRenderThreadState();
        if (this.mEGLConfigChooser == null) {
            this.mEGLConfigChooser = new SimpleEGLConfigChooser(this, true);
        }
        if (this.mEGLContextFactory == null) {
            this.mEGLContextFactory = new DefaultContextFactory(this, null);
        }
        if (this.mEGLWindowSurfaceFactory == null) {
            this.mEGLWindowSurfaceFactory = new DefaultWindowSurfaceFactory(null);
        }
        this.mRenderer = renderer;
        this.mGLThread = new GLThread(this.mThisWeakRef);
        this.mGLThread.start();
        AppMethodBeat.o(84476);
    }

    public void setEGLContextFactory(EGLContextFactory eGLContextFactory) {
        AppMethodBeat.i(84477);
        checkRenderThreadState();
        this.mEGLContextFactory = eGLContextFactory;
        AppMethodBeat.o(84477);
    }

    public void setEGLWindowSurfaceFactory(EGLWindowSurfaceFactory eGLWindowSurfaceFactory) {
        AppMethodBeat.i(84478);
        checkRenderThreadState();
        this.mEGLWindowSurfaceFactory = eGLWindowSurfaceFactory;
        AppMethodBeat.o(84478);
    }

    public void setEGLConfigChooser(EGLConfigChooser eGLConfigChooser) {
        AppMethodBeat.i(84479);
        checkRenderThreadState();
        this.mEGLConfigChooser = eGLConfigChooser;
        AppMethodBeat.o(84479);
    }

    public void setEGLConfigChooser(boolean z) {
        AppMethodBeat.i(84480);
        setEGLConfigChooser(new SimpleEGLConfigChooser(this, z));
        AppMethodBeat.o(84480);
    }

    public void setEGLConfigChooser(int i, int i2, int i3, int i4, int i5, int i6) {
        AppMethodBeat.i(84481);
        setEGLConfigChooser(new ComponentSizeChooser(this, i, i2, i3, i4, i5, i6));
        AppMethodBeat.o(84481);
    }

    public void setEGLContextClientVersion(int i) {
        AppMethodBeat.i(84482);
        checkRenderThreadState();
        this.mEGLContextClientVersion = i;
        AppMethodBeat.o(84482);
    }

    public void setRenderMode(int i) {
        AppMethodBeat.i(84483);
        this.mGLThread.setRenderMode(i);
        AppMethodBeat.o(84483);
    }

    public int getRenderMode() {
        AppMethodBeat.i(84484);
        int renderMode = this.mGLThread.getRenderMode();
        AppMethodBeat.o(84484);
        return renderMode;
    }

    public void requestRender() {
        AppMethodBeat.i(84485);
        this.mGLThread.requestRender();
        AppMethodBeat.o(84485);
    }

    public void surfaceCreated(SurfaceHolder surfaceHolder) {
        AppMethodBeat.i(84486);
        this.mGLThread.surfaceCreated();
        AppMethodBeat.o(84486);
    }

    public void surfaceDestroyed(SurfaceHolder surfaceHolder) {
        AppMethodBeat.i(84487);
        this.mGLThread.surfaceDestroyed();
        AppMethodBeat.o(84487);
    }

    public void surfaceChanged(SurfaceHolder surfaceHolder, int i, int i2, int i3) {
        AppMethodBeat.i(84488);
        this.mGLThread.onWindowResize(i2, i3);
        AppMethodBeat.o(84488);
    }

    public void surfaceRedrawNeededAsync(SurfaceHolder surfaceHolder, Runnable runnable) {
        AppMethodBeat.i(84489);
        if (this.mGLThread != null) {
            this.mGLThread.requestRenderAndNotify(runnable);
        }
        AppMethodBeat.o(84489);
    }

    @Deprecated
    public void surfaceRedrawNeeded(SurfaceHolder surfaceHolder) {
    }

    public void onPause() {
        AppMethodBeat.i(84490);
        this.mGLThread.onPause();
        AppMethodBeat.o(84490);
    }

    public void onResume() {
        AppMethodBeat.i(84491);
        this.mGLThread.onResume();
        AppMethodBeat.o(84491);
    }

    public void queueEvent(Runnable runnable) {
        AppMethodBeat.i(84492);
        this.mGLThread.queueEvent(runnable);
        AppMethodBeat.o(84492);
    }

    /* Access modifiers changed, original: protected */
    public void onAttachedToWindow() {
        AppMethodBeat.i(84493);
        super.onAttachedToWindow();
        if (this.mDetached && this.mRenderer != null) {
            int renderMode;
            if (this.mGLThread != null) {
                renderMode = this.mGLThread.getRenderMode();
            } else {
                renderMode = 1;
            }
            this.mGLThread = new GLThread(this.mThisWeakRef);
            if (renderMode != 1) {
                this.mGLThread.setRenderMode(renderMode);
            }
            this.mGLThread.start();
        }
        this.mDetached = false;
        AppMethodBeat.o(84493);
    }

    /* Access modifiers changed, original: protected */
    public void onDetachedFromWindow() {
        AppMethodBeat.i(84494);
        if (this.mGLThread != null) {
            this.mGLThread.requestExitAndWait();
        }
        this.mDetached = true;
        super.onDetachedFromWindow();
        AppMethodBeat.o(84494);
    }

    private void checkRenderThreadState() {
        AppMethodBeat.i(84495);
        if (this.mGLThread != null) {
            IllegalStateException illegalStateException = new IllegalStateException("setRenderer has already been called for this instance.");
            AppMethodBeat.o(84495);
            throw illegalStateException;
        }
        AppMethodBeat.o(84495);
    }

    static {
        AppMethodBeat.i(84496);
        AppMethodBeat.o(84496);
    }
}
