package com.facebook;

import android.graphics.Bitmap;
import android.graphics.Bitmap.CompressFormat;
import android.net.Uri;
import android.os.ParcelFileDescriptor;
import android.os.ParcelFileDescriptor.AutoCloseInputStream;
import android.os.Parcelable;
import com.facebook.GraphRequest.ParcelableResourceWithMimeType;
import com.facebook.internal.Logger;
import com.facebook.internal.Utility;
import com.tencent.matrix.trace.core.AppMethodBeat;
import java.io.OutputStream;
import java.net.URLEncoder;
import java.util.Collection;
import java.util.Locale;
import org.json.JSONArray;
import org.json.JSONObject;

class GraphRequest$Serializer implements GraphRequest$KeyValueSerializer {
    private boolean firstWrite = true;
    private final Logger logger;
    private final OutputStream outputStream;
    private boolean useUrlEncode = false;

    public GraphRequest$Serializer(OutputStream outputStream, Logger logger, boolean z) {
        this.outputStream = outputStream;
        this.logger = logger;
        this.useUrlEncode = z;
    }

    public void writeObject(String str, Object obj, GraphRequest graphRequest) {
        AppMethodBeat.i(71652);
        if (this.outputStream instanceof RequestOutputStream) {
            ((RequestOutputStream) this.outputStream).setCurrentRequest(graphRequest);
        }
        RuntimeException invalidTypeError;
        if (GraphRequest.access$000(obj)) {
            writeString(str, GraphRequest.access$100(obj));
            AppMethodBeat.o(71652);
        } else if (obj instanceof Bitmap) {
            writeBitmap(str, (Bitmap) obj);
            AppMethodBeat.o(71652);
        } else if (obj instanceof byte[]) {
            writeBytes(str, (byte[]) obj);
            AppMethodBeat.o(71652);
        } else if (obj instanceof Uri) {
            writeContentUri(str, (Uri) obj, null);
            AppMethodBeat.o(71652);
        } else if (obj instanceof ParcelFileDescriptor) {
            writeFile(str, (ParcelFileDescriptor) obj, null);
            AppMethodBeat.o(71652);
        } else if (obj instanceof ParcelableResourceWithMimeType) {
            ParcelableResourceWithMimeType parcelableResourceWithMimeType = (ParcelableResourceWithMimeType) obj;
            Parcelable resource = parcelableResourceWithMimeType.getResource();
            String mimeType = parcelableResourceWithMimeType.getMimeType();
            if (resource instanceof ParcelFileDescriptor) {
                writeFile(str, (ParcelFileDescriptor) resource, mimeType);
                AppMethodBeat.o(71652);
            } else if (resource instanceof Uri) {
                writeContentUri(str, (Uri) resource, mimeType);
                AppMethodBeat.o(71652);
            } else {
                invalidTypeError = getInvalidTypeError();
                AppMethodBeat.o(71652);
                throw invalidTypeError;
            }
        } else {
            invalidTypeError = getInvalidTypeError();
            AppMethodBeat.o(71652);
            throw invalidTypeError;
        }
    }

    private RuntimeException getInvalidTypeError() {
        AppMethodBeat.i(71653);
        IllegalArgumentException illegalArgumentException = new IllegalArgumentException("value is not a supported type.");
        AppMethodBeat.o(71653);
        return illegalArgumentException;
    }

    public void writeRequestsAsJson(String str, JSONArray jSONArray, Collection<GraphRequest> collection) {
        AppMethodBeat.i(71654);
        if (this.outputStream instanceof RequestOutputStream) {
            RequestOutputStream requestOutputStream = (RequestOutputStream) this.outputStream;
            writeContentDisposition(str, null, null);
            write("[", new Object[0]);
            int i = 0;
            for (GraphRequest graphRequest : collection) {
                JSONObject jSONObject = jSONArray.getJSONObject(i);
                requestOutputStream.setCurrentRequest(graphRequest);
                if (i > 0) {
                    write(",%s", jSONObject.toString());
                } else {
                    write("%s", jSONObject.toString());
                }
                i++;
            }
            write("]", new Object[0]);
            if (this.logger != null) {
                this.logger.appendKeyValue("    ".concat(String.valueOf(str)), jSONArray.toString());
            }
            AppMethodBeat.o(71654);
            return;
        }
        writeString(str, jSONArray.toString());
        AppMethodBeat.o(71654);
    }

    public void writeString(String str, String str2) {
        AppMethodBeat.i(71655);
        writeContentDisposition(str, null, null);
        writeLine("%s", str2);
        writeRecordBoundary();
        if (this.logger != null) {
            this.logger.appendKeyValue("    ".concat(String.valueOf(str)), str2);
        }
        AppMethodBeat.o(71655);
    }

    public void writeBitmap(String str, Bitmap bitmap) {
        AppMethodBeat.i(71656);
        writeContentDisposition(str, str, "image/png");
        bitmap.compress(CompressFormat.PNG, 100, this.outputStream);
        writeLine("", new Object[0]);
        writeRecordBoundary();
        if (this.logger != null) {
            this.logger.appendKeyValue("    ".concat(String.valueOf(str)), "<Image>");
        }
        AppMethodBeat.o(71656);
    }

    public void writeBytes(String str, byte[] bArr) {
        AppMethodBeat.i(71657);
        writeContentDisposition(str, str, "content/unknown");
        this.outputStream.write(bArr);
        writeLine("", new Object[0]);
        writeRecordBoundary();
        if (this.logger != null) {
            this.logger.appendKeyValue("    ".concat(String.valueOf(str)), String.format(Locale.ROOT, "<Data: %d>", new Object[]{Integer.valueOf(bArr.length)}));
        }
        AppMethodBeat.o(71657);
    }

    public void writeContentUri(String str, Uri uri, String str2) {
        int i;
        AppMethodBeat.i(71658);
        if (str2 == null) {
            str2 = "content/unknown";
        }
        writeContentDisposition(str, str, str2);
        if (this.outputStream instanceof ProgressNoopOutputStream) {
            ((ProgressNoopOutputStream) this.outputStream).addProgress(Utility.getContentSize(uri));
            i = 0;
        } else {
            i = Utility.copyAndCloseInputStream(FacebookSdk.getApplicationContext().getContentResolver().openInputStream(uri), this.outputStream) + 0;
        }
        writeLine("", new Object[0]);
        writeRecordBoundary();
        if (this.logger != null) {
            this.logger.appendKeyValue("    ".concat(String.valueOf(str)), String.format(Locale.ROOT, "<Data: %d>", new Object[]{Integer.valueOf(i)}));
        }
        AppMethodBeat.o(71658);
    }

    public void writeFile(String str, ParcelFileDescriptor parcelFileDescriptor, String str2) {
        int i;
        AppMethodBeat.i(71659);
        if (str2 == null) {
            str2 = "content/unknown";
        }
        writeContentDisposition(str, str, str2);
        if (this.outputStream instanceof ProgressNoopOutputStream) {
            ((ProgressNoopOutputStream) this.outputStream).addProgress(parcelFileDescriptor.getStatSize());
            i = 0;
        } else {
            i = Utility.copyAndCloseInputStream(new AutoCloseInputStream(parcelFileDescriptor), this.outputStream) + 0;
        }
        writeLine("", new Object[0]);
        writeRecordBoundary();
        if (this.logger != null) {
            this.logger.appendKeyValue("    ".concat(String.valueOf(str)), String.format(Locale.ROOT, "<Data: %d>", new Object[]{Integer.valueOf(i)}));
        }
        AppMethodBeat.o(71659);
    }

    public void writeRecordBoundary() {
        AppMethodBeat.i(71660);
        if (this.useUrlEncode) {
            this.outputStream.write("&".getBytes());
            AppMethodBeat.o(71660);
            return;
        }
        writeLine("--%s", GraphRequest.access$200());
        AppMethodBeat.o(71660);
    }

    public void writeContentDisposition(String str, String str2, String str3) {
        AppMethodBeat.i(71661);
        if (this.useUrlEncode) {
            this.outputStream.write(String.format("%s=", new Object[]{str}).getBytes());
            AppMethodBeat.o(71661);
            return;
        }
        write("Content-Disposition: form-data; name=\"%s\"", str);
        if (str2 != null) {
            write("; filename=\"%s\"", str2);
        }
        writeLine("", new Object[0]);
        if (str3 != null) {
            writeLine("%s: %s", "Content-Type", str3);
        }
        writeLine("", new Object[0]);
        AppMethodBeat.o(71661);
    }

    public void write(String str, Object... objArr) {
        AppMethodBeat.i(71662);
        if (this.useUrlEncode) {
            this.outputStream.write(URLEncoder.encode(String.format(Locale.US, str, objArr), "UTF-8").getBytes());
            AppMethodBeat.o(71662);
            return;
        }
        if (this.firstWrite) {
            this.outputStream.write("--".getBytes());
            this.outputStream.write(GraphRequest.access$200().getBytes());
            this.outputStream.write("\r\n".getBytes());
            this.firstWrite = false;
        }
        this.outputStream.write(String.format(str, objArr).getBytes());
        AppMethodBeat.o(71662);
    }

    public void writeLine(String str, Object... objArr) {
        AppMethodBeat.i(71663);
        write(str, objArr);
        if (!this.useUrlEncode) {
            write("\r\n", new Object[0]);
        }
        AppMethodBeat.o(71663);
    }
}
