package com.facebook.appevents.codeless;

import android.app.Activity;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.view.View;
import com.facebook.FacebookException;
import com.facebook.appevents.codeless.internal.EventBinding;
import com.facebook.appevents.codeless.internal.ParameterComponent;
import com.facebook.appevents.codeless.internal.ViewHierarchy;
import com.facebook.internal.InternalSettings;
import com.tencent.matrix.trace.core.AppMethodBeat;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

public class CodelessMatcher {
    private static final String CURRENT_CLASS_NAME = ".";
    private static final String PARENT_CLASS_NAME = "..";
    private static final String TAG = CodelessMatcher.class.getCanonicalName();
    private Set<Activity> activitiesSet = new HashSet();
    private HashMap<String, String> delegateMap = new HashMap();
    private final Handler uiThreadHandler = new Handler(Looper.getMainLooper());
    private Set<ViewMatcher> viewMatchers = new HashSet();

    static /* synthetic */ void access$000(CodelessMatcher codelessMatcher) {
        AppMethodBeat.i(72067);
        codelessMatcher.matchViews();
        AppMethodBeat.o(72067);
    }

    static {
        AppMethodBeat.i(72068);
        AppMethodBeat.o(72068);
    }

    public CodelessMatcher() {
        AppMethodBeat.i(72061);
        AppMethodBeat.o(72061);
    }

    public void add(Activity activity) {
        AppMethodBeat.i(72062);
        if (InternalSettings.isUnityApp()) {
            AppMethodBeat.o(72062);
        } else if (Thread.currentThread() != Looper.getMainLooper().getThread()) {
            FacebookException facebookException = new FacebookException("Can't add activity to CodelessMatcher on non-UI thread");
            AppMethodBeat.o(72062);
            throw facebookException;
        } else {
            this.activitiesSet.add(activity);
            this.delegateMap.clear();
            startTracking();
            AppMethodBeat.o(72062);
        }
    }

    public void remove(Activity activity) {
        AppMethodBeat.i(72063);
        if (InternalSettings.isUnityApp()) {
            AppMethodBeat.o(72063);
        } else if (Thread.currentThread() != Looper.getMainLooper().getThread()) {
            FacebookException facebookException = new FacebookException("Can't remove activity from CodelessMatcher on non-UI thread");
            AppMethodBeat.o(72063);
            throw facebookException;
        } else {
            this.activitiesSet.remove(activity);
            this.viewMatchers.clear();
            this.delegateMap.clear();
            AppMethodBeat.o(72063);
        }
    }

    public static Bundle getParameters(EventBinding eventBinding, View view, View view2) {
        AppMethodBeat.i(72064);
        Bundle bundle = new Bundle();
        if (eventBinding == null) {
            AppMethodBeat.o(72064);
            return bundle;
        }
        List<ParameterComponent> viewParameters = eventBinding.getViewParameters();
        if (viewParameters != null) {
            for (ParameterComponent parameterComponent : viewParameters) {
                if (parameterComponent.value != null && parameterComponent.value.length() > 0) {
                    bundle.putString(parameterComponent.name, parameterComponent.value);
                } else if (parameterComponent.path.size() > 0) {
                    List findViewByPath;
                    if (parameterComponent.pathType.equals("relative")) {
                        findViewByPath = ViewMatcher.findViewByPath(eventBinding, view2, parameterComponent.path, 0, -1, view2.getClass().getSimpleName());
                    } else {
                        findViewByPath = ViewMatcher.findViewByPath(eventBinding, view, parameterComponent.path, 0, -1, view.getClass().getSimpleName());
                    }
                    for (MatchedView matchedView : findViewByPath) {
                        if (matchedView.getView() != null) {
                            String textOfView = ViewHierarchy.getTextOfView(matchedView.getView());
                            if (textOfView.length() > 0) {
                                bundle.putString(parameterComponent.name, textOfView);
                                break;
                            }
                        }
                    }
                }
            }
        }
        AppMethodBeat.o(72064);
        return bundle;
    }

    private void startTracking() {
        AppMethodBeat.i(72065);
        if (Thread.currentThread() == Looper.getMainLooper().getThread()) {
            matchViews();
            AppMethodBeat.o(72065);
            return;
        }
        this.uiThreadHandler.post(new 1(this));
        AppMethodBeat.o(72065);
    }

    private void matchViews() {
        AppMethodBeat.i(72066);
        for (Activity activity : this.activitiesSet) {
            this.viewMatchers.add(new ViewMatcher(activity.getWindow().getDecorView().getRootView(), this.uiThreadHandler, this.delegateMap, activity.getClass().getSimpleName()));
        }
        AppMethodBeat.o(72066);
    }
}
