package com.google.android.gms.common.images;

import android.app.ActivityManager;
import android.content.Context;
import android.graphics.Bitmap;
import android.net.Uri;
import android.os.Handler;
import android.os.Looper;
import android.support.v4.f.g;
import android.widget.ImageView;
import com.google.android.gms.common.images.ImageRequest.ListenerImageRequest;
import com.google.android.gms.common.images.internal.PostProcessedResourceCache;
import com.google.android.gms.common.internal.Asserts;
import com.tencent.matrix.trace.core.AppMethodBeat;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public final class ImageManager {
    public static final int PRIORITY_HIGH = 3;
    public static final int PRIORITY_LOW = 1;
    public static final int PRIORITY_MEDIUM = 2;
    private static final Object zzov = new Object();
    private static HashSet<Uri> zzow = new HashSet();
    private static ImageManager zzox;
    private static ImageManager zzoy;
    private final Context mContext;
    private final Handler mHandler = new Handler(Looper.getMainLooper());
    private final ExecutorService zzoz = Executors.newFixedThreadPool(4);
    private final zza zzpa;
    private final PostProcessedResourceCache zzpb;
    private final Map<ImageRequest, ImageReceiver> zzpc;
    private final Map<Uri, ImageReceiver> zzpd;
    private final Map<Uri, Long> zzpe;

    static final class zza extends g<com.google.android.gms.common.images.ImageRequest.zza, Bitmap> {
        public zza(Context context) {
            ActivityManager activityManager = (ActivityManager) context.getSystemService("activity");
            super((int) (((float) ((((context.getApplicationInfo().flags & 1048576) != 0 ? 1 : null) != null ? activityManager.getLargeMemoryClass() : activityManager.getMemoryClass()) * 1048576)) * 0.33f));
            AppMethodBeat.i(61208);
            AppMethodBeat.o(61208);
        }

        public final /* synthetic */ void entryRemoved(boolean z, Object obj, Object obj2, Object obj3) {
            AppMethodBeat.i(61210);
            super.entryRemoved(z, (com.google.android.gms.common.images.ImageRequest.zza) obj, (Bitmap) obj2, (Bitmap) obj3);
            AppMethodBeat.o(61210);
        }

        public final /* synthetic */ int sizeOf(Object obj, Object obj2) {
            AppMethodBeat.i(61209);
            Bitmap bitmap = (Bitmap) obj2;
            int height = bitmap.getHeight() * bitmap.getRowBytes();
            AppMethodBeat.o(61209);
            return height;
        }
    }

    static {
        AppMethodBeat.i(61227);
        AppMethodBeat.o(61227);
    }

    private ImageManager(Context context, boolean z) {
        AppMethodBeat.i(61218);
        this.mContext = context.getApplicationContext();
        if (z) {
            this.zzpa = new zza(this.mContext);
            this.mContext.registerComponentCallbacks(new zzd(this.zzpa));
        } else {
            this.zzpa = null;
        }
        this.zzpb = new PostProcessedResourceCache();
        this.zzpc = new HashMap();
        this.zzpd = new HashMap();
        this.zzpe = new HashMap();
        AppMethodBeat.o(61218);
    }

    public static ImageManager create(Context context) {
        AppMethodBeat.i(61216);
        ImageManager create = create(context, false);
        AppMethodBeat.o(61216);
        return create;
    }

    public static ImageManager create(Context context, boolean z) {
        AppMethodBeat.i(61217);
        ImageManager imageManager;
        if (z) {
            if (zzoy == null) {
                zzoy = new ImageManager(context, true);
            }
            imageManager = zzoy;
            AppMethodBeat.o(61217);
            return imageManager;
        }
        if (zzox == null) {
            zzox = new ImageManager(context, false);
        }
        imageManager = zzox;
        AppMethodBeat.o(61217);
        return imageManager;
    }

    static /* synthetic */ Bitmap zza(ImageManager imageManager, com.google.android.gms.common.images.ImageRequest.zza zza) {
        AppMethodBeat.i(61226);
        Bitmap zza2 = imageManager.zza(zza);
        AppMethodBeat.o(61226);
        return zza2;
    }

    private final Bitmap zza(com.google.android.gms.common.images.ImageRequest.zza zza) {
        AppMethodBeat.i(61225);
        if (this.zzpa == null) {
            AppMethodBeat.o(61225);
            return null;
        }
        Bitmap bitmap = (Bitmap) this.zzpa.get(zza);
        AppMethodBeat.o(61225);
        return bitmap;
    }

    public final void loadImage(ImageView imageView, int i) {
        AppMethodBeat.i(61220);
        loadImage(new ImageRequest$ImageViewImageRequest(imageView, i));
        AppMethodBeat.o(61220);
    }

    public final void loadImage(ImageView imageView, Uri uri) {
        AppMethodBeat.i(61219);
        loadImage(new ImageRequest$ImageViewImageRequest(imageView, uri));
        AppMethodBeat.o(61219);
    }

    public final void loadImage(ImageView imageView, Uri uri, int i) {
        AppMethodBeat.i(61221);
        ImageRequest$ImageViewImageRequest imageRequest$ImageViewImageRequest = new ImageRequest$ImageViewImageRequest(imageView, uri);
        imageRequest$ImageViewImageRequest.setNoDataPlaceholder(i);
        loadImage(imageRequest$ImageViewImageRequest);
        AppMethodBeat.o(61221);
    }

    public final void loadImage(OnImageLoadedListener onImageLoadedListener, Uri uri) {
        AppMethodBeat.i(61222);
        loadImage(new ListenerImageRequest(onImageLoadedListener, uri));
        AppMethodBeat.o(61222);
    }

    public final void loadImage(OnImageLoadedListener onImageLoadedListener, Uri uri, int i) {
        AppMethodBeat.i(61223);
        ListenerImageRequest listenerImageRequest = new ListenerImageRequest(onImageLoadedListener, uri);
        listenerImageRequest.setNoDataPlaceholder(i);
        loadImage(listenerImageRequest);
        AppMethodBeat.o(61223);
    }

    public final void loadImage(ImageRequest imageRequest) {
        AppMethodBeat.i(61224);
        Asserts.checkMainThread("ImageManager.loadImage() must be called in the main thread");
        new zzc(this, imageRequest).run();
        AppMethodBeat.o(61224);
    }
}
