package com.tencent.mm.modelsfs;

import android.text.TextUtils;
import com.tencent.matrix.trace.core.AppMethodBeat;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.Map.Entry;

public class SFSContext {
    long mNativePtr;

    public static class Statistics implements Serializable {
        private static final long serialVersionUID = 1;
        public BlockFile[] blockFiles;
        public long blockSizeEmpty;
        public long blockSizeUsed;
        public BlockType[] blockTypes;
        public long overflowActualSize;
        public long totalActualSize;

        public String toString() {
            int i = 0;
            AppMethodBeat.i(93230);
            StringBuilder stringBuilder = new StringBuilder(4096);
            stringBuilder.append("Total:\n\tActualSize: ").append(this.totalActualSize).append(10).append("\tUsedBlockSize: ").append(this.blockSizeUsed).append(10).append("\tEmptyBlockSize: ").append(this.blockSizeEmpty).append(10).append("\tOverflowSize: ").append(this.overflowActualSize).append(10);
            for (BlockType blockType : this.blockTypes) {
                stringBuilder.append("BlockType: ").append(blockType.blockSize).append(10).append("\tUsedCount: ").append(blockType.usedCount).append(10).append("\tEmptyCount: ").append(blockType.emptyCount).append(10).append("\tActualSize: ").append(blockType.actualSize).append(10);
            }
            while (i < this.blockFiles.length) {
                BlockFile blockFile = this.blockFiles[i];
                stringBuilder.append("BlockFile: ").append(i).append(10).append("\tFileSize: ").append(blockFile.fileSize).append(10).append("\tUsedBlockCount: ").append(blockFile.blockCount).append(10).append("\tEmptyBlockCount: ").append(blockFile.emptyCount).append(10).append("\tTimestamp: ").append(blockFile.timestamp).append(10).append("\tDeleted: ").append(blockFile.deleted).append(10);
                i++;
            }
            String stringBuilder2 = stringBuilder.toString();
            AppMethodBeat.o(93230);
            return stringBuilder2;
        }
    }

    static native int nativeClear(long j);

    static native String nativeErrorMessage();

    private static native boolean nativeExists(long j, String str);

    private static native long nativeInit(String str);

    private static native int nativeList(long j, String str, List<FileEntry> list);

    private static native long nativeOpenRead(long j, String str);

    private static native long nativeOpenWrite(long j, String str);

    private static native void nativeRelease(long j);

    private static native void nativeSetIntArrayConf(int i, int[] iArr);

    private static native void nativeSetIntConf(int i, int i2);

    private static native void nativeSetStringConf(int i, String str);

    private static native FileEntry nativeStat(long j, String str);

    static native Statistics nativeStatistics(long j);

    private static native boolean nativeUnlink(long j, String str);

    private SFSContext(Builder builder) {
        AppMethodBeat.i(93231);
        for (Entry entry : builder.mConf.entrySet()) {
            int intValue = ((Integer) entry.getKey()).intValue();
            Object value = entry.getValue();
            if (value instanceof Integer) {
                nativeSetIntConf(intValue, ((Integer) value).intValue());
            } else if (value instanceof String) {
                nativeSetStringConf(intValue, (String) value);
            } else if (value instanceof int[]) {
                nativeSetIntArrayConf(intValue, (int[]) value);
            }
        }
        long nativeInit = nativeInit(builder.mName);
        if (nativeInit == 0) {
            RuntimeException runtimeException = new RuntimeException(nativeErrorMessage());
            AppMethodBeat.o(93231);
            throw runtimeException;
        }
        this.mNativePtr = nativeInit;
        AppMethodBeat.o(93231);
    }

    public final void release() {
        AppMethodBeat.i(93232);
        nativeRelease(this.mNativePtr);
        this.mNativePtr = 0;
        AppMethodBeat.o(93232);
    }

    public final InputStream openRead(String str) {
        AppMethodBeat.i(93233);
        if (this.mNativePtr == 0) {
            IllegalArgumentException illegalArgumentException = new IllegalArgumentException("Reuse already released SFSContext.");
            AppMethodBeat.o(93233);
            throw illegalArgumentException;
        }
        long tj;
        if (f.th(str)) {
            tj = f.tj(str);
            str = f.ti(str);
        } else {
            tj = 0;
        }
        long nativeOpenRead = nativeOpenRead(this.mNativePtr, str);
        if (nativeOpenRead == 0) {
            FileNotFoundException fileNotFoundException = new FileNotFoundException(str + ": " + nativeErrorMessage());
            AppMethodBeat.o(93233);
            throw fileNotFoundException;
        } else if (tj != 0) {
            d dVar = new d(nativeOpenRead, tj);
            AppMethodBeat.o(93233);
            return dVar;
        } else {
            InputStream sFSInputStream = new SFSInputStream(nativeOpenRead);
            AppMethodBeat.o(93233);
            return sFSInputStream;
        }
    }

    public final OutputStream pH(String str) {
        AppMethodBeat.i(93234);
        if (this.mNativePtr == 0) {
            IllegalArgumentException illegalArgumentException = new IllegalArgumentException("Reuse already released SFSContext.");
            AppMethodBeat.o(93234);
            throw illegalArgumentException;
        }
        String str2 = "";
        if (f.th(str)) {
            str2 = f.tk(str);
            str = f.ti(str);
        }
        OutputStream aR = aR(str, str2);
        AppMethodBeat.o(93234);
        return aR;
    }

    public final OutputStream aR(String str, String str2) {
        AppMethodBeat.i(93235);
        if (this.mNativePtr == 0) {
            IllegalArgumentException illegalArgumentException = new IllegalArgumentException("Reuse already released SFSContext.");
            AppMethodBeat.o(93235);
            throw illegalArgumentException;
        }
        long nativeOpenWrite = nativeOpenWrite(this.mNativePtr, str);
        if (nativeOpenWrite == 0) {
            IOException iOException = new IOException(str + ": " + nativeErrorMessage());
            AppMethodBeat.o(93235);
            throw iOException;
        } else if (TextUtils.isEmpty(str2)) {
            OutputStream sFSOutputStream = new SFSOutputStream(nativeOpenWrite);
            AppMethodBeat.o(93235);
            return sFSOutputStream;
        } else {
            e eVar = new e(nativeOpenWrite, str2);
            AppMethodBeat.o(93235);
            return eVar;
        }
    }

    public final List<FileEntry> tl(String str) {
        AppMethodBeat.i(93236);
        if (this.mNativePtr == 0) {
            IllegalArgumentException illegalArgumentException = new IllegalArgumentException("Reuse already released SFSContext.");
            AppMethodBeat.o(93236);
            throw illegalArgumentException;
        }
        ArrayList arrayList = new ArrayList();
        if (nativeList(this.mNativePtr, str, arrayList) != 0) {
            IOException iOException = new IOException(nativeErrorMessage());
            AppMethodBeat.o(93236);
            throw iOException;
        }
        AppMethodBeat.o(93236);
        return arrayList;
    }

    public final boolean exists(String str) {
        AppMethodBeat.i(93237);
        if (this.mNativePtr == 0) {
            IllegalArgumentException illegalArgumentException = new IllegalArgumentException("Reuse already released SFSContext.");
            AppMethodBeat.o(93237);
            throw illegalArgumentException;
        }
        if (f.th(str)) {
            f.tj(str);
            str = f.ti(str);
        }
        boolean nativeExists = nativeExists(this.mNativePtr, str);
        AppMethodBeat.o(93237);
        return nativeExists;
    }

    public final FileEntry tm(String str) {
        AppMethodBeat.i(93238);
        if (this.mNativePtr == 0) {
            IllegalArgumentException illegalArgumentException = new IllegalArgumentException("Reuse already released SFSContext.");
            AppMethodBeat.o(93238);
            throw illegalArgumentException;
        }
        if (f.th(str)) {
            f.tj(str);
            str = f.ti(str);
        }
        FileEntry nativeStat = nativeStat(this.mNativePtr, str);
        AppMethodBeat.o(93238);
        return nativeStat;
    }

    public final boolean pI(String str) {
        AppMethodBeat.i(93239);
        if (this.mNativePtr == 0) {
            IllegalArgumentException illegalArgumentException = new IllegalArgumentException("Reuse already released SFSContext.");
            AppMethodBeat.o(93239);
            throw illegalArgumentException;
        }
        if (f.th(str)) {
            f.tj(str);
            str = f.ti(str);
        }
        boolean nativeUnlink = nativeUnlink(this.mNativePtr, str);
        AppMethodBeat.o(93239);
        return nativeUnlink;
    }

    /* Access modifiers changed, original: protected */
    public void finalize() {
        AppMethodBeat.i(93240);
        if (this.mNativePtr != 0) {
            release();
        }
        super.finalize();
        AppMethodBeat.o(93240);
    }
}
