package com.tencent.mm.opensdk.modelmsg;

import android.graphics.Bitmap;
import android.graphics.Bitmap.CompressFormat;
import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.mm.opensdk.utils.Log;
import com.tencent.mm.opensdk.utils.d;
import java.io.ByteArrayOutputStream;

public final class WXMediaMessage {
    public static final String ACTION_WXAPPMESSAGE = "com.tencent.mm.sdk.openapi.Intent.ACTION_WXAPPMESSAGE";
    public static final int DESCRIPTION_LENGTH_LIMIT = 1024;
    public static final int MEDIA_TAG_NAME_LENGTH_LIMIT = 64;
    public static final int MESSAGE_ACTION_LENGTH_LIMIT = 2048;
    public static final int MESSAGE_EXT_LENGTH_LIMIT = 2048;
    public static final int MINI_PROGRAM__THUMB_LENGHT = 131072;
    private static final String TAG = "MicroMsg.SDK.WXMediaMessage";
    public static final int THUMB_LENGTH_LIMIT = 65536;
    public static final int TITLE_LENGTH_LIMIT = 512;
    public String description;
    public IMediaObject mediaObject;
    public String mediaTagName;
    public String messageAction;
    public String messageExt;
    public int sdkVer;
    public byte[] thumbData;
    public String title;

    public WXMediaMessage() {
        this(null);
    }

    public WXMediaMessage(IMediaObject iMediaObject) {
        this.mediaObject = iMediaObject;
    }

    /* Access modifiers changed, original: final */
    public final boolean checkArgs() {
        AppMethodBeat.i(128293);
        if (getType() == 8 && (this.thumbData == null || this.thumbData.length == 0)) {
            Log.e(TAG, "checkArgs fail, thumbData should not be null when send emoji");
            AppMethodBeat.o(128293);
            return false;
        } else if (d.a(getType()) && (this.thumbData == null || this.thumbData.length > MINI_PROGRAM__THUMB_LENGHT)) {
            Log.e(TAG, "checkArgs fail, thumbData should not be null or exceed 128kb");
            AppMethodBeat.o(128293);
            return false;
        } else if (!d.a(getType()) && this.thumbData != null && this.thumbData.length > 65536) {
            Log.e(TAG, "checkArgs fail, thumbData is invalid");
            AppMethodBeat.o(128293);
            return false;
        } else if (this.title != null && this.title.length() > TITLE_LENGTH_LIMIT) {
            Log.e(TAG, "checkArgs fail, title is invalid");
            AppMethodBeat.o(128293);
            return false;
        } else if (this.description != null && this.description.length() > DESCRIPTION_LENGTH_LIMIT) {
            Log.e(TAG, "checkArgs fail, description is invalid");
            AppMethodBeat.o(128293);
            return false;
        } else if (this.mediaObject == null) {
            Log.e(TAG, "checkArgs fail, mediaObject is null");
            AppMethodBeat.o(128293);
            return false;
        } else if (this.mediaTagName != null && this.mediaTagName.length() > 64) {
            Log.e(TAG, "checkArgs fail, mediaTagName is too long");
            AppMethodBeat.o(128293);
            return false;
        } else if (this.messageAction != null && this.messageAction.length() > 2048) {
            Log.e(TAG, "checkArgs fail, messageAction is too long");
            AppMethodBeat.o(128293);
            return false;
        } else if (this.messageExt == null || this.messageExt.length() <= 2048) {
            boolean checkArgs = this.mediaObject.checkArgs();
            AppMethodBeat.o(128293);
            return checkArgs;
        } else {
            Log.e(TAG, "checkArgs fail, messageExt is too long");
            AppMethodBeat.o(128293);
            return false;
        }
    }

    public final int getType() {
        AppMethodBeat.i(128291);
        if (this.mediaObject == null) {
            AppMethodBeat.o(128291);
            return 0;
        }
        int type = this.mediaObject.type();
        AppMethodBeat.o(128291);
        return type;
    }

    public final void setThumbImage(Bitmap bitmap) {
        AppMethodBeat.i(128292);
        try {
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            bitmap.compress(CompressFormat.JPEG, 85, byteArrayOutputStream);
            this.thumbData = byteArrayOutputStream.toByteArray();
            byteArrayOutputStream.close();
            AppMethodBeat.o(128292);
        } catch (Exception e) {
            Log.e(TAG, "setThumbImage exception:" + e.getMessage());
            AppMethodBeat.o(128292);
        }
    }
}
