package com.tencent.smtt.export.external;

import android.app.Service;
import android.content.Context;
import android.os.Build.VERSION;
import com.tencent.matrix.trace.core.AppMethodBeat;
import dalvik.system.DexClassLoader;
import java.io.File;
import java.io.InputStream;
import java.net.URL;
import java.util.Enumeration;
import java.util.Timer;

public class DexClassLoaderProvider extends DexClassLoader {
    private static final String IS_FIRST_LOAD_DEX_FLAG_FILE = "is_first_load_dex_flag_file";
    private static final String LAST_DEX_NAME = "tbs_jars_fusion_dex.jar";
    private static final long LOAD_DEX_DELAY = 3000;
    private static final String LOGTAG = "dexloader";
    protected static DexClassLoader mClassLoaderOriginal = null;
    private static Context mContext = null;
    private static boolean mForceLoadDexFlag = false;
    private static DexClassLoaderProvider mInstance = null;
    private static String mRealDexPath = null;
    protected static Service mService = null;
    private SpeedyDexClassLoader mClassLoader = null;

    private DexClassLoaderProvider(String str, String str2, String str3, ClassLoader classLoader, boolean z) {
        super(str, str2, str3, classLoader);
        AppMethodBeat.i(63730);
        if (z) {
            new StringBuilder("SpeedyDexClassLoader: ").append(mRealDexPath);
            this.mClassLoader = new SpeedyDexClassLoader(mRealDexPath, null, str3, classLoader);
            AppMethodBeat.o(63730);
            return;
        }
        new StringBuilder("DexClassLoader: ").append(mRealDexPath);
        this.mClassLoader = null;
        AppMethodBeat.o(63730);
    }

    public static DexClassLoader createDexClassLoader(String str, String str2, String str3, ClassLoader classLoader, Context context) {
        AppMethodBeat.i(63731);
        mContext = context.getApplicationContext();
        mRealDexPath = str;
        int lastIndexOf = str.lastIndexOf("/");
        String str4 = str.substring(0, lastIndexOf + 1) + "fake_dex.jar";
        String substring = str.substring(lastIndexOf + 1);
        if (supportSpeedyClassLoader() && is_first_load_tbs_dex(str2, substring)) {
            set_first_load_tbs_dex(str2, substring);
            mInstance = new DexClassLoaderProvider(str4, str2, str3, classLoader, true);
            doAsyncDexLoad(substring, str, str2, str3, classLoader);
        } else {
            mInstance = new DexClassLoaderProvider(str, str2, str3, classLoader, false);
        }
        DexClassLoaderProvider dexClassLoaderProvider = mInstance;
        AppMethodBeat.o(63731);
        return dexClassLoaderProvider;
    }

    private static void doAsyncDexLoad(String str, String str2, String str3, String str4, ClassLoader classLoader) {
        AppMethodBeat.i(63732);
        if (shouldUseDexLoaderService()) {
            new Timer().schedule(new 1(str, str2, str3, str4), LOAD_DEX_DELAY);
            AppMethodBeat.o(63732);
            return;
        }
        new Timer().schedule(new 2(str2, str3, str4, classLoader, str), LOAD_DEX_DELAY);
        AppMethodBeat.o(63732);
    }

    private static boolean is_first_load_tbs_dex(String str, String str2) {
        AppMethodBeat.i(63733);
        if (mForceLoadDexFlag) {
            AppMethodBeat.o(63733);
            return true;
        } else if (new File(str, str2 + "_is_first_load_dex_flag_file").exists()) {
            AppMethodBeat.o(63733);
            return false;
        } else {
            AppMethodBeat.o(63733);
            return true;
        }
    }

    static void setForceLoadDexFlag(boolean z, Service service) {
        mForceLoadDexFlag = z;
        mService = service;
    }

    private static void set_first_load_tbs_dex(String str, String str2) {
        AppMethodBeat.i(63734);
        File file = new File(str, str2 + "_is_first_load_dex_flag_file");
        if (!file.exists()) {
            try {
                file.createNewFile();
                AppMethodBeat.o(63734);
                return;
            } catch (Throwable th) {
            }
        }
        AppMethodBeat.o(63734);
    }

    private static boolean shouldUseDexLoaderService() {
        return !mForceLoadDexFlag && DexLoader.mCanUseDexLoaderProviderService;
    }

    private static boolean supportSpeedyClassLoader() {
        return VERSION.SDK_INT != 21 || DexLoader.mCanUseDexLoaderProviderService;
    }

    private boolean useSelfClassloader() {
        return this.mClassLoader == null;
    }

    public void clearAssertionStatus() {
        AppMethodBeat.i(63741);
        if (useSelfClassloader()) {
            super.clearAssertionStatus();
            AppMethodBeat.o(63741);
            return;
        }
        this.mClassLoader.clearAssertionStatus();
        AppMethodBeat.o(63741);
    }

    /* Access modifiers changed, original: protected */
    public Package definePackage(String str, String str2, String str3, String str4, String str5, String str6, String str7, URL url) {
        AppMethodBeat.i(63742);
        Package definePackage;
        if (useSelfClassloader()) {
            definePackage = super.definePackage(str, str2, str3, str4, str5, str6, str7, url);
            AppMethodBeat.o(63742);
            return definePackage;
        }
        definePackage = this.mClassLoader.definePackage(str, str2, str3, str4, str5, str6, str7, url);
        AppMethodBeat.o(63742);
        return definePackage;
    }

    /* Access modifiers changed, original: protected */
    public Class<?> findClass(String str) {
        AppMethodBeat.i(63735);
        Class findClass;
        if (useSelfClassloader()) {
            findClass = super.findClass(str);
            AppMethodBeat.o(63735);
            return findClass;
        }
        findClass = this.mClassLoader.findClass(str);
        AppMethodBeat.o(63735);
        return findClass;
    }

    public String findLibrary(String str) {
        AppMethodBeat.i(63736);
        String findLibrary;
        if (useSelfClassloader()) {
            findLibrary = super.findLibrary(str);
            AppMethodBeat.o(63736);
            return findLibrary;
        }
        findLibrary = this.mClassLoader.findLibrary(str);
        AppMethodBeat.o(63736);
        return findLibrary;
    }

    /* Access modifiers changed, original: protected */
    public URL findResource(String str) {
        AppMethodBeat.i(63737);
        URL findResource;
        if (useSelfClassloader()) {
            findResource = super.findResource(str);
            AppMethodBeat.o(63737);
            return findResource;
        }
        findResource = this.mClassLoader.findResource(str);
        AppMethodBeat.o(63737);
        return findResource;
    }

    /* Access modifiers changed, original: protected */
    public Enumeration<URL> findResources(String str) {
        AppMethodBeat.i(63738);
        Enumeration findResources;
        if (useSelfClassloader()) {
            findResources = super.findResources(str);
            AppMethodBeat.o(63738);
            return findResources;
        }
        findResources = this.mClassLoader.findResources(str);
        AppMethodBeat.o(63738);
        return findResources;
    }

    /* Access modifiers changed, original: protected|declared_synchronized */
    public synchronized Package getPackage(String str) {
        Package packageR;
        AppMethodBeat.i(63739);
        if (useSelfClassloader()) {
            packageR = super.getPackage(str);
            AppMethodBeat.o(63739);
        } else {
            packageR = this.mClassLoader.getPackage(str);
            AppMethodBeat.o(63739);
        }
        return packageR;
    }

    /* Access modifiers changed, original: protected */
    public Package[] getPackages() {
        AppMethodBeat.i(63743);
        Package[] packages;
        if (useSelfClassloader()) {
            packages = super.getPackages();
            AppMethodBeat.o(63743);
            return packages;
        }
        packages = this.mClassLoader.getPackages();
        AppMethodBeat.o(63743);
        return packages;
    }

    public URL getResource(String str) {
        AppMethodBeat.i(63744);
        URL resource;
        if (useSelfClassloader()) {
            resource = super.getResource(str);
            AppMethodBeat.o(63744);
            return resource;
        }
        resource = this.mClassLoader.getResource(str);
        AppMethodBeat.o(63744);
        return resource;
    }

    public InputStream getResourceAsStream(String str) {
        AppMethodBeat.i(63745);
        InputStream resourceAsStream;
        if (useSelfClassloader()) {
            resourceAsStream = getResourceAsStream(str);
            AppMethodBeat.o(63745);
            return resourceAsStream;
        }
        resourceAsStream = this.mClassLoader.getResourceAsStream(str);
        AppMethodBeat.o(63745);
        return resourceAsStream;
    }

    public Enumeration<URL> getResources(String str) {
        AppMethodBeat.i(63746);
        Enumeration resources;
        if (useSelfClassloader()) {
            resources = super.getResources(str);
            AppMethodBeat.o(63746);
            return resources;
        }
        resources = this.mClassLoader.getResources(str);
        AppMethodBeat.o(63746);
        return resources;
    }

    public Class<?> loadClass(String str) {
        AppMethodBeat.i(63748);
        Class loadClass;
        if (useSelfClassloader()) {
            loadClass = super.loadClass(str);
            AppMethodBeat.o(63748);
            return loadClass;
        }
        loadClass = this.mClassLoader.loadClass(str);
        AppMethodBeat.o(63748);
        return loadClass;
    }

    /* Access modifiers changed, original: protected */
    public Class<?> loadClass(String str, boolean z) {
        AppMethodBeat.i(63747);
        Class loadClass;
        if (useSelfClassloader()) {
            loadClass = super.loadClass(str, z);
            AppMethodBeat.o(63747);
            return loadClass;
        }
        loadClass = this.mClassLoader.loadClass(str, z);
        AppMethodBeat.o(63747);
        return loadClass;
    }

    public void setClassAssertionStatus(String str, boolean z) {
        AppMethodBeat.i(63749);
        if (useSelfClassloader()) {
            super.setClassAssertionStatus(str, z);
            AppMethodBeat.o(63749);
            return;
        }
        this.mClassLoader.setClassAssertionStatus(str, z);
        AppMethodBeat.o(63749);
    }

    public void setDefaultAssertionStatus(boolean z) {
        AppMethodBeat.i(63750);
        if (useSelfClassloader()) {
            super.setDefaultAssertionStatus(z);
            AppMethodBeat.o(63750);
            return;
        }
        this.mClassLoader.setDefaultAssertionStatus(z);
        AppMethodBeat.o(63750);
    }

    public void setPackageAssertionStatus(String str, boolean z) {
        AppMethodBeat.i(63751);
        if (useSelfClassloader()) {
            super.setPackageAssertionStatus(str, z);
            AppMethodBeat.o(63751);
            return;
        }
        this.mClassLoader.setPackageAssertionStatus(str, z);
        AppMethodBeat.o(63751);
    }

    public String toString() {
        AppMethodBeat.i(63740);
        String dexClassLoader;
        if (useSelfClassloader()) {
            dexClassLoader = super.toString();
            AppMethodBeat.o(63740);
            return dexClassLoader;
        }
        dexClassLoader = this.mClassLoader.toString();
        AppMethodBeat.o(63740);
        return dexClassLoader;
    }
}
