package com.tencent.tmassistantsdk.protocol;

import com.qq.taf.jce.JceInputStream;
import com.qq.taf.jce.JceOutputStream;
import com.qq.taf.jce.JceStruct;
import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.mm.sdk.platformtools.ab;
import com.tencent.tmassistantsdk.protocol.jce.ReportLogRequest;
import com.tencent.tmassistantsdk.protocol.jce.ReqHead;
import com.tencent.tmassistantsdk.protocol.jce.Request;
import com.tencent.tmassistantsdk.protocol.jce.Response;
import com.tencent.tmassistantsdk.protocol.jce.Terminal;
import com.tencent.tmassistantsdk.util.Cryptor;
import com.tencent.tmassistantsdk.util.GlobalUtil;
import java.util.List;

public class ProtocolPackage {
    static final String CRYPT_KEY = "ji*9^&43U0X-~./(";
    static final byte FLAG_CRYPT = (byte) 2;
    static final byte FLAG_ZIP = (byte) 1;
    public static final String ServerEncoding = "utf-8";
    private static final String TAG = "ProtocolPackage";
    static final int ZIP_TRIGGER = 256;

    public static JceStruct buildReportRequest(byte b, List<byte[]> list, String str, int i, String str2) {
        AppMethodBeat.i(76014);
        ReportLogRequest reportLogRequest = new ReportLogRequest();
        reportLogRequest.logType = b;
        reportLogRequest.logData = formatLogData(list);
        reportLogRequest.hostAppPackageName = str;
        reportLogRequest.hostAppVersion = i;
        reportLogRequest.hostUserId = str2;
        AppMethodBeat.o(76014);
        return reportLogRequest;
    }

    public static ReqHead getReqHead(JceStruct jceStruct) {
        AppMethodBeat.i(76015);
        if (jceStruct == null) {
            AppMethodBeat.o(76015);
            return null;
        }
        ReqHead reqHead = new ReqHead();
        reqHead.requestId = GlobalUtil.getMemUUID();
        String simpleName = jceStruct.getClass().getSimpleName();
        reqHead.cmdId = GlobalUtil.getInstance().getJceCmdIdByClassName(simpleName.substring(0, simpleName.length() - 7));
        reqHead.qua = GlobalUtil.getInstance().mQUA;
        reqHead.phoneGuid = GlobalUtil.getInstance().getPhoneGuid();
        reqHead.terminal = new Terminal();
        reqHead.assistantAPILevel = GlobalUtil.getInstance().getQQDownloaderAPILevel();
        reqHead.assistantVersionCode = GlobalUtil.getInstance().getQQDownloaderVersionCode();
        AppMethodBeat.o(76015);
        return reqHead;
    }

    public static Request buildRequest(JceStruct jceStruct) {
        AppMethodBeat.i(76016);
        if (jceStruct == null) {
            AppMethodBeat.o(76016);
            return null;
        }
        Request request = new Request();
        request.head = getReqHead(jceStruct);
        request.body = jceStructToUTF8Byte(jceStruct);
        AppMethodBeat.o(76016);
        return request;
    }

    public static byte[] buildPostData(Request request) {
        AppMethodBeat.i(76017);
        if (request == null) {
            AppMethodBeat.o(76017);
            return null;
        }
        request.head.encryptWithPack = (byte) 0;
        if (request.body.length > 256) {
            request.body = ZipUtils.zip(request.body);
            request.head.encryptWithPack = (byte) (request.head.encryptWithPack | 1);
        }
        request.body = encrypt(request.body, CRYPT_KEY.getBytes());
        request.head.encryptWithPack = (byte) (request.head.encryptWithPack | 2);
        byte[] jceStructToUTF8Byte = jceStructToUTF8Byte(request);
        AppMethodBeat.o(76017);
        return jceStructToUTF8Byte;
    }

    public static Response unpackPackage(byte[] bArr) {
        AppMethodBeat.i(76018);
        if (bArr == null || bArr.length < 4) {
            AppMethodBeat.o(76018);
            return null;
        }
        Response response = new Response();
        try {
            JceInputStream jceInputStream = new JceInputStream(bArr);
            jceInputStream.setServerEncoding(ServerEncoding);
            response.readFrom(jceInputStream);
            if (response.head.ret == 0) {
                if ((response.head.encryptWithPack & 2) == 2) {
                    response.body = decrypt(response.body, CRYPT_KEY.getBytes());
                }
                if ((response.head.encryptWithPack & 1) == 1) {
                    response.body = ZipUtils.unzip(response.body);
                }
                GlobalUtil.getInstance().setPhoneGuid(response.head.phoneGuid);
            }
            AppMethodBeat.o(76018);
            return response;
        } catch (Exception e) {
            ab.printErrStackTrace(TAG, e, "", new Object[0]);
            AppMethodBeat.o(76018);
            return null;
        }
    }

    public static JceStruct unpageageJceResponse(JceStruct jceStruct, byte[] bArr) {
        AppMethodBeat.i(76019);
        if (!(jceStruct == null || bArr == null)) {
            JceStruct createFromRequest = createFromRequest(jceStruct);
            if (createFromRequest != null) {
                try {
                    JceInputStream jceInputStream = new JceInputStream(bArr);
                    jceInputStream.setServerEncoding(ServerEncoding);
                    createFromRequest.readFrom(jceInputStream);
                    AppMethodBeat.o(76019);
                    return createFromRequest;
                } catch (Exception e) {
                    ab.printErrStackTrace(TAG, e, "", new Object[0]);
                    AppMethodBeat.o(76019);
                    return null;
                }
            }
        }
        AppMethodBeat.o(76019);
        return null;
    }

    private static JceStruct createFromRequest(JceStruct jceStruct) {
        AppMethodBeat.i(76020);
        if (jceStruct == null) {
            AppMethodBeat.o(76020);
            return null;
        }
        JceStruct jceStruct2;
        String name = jceStruct.getClass().getName();
        try {
            jceStruct2 = (JceStruct) Class.forName(name.substring(0, name.length() - 7) + "Response").newInstance();
        } catch (ClassNotFoundException e) {
            ab.printErrStackTrace(TAG, e, "", new Object[0]);
            jceStruct2 = null;
        } catch (IllegalAccessException e2) {
            ab.printErrStackTrace(TAG, e2, "", new Object[0]);
            jceStruct2 = null;
        } catch (InstantiationException e3) {
            ab.printErrStackTrace(TAG, e3, "", new Object[0]);
            jceStruct2 = null;
        }
        AppMethodBeat.o(76020);
        return jceStruct2;
    }

    public static byte[] jceStructToUTF8Byte(JceStruct jceStruct) {
        AppMethodBeat.i(76021);
        if (jceStruct == null) {
            AppMethodBeat.o(76021);
            return null;
        }
        JceOutputStream jceOutputStream = new JceOutputStream();
        jceOutputStream.setServerEncoding(ServerEncoding);
        jceStruct.writeTo(jceOutputStream);
        byte[] toByteArray = jceOutputStream.toByteArray();
        AppMethodBeat.o(76021);
        return toByteArray;
    }

    public static JceStruct bytes2JceObj(byte[] bArr, Class<? extends JceStruct> cls) {
        AppMethodBeat.i(76022);
        if (bArr == null) {
            AppMethodBeat.o(76022);
            return null;
        }
        try {
            JceInputStream jceInputStream = new JceInputStream(bArr);
            jceInputStream.setServerEncoding(ServerEncoding);
            JceStruct jceStruct = (JceStruct) cls.newInstance();
            jceStruct.readFrom(jceInputStream);
            AppMethodBeat.o(76022);
            return jceStruct;
        } catch (Exception e) {
            AppMethodBeat.o(76022);
            return null;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:39:0x008d A:{SYNTHETIC, Splitter:B:39:0x008d} */
    /* JADX WARNING: Removed duplicated region for block: B:42:0x0092 A:{SYNTHETIC, Splitter:B:42:0x0092} */
    /* JADX WARNING: Removed duplicated region for block: B:15:0x0039 A:{SYNTHETIC, Splitter:B:15:0x0039} */
    /* JADX WARNING: Removed duplicated region for block: B:18:0x003e A:{SYNTHETIC, Splitter:B:18:0x003e} */
    /* JADX WARNING: Removed duplicated region for block: B:39:0x008d A:{SYNTHETIC, Splitter:B:39:0x008d} */
    /* JADX WARNING: Removed duplicated region for block: B:42:0x0092 A:{SYNTHETIC, Splitter:B:42:0x0092} */
    public static byte[] formatLogData(java.util.List<byte[]> r9) {
        /*
        r1 = 0;
        r8 = 76023; // 0x128f7 float:1.06531E-40 double:3.75604E-319;
        r7 = 0;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r8);
        r3 = new java.io.ByteArrayOutputStream;	 Catch:{ Exception -> 0x00b8, all -> 0x0088 }
        r3.<init>();	 Catch:{ Exception -> 0x00b8, all -> 0x0088 }
        r2 = new java.io.DataOutputStream;	 Catch:{ Exception -> 0x00bd, all -> 0x00b3 }
        r2.<init>(r3);	 Catch:{ Exception -> 0x00bd, all -> 0x00b3 }
        r4 = r9.iterator();	 Catch:{ Exception -> 0x002a }
    L_0x0016:
        r0 = r4.hasNext();	 Catch:{ Exception -> 0x002a }
        if (r0 == 0) goto L_0x0046;
    L_0x001c:
        r0 = r4.next();	 Catch:{ Exception -> 0x002a }
        r0 = (byte[]) r0;	 Catch:{ Exception -> 0x002a }
        r5 = r0.length;	 Catch:{ Exception -> 0x002a }
        r2.writeInt(r5);	 Catch:{ Exception -> 0x002a }
        r2.write(r0);	 Catch:{ Exception -> 0x002a }
        goto L_0x0016;
    L_0x002a:
        r0 = move-exception;
    L_0x002b:
        r4 = "ProtocolPackage";
        r5 = "";
        r6 = 0;
        r6 = new java.lang.Object[r6];	 Catch:{ all -> 0x00b6 }
        com.tencent.mm.sdk.platformtools.ab.printErrStackTrace(r4, r0, r5, r6);	 Catch:{ all -> 0x00b6 }
        if (r3 == 0) goto L_0x003c;
    L_0x0039:
        r3.close();	 Catch:{ IOException -> 0x006e }
    L_0x003c:
        if (r2 == 0) goto L_0x0041;
    L_0x003e:
        r2.close();	 Catch:{ IOException -> 0x007b }
    L_0x0041:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        r0 = r1;
    L_0x0045:
        return r0;
    L_0x0046:
        r0 = r3.toByteArray();	 Catch:{ Exception -> 0x002a }
        r3.close();	 Catch:{ IOException -> 0x0054 }
    L_0x004d:
        r2.close();	 Catch:{ IOException -> 0x0061 }
    L_0x0050:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        goto L_0x0045;
    L_0x0054:
        r1 = move-exception;
        r3 = "ProtocolPackage";
        r4 = "";
        r5 = new java.lang.Object[r7];
        com.tencent.mm.sdk.platformtools.ab.printErrStackTrace(r3, r1, r4, r5);
        goto L_0x004d;
    L_0x0061:
        r1 = move-exception;
        r2 = "ProtocolPackage";
        r3 = "";
        r4 = new java.lang.Object[r7];
        com.tencent.mm.sdk.platformtools.ab.printErrStackTrace(r2, r1, r3, r4);
        goto L_0x0050;
    L_0x006e:
        r0 = move-exception;
        r3 = "ProtocolPackage";
        r4 = "";
        r5 = new java.lang.Object[r7];
        com.tencent.mm.sdk.platformtools.ab.printErrStackTrace(r3, r0, r4, r5);
        goto L_0x003c;
    L_0x007b:
        r0 = move-exception;
        r2 = "ProtocolPackage";
        r3 = "";
        r4 = new java.lang.Object[r7];
        com.tencent.mm.sdk.platformtools.ab.printErrStackTrace(r2, r0, r3, r4);
        goto L_0x0041;
    L_0x0088:
        r0 = move-exception;
        r2 = r1;
        r3 = r1;
    L_0x008b:
        if (r3 == 0) goto L_0x0090;
    L_0x008d:
        r3.close();	 Catch:{ IOException -> 0x0099 }
    L_0x0090:
        if (r2 == 0) goto L_0x0095;
    L_0x0092:
        r2.close();	 Catch:{ IOException -> 0x00a6 }
    L_0x0095:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        throw r0;
    L_0x0099:
        r1 = move-exception;
        r3 = "ProtocolPackage";
        r4 = "";
        r5 = new java.lang.Object[r7];
        com.tencent.mm.sdk.platformtools.ab.printErrStackTrace(r3, r1, r4, r5);
        goto L_0x0090;
    L_0x00a6:
        r1 = move-exception;
        r2 = "ProtocolPackage";
        r3 = "";
        r4 = new java.lang.Object[r7];
        com.tencent.mm.sdk.platformtools.ab.printErrStackTrace(r2, r1, r3, r4);
        goto L_0x0095;
    L_0x00b3:
        r0 = move-exception;
        r2 = r1;
        goto L_0x008b;
    L_0x00b6:
        r0 = move-exception;
        goto L_0x008b;
    L_0x00b8:
        r0 = move-exception;
        r2 = r1;
        r3 = r1;
        goto L_0x002b;
    L_0x00bd:
        r0 = move-exception;
        r2 = r1;
        goto L_0x002b;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.tmassistantsdk.protocol.ProtocolPackage.formatLogData(java.util.List):byte[]");
    }

    public static byte[] encrypt(byte[] bArr, byte[] bArr2) {
        AppMethodBeat.i(76024);
        byte[] encrypt = new Cryptor().encrypt(bArr, bArr2);
        AppMethodBeat.o(76024);
        return encrypt;
    }

    public static byte[] decrypt(byte[] bArr, byte[] bArr2) {
        AppMethodBeat.i(76025);
        byte[] decrypt = new Cryptor().decrypt(bArr, bArr2);
        AppMethodBeat.o(76025);
        return decrypt;
    }
}
