package com.tencent.ttpic.json;

import com.tencent.mars.cdn.CdnLogic;
import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.mm.plugin.appbrand.jsapi.storage.k;
import com.tencent.view.d;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;
import java.io.StringReader;

public class JSONTokener {
    private long character;
    private boolean eof;
    private long index;
    private long line;
    private char previous;
    private Reader reader;
    private boolean usePrevious;

    public JSONTokener(Reader reader) {
        AppMethodBeat.i(50183);
        if (!reader.markSupported()) {
            reader = new BufferedReader(reader);
        }
        this.reader = reader;
        this.eof = false;
        this.usePrevious = false;
        this.previous = 0;
        this.index = 0;
        this.character = 1;
        this.line = 1;
        AppMethodBeat.o(50183);
    }

    public JSONTokener(InputStream inputStream) {
        this(new InputStreamReader(inputStream));
        AppMethodBeat.i(50184);
        AppMethodBeat.o(50184);
    }

    public JSONTokener(String str) {
        this(new StringReader(str));
        AppMethodBeat.i(50185);
        AppMethodBeat.o(50185);
    }

    public void back() {
        AppMethodBeat.i(50186);
        if (this.usePrevious || this.index <= 0) {
            JSONException jSONException = new JSONException("Stepping back two steps is not supported");
            AppMethodBeat.o(50186);
            throw jSONException;
        }
        this.index--;
        this.character--;
        this.usePrevious = true;
        this.eof = false;
        AppMethodBeat.o(50186);
    }

    public static int dehexchar(char c) {
        if (c >= '0' && c <= '9') {
            return c - 48;
        }
        if (c >= 'A' && c <= 'F') {
            return c - 55;
        }
        if (c < 'a' || c > 'f') {
            return -1;
        }
        return c - 87;
    }

    public boolean end() {
        return this.eof && !this.usePrevious;
    }

    public boolean more() {
        AppMethodBeat.i(50187);
        next();
        if (end()) {
            AppMethodBeat.o(50187);
            return false;
        }
        back();
        AppMethodBeat.o(50187);
        return true;
    }

    public char next() {
        long j = 0;
        int i = 0;
        AppMethodBeat.i(50188);
        if (this.usePrevious) {
            this.usePrevious = false;
            i = this.previous;
        } else {
            try {
                int read = this.reader.read();
                if (read <= 0) {
                    this.eof = true;
                } else {
                    i = read;
                }
            } catch (IOException e) {
                JSONException jSONException = new JSONException(e);
                AppMethodBeat.o(50188);
                throw jSONException;
            }
        }
        this.index++;
        if (this.previous == 13) {
            this.line++;
            if (i != 10) {
                j = 1;
            }
            this.character = j;
        } else if (i == 10) {
            this.line = 1 + this.line;
            this.character = 0;
        } else {
            this.character++;
        }
        this.previous = (char) i;
        char c = this.previous;
        AppMethodBeat.o(50188);
        return c;
    }

    public char next(char c) {
        AppMethodBeat.i(50189);
        char next = next();
        if (next != c) {
            JSONException syntaxError = syntaxError("Expected '" + c + "' and instead saw '" + next + "'");
            AppMethodBeat.o(50189);
            throw syntaxError;
        }
        AppMethodBeat.o(50189);
        return next;
    }

    public String next(int i) {
        AppMethodBeat.i(50190);
        String str;
        if (i == 0) {
            str = "";
            AppMethodBeat.o(50190);
            return str;
        }
        char[] cArr = new char[i];
        for (int i2 = 0; i2 < i; i2++) {
            cArr[i2] = next();
            if (end()) {
                JSONException syntaxError = syntaxError("Substring bounds error");
                AppMethodBeat.o(50190);
                throw syntaxError;
            }
        }
        str = new String(cArr);
        AppMethodBeat.o(50190);
        return str;
    }

    public char nextClean() {
        char next;
        AppMethodBeat.i(50191);
        do {
            next = next();
            if (next == 0) {
                break;
            }
        } while (next <= ' ');
        AppMethodBeat.o(50191);
        return next;
    }

    public String nextString(char c) {
        AppMethodBeat.i(50192);
        StringBuffer stringBuffer = new StringBuffer();
        while (true) {
            char next = next();
            JSONException syntaxError;
            switch (next) {
                case 0:
                case 10:
                case d.MIC_BASE_SATURATION /*13*/:
                    syntaxError = syntaxError("Unterminated string");
                    AppMethodBeat.o(50192);
                    throw syntaxError;
                case '\\':
                    next = next();
                    switch (next) {
                        case d.MIC_CPU_NIGHTENHANCE /*34*/:
                        case '\'':
                        case '/':
                        case '\\':
                            stringBuffer.append(next);
                            break;
                        case k.CTRL_INDEX /*98*/:
                            stringBuffer.append(8);
                            break;
                        case CdnLogic.kAppTypeVideo /*102*/:
                            stringBuffer.append(12);
                            break;
                        case d.MIC_GAUSS_DOF /*110*/:
                            stringBuffer.append(10);
                            break;
                        case 'r':
                            stringBuffer.append(13);
                            break;
                        case 't':
                            stringBuffer.append(9);
                            break;
                        case d.MIC_ALPHA_ADJUST_REAL /*117*/:
                            stringBuffer.append((char) Integer.parseInt(next(4), 16));
                            break;
                        default:
                            syntaxError = syntaxError("Illegal escape.");
                            AppMethodBeat.o(50192);
                            throw syntaxError;
                    }
                default:
                    if (next != c) {
                        stringBuffer.append(next);
                        break;
                    }
                    String stringBuffer2 = stringBuffer.toString();
                    AppMethodBeat.o(50192);
                    return stringBuffer2;
            }
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:9:0x001d  */
    public java.lang.String nextTo(char r5) {
        /*
        r4 = this;
        r3 = 50193; // 0xc411 float:7.0335E-41 double:2.47986E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r3);
        r0 = new java.lang.StringBuffer;
        r0.<init>();
    L_0x000b:
        r1 = r4.next();
        if (r1 == r5) goto L_0x001b;
    L_0x0011:
        if (r1 == 0) goto L_0x001b;
    L_0x0013:
        r2 = 10;
        if (r1 == r2) goto L_0x001b;
    L_0x0017:
        r2 = 13;
        if (r1 != r2) goto L_0x002c;
    L_0x001b:
        if (r1 == 0) goto L_0x0020;
    L_0x001d:
        r4.back();
    L_0x0020:
        r0 = r0.toString();
        r0 = r0.trim();
        com.tencent.matrix.trace.core.AppMethodBeat.o(r3);
        return r0;
    L_0x002c:
        r0.append(r1);
        goto L_0x000b;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.ttpic.json.JSONTokener.nextTo(char):java.lang.String");
    }

    /* JADX WARNING: Removed duplicated region for block: B:9:0x0021  */
    public java.lang.String nextTo(java.lang.String r5) {
        /*
        r4 = this;
        r3 = 50194; // 0xc412 float:7.0337E-41 double:2.4799E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r3);
        r0 = new java.lang.StringBuffer;
        r0.<init>();
    L_0x000b:
        r1 = r4.next();
        r2 = r5.indexOf(r1);
        if (r2 >= 0) goto L_0x001f;
    L_0x0015:
        if (r1 == 0) goto L_0x001f;
    L_0x0017:
        r2 = 10;
        if (r1 == r2) goto L_0x001f;
    L_0x001b:
        r2 = 13;
        if (r1 != r2) goto L_0x0030;
    L_0x001f:
        if (r1 == 0) goto L_0x0024;
    L_0x0021:
        r4.back();
    L_0x0024:
        r0 = r0.toString();
        r0 = r0.trim();
        com.tencent.matrix.trace.core.AppMethodBeat.o(r3);
        return r0;
    L_0x0030:
        r0.append(r1);
        goto L_0x000b;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.ttpic.json.JSONTokener.nextTo(java.lang.String):java.lang.String");
    }

    public Object nextValue() {
        AppMethodBeat.i(50195);
        int nextClean = nextClean();
        String nextString;
        Object jSONArray;
        switch (nextClean) {
            case d.MIC_CPU_NIGHTENHANCE /*34*/:
            case 39:
                nextString = nextString(nextClean);
                AppMethodBeat.o(50195);
                return nextString;
            case 91:
                back();
                jSONArray = new JSONArray(this);
                AppMethodBeat.o(50195);
                return jSONArray;
            case d.MIC_RESClIP /*123*/:
                back();
                jSONArray = new JSONObject(this);
                AppMethodBeat.o(50195);
                return jSONArray;
            default:
                StringBuffer stringBuffer = new StringBuffer();
                while (nextClean >= 32 && ",:]}/\\\"[{;=#".indexOf(nextClean) < 0) {
                    stringBuffer.append(nextClean);
                    nextClean = next();
                }
                back();
                nextString = stringBuffer.toString().trim();
                if ("".equals(nextString)) {
                    JSONException syntaxError = syntaxError("Missing value");
                    AppMethodBeat.o(50195);
                    throw syntaxError;
                }
                jSONArray = JSONObject.stringToValue(nextString);
                AppMethodBeat.o(50195);
                return jSONArray;
        }
    }

    public char skipTo(char c) {
        AppMethodBeat.i(50196);
        try {
            char next;
            long j = this.index;
            long j2 = this.character;
            long j3 = this.line;
            this.reader.mark(1000000);
            do {
                next = next();
                if (next == 0) {
                    this.reader.reset();
                    this.index = j;
                    this.character = j2;
                    this.line = j3;
                    AppMethodBeat.o(50196);
                    break;
                }
            } while (next != c);
            back();
            AppMethodBeat.o(50196);
            return next;
        } catch (IOException e) {
            JSONException jSONException = new JSONException(e);
            AppMethodBeat.o(50196);
            throw jSONException;
        }
    }

    public JSONException syntaxError(String str) {
        AppMethodBeat.i(50197);
        JSONException jSONException = new JSONException(str + toString());
        AppMethodBeat.o(50197);
        return jSONException;
    }

    public String toString() {
        AppMethodBeat.i(50198);
        String str = " at " + this.index + " [character " + this.character + " line " + this.line + "]";
        AppMethodBeat.o(50198);
        return str;
    }
}
