package com.tencent.ttpic.util.youtu.bodydetector;

import android.graphics.PointF;
import android.os.Build.VERSION;
import android.os.Handler;
import android.os.HandlerThread;
import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.ttpic.baseutils.LogUtils;
import com.tencent.ttpic.manager.FeatureManager;
import com.tencent.ttpic.thread.FaceGestureDetGLThread.OnBodyDetListener;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.List;

public class BodyDetector {
    private static int[] leftIndex = new int[]{13, 14, 15, 16, 17};
    private static BodyDetector mInstance;
    private static int[] rightIndex = new int[]{41, 42, 43, 44, 45};
    private final int DETECT_INTERVAL = 10;
    private final int KEY_POINT_NUM_17 = 17;
    private final int KEY_POINT_NUM_59 = 59;
    boolean bodyDetected = false;
    private final Object dataLock = new Object();
    private Handler detectHandler;
    private int detectIndex = 0;
    private float[] detector_confidence = new float[59];
    private float[] detector_xmax = new float[59];
    private float[] detector_xmin = new float[59];
    private float[] detector_ymax = new float[59];
    private float[] detector_ymin = new float[59];
    private float[] fscore = new float[59];
    private float[] fscore17 = new float[17];
    private volatile boolean inited = false;
    private boolean mHasRect = false;
    private float mPConfidence;
    private float mPxmax;
    private float mPxmin;
    private float mPymax;
    private float mPymin;
    private float[] ptX = new float[59];
    private float[] ptX17 = new float[17];
    private float[] ptY = new float[59];
    private float[] ptY17 = new float[17];

    public native boolean nativeBodyDetect(byte[] bArr, int i, int i2, int i3, float[] fArr, float[] fArr2, float[] fArr3, float[] fArr4, float[] fArr5, int[] iArr);

    public native boolean nativeBodyKeypoint(byte[] bArr, int i, int i2, int i3, int i4, float f, float f2, float f3, float f4, float f5, float[] fArr, float[] fArr2, float[] fArr3);

    public native boolean nativeDestroy();

    public native boolean nativeDetectBody(byte[] bArr, int i, int i2, float[] fArr, float[] fArr2, float[] fArr3, float[] fArr4, float[] fArr5, float[] fArr6, int i3, int i4, int i5);

    public native boolean nativeInit(byte[] bArr, byte[] bArr2, byte[] bArr3, byte[] bArr4, byte[] bArr5, byte[] bArr6, byte[] bArr7, byte[] bArr8);

    public BodyDetector() {
        AppMethodBeat.i(84420);
        AppMethodBeat.o(84420);
    }

    static /* synthetic */ void access$1800(BodyDetector bodyDetector, float[] fArr, float[] fArr2) {
        AppMethodBeat.i(84426);
        bodyDetector.updatePreviousRect(fArr, fArr2);
        AppMethodBeat.o(84426);
    }

    static {
        AppMethodBeat.i(84427);
        if (FeatureManager.isBodyDetectionReady()) {
            try {
                if (VERSION.SDK_INT <= 17) {
                    System.load("/data/data/com.tencent.xnet/lib/libxnet.so");
                } else {
                    FeatureManager.loadLibrary("xnet");
                }
                FeatureManager.loadLibrary("bodydetector");
                AppMethodBeat.o(84427);
                return;
            } catch (Exception e) {
                LogUtils.e(e);
            }
        }
        AppMethodBeat.o(84427);
    }

    public static synchronized BodyDetector getInstance() {
        BodyDetector bodyDetector;
        synchronized (BodyDetector.class) {
            AppMethodBeat.i(84421);
            if (mInstance == null) {
                mInstance = new BodyDetector();
            }
            bodyDetector = mInstance;
            AppMethodBeat.o(84421);
        }
        return bodyDetector;
    }

    public void init() {
        Throwable e;
        byte[] bArr;
        byte[] bArr2;
        byte[] bArr3;
        byte[] bArr4;
        byte[] bArr5;
        byte[] bArr6;
        HandlerThread handlerThread;
        AppMethodBeat.i(84422);
        if (!FeatureManager.isBodyDetectionReady() || this.inited) {
            AppMethodBeat.o(84422);
            return;
        }
        InputStream modelStream;
        byte[] bArr7;
        try {
            modelStream = FeatureManager.getModelStream("xnet_keypoint1.param.bin.xd");
            bArr7 = new byte[modelStream.available()];
            try {
                modelStream.read(bArr7);
                modelStream.close();
            } catch (Exception e2) {
                e = e2;
                LogUtils.e(e);
                modelStream = FeatureManager.getModelStream("xnet_keypoint1.bin.xd");
                bArr = new byte[modelStream.available()];
                modelStream.read(bArr);
                modelStream.close();
                modelStream = FeatureManager.getModelStream("xnet_keypoint2.param.bin.xd");
                bArr2 = new byte[modelStream.available()];
                modelStream.read(bArr2);
                modelStream.close();
                modelStream = FeatureManager.getModelStream("xnet_keypoint2.bin.xd");
                bArr3 = new byte[modelStream.available()];
                modelStream.read(bArr3);
                modelStream.close();
                modelStream = FeatureManager.getModelStream("label.txt");
                bArr4 = new byte[modelStream.available()];
                try {
                    modelStream.read(bArr4);
                    modelStream.close();
                    bArr5 = bArr4;
                } catch (Exception e3) {
                    e = e3;
                    LogUtils.e(e);
                    bArr5 = bArr4;
                    modelStream = FeatureManager.getModelStream("threshold.txt");
                    bArr6 = new byte[modelStream.available()];
                    modelStream.read(bArr6);
                    modelStream.close();
                    handlerThread = new HandlerThread("BodyDetectThread");
                    handlerThread.start();
                    this.detectHandler = new Handler(handlerThread.getLooper());
                    this.inited = nativeInit(bArr7, bArr, bArr2, bArr3, null, null, bArr5, bArr6);
                    AppMethodBeat.o(84422);
                }
                modelStream = FeatureManager.getModelStream("threshold.txt");
                bArr6 = new byte[modelStream.available()];
                modelStream.read(bArr6);
                modelStream.close();
                handlerThread = new HandlerThread("BodyDetectThread");
                handlerThread.start();
                this.detectHandler = new Handler(handlerThread.getLooper());
                this.inited = nativeInit(bArr7, bArr, bArr2, bArr3, null, null, bArr5, bArr6);
                AppMethodBeat.o(84422);
            }
        } catch (Exception e4) {
            e = e4;
            bArr7 = null;
            LogUtils.e(e);
            modelStream = FeatureManager.getModelStream("xnet_keypoint1.bin.xd");
            bArr = new byte[modelStream.available()];
            modelStream.read(bArr);
            modelStream.close();
            modelStream = FeatureManager.getModelStream("xnet_keypoint2.param.bin.xd");
            bArr2 = new byte[modelStream.available()];
            modelStream.read(bArr2);
            modelStream.close();
            modelStream = FeatureManager.getModelStream("xnet_keypoint2.bin.xd");
            bArr3 = new byte[modelStream.available()];
            modelStream.read(bArr3);
            modelStream.close();
            modelStream = FeatureManager.getModelStream("label.txt");
            bArr4 = new byte[modelStream.available()];
            modelStream.read(bArr4);
            modelStream.close();
            bArr5 = bArr4;
            modelStream = FeatureManager.getModelStream("threshold.txt");
            bArr6 = new byte[modelStream.available()];
            modelStream.read(bArr6);
            modelStream.close();
            handlerThread = new HandlerThread("BodyDetectThread");
            handlerThread.start();
            this.detectHandler = new Handler(handlerThread.getLooper());
            this.inited = nativeInit(bArr7, bArr, bArr2, bArr3, null, null, bArr5, bArr6);
            AppMethodBeat.o(84422);
        }
        try {
            modelStream = FeatureManager.getModelStream("xnet_keypoint1.bin.xd");
            bArr = new byte[modelStream.available()];
            try {
                modelStream.read(bArr);
                modelStream.close();
            } catch (Exception e5) {
                e = e5;
                LogUtils.e(e);
                modelStream = FeatureManager.getModelStream("xnet_keypoint2.param.bin.xd");
                bArr2 = new byte[modelStream.available()];
                modelStream.read(bArr2);
                modelStream.close();
                modelStream = FeatureManager.getModelStream("xnet_keypoint2.bin.xd");
                bArr3 = new byte[modelStream.available()];
                modelStream.read(bArr3);
                modelStream.close();
                modelStream = FeatureManager.getModelStream("label.txt");
                bArr4 = new byte[modelStream.available()];
                modelStream.read(bArr4);
                modelStream.close();
                bArr5 = bArr4;
                modelStream = FeatureManager.getModelStream("threshold.txt");
                bArr6 = new byte[modelStream.available()];
                modelStream.read(bArr6);
                modelStream.close();
                handlerThread = new HandlerThread("BodyDetectThread");
                handlerThread.start();
                this.detectHandler = new Handler(handlerThread.getLooper());
                this.inited = nativeInit(bArr7, bArr, bArr2, bArr3, null, null, bArr5, bArr6);
                AppMethodBeat.o(84422);
            }
        } catch (Exception e6) {
            e = e6;
            bArr = null;
            LogUtils.e(e);
            modelStream = FeatureManager.getModelStream("xnet_keypoint2.param.bin.xd");
            bArr2 = new byte[modelStream.available()];
            modelStream.read(bArr2);
            modelStream.close();
            modelStream = FeatureManager.getModelStream("xnet_keypoint2.bin.xd");
            bArr3 = new byte[modelStream.available()];
            modelStream.read(bArr3);
            modelStream.close();
            modelStream = FeatureManager.getModelStream("label.txt");
            bArr4 = new byte[modelStream.available()];
            modelStream.read(bArr4);
            modelStream.close();
            bArr5 = bArr4;
            modelStream = FeatureManager.getModelStream("threshold.txt");
            bArr6 = new byte[modelStream.available()];
            modelStream.read(bArr6);
            modelStream.close();
            handlerThread = new HandlerThread("BodyDetectThread");
            handlerThread.start();
            this.detectHandler = new Handler(handlerThread.getLooper());
            this.inited = nativeInit(bArr7, bArr, bArr2, bArr3, null, null, bArr5, bArr6);
            AppMethodBeat.o(84422);
        }
        try {
            modelStream = FeatureManager.getModelStream("xnet_keypoint2.param.bin.xd");
            bArr2 = new byte[modelStream.available()];
            try {
                modelStream.read(bArr2);
                modelStream.close();
            } catch (Exception e7) {
                e = e7;
                LogUtils.e(e);
                modelStream = FeatureManager.getModelStream("xnet_keypoint2.bin.xd");
                bArr3 = new byte[modelStream.available()];
                modelStream.read(bArr3);
                modelStream.close();
                modelStream = FeatureManager.getModelStream("label.txt");
                bArr4 = new byte[modelStream.available()];
                modelStream.read(bArr4);
                modelStream.close();
                bArr5 = bArr4;
                modelStream = FeatureManager.getModelStream("threshold.txt");
                bArr6 = new byte[modelStream.available()];
                modelStream.read(bArr6);
                modelStream.close();
                handlerThread = new HandlerThread("BodyDetectThread");
                handlerThread.start();
                this.detectHandler = new Handler(handlerThread.getLooper());
                this.inited = nativeInit(bArr7, bArr, bArr2, bArr3, null, null, bArr5, bArr6);
                AppMethodBeat.o(84422);
            }
        } catch (Exception e8) {
            e = e8;
            bArr2 = null;
            LogUtils.e(e);
            modelStream = FeatureManager.getModelStream("xnet_keypoint2.bin.xd");
            bArr3 = new byte[modelStream.available()];
            modelStream.read(bArr3);
            modelStream.close();
            modelStream = FeatureManager.getModelStream("label.txt");
            bArr4 = new byte[modelStream.available()];
            modelStream.read(bArr4);
            modelStream.close();
            bArr5 = bArr4;
            modelStream = FeatureManager.getModelStream("threshold.txt");
            bArr6 = new byte[modelStream.available()];
            modelStream.read(bArr6);
            modelStream.close();
            handlerThread = new HandlerThread("BodyDetectThread");
            handlerThread.start();
            this.detectHandler = new Handler(handlerThread.getLooper());
            this.inited = nativeInit(bArr7, bArr, bArr2, bArr3, null, null, bArr5, bArr6);
            AppMethodBeat.o(84422);
        }
        try {
            modelStream = FeatureManager.getModelStream("xnet_keypoint2.bin.xd");
            bArr3 = new byte[modelStream.available()];
            try {
                modelStream.read(bArr3);
                modelStream.close();
            } catch (Exception e9) {
                e = e9;
                LogUtils.e(e);
                modelStream = FeatureManager.getModelStream("label.txt");
                bArr4 = new byte[modelStream.available()];
                modelStream.read(bArr4);
                modelStream.close();
                bArr5 = bArr4;
                modelStream = FeatureManager.getModelStream("threshold.txt");
                bArr6 = new byte[modelStream.available()];
                modelStream.read(bArr6);
                modelStream.close();
                handlerThread = new HandlerThread("BodyDetectThread");
                handlerThread.start();
                this.detectHandler = new Handler(handlerThread.getLooper());
                this.inited = nativeInit(bArr7, bArr, bArr2, bArr3, null, null, bArr5, bArr6);
                AppMethodBeat.o(84422);
            }
        } catch (Exception e10) {
            e = e10;
            bArr3 = null;
            LogUtils.e(e);
            modelStream = FeatureManager.getModelStream("label.txt");
            bArr4 = new byte[modelStream.available()];
            modelStream.read(bArr4);
            modelStream.close();
            bArr5 = bArr4;
            modelStream = FeatureManager.getModelStream("threshold.txt");
            bArr6 = new byte[modelStream.available()];
            modelStream.read(bArr6);
            modelStream.close();
            handlerThread = new HandlerThread("BodyDetectThread");
            handlerThread.start();
            this.detectHandler = new Handler(handlerThread.getLooper());
            this.inited = nativeInit(bArr7, bArr, bArr2, bArr3, null, null, bArr5, bArr6);
            AppMethodBeat.o(84422);
        }
        try {
            modelStream = FeatureManager.getModelStream("label.txt");
            bArr4 = new byte[modelStream.available()];
            modelStream.read(bArr4);
            modelStream.close();
            bArr5 = bArr4;
        } catch (Exception e11) {
            e = e11;
            bArr4 = null;
            LogUtils.e(e);
            bArr5 = bArr4;
            modelStream = FeatureManager.getModelStream("threshold.txt");
            bArr6 = new byte[modelStream.available()];
            modelStream.read(bArr6);
            modelStream.close();
            handlerThread = new HandlerThread("BodyDetectThread");
            handlerThread.start();
            this.detectHandler = new Handler(handlerThread.getLooper());
            this.inited = nativeInit(bArr7, bArr, bArr2, bArr3, null, null, bArr5, bArr6);
            AppMethodBeat.o(84422);
        }
        try {
            modelStream = FeatureManager.getModelStream("threshold.txt");
            bArr6 = new byte[modelStream.available()];
            try {
                modelStream.read(bArr6);
                modelStream.close();
            } catch (Exception e12) {
                e = e12;
                LogUtils.e(e);
                handlerThread = new HandlerThread("BodyDetectThread");
                handlerThread.start();
                this.detectHandler = new Handler(handlerThread.getLooper());
                this.inited = nativeInit(bArr7, bArr, bArr2, bArr3, null, null, bArr5, bArr6);
                AppMethodBeat.o(84422);
            }
        } catch (Exception e13) {
            e = e13;
            bArr6 = null;
            LogUtils.e(e);
            handlerThread = new HandlerThread("BodyDetectThread");
            handlerThread.start();
            this.detectHandler = new Handler(handlerThread.getLooper());
            this.inited = nativeInit(bArr7, bArr, bArr2, bArr3, null, null, bArr5, bArr6);
            AppMethodBeat.o(84422);
        }
        handlerThread = new HandlerThread("BodyDetectThread");
        handlerThread.start();
        this.detectHandler = new Handler(handlerThread.getLooper());
        this.inited = nativeInit(bArr7, bArr, bArr2, bArr3, null, null, bArr5, bArr6);
        AppMethodBeat.o(84422);
    }

    public void destroy() {
        AppMethodBeat.i(84423);
        if (this.inited) {
            nativeDestroy();
            this.inited = false;
        }
        if (this.detectHandler != null) {
            this.detectHandler.getLooper().quit();
        }
        AppMethodBeat.o(84423);
    }

    public boolean isInited() {
        return this.inited;
    }

    public void reset() {
        this.detectIndex = 0;
        this.bodyDetected = false;
    }

    public List<BodyDetectResult> detectBody(byte[] bArr, int i, int i2) {
        AppMethodBeat.i(84424);
        List<BodyDetectResult> arrayList = new ArrayList();
        if (this.inited) {
            if (this.detectIndex % 10 == 0) {
                this.detectHandler.post(new 1(this, bArr, i, i2));
            }
            synchronized (this.dataLock) {
                try {
                    if (this.bodyDetected) {
                        BodyDetectResult bodyDetectResult = new BodyDetectResult();
                        bodyDetectResult.bodyPoints = new ArrayList();
                        bodyDetectResult.bodyPointScores = new ArrayList();
                        for (int i3 = 0; i3 < 59; i3++) {
                            bodyDetectResult.bodyPoints.add(new PointF(this.ptX[i3], this.ptY[i3]));
                            bodyDetectResult.bodyPointScores.add(Float.valueOf(this.fscore[i3]));
                        }
                        arrayList.add(bodyDetectResult);
                    }
                } finally {
                    while (true) {
                    }
                    AppMethodBeat.o(84424);
                }
            }
            this.detectIndex++;
        } else {
            AppMethodBeat.o(84424);
        }
        return arrayList;
    }

    public void detectBody(OnBodyDetListener onBodyDetListener, byte[] bArr, int i, int i2) {
        AppMethodBeat.i(84425);
        if (this.inited) {
            this.detectHandler.post(new 2(this, bArr, i, i2, onBodyDetListener));
            AppMethodBeat.o(84425);
            return;
        }
        onBodyDetListener.onBodyDataReady(new ArrayList());
        AppMethodBeat.o(84425);
    }

    private void updatePreviousRect(float[] fArr, float[] fArr2) {
        float f;
        int length = leftIndex.length;
        int i = 0;
        float f2 = 0.0f;
        float f3 = 0.0f;
        float f4 = 0.0f;
        while (i < length) {
            f = ((fArr[rightIndex[i]] + fArr[leftIndex[i]]) / 2.0f) + f3;
            f2 += (fArr2[rightIndex[i]] + fArr2[leftIndex[i]]) / 2.0f;
            f4 += fArr[rightIndex[i]] - fArr[leftIndex[i]];
            i++;
            f3 = f;
        }
        float f5 = f3 / ((float) length);
        f2 /= (float) length;
        f = (float) (((double) (f4 / ((float) length))) * 1.5d);
        f3 = 4.0f * f;
        this.mPxmin = f5 - (f / 2.0f);
        this.mPxmax = f5 + (f / 2.0f);
        this.mPymin = f2 - (f3 / 2.0f);
        this.mPymax = (f3 / 2.0f) + f2;
    }
}
