package android.support.v4.view;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Rect;
import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.os.Parcelable;
import android.os.SystemClock;
import android.util.AttributeSet;
import android.view.KeyEvent;
import android.view.MotionEvent;
import android.view.VelocityTracker;
import android.view.View;
import android.view.View.MeasureSpec;
import android.view.ViewConfiguration;
import android.view.ViewGroup;
import android.view.ViewGroup.LayoutParams;
import android.view.ViewParent;
import android.view.accessibility.AccessibilityEvent;
import android.view.animation.Interpolator;
import android.widget.EdgeEffect;
import android.widget.Scroller;
import java.lang.annotation.ElementType;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;
import org.xwalk.core.XWalkEnvironment;

public class ViewPager extends ViewGroup {
    private static final int CLOSE_ENOUGH = 2;
    private static final Comparator<ItemInfo> COMPARATOR = new 1();
    private static final boolean DEBUG = false;
    private static final int DEFAULT_GUTTER_SIZE = 16;
    private static final int DEFAULT_OFFSCREEN_PAGES = 1;
    private static final int DRAW_ORDER_DEFAULT = 0;
    private static final int DRAW_ORDER_FORWARD = 1;
    private static final int DRAW_ORDER_REVERSE = 2;
    private static final int INVALID_POINTER = -1;
    static final int[] LAYOUT_ATTRS = new int[]{16842931};
    private static final int MAX_SETTLE_DURATION = 600;
    private static final int MIN_DISTANCE_FOR_FLING = 25;
    private static final int MIN_FLING_VELOCITY = 400;
    public static final int SCROLL_STATE_DRAGGING = 1;
    public static final int SCROLL_STATE_IDLE = 0;
    public static final int SCROLL_STATE_SETTLING = 2;
    private static final String TAG = "ViewPager";
    private static final boolean USE_CACHE = false;
    private static final Interpolator sInterpolator = new 2();
    private static final g sPositionComparator = new g();
    private int mActivePointerId = -1;
    p mAdapter;
    private List<c> mAdapterChangeListeners;
    private int mBottomPageBounds;
    private boolean mCalledSuper;
    private int mChildHeightMeasureSpec;
    private int mChildWidthMeasureSpec;
    private int mCloseEnough;
    int mCurItem;
    private int mDecorChildCount;
    private int mDefaultGutterSize;
    private int mDrawingOrder;
    private ArrayList<View> mDrawingOrderedChildren;
    private final Runnable mEndScrollRunnable = new 3(this);
    private int mExpectedAdapterCount;
    private long mFakeDragBeginTime;
    private boolean mFakeDragging;
    private boolean mFirstLayout = true;
    private float mFirstOffset = -3.4028235E38f;
    private int mFlingDistance;
    private int mGutterSize;
    private boolean mInLayout;
    private float mInitialMotionX;
    private float mInitialMotionY;
    private OnPageChangeListener mInternalPageChangeListener;
    private boolean mIsBeingDragged;
    private boolean mIsScrollStarted;
    private boolean mIsUnableToDrag;
    private final ArrayList<ItemInfo> mItems = new ArrayList();
    private float mLastMotionX;
    private float mLastMotionY;
    private float mLastOffset = Float.MAX_VALUE;
    private EdgeEffect mLeftEdge;
    private Drawable mMarginDrawable;
    private int mMaximumVelocity;
    private int mMinimumVelocity;
    private boolean mNeedCalculatePageOffsets = false;
    private e mObserver;
    private int mOffscreenPageLimit = 1;
    private OnPageChangeListener mOnPageChangeListener;
    private List<OnPageChangeListener> mOnPageChangeListeners;
    private int mPageMargin;
    private d mPageTransformer;
    private int mPageTransformerLayerType;
    private boolean mPopulatePending;
    private Parcelable mRestoredAdapterState = null;
    private ClassLoader mRestoredClassLoader = null;
    private int mRestoredCurItem = -1;
    private EdgeEffect mRightEdge;
    private int mScrollState = 0;
    private Scroller mScroller;
    private boolean mScrollingCacheEnabled;
    private final ItemInfo mTempItem = new ItemInfo();
    private final Rect mTempRect = new Rect();
    private int mTopPageBounds;
    private int mTouchSlop;
    private VelocityTracker mVelocityTracker;

    static class ItemInfo {
        Object object;
        float offset;
        int position;
        boolean scrolling;
        float widthFactor;

        ItemInfo() {
        }
    }

    public interface OnPageChangeListener {
        void onPageScrollStateChanged(int i);

        void onPageScrolled(int i, float f, int i2);

        void onPageSelected(int i);
    }

    @Inherited
    @Target({ElementType.TYPE})
    @Retention(RetentionPolicy.RUNTIME)
    public @interface a {
    }

    class b extends a {
        b() {
        }

        public final void onInitializeAccessibilityEvent(View view, AccessibilityEvent accessibilityEvent) {
            super.onInitializeAccessibilityEvent(view, accessibilityEvent);
            accessibilityEvent.setClassName(ViewPager.class.getName());
            accessibilityEvent.setScrollable(er());
            if (accessibilityEvent.getEventType() == 4096 && ViewPager.this.mAdapter != null) {
                accessibilityEvent.setItemCount(ViewPager.this.mAdapter.getCount());
                accessibilityEvent.setFromIndex(ViewPager.this.mCurItem);
                accessibilityEvent.setToIndex(ViewPager.this.mCurItem);
            }
        }

        public final void onInitializeAccessibilityNodeInfo(View view, android.support.v4.view.a.b bVar) {
            super.onInitializeAccessibilityNodeInfo(view, bVar);
            bVar.setClassName(ViewPager.class.getName());
            bVar.setScrollable(er());
            if (ViewPager.this.canScrollHorizontally(1)) {
                bVar.addAction(4096);
            }
            if (ViewPager.this.canScrollHorizontally(-1)) {
                bVar.addAction(8192);
            }
        }

        public final boolean performAccessibilityAction(View view, int i, Bundle bundle) {
            if (super.performAccessibilityAction(view, i, bundle)) {
                return true;
            }
            switch (i) {
                case 4096:
                    if (!ViewPager.this.canScrollHorizontally(1)) {
                        return false;
                    }
                    ViewPager.this.setCurrentItem(ViewPager.this.mCurItem + 1);
                    return true;
                case 8192:
                    if (!ViewPager.this.canScrollHorizontally(-1)) {
                        return false;
                    }
                    ViewPager.this.setCurrentItem(ViewPager.this.mCurItem - 1);
                    return true;
                default:
                    return false;
            }
        }

        private boolean er() {
            return ViewPager.this.mAdapter != null && ViewPager.this.mAdapter.getCount() > 1;
        }
    }

    public ViewPager(Context context) {
        super(context);
        initViewPager();
    }

    public ViewPager(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
        initViewPager();
    }

    /* Access modifiers changed, original: 0000 */
    public void initViewPager() {
        setWillNotDraw(false);
        setDescendantFocusability(262144);
        setFocusable(true);
        Context context = getContext();
        this.mScroller = new Scroller(context, sInterpolator);
        ViewConfiguration viewConfiguration = ViewConfiguration.get(context);
        float f = context.getResources().getDisplayMetrics().density;
        this.mTouchSlop = viewConfiguration.getScaledPagingTouchSlop();
        this.mMinimumVelocity = (int) (400.0f * f);
        this.mMaximumVelocity = viewConfiguration.getScaledMaximumFlingVelocity();
        this.mLeftEdge = new EdgeEffect(context);
        this.mRightEdge = new EdgeEffect(context);
        this.mFlingDistance = (int) (25.0f * f);
        this.mCloseEnough = (int) (2.0f * f);
        this.mDefaultGutterSize = (int) (16.0f * f);
        s.a(this, new b());
        if (s.S(this) == 0) {
            s.o(this, 1);
        }
        s.a(this, new 4(this));
    }

    /* Access modifiers changed, original: protected */
    public void onDetachedFromWindow() {
        removeCallbacks(this.mEndScrollRunnable);
        if (!(this.mScroller == null || this.mScroller.isFinished())) {
            this.mScroller.abortAnimation();
        }
        super.onDetachedFromWindow();
    }

    /* Access modifiers changed, original: 0000 */
    public void setScrollState(int i) {
        if (this.mScrollState != i) {
            this.mScrollState = i;
            if (this.mPageTransformer != null) {
                enableLayers(i != 0);
            }
            dispatchOnScrollStateChanged(i);
        }
    }

    public void setAdapter(p pVar) {
        int i = 0;
        if (this.mAdapter != null) {
            this.mAdapter.setViewPagerObserver(null);
            this.mAdapter.startUpdate(this);
            for (int i2 = 0; i2 < this.mItems.size(); i2++) {
                ItemInfo itemInfo = (ItemInfo) this.mItems.get(i2);
                this.mAdapter.destroyItem(this, itemInfo.position, itemInfo.object);
            }
            this.mAdapter.finishUpdate(this);
            this.mItems.clear();
            removeNonDecorViews();
            this.mCurItem = 0;
            scrollTo(0, 0);
        }
        p pVar2 = this.mAdapter;
        this.mAdapter = pVar;
        this.mExpectedAdapterCount = 0;
        if (this.mAdapter != null) {
            if (this.mObserver == null) {
                this.mObserver = new e(this);
            }
            this.mAdapter.setViewPagerObserver(this.mObserver);
            this.mPopulatePending = false;
            boolean z = this.mFirstLayout;
            this.mFirstLayout = true;
            this.mExpectedAdapterCount = this.mAdapter.getCount();
            if (this.mRestoredCurItem >= 0) {
                this.mAdapter.restoreState(this.mRestoredAdapterState, this.mRestoredClassLoader);
                setCurrentItemInternal(this.mRestoredCurItem, false, true);
                this.mRestoredCurItem = -1;
                this.mRestoredAdapterState = null;
                this.mRestoredClassLoader = null;
            } else if (z) {
                requestLayout();
            } else {
                populate();
            }
        }
        if (this.mAdapterChangeListeners != null && !this.mAdapterChangeListeners.isEmpty()) {
            int size = this.mAdapterChangeListeners.size();
            while (i < size) {
                ((c) this.mAdapterChangeListeners.get(i)).a(this, pVar2, pVar);
                i++;
            }
        }
    }

    private void removeNonDecorViews() {
        int i = 0;
        while (true) {
            int i2 = i;
            if (i2 < getChildCount()) {
                if (!((LayoutParams) getChildAt(i2).getLayoutParams()).Nq) {
                    removeViewAt(i2);
                    i2--;
                }
                i = i2 + 1;
            } else {
                return;
            }
        }
    }

    public p getAdapter() {
        return this.mAdapter;
    }

    public void addOnAdapterChangeListener(c cVar) {
        if (this.mAdapterChangeListeners == null) {
            this.mAdapterChangeListeners = new ArrayList();
        }
        this.mAdapterChangeListeners.add(cVar);
    }

    public void removeOnAdapterChangeListener(c cVar) {
        if (this.mAdapterChangeListeners != null) {
            this.mAdapterChangeListeners.remove(cVar);
        }
    }

    private int getClientWidth() {
        return (getMeasuredWidth() - getPaddingLeft()) - getPaddingRight();
    }

    public void setCurrentItem(int i) {
        boolean z;
        this.mPopulatePending = false;
        if (this.mFirstLayout) {
            z = false;
        } else {
            z = true;
        }
        setCurrentItemInternal(i, z, false);
    }

    public void setCurrentItem(int i, boolean z) {
        this.mPopulatePending = false;
        setCurrentItemInternal(i, z, false);
    }

    public int getCurrentItem() {
        return this.mCurItem;
    }

    /* Access modifiers changed, original: 0000 */
    public void setCurrentItemInternal(int i, boolean z, boolean z2) {
        setCurrentItemInternal(i, z, z2, 0);
    }

    /* Access modifiers changed, original: 0000 */
    public void setCurrentItemInternal(int i, boolean z, boolean z2, int i2) {
        boolean z3 = false;
        if (this.mAdapter == null || this.mAdapter.getCount() <= 0) {
            setScrollingCacheEnabled(false);
        } else if (z2 || this.mCurItem != i || this.mItems.size() == 0) {
            if (i < 0) {
                i = 0;
            } else if (i >= this.mAdapter.getCount()) {
                i = this.mAdapter.getCount() - 1;
            }
            int i3 = this.mOffscreenPageLimit;
            if (i > this.mCurItem + i3 || i < this.mCurItem - i3) {
                for (int i4 = 0; i4 < this.mItems.size(); i4++) {
                    ((ItemInfo) this.mItems.get(i4)).scrolling = true;
                }
            }
            if (this.mCurItem != i) {
                z3 = true;
            }
            if (this.mFirstLayout) {
                this.mCurItem = i;
                if (z3) {
                    dispatchOnPageSelected(i);
                }
                requestLayout();
                return;
            }
            populate(i);
            scrollToItem(i, z, i2, z3);
        } else {
            setScrollingCacheEnabled(false);
        }
    }

    private void scrollToItem(int i, boolean z, int i2, boolean z2) {
        int max;
        ItemInfo infoForPosition = infoForPosition(i);
        if (infoForPosition != null) {
            max = (int) (Math.max(this.mFirstOffset, Math.min(infoForPosition.offset, this.mLastOffset)) * ((float) getClientWidth()));
        } else {
            max = 0;
        }
        if (z) {
            smoothScrollTo(max, 0, i2);
            if (z2) {
                dispatchOnPageSelected(i);
                return;
            }
            return;
        }
        if (z2) {
            dispatchOnPageSelected(i);
        }
        completeScroll(false);
        scrollTo(max, 0);
        pageScrolled(max);
    }

    @Deprecated
    public void setOnPageChangeListener(OnPageChangeListener onPageChangeListener) {
        this.mOnPageChangeListener = onPageChangeListener;
    }

    public void addOnPageChangeListener(OnPageChangeListener onPageChangeListener) {
        if (this.mOnPageChangeListeners == null) {
            this.mOnPageChangeListeners = new ArrayList();
        }
        this.mOnPageChangeListeners.add(onPageChangeListener);
    }

    public void removeOnPageChangeListener(OnPageChangeListener onPageChangeListener) {
        if (this.mOnPageChangeListeners != null) {
            this.mOnPageChangeListeners.remove(onPageChangeListener);
        }
    }

    public void clearOnPageChangeListeners() {
        if (this.mOnPageChangeListeners != null) {
            this.mOnPageChangeListeners.clear();
        }
    }

    public void setPageTransformer(boolean z, d dVar) {
        setPageTransformer(z, dVar, 2);
    }

    public void setPageTransformer(boolean z, d dVar, int i) {
        boolean z2;
        int i2 = 1;
        boolean z3 = dVar != null;
        if (this.mPageTransformer != null) {
            z2 = true;
        } else {
            z2 = false;
        }
        int i3 = z3 != z2 ? 1 : 0;
        this.mPageTransformer = dVar;
        setChildrenDrawingOrderEnabled(z3);
        if (z3) {
            if (z) {
                i2 = 2;
            }
            this.mDrawingOrder = i2;
            this.mPageTransformerLayerType = i;
        } else {
            this.mDrawingOrder = 0;
        }
        if (i3 != 0) {
            populate();
        }
    }

    /* Access modifiers changed, original: protected */
    public int getChildDrawingOrder(int i, int i2) {
        if (this.mDrawingOrder == 2) {
            i2 = (i - 1) - i2;
        }
        return ((LayoutParams) ((View) this.mDrawingOrderedChildren.get(i2)).getLayoutParams()).Ns;
    }

    /* Access modifiers changed, original: 0000 */
    public OnPageChangeListener setInternalPageChangeListener(OnPageChangeListener onPageChangeListener) {
        OnPageChangeListener onPageChangeListener2 = this.mInternalPageChangeListener;
        this.mInternalPageChangeListener = onPageChangeListener;
        return onPageChangeListener2;
    }

    public int getOffscreenPageLimit() {
        return this.mOffscreenPageLimit;
    }

    public void setOffscreenPageLimit(int i) {
        if (i <= 0) {
            new StringBuilder("Requested offscreen page limit ").append(i).append(" too small; defaulting to 1");
            i = 1;
        }
        if (i != this.mOffscreenPageLimit) {
            this.mOffscreenPageLimit = i;
            populate();
        }
    }

    public void setPageMargin(int i) {
        int i2 = this.mPageMargin;
        this.mPageMargin = i;
        int width = getWidth();
        recomputeScrollPosition(width, width, i, i2);
        requestLayout();
    }

    public int getPageMargin() {
        return this.mPageMargin;
    }

    public void setPageMarginDrawable(Drawable drawable) {
        this.mMarginDrawable = drawable;
        if (drawable != null) {
            refreshDrawableState();
        }
        setWillNotDraw(drawable == null);
        invalidate();
    }

    public void setPageMarginDrawable(int i) {
        setPageMarginDrawable(android.support.v4.content.b.g(getContext(), i));
    }

    /* Access modifiers changed, original: protected */
    public boolean verifyDrawable(Drawable drawable) {
        return super.verifyDrawable(drawable) || drawable == this.mMarginDrawable;
    }

    /* Access modifiers changed, original: protected */
    public void drawableStateChanged() {
        super.drawableStateChanged();
        Drawable drawable = this.mMarginDrawable;
        if (drawable != null && drawable.isStateful()) {
            drawable.setState(getDrawableState());
        }
    }

    /* Access modifiers changed, original: 0000 */
    public float distanceInfluenceForSnapDuration(float f) {
        return (float) Math.sin((double) ((f - 0.5f) * 0.47123894f));
    }

    /* Access modifiers changed, original: 0000 */
    public void smoothScrollTo(int i, int i2) {
        smoothScrollTo(i, i2, 0);
    }

    /* Access modifiers changed, original: 0000 */
    public void smoothScrollTo(int i, int i2, int i3) {
        if (getChildCount() == 0) {
            setScrollingCacheEnabled(false);
            return;
        }
        int currX;
        int i4;
        boolean z = (this.mScroller == null || this.mScroller.isFinished()) ? false : true;
        if (z) {
            currX = this.mIsScrollStarted ? this.mScroller.getCurrX() : this.mScroller.getStartX();
            this.mScroller.abortAnimation();
            setScrollingCacheEnabled(false);
            i4 = currX;
        } else {
            i4 = getScrollX();
        }
        int scrollY = getScrollY();
        int i5 = i - i4;
        int i6 = i2 - scrollY;
        if (i5 == 0 && i6 == 0) {
            completeScroll(false);
            populate();
            setScrollState(0);
            return;
        }
        setScrollingCacheEnabled(true);
        setScrollState(2);
        currX = getClientWidth();
        int i7 = currX / 2;
        float distanceInfluenceForSnapDuration = (((float) i7) * distanceInfluenceForSnapDuration(Math.min(1.0f, (((float) Math.abs(i5)) * 1.0f) / ((float) currX)))) + ((float) i7);
        int abs = Math.abs(i3);
        if (abs > 0) {
            currX = Math.round(1000.0f * Math.abs(distanceInfluenceForSnapDuration / ((float) abs))) * 4;
        } else {
            currX = (int) (((((float) Math.abs(i5)) / ((((float) currX) * this.mAdapter.getPageWidth(this.mCurItem)) + ((float) this.mPageMargin))) + 1.0f) * 100.0f);
        }
        i7 = Math.min(currX, MAX_SETTLE_DURATION);
        this.mIsScrollStarted = false;
        this.mScroller.startScroll(i4, scrollY, i5, i6, i7);
        s.R(this);
    }

    /* Access modifiers changed, original: 0000 */
    public ItemInfo addNewItem(int i, int i2) {
        ItemInfo itemInfo = new ItemInfo();
        itemInfo.position = i;
        itemInfo.object = this.mAdapter.instantiateItem(this, i);
        itemInfo.widthFactor = this.mAdapter.getPageWidth(i);
        if (i2 < 0 || i2 >= this.mItems.size()) {
            this.mItems.add(itemInfo);
        } else {
            this.mItems.add(i2, itemInfo);
        }
        return itemInfo;
    }

    /* Access modifiers changed, original: 0000 */
    public void dataSetChanged() {
        boolean z;
        int count = this.mAdapter.getCount();
        this.mExpectedAdapterCount = count;
        if (this.mItems.size() >= (this.mOffscreenPageLimit * 2) + 1 || this.mItems.size() >= count) {
            z = false;
        } else {
            z = true;
        }
        int i = this.mCurItem;
        int i2 = 0;
        int i3 = 0;
        boolean z2 = z;
        while (i2 < this.mItems.size()) {
            ItemInfo itemInfo = (ItemInfo) this.mItems.get(i2);
            int itemPosition = this.mAdapter.getItemPosition(itemInfo.object);
            if (itemPosition != -1) {
                if (itemPosition == -2) {
                    this.mItems.remove(i2);
                    i2--;
                    if (i3 == 0) {
                        this.mAdapter.startUpdate(this);
                        i3 = true;
                    }
                    this.mAdapter.destroyItem(this, itemInfo.position, itemInfo.object);
                    if (this.mCurItem == itemInfo.position) {
                        i = Math.max(0, Math.min(this.mCurItem, count - 1));
                        z2 = true;
                    } else {
                        z2 = true;
                    }
                } else if (itemInfo.position != itemPosition) {
                    if (itemInfo.position == this.mCurItem) {
                        i = itemPosition;
                    }
                    itemInfo.position = itemPosition;
                    z2 = true;
                }
            }
            i2++;
        }
        if (i3 != 0) {
            this.mAdapter.finishUpdate(this);
        }
        Collections.sort(this.mItems, COMPARATOR);
        if (z2) {
            i3 = getChildCount();
            for (i2 = 0; i2 < i3; i2++) {
                LayoutParams layoutParams = (LayoutParams) getChildAt(i2).getLayoutParams();
                if (!layoutParams.Nq) {
                    layoutParams.widthFactor = 0.0f;
                }
            }
            setCurrentItemInternal(i, false, true);
            requestLayout();
        }
    }

    /* Access modifiers changed, original: 0000 */
    public void populate() {
        populate(this.mCurItem);
    }

    /* Access modifiers changed, original: 0000 */
    /* JADX WARNING: Missing block: B:25:0x00c7, code skipped:
            if (r0.position == r13.mCurItem) goto L_0x00c9;
     */
    public void populate(int r14) {
        /*
        r13 = this;
        r0 = 0;
        r1 = r13.mCurItem;
        if (r1 == r14) goto L_0x0290;
    L_0x0005:
        r0 = r13.mCurItem;
        r0 = r13.infoForPosition(r0);
        r13.mCurItem = r14;
        r1 = r0;
    L_0x000e:
        r0 = r13.mAdapter;
        if (r0 != 0) goto L_0x0016;
    L_0x0012:
        r13.sortChildDrawingOrder();
    L_0x0015:
        return;
    L_0x0016:
        r0 = r13.mPopulatePending;
        if (r0 == 0) goto L_0x001e;
    L_0x001a:
        r13.sortChildDrawingOrder();
        goto L_0x0015;
    L_0x001e:
        r0 = r13.getWindowToken();
        if (r0 == 0) goto L_0x0015;
    L_0x0024:
        r0 = r13.mAdapter;
        r0.startUpdate(r13);
        r0 = r13.mOffscreenPageLimit;
        r2 = 0;
        r3 = r13.mCurItem;
        r3 = r3 - r0;
        r9 = java.lang.Math.max(r2, r3);
        r2 = r13.mAdapter;
        r10 = r2.getCount();
        r2 = r10 + -1;
        r3 = r13.mCurItem;
        r0 = r0 + r3;
        r11 = java.lang.Math.min(r2, r0);
        r0 = r13.mExpectedAdapterCount;
        if (r10 == r0) goto L_0x00aa;
    L_0x0046:
        r0 = r13.getResources();	 Catch:{ NotFoundException -> 0x00a0 }
        r1 = r13.getId();	 Catch:{ NotFoundException -> 0x00a0 }
        r0 = r0.getResourceName(r1);	 Catch:{ NotFoundException -> 0x00a0 }
    L_0x0052:
        r1 = new java.lang.IllegalStateException;
        r2 = new java.lang.StringBuilder;
        r3 = "The application's PagerAdapter changed the adapter's contents without calling PagerAdapter#notifyDataSetChanged! Expected adapter item count: ";
        r2.<init>(r3);
        r3 = r13.mExpectedAdapterCount;
        r2 = r2.append(r3);
        r3 = ", found: ";
        r2 = r2.append(r3);
        r2 = r2.append(r10);
        r3 = " Pager id: ";
        r2 = r2.append(r3);
        r0 = r2.append(r0);
        r2 = " Pager class: ";
        r0 = r0.append(r2);
        r2 = r13.getClass();
        r0 = r0.append(r2);
        r2 = " Problematic adapter: ";
        r0 = r0.append(r2);
        r2 = r13.mAdapter;
        r2 = r2.getClass();
        r0 = r0.append(r2);
        r0 = r0.toString();
        r1.<init>(r0);
        throw r1;
    L_0x00a0:
        r0 = move-exception;
        r0 = r13.getId();
        r0 = java.lang.Integer.toHexString(r0);
        goto L_0x0052;
    L_0x00aa:
        r3 = 0;
        r0 = 0;
        r2 = r0;
    L_0x00ad:
        r0 = r13.mItems;
        r0 = r0.size();
        if (r2 >= r0) goto L_0x028d;
    L_0x00b5:
        r0 = r13.mItems;
        r0 = r0.get(r2);
        r0 = (android.support.v4.view.ViewPager.ItemInfo) r0;
        r4 = r0.position;
        r5 = r13.mCurItem;
        if (r4 < r5) goto L_0x0120;
    L_0x00c3:
        r4 = r0.position;
        r5 = r13.mCurItem;
        if (r4 != r5) goto L_0x028d;
    L_0x00c9:
        if (r0 != 0) goto L_0x028a;
    L_0x00cb:
        if (r10 <= 0) goto L_0x028a;
    L_0x00cd:
        r0 = r13.mCurItem;
        r0 = r13.addNewItem(r0, r2);
        r8 = r0;
    L_0x00d4:
        if (r8 == 0) goto L_0x0213;
    L_0x00d6:
        r5 = 0;
        r4 = r2 + -1;
        if (r4 < 0) goto L_0x0124;
    L_0x00db:
        r0 = r13.mItems;
        r0 = r0.get(r4);
        r0 = (android.support.v4.view.ViewPager.ItemInfo) r0;
    L_0x00e3:
        r12 = r13.getClientWidth();
        if (r12 > 0) goto L_0x0126;
    L_0x00e9:
        r3 = 0;
    L_0x00ea:
        r6 = r13.mCurItem;
        r7 = r6 + -1;
        r6 = r2;
    L_0x00ef:
        if (r7 < 0) goto L_0x0167;
    L_0x00f1:
        r2 = (r5 > r3 ? 1 : (r5 == r3 ? 0 : -1));
        if (r2 < 0) goto L_0x0136;
    L_0x00f5:
        if (r7 >= r9) goto L_0x0136;
    L_0x00f7:
        if (r0 == 0) goto L_0x0167;
    L_0x00f9:
        r2 = r0.position;
        if (r7 != r2) goto L_0x0287;
    L_0x00fd:
        r2 = r0.scrolling;
        if (r2 != 0) goto L_0x0287;
    L_0x0101:
        r2 = r13.mItems;
        r2.remove(r4);
        r2 = r13.mAdapter;
        r0 = r0.object;
        r2.destroyItem(r13, r7, r0);
        r2 = r4 + -1;
        r4 = r6 + -1;
        if (r2 < 0) goto L_0x0134;
    L_0x0113:
        r0 = r13.mItems;
        r0 = r0.get(r2);
        r0 = (android.support.v4.view.ViewPager.ItemInfo) r0;
    L_0x011b:
        r6 = r4;
    L_0x011c:
        r7 = r7 + -1;
        r4 = r2;
        goto L_0x00ef;
    L_0x0120:
        r0 = r2 + 1;
        r2 = r0;
        goto L_0x00ad;
    L_0x0124:
        r0 = 0;
        goto L_0x00e3;
    L_0x0126:
        r3 = 1073741824; // 0x40000000 float:2.0 double:5.304989477E-315;
        r6 = r8.widthFactor;
        r3 = r3 - r6;
        r6 = r13.getPaddingLeft();
        r6 = (float) r6;
        r7 = (float) r12;
        r6 = r6 / r7;
        r3 = r3 + r6;
        goto L_0x00ea;
    L_0x0134:
        r0 = 0;
        goto L_0x011b;
    L_0x0136:
        if (r0 == 0) goto L_0x014e;
    L_0x0138:
        r2 = r0.position;
        if (r7 != r2) goto L_0x014e;
    L_0x013c:
        r0 = r0.widthFactor;
        r5 = r5 + r0;
        r2 = r4 + -1;
        if (r2 < 0) goto L_0x014c;
    L_0x0143:
        r0 = r13.mItems;
        r0 = r0.get(r2);
        r0 = (android.support.v4.view.ViewPager.ItemInfo) r0;
        goto L_0x011c;
    L_0x014c:
        r0 = 0;
        goto L_0x011c;
    L_0x014e:
        r0 = r4 + 1;
        r0 = r13.addNewItem(r7, r0);
        r0 = r0.widthFactor;
        r5 = r5 + r0;
        r6 = r6 + 1;
        if (r4 < 0) goto L_0x0165;
    L_0x015b:
        r0 = r13.mItems;
        r0 = r0.get(r4);
        r0 = (android.support.v4.view.ViewPager.ItemInfo) r0;
    L_0x0163:
        r2 = r4;
        goto L_0x011c;
    L_0x0165:
        r0 = 0;
        goto L_0x0163;
    L_0x0167:
        r3 = r8.widthFactor;
        r4 = r6 + 1;
        r0 = 1073741824; // 0x40000000 float:2.0 double:5.304989477E-315;
        r0 = (r3 > r0 ? 1 : (r3 == r0 ? 0 : -1));
        if (r0 >= 0) goto L_0x0207;
    L_0x0171:
        r0 = r13.mItems;
        r0 = r0.size();
        if (r4 >= r0) goto L_0x01bd;
    L_0x0179:
        r0 = r13.mItems;
        r0 = r0.get(r4);
        r0 = (android.support.v4.view.ViewPager.ItemInfo) r0;
        r5 = r0;
    L_0x0182:
        if (r12 > 0) goto L_0x01bf;
    L_0x0184:
        r0 = 0;
        r2 = r0;
    L_0x0186:
        r0 = r13.mCurItem;
        r7 = r0 + 1;
        r0 = r5;
    L_0x018b:
        if (r7 >= r10) goto L_0x0207;
    L_0x018d:
        r5 = (r3 > r2 ? 1 : (r3 == r2 ? 0 : -1));
        if (r5 < 0) goto L_0x01cd;
    L_0x0191:
        if (r7 <= r11) goto L_0x01cd;
    L_0x0193:
        if (r0 == 0) goto L_0x0207;
    L_0x0195:
        r5 = r0.position;
        if (r7 != r5) goto L_0x01b9;
    L_0x0199:
        r5 = r0.scrolling;
        if (r5 != 0) goto L_0x01b9;
    L_0x019d:
        r5 = r13.mItems;
        r5.remove(r4);
        r5 = r13.mAdapter;
        r0 = r0.object;
        r5.destroyItem(r13, r7, r0);
        r0 = r13.mItems;
        r0 = r0.size();
        if (r4 >= r0) goto L_0x01cb;
    L_0x01b1:
        r0 = r13.mItems;
        r0 = r0.get(r4);
        r0 = (android.support.v4.view.ViewPager.ItemInfo) r0;
    L_0x01b9:
        r5 = r7 + 1;
        r7 = r5;
        goto L_0x018b;
    L_0x01bd:
        r5 = 0;
        goto L_0x0182;
    L_0x01bf:
        r0 = r13.getPaddingRight();
        r0 = (float) r0;
        r2 = (float) r12;
        r0 = r0 / r2;
        r2 = 1073741824; // 0x40000000 float:2.0 double:5.304989477E-315;
        r0 = r0 + r2;
        r2 = r0;
        goto L_0x0186;
    L_0x01cb:
        r0 = 0;
        goto L_0x01b9;
    L_0x01cd:
        if (r0 == 0) goto L_0x01eb;
    L_0x01cf:
        r5 = r0.position;
        if (r7 != r5) goto L_0x01eb;
    L_0x01d3:
        r0 = r0.widthFactor;
        r3 = r3 + r0;
        r4 = r4 + 1;
        r0 = r13.mItems;
        r0 = r0.size();
        if (r4 >= r0) goto L_0x01e9;
    L_0x01e0:
        r0 = r13.mItems;
        r0 = r0.get(r4);
        r0 = (android.support.v4.view.ViewPager.ItemInfo) r0;
        goto L_0x01b9;
    L_0x01e9:
        r0 = 0;
        goto L_0x01b9;
    L_0x01eb:
        r0 = r13.addNewItem(r7, r4);
        r4 = r4 + 1;
        r0 = r0.widthFactor;
        r3 = r3 + r0;
        r0 = r13.mItems;
        r0 = r0.size();
        if (r4 >= r0) goto L_0x0205;
    L_0x01fc:
        r0 = r13.mItems;
        r0 = r0.get(r4);
        r0 = (android.support.v4.view.ViewPager.ItemInfo) r0;
        goto L_0x01b9;
    L_0x0205:
        r0 = 0;
        goto L_0x01b9;
    L_0x0207:
        r13.calculatePageOffsets(r8, r6, r1);
        r0 = r13.mAdapter;
        r1 = r13.mCurItem;
        r2 = r8.object;
        r0.setPrimaryItem(r13, r1, r2);
    L_0x0213:
        r0 = r13.mAdapter;
        r0.finishUpdate(r13);
        r2 = r13.getChildCount();
        r0 = 0;
        r1 = r0;
    L_0x021e:
        if (r1 >= r2) goto L_0x0249;
    L_0x0220:
        r3 = r13.getChildAt(r1);
        r0 = r3.getLayoutParams();
        r0 = (android.support.v4.view.ViewPager.LayoutParams) r0;
        r0.Ns = r1;
        r4 = r0.Nq;
        if (r4 != 0) goto L_0x0245;
    L_0x0230:
        r4 = r0.widthFactor;
        r5 = 0;
        r4 = (r4 > r5 ? 1 : (r4 == r5 ? 0 : -1));
        if (r4 != 0) goto L_0x0245;
    L_0x0237:
        r3 = r13.infoForChild(r3);
        if (r3 == 0) goto L_0x0245;
    L_0x023d:
        r4 = r3.widthFactor;
        r0.widthFactor = r4;
        r3 = r3.position;
        r0.position = r3;
    L_0x0245:
        r0 = r1 + 1;
        r1 = r0;
        goto L_0x021e;
    L_0x0249:
        r13.sortChildDrawingOrder();
        r0 = r13.hasFocus();
        if (r0 == 0) goto L_0x0015;
    L_0x0252:
        r0 = r13.findFocus();
        if (r0 == 0) goto L_0x0285;
    L_0x0258:
        r0 = r13.infoForAnyChild(r0);
    L_0x025c:
        if (r0 == 0) goto L_0x0264;
    L_0x025e:
        r0 = r0.position;
        r1 = r13.mCurItem;
        if (r0 == r1) goto L_0x0015;
    L_0x0264:
        r0 = 0;
    L_0x0265:
        r1 = r13.getChildCount();
        if (r0 >= r1) goto L_0x0015;
    L_0x026b:
        r1 = r13.getChildAt(r0);
        r2 = r13.infoForChild(r1);
        if (r2 == 0) goto L_0x0282;
    L_0x0275:
        r2 = r2.position;
        r3 = r13.mCurItem;
        if (r2 != r3) goto L_0x0282;
    L_0x027b:
        r2 = 2;
        r1 = r1.requestFocus(r2);
        if (r1 != 0) goto L_0x0015;
    L_0x0282:
        r0 = r0 + 1;
        goto L_0x0265;
    L_0x0285:
        r0 = 0;
        goto L_0x025c;
    L_0x0287:
        r2 = r4;
        goto L_0x011c;
    L_0x028a:
        r8 = r0;
        goto L_0x00d4;
    L_0x028d:
        r0 = r3;
        goto L_0x00c9;
    L_0x0290:
        r1 = r0;
        goto L_0x000e;
        */
        throw new UnsupportedOperationException("Method not decompiled: android.support.v4.view.ViewPager.populate(int):void");
    }

    private void sortChildDrawingOrder() {
        if (this.mDrawingOrder != 0) {
            if (this.mDrawingOrderedChildren == null) {
                this.mDrawingOrderedChildren = new ArrayList();
            } else {
                this.mDrawingOrderedChildren.clear();
            }
            int childCount = getChildCount();
            for (int i = 0; i < childCount; i++) {
                this.mDrawingOrderedChildren.add(getChildAt(i));
            }
            Collections.sort(this.mDrawingOrderedChildren, sPositionComparator);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:20:0x005d A:{LOOP_END, LOOP:2: B:18:0x0059->B:20:0x005d} */
    /* JADX WARNING: Removed duplicated region for block: B:35:0x00a6 A:{LOOP_END, LOOP:5: B:33:0x00a2->B:35:0x00a6} */
    private void calculatePageOffsets(android.support.v4.view.ViewPager.ItemInfo r12, int r13, android.support.v4.view.ViewPager.ItemInfo r14) {
        /*
        r11 = this;
        r4 = 0;
        r10 = 1065353216; // 0x3f800000 float:1.0 double:5.263544247E-315;
        r0 = r11.mAdapter;
        r7 = r0.getCount();
        r0 = r11.getClientWidth();
        if (r0 <= 0) goto L_0x0056;
    L_0x000f:
        r1 = r11.mPageMargin;
        r1 = (float) r1;
        r0 = (float) r0;
        r0 = r1 / r0;
        r6 = r0;
    L_0x0016:
        if (r14 == 0) goto L_0x00bb;
    L_0x0018:
        r0 = r14.position;
        r1 = r12.position;
        if (r0 >= r1) goto L_0x0072;
    L_0x001e:
        r1 = r14.offset;
        r2 = r14.widthFactor;
        r1 = r1 + r2;
        r2 = r1 + r6;
        r0 = r0 + 1;
        r1 = r0;
        r3 = r4;
    L_0x0029:
        r0 = r12.position;
        if (r1 > r0) goto L_0x00bb;
    L_0x002d:
        r0 = r11.mItems;
        r0 = r0.size();
        if (r3 >= r0) goto L_0x00bb;
    L_0x0035:
        r0 = r11.mItems;
        r0 = r0.get(r3);
        r0 = (android.support.v4.view.ViewPager.ItemInfo) r0;
    L_0x003d:
        r5 = r0.position;
        if (r1 <= r5) goto L_0x0059;
    L_0x0041:
        r5 = r11.mItems;
        r5 = r5.size();
        r5 = r5 + -1;
        if (r3 >= r5) goto L_0x0059;
    L_0x004b:
        r3 = r3 + 1;
        r0 = r11.mItems;
        r0 = r0.get(r3);
        r0 = (android.support.v4.view.ViewPager.ItemInfo) r0;
        goto L_0x003d;
    L_0x0056:
        r0 = 0;
        r6 = r0;
        goto L_0x0016;
    L_0x0059:
        r5 = r0.position;
        if (r1 >= r5) goto L_0x0068;
    L_0x005d:
        r5 = r11.mAdapter;
        r5 = r5.getPageWidth(r1);
        r5 = r5 + r6;
        r2 = r2 + r5;
        r1 = r1 + 1;
        goto L_0x0059;
    L_0x0068:
        r0.offset = r2;
        r0 = r0.widthFactor;
        r0 = r0 + r6;
        r2 = r2 + r0;
        r0 = r1 + 1;
        r1 = r0;
        goto L_0x0029;
    L_0x0072:
        r1 = r12.position;
        if (r0 <= r1) goto L_0x00bb;
    L_0x0076:
        r1 = r11.mItems;
        r1 = r1.size();
        r3 = r1 + -1;
        r2 = r14.offset;
        r0 = r0 + -1;
        r1 = r0;
    L_0x0083:
        r0 = r12.position;
        if (r1 < r0) goto L_0x00bb;
    L_0x0087:
        if (r3 < 0) goto L_0x00bb;
    L_0x0089:
        r0 = r11.mItems;
        r0 = r0.get(r3);
        r0 = (android.support.v4.view.ViewPager.ItemInfo) r0;
    L_0x0091:
        r5 = r0.position;
        if (r1 >= r5) goto L_0x00a2;
    L_0x0095:
        if (r3 <= 0) goto L_0x00a2;
    L_0x0097:
        r3 = r3 + -1;
        r0 = r11.mItems;
        r0 = r0.get(r3);
        r0 = (android.support.v4.view.ViewPager.ItemInfo) r0;
        goto L_0x0091;
    L_0x00a2:
        r5 = r0.position;
        if (r1 <= r5) goto L_0x00b1;
    L_0x00a6:
        r5 = r11.mAdapter;
        r5 = r5.getPageWidth(r1);
        r5 = r5 + r6;
        r2 = r2 - r5;
        r1 = r1 + -1;
        goto L_0x00a2;
    L_0x00b1:
        r5 = r0.widthFactor;
        r5 = r5 + r6;
        r2 = r2 - r5;
        r0.offset = r2;
        r0 = r1 + -1;
        r1 = r0;
        goto L_0x0083;
    L_0x00bb:
        r0 = r11.mItems;
        r8 = r0.size();
        r1 = r12.offset;
        r0 = r12.position;
        r2 = r0 + -1;
        r0 = r12.position;
        if (r0 != 0) goto L_0x00fa;
    L_0x00cb:
        r0 = r12.offset;
    L_0x00cd:
        r11.mFirstOffset = r0;
        r0 = r12.position;
        r3 = r7 + -1;
        if (r0 != r3) goto L_0x00fe;
    L_0x00d5:
        r0 = r12.offset;
        r3 = r12.widthFactor;
        r0 = r0 + r3;
        r0 = r0 - r10;
    L_0x00db:
        r11.mLastOffset = r0;
        r0 = r13 + -1;
        r5 = r0;
    L_0x00e0:
        if (r5 < 0) goto L_0x0114;
    L_0x00e2:
        r0 = r11.mItems;
        r0 = r0.get(r5);
        r0 = (android.support.v4.view.ViewPager.ItemInfo) r0;
    L_0x00ea:
        r3 = r0.position;
        if (r2 <= r3) goto L_0x0102;
    L_0x00ee:
        r9 = r11.mAdapter;
        r3 = r2 + -1;
        r2 = r9.getPageWidth(r2);
        r2 = r2 + r6;
        r1 = r1 - r2;
        r2 = r3;
        goto L_0x00ea;
    L_0x00fa:
        r0 = -8388609; // 0xffffffffff7fffff float:-3.4028235E38 double:NaN;
        goto L_0x00cd;
    L_0x00fe:
        r0 = 2139095039; // 0x7f7fffff float:3.4028235E38 double:1.056853372E-314;
        goto L_0x00db;
    L_0x0102:
        r3 = r0.widthFactor;
        r3 = r3 + r6;
        r1 = r1 - r3;
        r0.offset = r1;
        r0 = r0.position;
        if (r0 != 0) goto L_0x010e;
    L_0x010c:
        r11.mFirstOffset = r1;
    L_0x010e:
        r0 = r5 + -1;
        r2 = r2 + -1;
        r5 = r0;
        goto L_0x00e0;
    L_0x0114:
        r0 = r12.offset;
        r1 = r12.widthFactor;
        r0 = r0 + r1;
        r1 = r0 + r6;
        r0 = r12.position;
        r2 = r0 + 1;
        r0 = r13 + 1;
        r5 = r0;
    L_0x0122:
        if (r5 >= r8) goto L_0x0154;
    L_0x0124:
        r0 = r11.mItems;
        r0 = r0.get(r5);
        r0 = (android.support.v4.view.ViewPager.ItemInfo) r0;
    L_0x012c:
        r3 = r0.position;
        if (r2 >= r3) goto L_0x013c;
    L_0x0130:
        r9 = r11.mAdapter;
        r3 = r2 + 1;
        r2 = r9.getPageWidth(r2);
        r2 = r2 + r6;
        r1 = r1 + r2;
        r2 = r3;
        goto L_0x012c;
    L_0x013c:
        r3 = r0.position;
        r9 = r7 + -1;
        if (r3 != r9) goto L_0x0148;
    L_0x0142:
        r3 = r0.widthFactor;
        r3 = r3 + r1;
        r3 = r3 - r10;
        r11.mLastOffset = r3;
    L_0x0148:
        r0.offset = r1;
        r0 = r0.widthFactor;
        r0 = r0 + r6;
        r1 = r1 + r0;
        r0 = r5 + 1;
        r2 = r2 + 1;
        r5 = r0;
        goto L_0x0122;
    L_0x0154:
        r11.mNeedCalculatePageOffsets = r4;
        return;
        */
        throw new UnsupportedOperationException("Method not decompiled: android.support.v4.view.ViewPager.calculatePageOffsets(android.support.v4.view.ViewPager$ItemInfo, int, android.support.v4.view.ViewPager$ItemInfo):void");
    }

    public Parcelable onSaveInstanceState() {
        SavedState savedState = new SavedState(super.onSaveInstanceState());
        savedState.position = this.mCurItem;
        if (this.mAdapter != null) {
            savedState.Nt = this.mAdapter.saveState();
        }
        return savedState;
    }

    public void onRestoreInstanceState(Parcelable parcelable) {
        if (parcelable instanceof SavedState) {
            SavedState savedState = (SavedState) parcelable;
            super.onRestoreInstanceState(savedState.LC);
            if (this.mAdapter != null) {
                this.mAdapter.restoreState(savedState.Nt, savedState.Nu);
                setCurrentItemInternal(savedState.position, false, true);
                return;
            }
            this.mRestoredCurItem = savedState.position;
            this.mRestoredAdapterState = savedState.Nt;
            this.mRestoredClassLoader = savedState.Nu;
            return;
        }
        super.onRestoreInstanceState(parcelable);
    }

    public void addView(View view, int i, LayoutParams layoutParams) {
        LayoutParams layoutParams2;
        if (checkLayoutParams(layoutParams)) {
            layoutParams2 = layoutParams;
        } else {
            layoutParams2 = generateLayoutParams(layoutParams);
        }
        LayoutParams layoutParams3 = (LayoutParams) layoutParams2;
        layoutParams3.Nq |= isDecorView(view);
        if (!this.mInLayout) {
            super.addView(view, i, layoutParams2);
        } else if (layoutParams3 == null || !layoutParams3.Nq) {
            layoutParams3.Nr = true;
            addViewInLayout(view, i, layoutParams2);
        } else {
            throw new IllegalStateException("Cannot add pager decor view during layout");
        }
    }

    private static boolean isDecorView(View view) {
        return view.getClass().getAnnotation(a.class) != null;
    }

    public void removeView(View view) {
        if (this.mInLayout) {
            removeViewInLayout(view);
        } else {
            super.removeView(view);
        }
    }

    /* Access modifiers changed, original: 0000 */
    public ItemInfo infoForChild(View view) {
        int i = 0;
        while (true) {
            int i2 = i;
            if (i2 >= this.mItems.size()) {
                return null;
            }
            ItemInfo itemInfo = (ItemInfo) this.mItems.get(i2);
            if (this.mAdapter.isViewFromObject(view, itemInfo.object)) {
                return itemInfo;
            }
            i = i2 + 1;
        }
    }

    /* Access modifiers changed, original: 0000 */
    public ItemInfo infoForAnyChild(View view) {
        while (true) {
            ViewPager parent = view.getParent();
            if (parent == this) {
                return infoForChild(view);
            }
            if (parent != null && (parent instanceof View)) {
                view = parent;
            }
        }
        return null;
    }

    /* Access modifiers changed, original: 0000 */
    public ItemInfo infoForPosition(int i) {
        int i2 = 0;
        while (true) {
            int i3 = i2;
            if (i3 >= this.mItems.size()) {
                return null;
            }
            ItemInfo itemInfo = (ItemInfo) this.mItems.get(i3);
            if (itemInfo.position == i) {
                return itemInfo;
            }
            i2 = i3 + 1;
        }
    }

    /* Access modifiers changed, original: protected */
    public void onAttachedToWindow() {
        super.onAttachedToWindow();
        this.mFirstLayout = true;
    }

    /* Access modifiers changed, original: protected */
    /* JADX WARNING: Removed duplicated region for block: B:38:0x00b5  */
    /* JADX WARNING: Removed duplicated region for block: B:32:0x00a1  */
    public void onMeasure(int r14, int r15) {
        /*
        r13 = this;
        r0 = 0;
        r0 = getDefaultSize(r0, r14);
        r1 = 0;
        r1 = getDefaultSize(r1, r15);
        r13.setMeasuredDimension(r0, r1);
        r0 = r13.getMeasuredWidth();
        r1 = r0 / 10;
        r2 = r13.mDefaultGutterSize;
        r1 = java.lang.Math.min(r1, r2);
        r13.mGutterSize = r1;
        r1 = r13.getPaddingLeft();
        r0 = r0 - r1;
        r1 = r13.getPaddingRight();
        r4 = r0 - r1;
        r0 = r13.getMeasuredHeight();
        r1 = r13.getPaddingTop();
        r0 = r0 - r1;
        r1 = r13.getPaddingBottom();
        r6 = r0 - r1;
        r10 = r13.getChildCount();
        r0 = 0;
        r9 = r0;
    L_0x003b:
        if (r9 >= r10) goto L_0x00bd;
    L_0x003d:
        r11 = r13.getChildAt(r9);
        r0 = r11.getVisibility();
        r1 = 8;
        if (r0 == r1) goto L_0x00a6;
    L_0x0049:
        r0 = r11.getLayoutParams();
        r0 = (android.support.v4.view.ViewPager.LayoutParams) r0;
        if (r0 == 0) goto L_0x00a6;
    L_0x0051:
        r1 = r0.Nq;
        if (r1 == 0) goto L_0x00a6;
    L_0x0055:
        r1 = r0.gravity;
        r5 = r1 & 7;
        r1 = r0.gravity;
        r3 = r1 & 112;
        r2 = -2147483648; // 0xffffffff80000000 float:-0.0 double:NaN;
        r1 = -2147483648; // 0xffffffff80000000 float:-0.0 double:NaN;
        r7 = 48;
        if (r3 == r7) goto L_0x0069;
    L_0x0065:
        r7 = 80;
        if (r3 != r7) goto L_0x00aa;
    L_0x0069:
        r3 = 1;
        r8 = r3;
    L_0x006b:
        r3 = 3;
        if (r5 == r3) goto L_0x0071;
    L_0x006e:
        r3 = 5;
        if (r5 != r3) goto L_0x00ad;
    L_0x0071:
        r3 = 1;
        r7 = r3;
    L_0x0073:
        if (r8 == 0) goto L_0x00b0;
    L_0x0075:
        r2 = 1073741824; // 0x40000000 float:2.0 double:5.304989477E-315;
    L_0x0077:
        r3 = r0.width;
        r5 = -2;
        if (r3 == r5) goto L_0x0110;
    L_0x007c:
        r5 = 1073741824; // 0x40000000 float:2.0 double:5.304989477E-315;
        r2 = r0.width;
        r3 = -1;
        if (r2 == r3) goto L_0x010d;
    L_0x0083:
        r2 = r0.width;
        r3 = r2;
    L_0x0086:
        r2 = r0.height;
        r12 = -2;
        if (r2 == r12) goto L_0x010b;
    L_0x008b:
        r1 = 1073741824; // 0x40000000 float:2.0 double:5.304989477E-315;
        r2 = r0.height;
        r12 = -1;
        if (r2 == r12) goto L_0x010b;
    L_0x0092:
        r0 = r0.height;
    L_0x0094:
        r2 = android.view.View.MeasureSpec.makeMeasureSpec(r3, r5);
        r0 = android.view.View.MeasureSpec.makeMeasureSpec(r0, r1);
        r11.measure(r2, r0);
        if (r8 == 0) goto L_0x00b5;
    L_0x00a1:
        r0 = r11.getMeasuredHeight();
        r6 = r6 - r0;
    L_0x00a6:
        r0 = r9 + 1;
        r9 = r0;
        goto L_0x003b;
    L_0x00aa:
        r3 = 0;
        r8 = r3;
        goto L_0x006b;
    L_0x00ad:
        r3 = 0;
        r7 = r3;
        goto L_0x0073;
    L_0x00b0:
        if (r7 == 0) goto L_0x0077;
    L_0x00b2:
        r1 = 1073741824; // 0x40000000 float:2.0 double:5.304989477E-315;
        goto L_0x0077;
    L_0x00b5:
        if (r7 == 0) goto L_0x00a6;
    L_0x00b7:
        r0 = r11.getMeasuredWidth();
        r4 = r4 - r0;
        goto L_0x00a6;
    L_0x00bd:
        r0 = 1073741824; // 0x40000000 float:2.0 double:5.304989477E-315;
        r0 = android.view.View.MeasureSpec.makeMeasureSpec(r4, r0);
        r13.mChildWidthMeasureSpec = r0;
        r0 = 1073741824; // 0x40000000 float:2.0 double:5.304989477E-315;
        r0 = android.view.View.MeasureSpec.makeMeasureSpec(r6, r0);
        r13.mChildHeightMeasureSpec = r0;
        r0 = 1;
        r13.mInLayout = r0;
        r13.populate();
        r0 = 0;
        r13.mInLayout = r0;
        r2 = r13.getChildCount();
        r0 = 0;
        r1 = r0;
    L_0x00dc:
        if (r1 >= r2) goto L_0x010a;
    L_0x00de:
        r3 = r13.getChildAt(r1);
        r0 = r3.getVisibility();
        r5 = 8;
        if (r0 == r5) goto L_0x0106;
    L_0x00ea:
        r0 = r3.getLayoutParams();
        r0 = (android.support.v4.view.ViewPager.LayoutParams) r0;
        if (r0 == 0) goto L_0x00f6;
    L_0x00f2:
        r5 = r0.Nq;
        if (r5 != 0) goto L_0x0106;
    L_0x00f6:
        r5 = (float) r4;
        r0 = r0.widthFactor;
        r0 = r0 * r5;
        r0 = (int) r0;
        r5 = 1073741824; // 0x40000000 float:2.0 double:5.304989477E-315;
        r0 = android.view.View.MeasureSpec.makeMeasureSpec(r0, r5);
        r5 = r13.mChildHeightMeasureSpec;
        r3.measure(r0, r5);
    L_0x0106:
        r0 = r1 + 1;
        r1 = r0;
        goto L_0x00dc;
    L_0x010a:
        return;
    L_0x010b:
        r0 = r6;
        goto L_0x0094;
    L_0x010d:
        r3 = r4;
        goto L_0x0086;
    L_0x0110:
        r3 = r4;
        r5 = r2;
        goto L_0x0086;
        */
        throw new UnsupportedOperationException("Method not decompiled: android.support.v4.view.ViewPager.onMeasure(int, int):void");
    }

    /* Access modifiers changed, original: protected */
    public void onSizeChanged(int i, int i2, int i3, int i4) {
        super.onSizeChanged(i, i2, i3, i4);
        if (i != i3) {
            recomputeScrollPosition(i, i3, this.mPageMargin, this.mPageMargin);
        }
    }

    private void recomputeScrollPosition(int i, int i2, int i3, int i4) {
        if (i2 <= 0 || this.mItems.isEmpty()) {
            ItemInfo infoForPosition = infoForPosition(this.mCurItem);
            int min = (int) ((infoForPosition != null ? Math.min(infoForPosition.offset, this.mLastOffset) : 0.0f) * ((float) ((i - getPaddingLeft()) - getPaddingRight())));
            if (min != getScrollX()) {
                completeScroll(false);
                scrollTo(min, getScrollY());
            }
        } else if (this.mScroller.isFinished()) {
            scrollTo((int) (((float) (((i - getPaddingLeft()) - getPaddingRight()) + i3)) * (((float) getScrollX()) / ((float) (((i2 - getPaddingLeft()) - getPaddingRight()) + i4)))), getScrollY());
        } else {
            this.mScroller.setFinalX(getCurrentItem() * getClientWidth());
        }
    }

    /* Access modifiers changed, original: protected */
    public void onLayout(boolean z, int i, int i2, int i3, int i4) {
        LayoutParams layoutParams;
        int max;
        int i5;
        int childCount = getChildCount();
        int i6 = i3 - i;
        int i7 = i4 - i2;
        int paddingLeft = getPaddingLeft();
        int paddingTop = getPaddingTop();
        int paddingRight = getPaddingRight();
        int paddingBottom = getPaddingBottom();
        int scrollX = getScrollX();
        int i8 = 0;
        int i9 = 0;
        while (i9 < childCount) {
            int i10;
            int max2;
            View childAt = getChildAt(i9);
            if (childAt.getVisibility() != 8) {
                layoutParams = (LayoutParams) childAt.getLayoutParams();
                if (layoutParams.Nq) {
                    int i11 = layoutParams.gravity & 112;
                    switch (layoutParams.gravity & 7) {
                        case 1:
                            max = Math.max((i6 - childAt.getMeasuredWidth()) / 2, paddingLeft);
                            i5 = paddingRight;
                            i10 = paddingLeft;
                            break;
                        case 3:
                            i10 = paddingLeft + childAt.getMeasuredWidth();
                            max = paddingLeft;
                            i5 = paddingRight;
                            break;
                        case 5:
                            max = (i6 - paddingRight) - childAt.getMeasuredWidth();
                            i5 = paddingRight + childAt.getMeasuredWidth();
                            i10 = paddingLeft;
                            break;
                        default:
                            max = paddingLeft;
                            i5 = paddingRight;
                            i10 = paddingLeft;
                            break;
                    }
                    switch (i11) {
                        case 16:
                            max2 = Math.max((i7 - childAt.getMeasuredHeight()) / 2, paddingTop);
                            paddingRight = paddingTop;
                            break;
                        case 48:
                            paddingRight = paddingTop + childAt.getMeasuredHeight();
                            max2 = paddingTop;
                            break;
                        case 80:
                            max2 = (i7 - paddingBottom) - childAt.getMeasuredHeight();
                            paddingBottom += childAt.getMeasuredHeight();
                            paddingRight = paddingTop;
                            break;
                        default:
                            max2 = paddingTop;
                            paddingRight = paddingTop;
                            break;
                    }
                    paddingTop = max + scrollX;
                    childAt.layout(paddingTop, max2, childAt.getMeasuredWidth() + paddingTop, childAt.getMeasuredHeight() + max2);
                    max2 = i8 + 1;
                    paddingTop = paddingRight;
                    i9++;
                    i8 = max2;
                    paddingRight = i5;
                    paddingLeft = i10;
                }
            }
            max2 = i8;
            i5 = paddingRight;
            i10 = paddingLeft;
            i9++;
            i8 = max2;
            paddingRight = i5;
            paddingLeft = i10;
        }
        i5 = (i6 - paddingLeft) - paddingRight;
        for (paddingRight = 0; paddingRight < childCount; paddingRight++) {
            View childAt2 = getChildAt(paddingRight);
            if (childAt2.getVisibility() != 8) {
                layoutParams = (LayoutParams) childAt2.getLayoutParams();
                if (!layoutParams.Nq) {
                    ItemInfo infoForChild = infoForChild(childAt2);
                    if (infoForChild != null) {
                        max = ((int) (infoForChild.offset * ((float) i5))) + paddingLeft;
                        if (layoutParams.Nr) {
                            layoutParams.Nr = false;
                            childAt2.measure(MeasureSpec.makeMeasureSpec((int) (layoutParams.widthFactor * ((float) i5)), 1073741824), MeasureSpec.makeMeasureSpec((i7 - paddingTop) - paddingBottom, 1073741824));
                        }
                        childAt2.layout(max, paddingTop, childAt2.getMeasuredWidth() + max, childAt2.getMeasuredHeight() + paddingTop);
                    }
                }
            }
        }
        this.mTopPageBounds = paddingTop;
        this.mBottomPageBounds = i7 - paddingBottom;
        this.mDecorChildCount = i8;
        if (this.mFirstLayout) {
            scrollToItem(this.mCurItem, false, 0, false);
        }
        this.mFirstLayout = false;
    }

    public void computeScroll() {
        this.mIsScrollStarted = true;
        if (this.mScroller.isFinished() || !this.mScroller.computeScrollOffset()) {
            completeScroll(true);
            return;
        }
        int scrollX = getScrollX();
        int scrollY = getScrollY();
        int currX = this.mScroller.getCurrX();
        int currY = this.mScroller.getCurrY();
        if (!(scrollX == currX && scrollY == currY)) {
            scrollTo(currX, currY);
            if (!pageScrolled(currX)) {
                this.mScroller.abortAnimation();
                scrollTo(0, currY);
            }
        }
        s.R(this);
    }

    private boolean pageScrolled(int i) {
        if (this.mItems.size() != 0) {
            ItemInfo infoForCurrentScrollPosition = infoForCurrentScrollPosition();
            int clientWidth = getClientWidth();
            int i2 = this.mPageMargin + clientWidth;
            float f = ((float) this.mPageMargin) / ((float) clientWidth);
            int i3 = infoForCurrentScrollPosition.position;
            float f2 = ((((float) i) / ((float) clientWidth)) - infoForCurrentScrollPosition.offset) / (infoForCurrentScrollPosition.widthFactor + f);
            clientWidth = (int) (((float) i2) * f2);
            this.mCalledSuper = false;
            onPageScrolled(i3, f2, clientWidth);
            if (this.mCalledSuper) {
                return true;
            }
            throw new IllegalStateException("onPageScrolled did not call superclass implementation");
        } else if (this.mFirstLayout) {
            return false;
        } else {
            this.mCalledSuper = false;
            onPageScrolled(0, 0.0f, 0);
            if (this.mCalledSuper) {
                return false;
            }
            throw new IllegalStateException("onPageScrolled did not call superclass implementation");
        }
    }

    /* Access modifiers changed, original: protected */
    public void onPageScrolled(int i, float f, int i2) {
        int paddingLeft;
        int paddingRight;
        int i3;
        if (this.mDecorChildCount > 0) {
            int scrollX = getScrollX();
            paddingLeft = getPaddingLeft();
            paddingRight = getPaddingRight();
            int width = getWidth();
            int childCount = getChildCount();
            int i4 = 0;
            while (i4 < childCount) {
                View childAt = getChildAt(i4);
                LayoutParams layoutParams = (LayoutParams) childAt.getLayoutParams();
                if (layoutParams.Nq) {
                    int max;
                    switch (layoutParams.gravity & 7) {
                        case 1:
                            max = Math.max((width - childAt.getMeasuredWidth()) / 2, paddingLeft);
                            i3 = paddingLeft;
                            break;
                        case 3:
                            i3 = paddingLeft + childAt.getWidth();
                            max = paddingLeft;
                            break;
                        case 5:
                            max = (width - paddingRight) - childAt.getMeasuredWidth();
                            paddingRight += childAt.getMeasuredWidth();
                            i3 = paddingLeft;
                            break;
                        default:
                            max = paddingLeft;
                            i3 = paddingLeft;
                            break;
                    }
                    max = (max + scrollX) - childAt.getLeft();
                    if (max != 0) {
                        childAt.offsetLeftAndRight(max);
                    }
                } else {
                    i3 = paddingLeft;
                }
                i4++;
                paddingLeft = i3;
            }
        }
        dispatchOnPageScrolled(i, f, i2);
        if (this.mPageTransformer != null) {
            paddingRight = getScrollX();
            i3 = getChildCount();
            for (paddingLeft = 0; paddingLeft < i3; paddingLeft++) {
                View childAt2 = getChildAt(paddingLeft);
                if (!((LayoutParams) childAt2.getLayoutParams()).Nq) {
                    this.mPageTransformer.j(childAt2, ((float) (childAt2.getLeft() - paddingRight)) / ((float) getClientWidth()));
                }
            }
        }
        this.mCalledSuper = true;
    }

    private void dispatchOnPageScrolled(int i, float f, int i2) {
        if (this.mOnPageChangeListener != null) {
            this.mOnPageChangeListener.onPageScrolled(i, f, i2);
        }
        if (this.mOnPageChangeListeners != null) {
            int size = this.mOnPageChangeListeners.size();
            for (int i3 = 0; i3 < size; i3++) {
                OnPageChangeListener onPageChangeListener = (OnPageChangeListener) this.mOnPageChangeListeners.get(i3);
                if (onPageChangeListener != null) {
                    onPageChangeListener.onPageScrolled(i, f, i2);
                }
            }
        }
        if (this.mInternalPageChangeListener != null) {
            this.mInternalPageChangeListener.onPageScrolled(i, f, i2);
        }
    }

    private void dispatchOnPageSelected(int i) {
        if (this.mOnPageChangeListener != null) {
            this.mOnPageChangeListener.onPageSelected(i);
        }
        if (this.mOnPageChangeListeners != null) {
            int size = this.mOnPageChangeListeners.size();
            for (int i2 = 0; i2 < size; i2++) {
                OnPageChangeListener onPageChangeListener = (OnPageChangeListener) this.mOnPageChangeListeners.get(i2);
                if (onPageChangeListener != null) {
                    onPageChangeListener.onPageSelected(i);
                }
            }
        }
        if (this.mInternalPageChangeListener != null) {
            this.mInternalPageChangeListener.onPageSelected(i);
        }
    }

    private void dispatchOnScrollStateChanged(int i) {
        if (this.mOnPageChangeListener != null) {
            this.mOnPageChangeListener.onPageScrollStateChanged(i);
        }
        if (this.mOnPageChangeListeners != null) {
            int size = this.mOnPageChangeListeners.size();
            for (int i2 = 0; i2 < size; i2++) {
                OnPageChangeListener onPageChangeListener = (OnPageChangeListener) this.mOnPageChangeListeners.get(i2);
                if (onPageChangeListener != null) {
                    onPageChangeListener.onPageScrollStateChanged(i);
                }
            }
        }
        if (this.mInternalPageChangeListener != null) {
            this.mInternalPageChangeListener.onPageScrollStateChanged(i);
        }
    }

    private void completeScroll(boolean z) {
        int scrollX;
        boolean z2 = this.mScrollState == 2;
        if (z2) {
            boolean z3;
            setScrollingCacheEnabled(false);
            if (this.mScroller.isFinished()) {
                z3 = false;
            } else {
                z3 = true;
            }
            if (z3) {
                this.mScroller.abortAnimation();
                scrollX = getScrollX();
                int scrollY = getScrollY();
                int currX = this.mScroller.getCurrX();
                int currY = this.mScroller.getCurrY();
                if (!(scrollX == currX && scrollY == currY)) {
                    scrollTo(currX, currY);
                    if (currX != scrollX) {
                        pageScrolled(currX);
                    }
                }
            }
        }
        this.mPopulatePending = false;
        boolean z4 = z2;
        for (scrollX = 0; scrollX < this.mItems.size(); scrollX++) {
            ItemInfo itemInfo = (ItemInfo) this.mItems.get(scrollX);
            if (itemInfo.scrolling) {
                itemInfo.scrolling = false;
                z4 = true;
            }
        }
        if (!z4) {
            return;
        }
        if (z) {
            s.b(this, this.mEndScrollRunnable);
        } else {
            this.mEndScrollRunnable.run();
        }
    }

    private boolean isGutterDrag(float f, float f2) {
        return (f < ((float) this.mGutterSize) && f2 > 0.0f) || (f > ((float) (getWidth() - this.mGutterSize)) && f2 < 0.0f);
    }

    private void enableLayers(boolean z) {
        int childCount = getChildCount();
        for (int i = 0; i < childCount; i++) {
            int i2;
            if (z) {
                i2 = this.mPageTransformerLayerType;
            } else {
                i2 = 0;
            }
            getChildAt(i).setLayerType(i2, null);
        }
    }

    public boolean onInterceptTouchEvent(MotionEvent motionEvent) {
        int action = motionEvent.getAction() & XWalkEnvironment.SDK_SUPPORT_INVOKE_RUNTIME_MIN_APKVERSION;
        if (action == 3 || action == 1) {
            resetTouch();
            return false;
        }
        if (action != 0) {
            if (this.mIsBeingDragged) {
                return true;
            }
            if (this.mIsUnableToDrag) {
                return false;
            }
        }
        switch (action) {
            case 0:
                float x = motionEvent.getX();
                this.mInitialMotionX = x;
                this.mLastMotionX = x;
                x = motionEvent.getY();
                this.mInitialMotionY = x;
                this.mLastMotionY = x;
                this.mActivePointerId = motionEvent.getPointerId(0);
                this.mIsUnableToDrag = false;
                this.mIsScrollStarted = true;
                this.mScroller.computeScrollOffset();
                if (this.mScrollState == 2 && Math.abs(this.mScroller.getFinalX() - this.mScroller.getCurrX()) > this.mCloseEnough) {
                    this.mScroller.abortAnimation();
                    this.mPopulatePending = false;
                    populate();
                    this.mIsBeingDragged = true;
                    requestParentDisallowInterceptTouchEvent(true);
                    setScrollState(1);
                    break;
                }
                completeScroll(false);
                this.mIsBeingDragged = false;
                break;
            case 2:
                action = this.mActivePointerId;
                if (action != -1) {
                    action = motionEvent.findPointerIndex(action);
                    float x2 = motionEvent.getX(action);
                    float f = x2 - this.mLastMotionX;
                    float abs = Math.abs(f);
                    float y = motionEvent.getY(action);
                    float abs2 = Math.abs(y - this.mInitialMotionY);
                    if (!(f == 0.0f || isGutterDrag(this.mLastMotionX, f))) {
                        if (canScroll(this, false, (int) f, (int) x2, (int) y)) {
                            this.mLastMotionX = x2;
                            this.mLastMotionY = y;
                            this.mIsUnableToDrag = true;
                            return false;
                        }
                    }
                    if (abs > ((float) this.mTouchSlop) && 0.5f * abs > abs2) {
                        this.mIsBeingDragged = true;
                        requestParentDisallowInterceptTouchEvent(true);
                        setScrollState(1);
                        this.mLastMotionX = f > 0.0f ? this.mInitialMotionX + ((float) this.mTouchSlop) : this.mInitialMotionX - ((float) this.mTouchSlop);
                        this.mLastMotionY = y;
                        setScrollingCacheEnabled(true);
                    } else if (abs2 > ((float) this.mTouchSlop)) {
                        this.mIsUnableToDrag = true;
                    }
                    if (this.mIsBeingDragged && performDrag(x2)) {
                        s.R(this);
                        break;
                    }
                }
                break;
            case 6:
                onSecondaryPointerUp(motionEvent);
                break;
        }
        if (this.mVelocityTracker == null) {
            this.mVelocityTracker = VelocityTracker.obtain();
        }
        this.mVelocityTracker.addMovement(motionEvent);
        return this.mIsBeingDragged;
    }

    public boolean onTouchEvent(MotionEvent motionEvent) {
        boolean z = false;
        if (this.mFakeDragging) {
            return true;
        }
        if (motionEvent.getAction() == 0 && motionEvent.getEdgeFlags() != 0) {
            return false;
        }
        if (this.mAdapter == null || this.mAdapter.getCount() == 0) {
            return false;
        }
        if (this.mVelocityTracker == null) {
            this.mVelocityTracker = VelocityTracker.obtain();
        }
        this.mVelocityTracker.addMovement(motionEvent);
        float x;
        int xVelocity;
        switch (motionEvent.getAction() & XWalkEnvironment.SDK_SUPPORT_INVOKE_RUNTIME_MIN_APKVERSION) {
            case 0:
                this.mScroller.abortAnimation();
                this.mPopulatePending = false;
                populate();
                x = motionEvent.getX();
                this.mInitialMotionX = x;
                this.mLastMotionX = x;
                x = motionEvent.getY();
                this.mInitialMotionY = x;
                this.mLastMotionY = x;
                this.mActivePointerId = motionEvent.getPointerId(0);
                break;
            case 1:
                if (this.mIsBeingDragged) {
                    VelocityTracker velocityTracker = this.mVelocityTracker;
                    velocityTracker.computeCurrentVelocity(1000, (float) this.mMaximumVelocity);
                    xVelocity = (int) velocityTracker.getXVelocity(this.mActivePointerId);
                    this.mPopulatePending = true;
                    int clientWidth = getClientWidth();
                    int scrollX = getScrollX();
                    ItemInfo infoForCurrentScrollPosition = infoForCurrentScrollPosition();
                    setCurrentItemInternal(determineTargetPage(infoForCurrentScrollPosition.position, ((((float) scrollX) / ((float) clientWidth)) - infoForCurrentScrollPosition.offset) / (infoForCurrentScrollPosition.widthFactor + (((float) this.mPageMargin) / ((float) clientWidth))), xVelocity, (int) (motionEvent.getX(motionEvent.findPointerIndex(this.mActivePointerId)) - this.mInitialMotionX)), true, true, xVelocity);
                    z = resetTouch();
                    break;
                }
                break;
            case 2:
                if (!this.mIsBeingDragged) {
                    xVelocity = motionEvent.findPointerIndex(this.mActivePointerId);
                    if (xVelocity == -1) {
                        z = resetTouch();
                        break;
                    }
                    float x2 = motionEvent.getX(xVelocity);
                    float abs = Math.abs(x2 - this.mLastMotionX);
                    float y = motionEvent.getY(xVelocity);
                    x = Math.abs(y - this.mLastMotionY);
                    if (abs > ((float) this.mTouchSlop) && abs > x) {
                        this.mIsBeingDragged = true;
                        requestParentDisallowInterceptTouchEvent(true);
                        if (x2 - this.mInitialMotionX > 0.0f) {
                            x = this.mInitialMotionX + ((float) this.mTouchSlop);
                        } else {
                            x = this.mInitialMotionX - ((float) this.mTouchSlop);
                        }
                        this.mLastMotionX = x;
                        this.mLastMotionY = y;
                        setScrollState(1);
                        setScrollingCacheEnabled(true);
                        ViewParent parent = getParent();
                        if (parent != null) {
                            parent.requestDisallowInterceptTouchEvent(true);
                        }
                    }
                }
                if (this.mIsBeingDragged) {
                    z = performDrag(motionEvent.getX(motionEvent.findPointerIndex(this.mActivePointerId))) | 0;
                    break;
                }
                break;
            case 3:
                if (this.mIsBeingDragged) {
                    scrollToItem(this.mCurItem, true, 0, false);
                    z = resetTouch();
                    break;
                }
                break;
            case 5:
                xVelocity = motionEvent.getActionIndex();
                this.mLastMotionX = motionEvent.getX(xVelocity);
                this.mActivePointerId = motionEvent.getPointerId(xVelocity);
                break;
            case 6:
                onSecondaryPointerUp(motionEvent);
                this.mLastMotionX = motionEvent.getX(motionEvent.findPointerIndex(this.mActivePointerId));
                break;
        }
        if (z) {
            s.R(this);
        }
        return true;
    }

    private boolean resetTouch() {
        this.mActivePointerId = -1;
        endDrag();
        this.mLeftEdge.onRelease();
        this.mRightEdge.onRelease();
        return this.mLeftEdge.isFinished() || this.mRightEdge.isFinished();
    }

    private void requestParentDisallowInterceptTouchEvent(boolean z) {
        ViewParent parent = getParent();
        if (parent != null) {
            parent.requestDisallowInterceptTouchEvent(z);
        }
    }

    private boolean performDrag(float f) {
        int i;
        float f2;
        int i2;
        boolean z = true;
        float f3 = this.mLastMotionX - f;
        this.mLastMotionX = f;
        float scrollX = ((float) getScrollX()) + f3;
        int clientWidth = getClientWidth();
        float f4 = ((float) clientWidth) * this.mFirstOffset;
        float f5 = ((float) clientWidth) * this.mLastOffset;
        ItemInfo itemInfo = (ItemInfo) this.mItems.get(0);
        ItemInfo itemInfo2 = (ItemInfo) this.mItems.get(this.mItems.size() - 1);
        if (itemInfo.position != 0) {
            f4 = ((float) clientWidth) * itemInfo.offset;
            i = 0;
        } else {
            boolean i3 = true;
        }
        if (itemInfo2.position != this.mAdapter.getCount() - 1) {
            f2 = itemInfo2.offset * ((float) clientWidth);
            i2 = 0;
        } else {
            boolean i22 = true;
            f2 = f5;
        }
        if (scrollX < f4) {
            if (i3 != 0) {
                this.mLeftEdge.onPull(Math.abs(f4 - scrollX) / ((float) clientWidth));
            } else {
                z = false;
            }
        } else if (scrollX > f2) {
            if (i22 != 0) {
                this.mRightEdge.onPull(Math.abs(scrollX - f2) / ((float) clientWidth));
            } else {
                z = false;
            }
            f4 = f2;
        } else {
            z = false;
            f4 = scrollX;
        }
        this.mLastMotionX += f4 - ((float) ((int) f4));
        scrollTo((int) f4, getScrollY());
        pageScrolled((int) f4);
        return z;
    }

    private ItemInfo infoForCurrentScrollPosition() {
        float f;
        int clientWidth = getClientWidth();
        float scrollX = clientWidth > 0 ? ((float) getScrollX()) / ((float) clientWidth) : 0.0f;
        if (clientWidth > 0) {
            f = ((float) this.mPageMargin) / ((float) clientWidth);
        } else {
            f = 0.0f;
        }
        int i = -1;
        Object obj = 1;
        int i2 = 0;
        ItemInfo itemInfo = null;
        float f2 = 0.0f;
        float f3 = 0.0f;
        while (i2 < this.mItems.size()) {
            ItemInfo itemInfo2;
            ItemInfo itemInfo3 = (ItemInfo) this.mItems.get(i2);
            if (obj != null || itemInfo3.position == i + 1) {
                itemInfo2 = itemInfo3;
            } else {
                itemInfo3 = this.mTempItem;
                itemInfo3.offset = (f3 + f2) + f;
                itemInfo3.position = i + 1;
                itemInfo3.widthFactor = this.mAdapter.getPageWidth(itemInfo3.position);
                i2--;
                itemInfo2 = itemInfo3;
            }
            f3 = itemInfo2.offset;
            float f4 = (itemInfo2.widthFactor + f3) + f;
            if (obj == null && scrollX < f3) {
                return itemInfo;
            }
            if (scrollX < f4 || i2 == this.mItems.size() - 1) {
                return itemInfo2;
            }
            i = itemInfo2.position;
            f2 = itemInfo2.widthFactor;
            i2++;
            itemInfo = itemInfo2;
            obj = null;
        }
        return itemInfo;
    }

    private int determineTargetPage(int i, float f, int i2, int i3) {
        if (Math.abs(i3) <= this.mFlingDistance || Math.abs(i2) <= this.mMinimumVelocity) {
            i += (int) ((i >= this.mCurItem ? 0.4f : 0.6f) + f);
        } else if (i2 <= 0) {
            i++;
        }
        if (this.mItems.size() <= 0) {
            return i;
        }
        return Math.max(((ItemInfo) this.mItems.get(0)).position, Math.min(i, ((ItemInfo) this.mItems.get(this.mItems.size() - 1)).position));
    }

    public void draw(Canvas canvas) {
        super.draw(canvas);
        int i = 0;
        int overScrollMode = getOverScrollMode();
        if (overScrollMode == 0 || (overScrollMode == 1 && this.mAdapter != null && this.mAdapter.getCount() > 1)) {
            int width;
            if (!this.mLeftEdge.isFinished()) {
                overScrollMode = canvas.save();
                i = (getHeight() - getPaddingTop()) - getPaddingBottom();
                width = getWidth();
                canvas.rotate(270.0f);
                canvas.translate((float) ((-i) + getPaddingTop()), this.mFirstOffset * ((float) width));
                this.mLeftEdge.setSize(i, width);
                i = this.mLeftEdge.draw(canvas) | 0;
                canvas.restoreToCount(overScrollMode);
            }
            if (!this.mRightEdge.isFinished()) {
                overScrollMode = canvas.save();
                width = getWidth();
                int height = (getHeight() - getPaddingTop()) - getPaddingBottom();
                canvas.rotate(90.0f);
                canvas.translate((float) (-getPaddingTop()), (-(this.mLastOffset + 1.0f)) * ((float) width));
                this.mRightEdge.setSize(height, width);
                i |= this.mRightEdge.draw(canvas);
                canvas.restoreToCount(overScrollMode);
            }
        } else {
            this.mLeftEdge.finish();
            this.mRightEdge.finish();
        }
        if (i != 0) {
            s.R(this);
        }
    }

    /* Access modifiers changed, original: protected */
    public void onDraw(Canvas canvas) {
        super.onDraw(canvas);
        if (this.mPageMargin > 0 && this.mMarginDrawable != null && this.mItems.size() > 0 && this.mAdapter != null) {
            int scrollX = getScrollX();
            int width = getWidth();
            float f = ((float) this.mPageMargin) / ((float) width);
            ItemInfo itemInfo = (ItemInfo) this.mItems.get(0);
            float f2 = itemInfo.offset;
            int size = this.mItems.size();
            int i = itemInfo.position;
            int i2 = ((ItemInfo) this.mItems.get(size - 1)).position;
            int i3 = i;
            int i4 = 0;
            while (i3 < i2) {
                float f3;
                while (i3 > itemInfo.position && i4 < size) {
                    i4++;
                    itemInfo = (ItemInfo) this.mItems.get(i4);
                }
                if (i3 == itemInfo.position) {
                    f3 = (itemInfo.offset + itemInfo.widthFactor) * ((float) width);
                    f2 = (itemInfo.offset + itemInfo.widthFactor) + f;
                } else {
                    float pageWidth = this.mAdapter.getPageWidth(i3);
                    f3 = (f2 + pageWidth) * ((float) width);
                    f2 += pageWidth + f;
                }
                if (((float) this.mPageMargin) + f3 > ((float) scrollX)) {
                    this.mMarginDrawable.setBounds(Math.round(f3), this.mTopPageBounds, Math.round(((float) this.mPageMargin) + f3), this.mBottomPageBounds);
                    this.mMarginDrawable.draw(canvas);
                }
                if (f3 <= ((float) (scrollX + width))) {
                    i3++;
                } else {
                    return;
                }
            }
        }
    }

    public boolean beginFakeDrag() {
        if (this.mIsBeingDragged) {
            return false;
        }
        this.mFakeDragging = true;
        setScrollState(1);
        this.mLastMotionX = 0.0f;
        this.mInitialMotionX = 0.0f;
        if (this.mVelocityTracker == null) {
            this.mVelocityTracker = VelocityTracker.obtain();
        } else {
            this.mVelocityTracker.clear();
        }
        long uptimeMillis = SystemClock.uptimeMillis();
        MotionEvent obtain = MotionEvent.obtain(uptimeMillis, uptimeMillis, 0, 0.0f, 0.0f, 0);
        this.mVelocityTracker.addMovement(obtain);
        obtain.recycle();
        this.mFakeDragBeginTime = uptimeMillis;
        return true;
    }

    public void endFakeDrag() {
        if (this.mFakeDragging) {
            if (this.mAdapter != null) {
                VelocityTracker velocityTracker = this.mVelocityTracker;
                velocityTracker.computeCurrentVelocity(1000, (float) this.mMaximumVelocity);
                int xVelocity = (int) velocityTracker.getXVelocity(this.mActivePointerId);
                this.mPopulatePending = true;
                int clientWidth = getClientWidth();
                int scrollX = getScrollX();
                ItemInfo infoForCurrentScrollPosition = infoForCurrentScrollPosition();
                setCurrentItemInternal(determineTargetPage(infoForCurrentScrollPosition.position, ((((float) scrollX) / ((float) clientWidth)) - infoForCurrentScrollPosition.offset) / infoForCurrentScrollPosition.widthFactor, xVelocity, (int) (this.mLastMotionX - this.mInitialMotionX)), true, true, xVelocity);
            }
            endDrag();
            this.mFakeDragging = false;
            return;
        }
        throw new IllegalStateException("No fake drag in progress. Call beginFakeDrag first.");
    }

    public void fakeDragBy(float f) {
        if (!this.mFakeDragging) {
            throw new IllegalStateException("No fake drag in progress. Call beginFakeDrag first.");
        } else if (this.mAdapter != null) {
            float f2;
            float f3;
            this.mLastMotionX += f;
            float scrollX = ((float) getScrollX()) - f;
            int clientWidth = getClientWidth();
            float f4 = ((float) clientWidth) * this.mFirstOffset;
            float f5 = ((float) clientWidth) * this.mLastOffset;
            ItemInfo itemInfo = (ItemInfo) this.mItems.get(0);
            ItemInfo itemInfo2 = (ItemInfo) this.mItems.get(this.mItems.size() - 1);
            if (itemInfo.position != 0) {
                f2 = itemInfo.offset * ((float) clientWidth);
            } else {
                f2 = f4;
            }
            if (itemInfo2.position != this.mAdapter.getCount() - 1) {
                f3 = itemInfo2.offset * ((float) clientWidth);
            } else {
                f3 = f5;
            }
            if (scrollX >= f2) {
                if (scrollX > f3) {
                    f2 = f3;
                } else {
                    f2 = scrollX;
                }
            }
            this.mLastMotionX += f2 - ((float) ((int) f2));
            scrollTo((int) f2, getScrollY());
            pageScrolled((int) f2);
            MotionEvent obtain = MotionEvent.obtain(this.mFakeDragBeginTime, SystemClock.uptimeMillis(), 2, this.mLastMotionX, 0.0f, 0);
            this.mVelocityTracker.addMovement(obtain);
            obtain.recycle();
        }
    }

    public boolean isFakeDragging() {
        return this.mFakeDragging;
    }

    private void onSecondaryPointerUp(MotionEvent motionEvent) {
        int actionIndex = motionEvent.getActionIndex();
        if (motionEvent.getPointerId(actionIndex) == this.mActivePointerId) {
            actionIndex = actionIndex == 0 ? 1 : 0;
            this.mLastMotionX = motionEvent.getX(actionIndex);
            this.mActivePointerId = motionEvent.getPointerId(actionIndex);
            if (this.mVelocityTracker != null) {
                this.mVelocityTracker.clear();
            }
        }
    }

    private void endDrag() {
        this.mIsBeingDragged = false;
        this.mIsUnableToDrag = false;
        if (this.mVelocityTracker != null) {
            this.mVelocityTracker.recycle();
            this.mVelocityTracker = null;
        }
    }

    private void setScrollingCacheEnabled(boolean z) {
        if (this.mScrollingCacheEnabled != z) {
            this.mScrollingCacheEnabled = z;
        }
    }

    public boolean canScrollHorizontally(int i) {
        if (this.mAdapter == null) {
            return false;
        }
        int clientWidth = getClientWidth();
        int scrollX = getScrollX();
        if (i < 0) {
            if (scrollX > ((int) (((float) clientWidth) * this.mFirstOffset))) {
                return true;
            }
            return false;
        } else if (i <= 0 || scrollX >= ((int) (((float) clientWidth) * this.mLastOffset))) {
            return false;
        } else {
            return true;
        }
    }

    /* Access modifiers changed, original: protected */
    public boolean canScroll(View view, boolean z, int i, int i2, int i3) {
        if (view instanceof ViewGroup) {
            ViewGroup viewGroup = (ViewGroup) view;
            int scrollX = view.getScrollX();
            int scrollY = view.getScrollY();
            for (int childCount = viewGroup.getChildCount() - 1; childCount >= 0; childCount--) {
                View childAt = viewGroup.getChildAt(childCount);
                if (i2 + scrollX >= childAt.getLeft() && i2 + scrollX < childAt.getRight() && i3 + scrollY >= childAt.getTop() && i3 + scrollY < childAt.getBottom()) {
                    if (canScroll(childAt, true, i, (i2 + scrollX) - childAt.getLeft(), (i3 + scrollY) - childAt.getTop())) {
                        return true;
                    }
                }
            }
        }
        if (z && view.canScrollHorizontally(-i)) {
            return true;
        }
        return false;
    }

    public boolean dispatchKeyEvent(KeyEvent keyEvent) {
        return super.dispatchKeyEvent(keyEvent) || executeKeyEvent(keyEvent);
    }

    public boolean executeKeyEvent(KeyEvent keyEvent) {
        if (keyEvent.getAction() != 0) {
            return false;
        }
        switch (keyEvent.getKeyCode()) {
            case 21:
                if (keyEvent.hasModifiers(2)) {
                    return pageLeft();
                }
                return arrowScroll(17);
            case 22:
                if (keyEvent.hasModifiers(2)) {
                    return pageRight();
                }
                return arrowScroll(66);
            case 61:
                if (keyEvent.hasNoModifiers()) {
                    return arrowScroll(2);
                }
                if (keyEvent.hasModifiers(1)) {
                    return arrowScroll(1);
                }
                return false;
            default:
                return false;
        }
    }

    /* JADX WARNING: Missing block: B:38:0x00c0, code skipped:
            if (r10 != 2) goto L_0x00c8;
     */
    public boolean arrowScroll(int r10) {
        /*
        r9 = this;
        r1 = 0;
        r8 = 66;
        r7 = 17;
        r4 = 1;
        r3 = 0;
        r2 = r9.findFocus();
        if (r2 != r9) goto L_0x003e;
    L_0x000d:
        r0 = r1;
    L_0x000e:
        r1 = android.view.FocusFinder.getInstance();
        r1 = r1.findNextFocus(r9, r0, r10);
        if (r1 == 0) goto L_0x00b3;
    L_0x0018:
        if (r1 == r0) goto L_0x00b3;
    L_0x001a:
        if (r10 != r7) goto L_0x0098;
    L_0x001c:
        r2 = r9.mTempRect;
        r2 = r9.getChildRectInPagerCoordinates(r2, r1);
        r2 = r2.left;
        r3 = r9.mTempRect;
        r3 = r9.getChildRectInPagerCoordinates(r3, r0);
        r3 = r3.left;
        if (r0 == 0) goto L_0x0093;
    L_0x002e:
        if (r2 < r3) goto L_0x0093;
    L_0x0030:
        r0 = r9.pageLeft();
    L_0x0034:
        if (r0 == 0) goto L_0x003d;
    L_0x0036:
        r1 = android.view.SoundEffectConstants.getContantForFocusDirection(r10);
        r9.playSoundEffect(r1);
    L_0x003d:
        return r0;
    L_0x003e:
        if (r2 == 0) goto L_0x00cb;
    L_0x0040:
        r0 = r2.getParent();
    L_0x0044:
        r5 = r0 instanceof android.view.ViewGroup;
        if (r5 == 0) goto L_0x00ce;
    L_0x0048:
        if (r0 != r9) goto L_0x007c;
    L_0x004a:
        r0 = r4;
    L_0x004b:
        if (r0 != 0) goto L_0x00cb;
    L_0x004d:
        r5 = new java.lang.StringBuilder;
        r5.<init>();
        r0 = r2.getClass();
        r0 = r0.getSimpleName();
        r5.append(r0);
        r0 = r2.getParent();
    L_0x0061:
        r2 = r0 instanceof android.view.ViewGroup;
        if (r2 == 0) goto L_0x0081;
    L_0x0065:
        r2 = " => ";
        r2 = r5.append(r2);
        r6 = r0.getClass();
        r6 = r6.getSimpleName();
        r2.append(r6);
        r0 = r0.getParent();
        goto L_0x0061;
    L_0x007c:
        r0 = r0.getParent();
        goto L_0x0044;
    L_0x0081:
        r0 = new java.lang.StringBuilder;
        r2 = "arrowScroll tried to find focus based on non-child current focused view ";
        r0.<init>(r2);
        r2 = r5.toString();
        r0.append(r2);
        r0 = r1;
        goto L_0x000e;
    L_0x0093:
        r0 = r1.requestFocus();
        goto L_0x0034;
    L_0x0098:
        if (r10 != r8) goto L_0x00c8;
    L_0x009a:
        r2 = r9.mTempRect;
        r2 = r9.getChildRectInPagerCoordinates(r2, r1);
        r2 = r2.left;
        r3 = r9.mTempRect;
        r3 = r9.getChildRectInPagerCoordinates(r3, r0);
        r3 = r3.left;
        if (r0 == 0) goto L_0x00ae;
    L_0x00ac:
        if (r2 <= r3) goto L_0x00c2;
    L_0x00ae:
        r0 = r1.requestFocus();
        goto L_0x0034;
    L_0x00b3:
        if (r10 == r7) goto L_0x00b7;
    L_0x00b5:
        if (r10 != r4) goto L_0x00bd;
    L_0x00b7:
        r0 = r9.pageLeft();
        goto L_0x0034;
    L_0x00bd:
        if (r10 == r8) goto L_0x00c2;
    L_0x00bf:
        r0 = 2;
        if (r10 != r0) goto L_0x00c8;
    L_0x00c2:
        r0 = r9.pageRight();
        goto L_0x0034;
    L_0x00c8:
        r0 = r3;
        goto L_0x0034;
    L_0x00cb:
        r0 = r2;
        goto L_0x000e;
    L_0x00ce:
        r0 = r3;
        goto L_0x004b;
        */
        throw new UnsupportedOperationException("Method not decompiled: android.support.v4.view.ViewPager.arrowScroll(int):boolean");
    }

    private Rect getChildRectInPagerCoordinates(Rect rect, View view) {
        Rect rect2;
        if (rect == null) {
            rect2 = new Rect();
        } else {
            rect2 = rect;
        }
        if (view == null) {
            rect2.set(0, 0, 0, 0);
            return rect2;
        }
        rect2.left = view.getLeft();
        rect2.right = view.getRight();
        rect2.top = view.getTop();
        rect2.bottom = view.getBottom();
        ViewPager parent = view.getParent();
        while ((parent instanceof ViewGroup) && parent != this) {
            ViewGroup viewGroup = parent;
            rect2.left += viewGroup.getLeft();
            rect2.right += viewGroup.getRight();
            rect2.top += viewGroup.getTop();
            rect2.bottom += viewGroup.getBottom();
            parent = viewGroup.getParent();
        }
        return rect2;
    }

    /* Access modifiers changed, original: 0000 */
    public boolean pageLeft() {
        if (this.mCurItem <= 0) {
            return false;
        }
        setCurrentItem(this.mCurItem - 1, true);
        return true;
    }

    /* Access modifiers changed, original: 0000 */
    public boolean pageRight() {
        if (this.mAdapter == null || this.mCurItem >= this.mAdapter.getCount() - 1) {
            return false;
        }
        setCurrentItem(this.mCurItem + 1, true);
        return true;
    }

    public void addFocusables(ArrayList<View> arrayList, int i, int i2) {
        int size = arrayList.size();
        int descendantFocusability = getDescendantFocusability();
        if (descendantFocusability != 393216) {
            for (int i3 = 0; i3 < getChildCount(); i3++) {
                View childAt = getChildAt(i3);
                if (childAt.getVisibility() == 0) {
                    ItemInfo infoForChild = infoForChild(childAt);
                    if (infoForChild != null && infoForChild.position == this.mCurItem) {
                        childAt.addFocusables(arrayList, i, i2);
                    }
                }
            }
        }
        if ((descendantFocusability == 262144 && size != arrayList.size()) || !isFocusable()) {
            return;
        }
        if (((i2 & 1) != 1 || !isInTouchMode() || isFocusableInTouchMode()) && arrayList != null) {
            arrayList.add(this);
        }
    }

    public void addTouchables(ArrayList<View> arrayList) {
        for (int i = 0; i < getChildCount(); i++) {
            View childAt = getChildAt(i);
            if (childAt.getVisibility() == 0) {
                ItemInfo infoForChild = infoForChild(childAt);
                if (infoForChild != null && infoForChild.position == this.mCurItem) {
                    childAt.addTouchables(arrayList);
                }
            }
        }
    }

    /* Access modifiers changed, original: protected */
    public boolean onRequestFocusInDescendants(int i, Rect rect) {
        int i2;
        int i3;
        int childCount = getChildCount();
        if ((i & 2) != 0) {
            i2 = 1;
            i3 = 0;
        } else {
            i3 = childCount - 1;
            i2 = -1;
            childCount = -1;
        }
        while (i3 != childCount) {
            View childAt = getChildAt(i3);
            if (childAt.getVisibility() == 0) {
                ItemInfo infoForChild = infoForChild(childAt);
                if (infoForChild != null && infoForChild.position == this.mCurItem && childAt.requestFocus(i, rect)) {
                    return true;
                }
            }
            i3 += i2;
        }
        return false;
    }

    public boolean dispatchPopulateAccessibilityEvent(AccessibilityEvent accessibilityEvent) {
        if (accessibilityEvent.getEventType() == 4096) {
            return super.dispatchPopulateAccessibilityEvent(accessibilityEvent);
        }
        int childCount = getChildCount();
        for (int i = 0; i < childCount; i++) {
            View childAt = getChildAt(i);
            if (childAt.getVisibility() == 0) {
                ItemInfo infoForChild = infoForChild(childAt);
                if (infoForChild != null && infoForChild.position == this.mCurItem && childAt.dispatchPopulateAccessibilityEvent(accessibilityEvent)) {
                    return true;
                }
            }
        }
        return false;
    }

    /* Access modifiers changed, original: protected */
    public LayoutParams generateDefaultLayoutParams() {
        return new LayoutParams();
    }

    /* Access modifiers changed, original: protected */
    public LayoutParams generateLayoutParams(LayoutParams layoutParams) {
        return generateDefaultLayoutParams();
    }

    /* Access modifiers changed, original: protected */
    public boolean checkLayoutParams(LayoutParams layoutParams) {
        return (layoutParams instanceof LayoutParams) && super.checkLayoutParams(layoutParams);
    }

    public LayoutParams generateLayoutParams(AttributeSet attributeSet) {
        return new LayoutParams(getContext(), attributeSet);
    }
}
