package com.facebook.internal;

import android.annotation.SuppressLint;
import android.app.Dialog;
import android.app.ProgressDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.DialogInterface.OnCancelListener;
import android.content.pm.ApplicationInfo;
import android.content.pm.PackageManager.NameNotFoundException;
import android.net.Uri;
import android.os.AsyncTask.Status;
import android.os.Bundle;
import android.util.DisplayMetrics;
import android.view.Display;
import android.view.KeyEvent;
import android.view.ViewGroup;
import android.view.WindowManager;
import android.view.WindowManager.LayoutParams;
import android.webkit.WebView;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.LinearLayout;
import com.facebook.FacebookException;
import com.facebook.FacebookOperationCanceledException;
import com.facebook.FacebookSdk;
import com.tencent.map.lib.mapstructure.MapRouteSectionWithName;
import com.tencent.matrix.trace.core.AppMethodBeat;
import java.util.Locale;

public class WebDialog extends Dialog {
    private static final int API_EC_DIALOG_CANCEL = 4201;
    private static final int BACKGROUND_GRAY = -872415232;
    private static final int DEFAULT_THEME = 2131493844;
    static final boolean DISABLE_SSL_CHECK_FOR_TESTING = false;
    private static final String DISPLAY_TOUCH = "touch";
    private static final String LOG_TAG = "FacebookSDK.WebDialog";
    private static final int MAX_PADDING_SCREEN_HEIGHT = 1280;
    private static final int MAX_PADDING_SCREEN_WIDTH = 800;
    private static final double MIN_SCALE_FACTOR = 0.5d;
    private static final int NO_PADDING_SCREEN_HEIGHT = 800;
    private static final int NO_PADDING_SCREEN_WIDTH = 480;
    private static volatile int webDialogTheme;
    private FrameLayout contentFrameLayout;
    private ImageView crossImageView;
    private String expectedRedirectUrl;
    private boolean isDetached;
    private boolean isPageFinished;
    private boolean listenerCalled;
    private OnCompleteListener onCompleteListener;
    private ProgressDialog spinner;
    private UploadStagingResourcesTask uploadTask;
    private String url;
    private WebView webView;
    private LayoutParams windowParams;

    static /* synthetic */ void access$1000(WebDialog webDialog, int i) {
        AppMethodBeat.i(96694);
        webDialog.setUpWebView(i);
        AppMethodBeat.o(96694);
    }

    protected static void initDefaultTheme(Context context) {
        AppMethodBeat.i(96673);
        if (context == null) {
            AppMethodBeat.o(96673);
            return;
        }
        try {
            ApplicationInfo applicationInfo = context.getPackageManager().getApplicationInfo(context.getPackageName(), MapRouteSectionWithName.kMaxRoadNameLength);
            if (applicationInfo == null || applicationInfo.metaData == null) {
                AppMethodBeat.o(96673);
                return;
            }
            if (webDialogTheme == 0) {
                setWebDialogTheme(applicationInfo.metaData.getInt("com.facebook.sdk.WebDialogTheme"));
            }
            AppMethodBeat.o(96673);
        } catch (NameNotFoundException e) {
            AppMethodBeat.o(96673);
        }
    }

    public static WebDialog newInstance(Context context, String str, Bundle bundle, int i, OnCompleteListener onCompleteListener) {
        AppMethodBeat.i(96674);
        initDefaultTheme(context);
        WebDialog webDialog = new WebDialog(context, str, bundle, i, onCompleteListener);
        AppMethodBeat.o(96674);
        return webDialog;
    }

    public static int getWebDialogTheme() {
        AppMethodBeat.i(96675);
        Validate.sdkInitialized();
        int i = webDialogTheme;
        AppMethodBeat.o(96675);
        return i;
    }

    public static void setWebDialogTheme(int i) {
        if (i == 0) {
            i = DEFAULT_THEME;
        }
        webDialogTheme = i;
    }

    protected WebDialog(Context context, String str) {
        this(context, str, getWebDialogTheme());
        AppMethodBeat.i(96676);
        AppMethodBeat.o(96676);
    }

    private WebDialog(Context context, String str, int i) {
        if (i == 0) {
            i = getWebDialogTheme();
        }
        super(context, i);
        AppMethodBeat.i(96677);
        this.expectedRedirectUrl = "fbconnect://success";
        this.listenerCalled = false;
        this.isDetached = false;
        this.isPageFinished = false;
        this.url = str;
        AppMethodBeat.o(96677);
    }

    private WebDialog(Context context, String str, Bundle bundle, int i, OnCompleteListener onCompleteListener) {
        if (i == 0) {
            i = getWebDialogTheme();
        }
        super(context, i);
        AppMethodBeat.i(96678);
        this.expectedRedirectUrl = "fbconnect://success";
        this.listenerCalled = false;
        this.isDetached = false;
        this.isPageFinished = false;
        if (bundle == null) {
            bundle = new Bundle();
        }
        this.expectedRedirectUrl = Utility.isChromeOS(context) ? "fbconnect://chrome_os_success" : "fbconnect://success";
        bundle.putString("redirect_uri", this.expectedRedirectUrl);
        bundle.putString("display", DISPLAY_TOUCH);
        bundle.putString("client_id", FacebookSdk.getApplicationId());
        bundle.putString("sdk", String.format(Locale.ROOT, "android-%s", new Object[]{FacebookSdk.getSdkVersion()}));
        this.onCompleteListener = onCompleteListener;
        if (str.equals("share") && bundle.containsKey("media")) {
            this.uploadTask = new UploadStagingResourcesTask(this, str, bundle);
            AppMethodBeat.o(96678);
            return;
        }
        this.url = Utility.buildUri(ServerProtocol.getDialogAuthority(), FacebookSdk.getGraphApiVersion() + "/dialog/" + str, bundle).toString();
        AppMethodBeat.o(96678);
    }

    public void setOnCompleteListener(OnCompleteListener onCompleteListener) {
        this.onCompleteListener = onCompleteListener;
    }

    public OnCompleteListener getOnCompleteListener() {
        return this.onCompleteListener;
    }

    public boolean onKeyDown(int i, KeyEvent keyEvent) {
        AppMethodBeat.i(96679);
        if (i == 4) {
            cancel();
        }
        boolean onKeyDown = super.onKeyDown(i, keyEvent);
        AppMethodBeat.o(96679);
        return onKeyDown;
    }

    public void dismiss() {
        AppMethodBeat.i(96680);
        if (this.webView != null) {
            this.webView.stopLoading();
        }
        if (!(this.isDetached || this.spinner == null || !this.spinner.isShowing())) {
            this.spinner.dismiss();
        }
        super.dismiss();
        AppMethodBeat.o(96680);
    }

    /* Access modifiers changed, original: protected */
    public void onStart() {
        AppMethodBeat.i(96681);
        super.onStart();
        if (this.uploadTask == null || this.uploadTask.getStatus() != Status.PENDING) {
            resize();
            AppMethodBeat.o(96681);
            return;
        }
        this.uploadTask.execute(new Void[0]);
        this.spinner.show();
        AppMethodBeat.o(96681);
    }

    /* Access modifiers changed, original: protected */
    public void onStop() {
        AppMethodBeat.i(96682);
        if (this.uploadTask != null) {
            this.uploadTask.cancel(true);
            this.spinner.dismiss();
        }
        super.onStop();
        AppMethodBeat.o(96682);
    }

    public void onDetachedFromWindow() {
        AppMethodBeat.i(96683);
        this.isDetached = true;
        super.onDetachedFromWindow();
        AppMethodBeat.o(96683);
    }

    public void onAttachedToWindow() {
        AppMethodBeat.i(96684);
        this.isDetached = false;
        if (Utility.mustFixWindowParamsForAutofill(getContext()) && this.windowParams != null && this.windowParams.token == null) {
            this.windowParams.token = getOwnerActivity().getWindow().getAttributes().token;
            Utility.logd(LOG_TAG, "Set token on onAttachedToWindow(): " + this.windowParams.token);
        }
        super.onAttachedToWindow();
        AppMethodBeat.o(96684);
    }

    public void onWindowAttributesChanged(LayoutParams layoutParams) {
        AppMethodBeat.i(96685);
        if (layoutParams.token == null) {
            this.windowParams = layoutParams;
        }
        super.onWindowAttributesChanged(layoutParams);
        AppMethodBeat.o(96685);
    }

    /* Access modifiers changed, original: protected */
    public void onCreate(Bundle bundle) {
        AppMethodBeat.i(96686);
        super.onCreate(bundle);
        this.spinner = new ProgressDialog(getContext());
        this.spinner.requestWindowFeature(1);
        this.spinner.setMessage(getContext().getString(2131296301));
        this.spinner.setCanceledOnTouchOutside(false);
        this.spinner.setOnCancelListener(new OnCancelListener() {
            public void onCancel(DialogInterface dialogInterface) {
                AppMethodBeat.i(96655);
                WebDialog.this.cancel();
                AppMethodBeat.o(96655);
            }
        });
        requestWindowFeature(1);
        this.contentFrameLayout = new FrameLayout(getContext());
        resize();
        getWindow().setGravity(17);
        getWindow().setSoftInputMode(16);
        createCrossImage();
        if (this.url != null) {
            setUpWebView((this.crossImageView.getDrawable().getIntrinsicWidth() / 2) + 1);
        }
        this.contentFrameLayout.addView(this.crossImageView, new ViewGroup.LayoutParams(-2, -2));
        setContentView(this.contentFrameLayout);
        AppMethodBeat.o(96686);
    }

    /* Access modifiers changed, original: protected */
    public void setExpectedRedirectUrl(String str) {
        this.expectedRedirectUrl = str;
    }

    /* Access modifiers changed, original: protected */
    public Bundle parseResponseUri(String str) {
        AppMethodBeat.i(96687);
        Uri parse = Uri.parse(str);
        Bundle parseUrlQueryString = Utility.parseUrlQueryString(parse.getQuery());
        parseUrlQueryString.putAll(Utility.parseUrlQueryString(parse.getFragment()));
        AppMethodBeat.o(96687);
        return parseUrlQueryString;
    }

    /* Access modifiers changed, original: protected */
    public boolean isListenerCalled() {
        return this.listenerCalled;
    }

    /* Access modifiers changed, original: protected */
    public boolean isPageFinished() {
        return this.isPageFinished;
    }

    /* Access modifiers changed, original: protected */
    public WebView getWebView() {
        return this.webView;
    }

    public void resize() {
        AppMethodBeat.i(96688);
        Display defaultDisplay = ((WindowManager) getContext().getSystemService("window")).getDefaultDisplay();
        DisplayMetrics displayMetrics = new DisplayMetrics();
        defaultDisplay.getMetrics(displayMetrics);
        getWindow().setLayout(Math.min(getScaledSize(displayMetrics.widthPixels < displayMetrics.heightPixels ? displayMetrics.widthPixels : displayMetrics.heightPixels, displayMetrics.density, 480, 800), displayMetrics.widthPixels), Math.min(getScaledSize(displayMetrics.widthPixels < displayMetrics.heightPixels ? displayMetrics.heightPixels : displayMetrics.widthPixels, displayMetrics.density, 800, MAX_PADDING_SCREEN_HEIGHT), displayMetrics.heightPixels));
        AppMethodBeat.o(96688);
    }

    private int getScaledSize(int i, float f, int i2, int i3) {
        double d = MIN_SCALE_FACTOR;
        int i4 = (int) (((float) i) / f);
        if (i4 <= i2) {
            d = 1.0d;
        } else if (i4 < i3) {
            d = MIN_SCALE_FACTOR + ((((double) (i3 - i4)) / ((double) (i3 - i2))) * MIN_SCALE_FACTOR);
        }
        return (int) (d * ((double) i));
    }

    /* Access modifiers changed, original: protected */
    public void sendSuccessToListener(Bundle bundle) {
        AppMethodBeat.i(96689);
        if (!(this.onCompleteListener == null || this.listenerCalled)) {
            this.listenerCalled = true;
            this.onCompleteListener.onComplete(bundle, null);
            dismiss();
        }
        AppMethodBeat.o(96689);
    }

    /* Access modifiers changed, original: protected */
    public void sendErrorToListener(Throwable th) {
        AppMethodBeat.i(96690);
        if (!(this.onCompleteListener == null || this.listenerCalled)) {
            FacebookException facebookException;
            this.listenerCalled = true;
            if (th instanceof FacebookException) {
                facebookException = (FacebookException) th;
            } else {
                facebookException = new FacebookException(th);
            }
            this.onCompleteListener.onComplete(null, facebookException);
            dismiss();
        }
        AppMethodBeat.o(96690);
    }

    public void cancel() {
        AppMethodBeat.i(96691);
        if (!(this.onCompleteListener == null || this.listenerCalled)) {
            sendErrorToListener(new FacebookOperationCanceledException());
        }
        AppMethodBeat.o(96691);
    }

    private void createCrossImage() {
        AppMethodBeat.i(96692);
        this.crossImageView = new ImageView(getContext());
        this.crossImageView.setOnClickListener(new 2(this));
        this.crossImageView.setImageDrawable(getContext().getResources().getDrawable(2130838383));
        this.crossImageView.setVisibility(4);
        AppMethodBeat.o(96692);
    }

    @SuppressLint({"SetJavaScriptEnabled"})
    private void setUpWebView(int i) {
        AppMethodBeat.i(96693);
        LinearLayout linearLayout = new LinearLayout(getContext());
        this.webView = new 3(this, getContext());
        this.webView.setVerticalScrollBarEnabled(false);
        this.webView.setHorizontalScrollBarEnabled(false);
        this.webView.setWebViewClient(new DialogWebViewClient(this, null));
        this.webView.getSettings().setJavaScriptEnabled(true);
        this.webView.loadUrl(this.url);
        this.webView.setLayoutParams(new FrameLayout.LayoutParams(-1, -1));
        this.webView.setVisibility(4);
        this.webView.getSettings().setSavePassword(false);
        this.webView.getSettings().setSaveFormData(false);
        this.webView.setFocusable(true);
        this.webView.setFocusableInTouchMode(true);
        this.webView.setOnTouchListener(new 4(this));
        linearLayout.setPadding(i, i, i, i);
        linearLayout.addView(this.webView);
        linearLayout.setBackgroundColor(BACKGROUND_GRAY);
        this.contentFrameLayout.addView(linearLayout);
        AppMethodBeat.o(96693);
    }
}
