package com.facebook.login.widget;

import android.app.Activity;
import android.content.Context;
import android.content.res.Resources;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Paint.FontMetrics;
import android.support.v7.c.a.b;
import android.util.AttributeSet;
import android.view.View;
import com.facebook.AccessToken;
import com.facebook.AccessTokenTracker;
import com.facebook.CallbackManager;
import com.facebook.FacebookButtonBase;
import com.facebook.FacebookCallback;
import com.facebook.FacebookSdk;
import com.facebook.internal.CallbackManagerImpl.RequestCodeOffset;
import com.facebook.internal.FetchedAppSettings;
import com.facebook.internal.Utility;
import com.facebook.login.DefaultAudience;
import com.facebook.login.LoginBehavior;
import com.facebook.login.LoginManager;
import com.facebook.login.LoginResult;
import com.facebook.login.R;
import com.tencent.matrix.trace.core.AppMethodBeat;
import java.util.Arrays;
import java.util.List;

public class LoginButton extends FacebookButtonBase {
    private static final String TAG = LoginButton.class.getName();
    private AccessTokenTracker accessTokenTracker;
    private boolean confirmLogout;
    private String loginLogoutEventName = "fb_login_view_usage";
    private LoginManager loginManager;
    private String loginText;
    private String logoutText;
    private LoginButtonProperties properties = new LoginButtonProperties();
    private boolean toolTipChecked;
    private long toolTipDisplayTime = 6000;
    private ToolTipMode toolTipMode;
    private ToolTipPopup toolTipPopup;
    private ToolTipPopup$Style toolTipStyle = ToolTipPopup$Style.BLUE;

    static /* synthetic */ void access$000(LoginButton loginButton, FetchedAppSettings fetchedAppSettings) {
        AppMethodBeat.i(92681);
        loginButton.showToolTipPerSettings(fetchedAppSettings);
        AppMethodBeat.o(92681);
    }

    static /* synthetic */ Activity access$100(LoginButton loginButton) {
        AppMethodBeat.i(92682);
        Activity activity = loginButton.getActivity();
        AppMethodBeat.o(92682);
        return activity;
    }

    static /* synthetic */ void access$200(LoginButton loginButton) {
        AppMethodBeat.i(92683);
        loginButton.setButtonText();
        AppMethodBeat.o(92683);
    }

    static /* synthetic */ void access$300(LoginButton loginButton, View view) {
        AppMethodBeat.i(92684);
        loginButton.callExternalOnClickListener(view);
        AppMethodBeat.o(92684);
    }

    static /* synthetic */ Activity access$800(LoginButton loginButton) {
        AppMethodBeat.i(92685);
        Activity activity = loginButton.getActivity();
        AppMethodBeat.o(92685);
        return activity;
    }

    static /* synthetic */ Activity access$900(LoginButton loginButton) {
        AppMethodBeat.i(92686);
        Activity activity = loginButton.getActivity();
        AppMethodBeat.o(92686);
        return activity;
    }

    static {
        AppMethodBeat.i(92687);
        AppMethodBeat.o(92687);
    }

    public LoginButton(Context context) {
        super(context, null, 0, 0, "fb_login_button_create", "fb_login_button_did_tap");
        AppMethodBeat.i(92647);
        AppMethodBeat.o(92647);
    }

    public LoginButton(Context context, AttributeSet attributeSet) {
        super(context, attributeSet, 0, 0, "fb_login_button_create", "fb_login_button_did_tap");
        AppMethodBeat.i(92648);
        AppMethodBeat.o(92648);
    }

    public LoginButton(Context context, AttributeSet attributeSet, int i) {
        super(context, attributeSet, i, 0, "fb_login_button_create", "fb_login_button_did_tap");
        AppMethodBeat.i(92649);
        AppMethodBeat.o(92649);
    }

    public void setDefaultAudience(DefaultAudience defaultAudience) {
        AppMethodBeat.i(92650);
        this.properties.setDefaultAudience(defaultAudience);
        AppMethodBeat.o(92650);
    }

    public DefaultAudience getDefaultAudience() {
        AppMethodBeat.i(92651);
        DefaultAudience defaultAudience = this.properties.getDefaultAudience();
        AppMethodBeat.o(92651);
        return defaultAudience;
    }

    public void setReadPermissions(List<String> list) {
        AppMethodBeat.i(92652);
        this.properties.setReadPermissions(list);
        AppMethodBeat.o(92652);
    }

    public void setReadPermissions(String... strArr) {
        AppMethodBeat.i(92653);
        this.properties.setReadPermissions(Arrays.asList(strArr));
        AppMethodBeat.o(92653);
    }

    public void setPublishPermissions(List<String> list) {
        AppMethodBeat.i(92654);
        this.properties.setPublishPermissions(list);
        AppMethodBeat.o(92654);
    }

    public void setPublishPermissions(String... strArr) {
        AppMethodBeat.i(92655);
        this.properties.setPublishPermissions(Arrays.asList(strArr));
        AppMethodBeat.o(92655);
    }

    public void clearPermissions() {
        AppMethodBeat.i(92656);
        this.properties.clearPermissions();
        AppMethodBeat.o(92656);
    }

    public void setLoginBehavior(LoginBehavior loginBehavior) {
        AppMethodBeat.i(92657);
        this.properties.setLoginBehavior(loginBehavior);
        AppMethodBeat.o(92657);
    }

    public LoginBehavior getLoginBehavior() {
        AppMethodBeat.i(92658);
        LoginBehavior loginBehavior = this.properties.getLoginBehavior();
        AppMethodBeat.o(92658);
        return loginBehavior;
    }

    public String getAuthType() {
        AppMethodBeat.i(92659);
        String authType = this.properties.getAuthType();
        AppMethodBeat.o(92659);
        return authType;
    }

    public void setAuthType(String str) {
        AppMethodBeat.i(92660);
        this.properties.setAuthType(str);
        AppMethodBeat.o(92660);
    }

    public void setToolTipStyle(ToolTipPopup$Style toolTipPopup$Style) {
        this.toolTipStyle = toolTipPopup$Style;
    }

    public void setToolTipMode(ToolTipMode toolTipMode) {
        this.toolTipMode = toolTipMode;
    }

    public ToolTipMode getToolTipMode() {
        return this.toolTipMode;
    }

    public void setToolTipDisplayTime(long j) {
        this.toolTipDisplayTime = j;
    }

    public long getToolTipDisplayTime() {
        return this.toolTipDisplayTime;
    }

    public void dismissToolTip() {
        AppMethodBeat.i(92661);
        if (this.toolTipPopup != null) {
            this.toolTipPopup.dismiss();
            this.toolTipPopup = null;
        }
        AppMethodBeat.o(92661);
    }

    public void registerCallback(CallbackManager callbackManager, FacebookCallback<LoginResult> facebookCallback) {
        AppMethodBeat.i(92662);
        getLoginManager().registerCallback(callbackManager, facebookCallback);
        AppMethodBeat.o(92662);
    }

    public void unregisterCallback(CallbackManager callbackManager) {
        AppMethodBeat.i(92663);
        getLoginManager().unregisterCallback(callbackManager);
        AppMethodBeat.o(92663);
    }

    public void onAttachedToWindow() {
        AppMethodBeat.i(92664);
        super.onAttachedToWindow();
        if (!(this.accessTokenTracker == null || this.accessTokenTracker.isTracking())) {
            this.accessTokenTracker.startTracking();
            setButtonText();
        }
        AppMethodBeat.o(92664);
    }

    public void onDraw(Canvas canvas) {
        AppMethodBeat.i(92665);
        super.onDraw(canvas);
        if (!(this.toolTipChecked || isInEditMode())) {
            this.toolTipChecked = true;
            checkToolTipSettings();
        }
        AppMethodBeat.o(92665);
    }

    private void showToolTipPerSettings(FetchedAppSettings fetchedAppSettings) {
        AppMethodBeat.i(92666);
        if (fetchedAppSettings != null && fetchedAppSettings.getNuxEnabled() && getVisibility() == 0) {
            displayToolTip(fetchedAppSettings.getNuxContent());
        }
        AppMethodBeat.o(92666);
    }

    private void displayToolTip(String str) {
        AppMethodBeat.i(92667);
        this.toolTipPopup = new ToolTipPopup(str, this);
        this.toolTipPopup.setStyle(this.toolTipStyle);
        this.toolTipPopup.setNuxDisplayTime(this.toolTipDisplayTime);
        this.toolTipPopup.show();
        AppMethodBeat.o(92667);
    }

    private void checkToolTipSettings() {
        AppMethodBeat.i(92668);
        switch (3.$SwitchMap$com$facebook$login$widget$LoginButton$ToolTipMode[this.toolTipMode.ordinal()]) {
            case 1:
                FacebookSdk.getExecutor().execute(new 1(this, Utility.getMetadataApplicationId(getContext())));
                AppMethodBeat.o(92668);
                return;
            case 2:
                displayToolTip(getResources().getString(2131296317));
                break;
        }
        AppMethodBeat.o(92668);
    }

    /* Access modifiers changed, original: protected */
    public void onLayout(boolean z, int i, int i2, int i3, int i4) {
        AppMethodBeat.i(92669);
        super.onLayout(z, i, i2, i3, i4);
        setButtonText();
        AppMethodBeat.o(92669);
    }

    /* Access modifiers changed, original: protected */
    public void onDetachedFromWindow() {
        AppMethodBeat.i(92670);
        super.onDetachedFromWindow();
        if (this.accessTokenTracker != null) {
            this.accessTokenTracker.stopTracking();
        }
        dismissToolTip();
        AppMethodBeat.o(92670);
    }

    /* Access modifiers changed, original: protected */
    public void onVisibilityChanged(View view, int i) {
        AppMethodBeat.i(92671);
        super.onVisibilityChanged(view, i);
        if (i != 0) {
            dismissToolTip();
        }
        AppMethodBeat.o(92671);
    }

    /* Access modifiers changed, original: 0000 */
    public List<String> getPermissions() {
        AppMethodBeat.i(92672);
        List permissions = this.properties.getPermissions();
        AppMethodBeat.o(92672);
        return permissions;
    }

    /* Access modifiers changed, original: 0000 */
    public void setProperties(LoginButtonProperties loginButtonProperties) {
        this.properties = loginButtonProperties;
    }

    public void configureButton(Context context, AttributeSet attributeSet, int i, int i2) {
        AppMethodBeat.i(92673);
        super.configureButton(context, attributeSet, i, i2);
        setInternalOnClickListener(getNewLoginClickListener());
        parseLoginButtonAttributes(context, attributeSet, i, i2);
        if (isInEditMode()) {
            setBackgroundColor(getResources().getColor(2131689891));
            this.loginText = "Continue with Facebook";
        } else {
            this.accessTokenTracker = new 2(this);
        }
        setButtonText();
        setCompoundDrawablesWithIntrinsicBounds(b.g(getContext(), 2130838381), null, null, null);
        AppMethodBeat.o(92673);
    }

    /* Access modifiers changed, original: protected */
    public LoginClickListener getNewLoginClickListener() {
        AppMethodBeat.i(92674);
        LoginClickListener loginClickListener = new LoginClickListener(this);
        AppMethodBeat.o(92674);
        return loginClickListener;
    }

    public int getDefaultStyleResource() {
        return 2131493849;
    }

    private void parseLoginButtonAttributes(Context context, AttributeSet attributeSet, int i, int i2) {
        AppMethodBeat.i(92675);
        this.toolTipMode = ToolTipMode.DEFAULT;
        TypedArray obtainStyledAttributes = context.getTheme().obtainStyledAttributes(attributeSet, R.styleable.com_facebook_login_view, i, i2);
        try {
            this.confirmLogout = obtainStyledAttributes.getBoolean(0, true);
            this.loginText = obtainStyledAttributes.getString(1);
            this.logoutText = obtainStyledAttributes.getString(2);
            this.toolTipMode = ToolTipMode.fromInt(obtainStyledAttributes.getInt(3, ToolTipMode.DEFAULT.getValue()));
        } finally {
            obtainStyledAttributes.recycle();
            AppMethodBeat.o(92675);
        }
    }

    /* Access modifiers changed, original: protected */
    public void onMeasure(int i, int i2) {
        int measureButtonWidth;
        AppMethodBeat.i(92676);
        FontMetrics fontMetrics = getPaint().getFontMetrics();
        int compoundPaddingBottom = getCompoundPaddingBottom() + (((int) Math.ceil((double) (Math.abs(fontMetrics.bottom) + Math.abs(fontMetrics.top)))) + getCompoundPaddingTop());
        Resources resources = getResources();
        String str = this.loginText;
        if (str == null) {
            str = resources.getString(2131296304);
            measureButtonWidth = measureButtonWidth(str);
            if (resolveSize(measureButtonWidth, i) < measureButtonWidth) {
                str = resources.getString(2131296303);
            }
        }
        measureButtonWidth = measureButtonWidth(str);
        str = this.logoutText;
        if (str == null) {
            str = resources.getString(2131296307);
        }
        setMeasuredDimension(resolveSize(Math.max(measureButtonWidth, measureButtonWidth(str)), i), compoundPaddingBottom);
        AppMethodBeat.o(92676);
    }

    private int measureButtonWidth(String str) {
        AppMethodBeat.i(92677);
        int measureTextWidth = (measureTextWidth(str) + (getCompoundPaddingLeft() + getCompoundDrawablePadding())) + getCompoundPaddingRight();
        AppMethodBeat.o(92677);
        return measureTextWidth;
    }

    private void setButtonText() {
        AppMethodBeat.i(92678);
        Resources resources = getResources();
        CharSequence charSequence;
        if (!isInEditMode() && AccessToken.isCurrentAccessTokenActive()) {
            if (this.logoutText != null) {
                charSequence = this.logoutText;
            } else {
                charSequence = resources.getString(2131296307);
            }
            setText(charSequence);
            AppMethodBeat.o(92678);
        } else if (this.loginText != null) {
            setText(this.loginText);
            AppMethodBeat.o(92678);
        } else {
            charSequence = resources.getString(2131296304);
            int width = getWidth();
            if (width != 0 && measureButtonWidth(charSequence) > width) {
                charSequence = resources.getString(2131296303);
            }
            setText(charSequence);
            AppMethodBeat.o(92678);
        }
    }

    public int getDefaultRequestCode() {
        AppMethodBeat.i(92679);
        int toRequestCode = RequestCodeOffset.Login.toRequestCode();
        AppMethodBeat.o(92679);
        return toRequestCode;
    }

    /* Access modifiers changed, original: 0000 */
    public LoginManager getLoginManager() {
        AppMethodBeat.i(92680);
        if (this.loginManager == null) {
            this.loginManager = LoginManager.getInstance();
        }
        LoginManager loginManager = this.loginManager;
        AppMethodBeat.o(92680);
        return loginManager;
    }

    /* Access modifiers changed, original: 0000 */
    public void setLoginManager(LoginManager loginManager) {
        this.loginManager = loginManager;
    }
}
