package com.tencent.qqvideo.proxy.common;

import android.content.Context;
import android.content.pm.PackageManager;
import android.content.pm.PackageManager.NameNotFoundException;
import android.content.res.Configuration;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.net.NetworkInfo.State;
import android.net.TrafficStats;
import android.net.wifi.WifiInfo;
import android.net.wifi.WifiManager;
import android.os.Build.VERSION;
import android.provider.Settings.System;
import android.telephony.TelephonyManager;
import android.text.TextUtils;
import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.tencentmap.mapsdk.map.BuildConfig;
import com.tencent.tmassistantsdk.logreport.UpdateInfoReportManager$UpdateLogConst;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.IOException;
import java.io.PrintStream;

public class VcSystemInfo {
    public static final int CHIP_ARM_LATER = 50;
    public static final int CHIP_ARM_V5 = 3;
    public static final int CHIP_ARM_V6 = 4;
    public static final int CHIP_ARM_V7_NENO = 6;
    public static final int CHIP_ARM_V7_NO_NENO = 5;
    public static final int CHIP_MIPS = 2;
    public static final int CHIP_UNKNOW = 0;
    public static final int CHIP_X86 = 1;
    public static final int NETWORK_AP_3G = 2;
    public static final int NETWORK_AP_GPRS = 3;
    public static final int NETWORK_AP_LINE = 4;
    public static final int NETWORK_AP_WIFI = 1;
    public static final int NETWORK_CLASS_2_G = 2;
    public static final int NETWORK_CLASS_3_G = 3;
    public static final int NETWORK_CLASS_4_G = 4;
    public static final int NETWORK_CLASS_UNKNOWN = 0;
    public static final int NETWORK_NONE = 0;
    private static final int NETWORK_TYPE_1xRTT = 7;
    private static final int NETWORK_TYPE_CDMA = 4;
    private static final int NETWORK_TYPE_EDGE = 2;
    private static final int NETWORK_TYPE_EHRPD = 14;
    private static final int NETWORK_TYPE_EVDO_0 = 5;
    private static final int NETWORK_TYPE_EVDO_A = 6;
    private static final int NETWORK_TYPE_EVDO_B = 12;
    private static final int NETWORK_TYPE_GPRS = 1;
    private static final int NETWORK_TYPE_HSDPA = 8;
    private static final int NETWORK_TYPE_HSPA = 10;
    private static final int NETWORK_TYPE_HSPAP = 15;
    private static final int NETWORK_TYPE_HSUPA = 9;
    private static final int NETWORK_TYPE_IDEN = 11;
    private static final int NETWORK_TYPE_LTE = 13;
    private static final int NETWORK_TYPE_UMTS = 3;
    public static final int PLAYER_LEVEL_1 = 1;
    public static final int PLAYER_LEVEL_11 = 11;
    public static final int PLAYER_LEVEL_16 = 16;
    public static final int PLAYER_LEVEL_21 = 21;
    public static final int PLAYER_LEVEL_26 = 26;
    public static final int PLAYER_LEVEL_6 = 6;
    private static final String TAG = "VcSystemInfo";
    public static final int TYPE_CMNET = 2;
    public static final int TYPE_CMWAP = 3;
    public static final int TYPE_NONE = 0;
    public static final int TYPE_OTHER = 4;
    public static final int TYPE_WIFI = 1;
    private static int appVersionCode = 0;
    private static String appVersionName;
    private static String deviceID = BuildConfig.FLAVOR;
    private static String deviceIMEI;
    private static String deviceIMSI;
    private static String deviceMacAddr;
    public static int mCpuArchitecture = 0;
    public static String mCpuHardware = BuildConfig.FLAVOR;
    private static int mDeviceLevel = 0;
    public static String mFeature = BuildConfig.FLAVOR;
    private static int mMCC = 0;
    private static int mMNC = 0;
    public static String mProcessorName = "N/A";
    public static int mScreenHeight;
    public static int mScreenWidth;
    public int mCoreNumber = 1;
    public long mCurrCpuFreq = 0;
    private long mLastCpu;
    private long mLastIdle;
    public long mMaxCpuFreq = 0;
    public int mdispHeight;
    public int mdispWidth;

    public VcSystemInfo() {
        mScreenWidth = 320;
        mScreenHeight = 480;
        this.mdispWidth = 320;
        this.mdispHeight = 240;
        this.mLastCpu = 0;
        this.mLastIdle = 0;
    }

    public static String getDeviceIMEI(Context context) {
        AppMethodBeat.i(124429);
        String str;
        if (!TextUtils.isEmpty(deviceIMEI)) {
            str = deviceIMEI;
            AppMethodBeat.o(124429);
            return str;
        } else if (context == null) {
            str = BuildConfig.FLAVOR;
            AppMethodBeat.o(124429);
            return str;
        } else {
            try {
                TelephonyManager telephonyManager = (TelephonyManager) context.getSystemService("phone");
                if (telephonyManager != null) {
                    str = telephonyManager.getDeviceId();
                    deviceIMEI = str;
                    if (str == null) {
                        deviceIMEI = BuildConfig.FLAVOR;
                    }
                    str = deviceIMEI;
                    AppMethodBeat.o(124429);
                    return str;
                }
            } catch (Throwable th) {
            }
            str = BuildConfig.FLAVOR;
            AppMethodBeat.o(124429);
            return str;
        }
    }

    public static String getDeviceIMSI(Context context) {
        AppMethodBeat.i(124430);
        String str;
        if (!TextUtils.isEmpty(deviceIMSI)) {
            str = deviceIMSI;
            AppMethodBeat.o(124430);
            return str;
        } else if (context == null) {
            str = BuildConfig.FLAVOR;
            AppMethodBeat.o(124430);
            return str;
        } else {
            try {
                TelephonyManager telephonyManager = (TelephonyManager) context.getSystemService("phone");
                if (telephonyManager != null) {
                    str = telephonyManager.getSubscriberId();
                    deviceIMSI = str;
                    if (str == null) {
                        deviceIMSI = BuildConfig.FLAVOR;
                    }
                    str = deviceIMSI;
                    AppMethodBeat.o(124430);
                    return str;
                }
            } catch (Throwable th) {
            }
            str = BuildConfig.FLAVOR;
            AppMethodBeat.o(124430);
            return str;
        }
    }

    public static String getDeviceID(Context context) {
        AppMethodBeat.i(124431);
        String str;
        if (!TextUtils.isEmpty(deviceID)) {
            str = deviceID;
            AppMethodBeat.o(124431);
            return str;
        } else if (context == null) {
            str = BuildConfig.FLAVOR;
            AppMethodBeat.o(124431);
            return str;
        } else {
            try {
                str = System.getString(context.getContentResolver(), "android_id");
                deviceID = str;
                if (str == null) {
                    deviceID = BuildConfig.FLAVOR;
                }
            } catch (Throwable th) {
                deviceID = BuildConfig.FLAVOR;
            }
            str = deviceID;
            AppMethodBeat.o(124431);
            return str;
        }
    }

    public static String getDeviceMacAddr(Context context) {
        AppMethodBeat.i(124432);
        String str;
        if (!TextUtils.isEmpty(deviceMacAddr)) {
            str = deviceMacAddr;
            AppMethodBeat.o(124432);
            return str;
        } else if (context == null) {
            str = BuildConfig.FLAVOR;
            AppMethodBeat.o(124432);
            return str;
        } else {
            try {
                WifiManager wifiManager = (WifiManager) context.getSystemService("wifi");
                if (wifiManager != null) {
                    WifiInfo connectionInfo = wifiManager.getConnectionInfo();
                    if (connectionInfo != null) {
                        str = connectionInfo.getMacAddress();
                        deviceMacAddr = str;
                        if (str == null) {
                            deviceMacAddr = BuildConfig.FLAVOR;
                        }
                        str = deviceMacAddr;
                        AppMethodBeat.o(124432);
                        return str;
                    }
                }
            } catch (Throwable th) {
            }
            str = BuildConfig.FLAVOR;
            AppMethodBeat.o(124432);
            return str;
        }
    }

    public static String getOsVersion() {
        return VERSION.RELEASE;
    }

    public static int getOsVerIntFromVerStr() {
        AppMethodBeat.i(124433);
        String osVersion = getOsVersion();
        int osVerInt = getOsVerInt();
        if (osVersion.length() >= 3) {
            try {
                int parseInt = Integer.parseInt(osVersion.substring(0, 1));
                int parseInt2 = Integer.parseInt(osVersion.substring(2, 3));
                if (parseInt != 2) {
                    if (parseInt == 4) {
                        switch (parseInt2) {
                            case 0:
                                osVerInt = 14;
                                break;
                            case 1:
                                osVerInt = 16;
                                break;
                            case 2:
                                osVerInt = 17;
                                break;
                            case 3:
                                osVerInt = 18;
                                break;
                            case 4:
                                osVerInt = 19;
                                break;
                        }
                    }
                } else if (parseInt2 == 3) {
                    osVerInt = 9;
                }
            } catch (Exception e) {
            }
        }
        AppMethodBeat.o(124433);
        return osVerInt;
    }

    public static int getOsVerInt() {
        switch (VERSION.SDK_INT) {
            case 9:
            case 10:
                return 9;
            case 14:
            case 15:
                return 14;
            case 16:
                return 16;
            case 17:
                return 17;
            case 18:
                return 18;
            case 19:
            case 20:
                return 19;
            default:
                return 0;
        }
    }

    public static String getRomInfo() {
        return VERSION.INCREMENTAL;
    }

    public static int GetNetAP(Context context) {
        AppMethodBeat.i(124434);
        if (context == null) {
            AppMethodBeat.o(124434);
            return 0;
        }
        ConnectivityManager connectivityManager = (ConnectivityManager) context.getSystemService("connectivity");
        if (connectivityManager == null) {
            AppMethodBeat.o(124434);
            return 0;
        }
        NetworkInfo activeNetworkInfo = connectivityManager.getActiveNetworkInfo();
        if (activeNetworkInfo == null) {
            AppMethodBeat.o(124434);
            return 0;
        }
        if ("wifi".equalsIgnoreCase(activeNetworkInfo.getTypeName())) {
            AppMethodBeat.o(124434);
            return 1;
        }
        AppMethodBeat.o(124434);
        return 2;
    }

    public static String getAppName(Context context, String str) {
        AppMethodBeat.i(124435);
        String str2;
        if (context == null) {
            str2 = BuildConfig.FLAVOR;
            AppMethodBeat.o(124435);
            return str2;
        }
        try {
            PackageManager packageManager = context.getPackageManager();
            str2 = packageManager.getApplicationLabel(packageManager.getApplicationInfo(str, 0)).toString();
            AppMethodBeat.o(124435);
            return str2;
        } catch (Throwable th) {
            str2 = BuildConfig.FLAVOR;
            AppMethodBeat.o(124435);
            return str2;
        }
    }

    public static String getAppVersionName(Context context) {
        AppMethodBeat.i(124436);
        String str;
        if (TextUtils.isEmpty(appVersionName)) {
            String str2 = BuildConfig.FLAVOR;
            if (context == null) {
                AppMethodBeat.o(124436);
                return str2;
            }
            try {
                str = context.getPackageManager().getPackageInfo(context.getPackageName(), 0).versionName;
                appVersionName = str;
                if (str == null) {
                    try {
                        str = BuildConfig.FLAVOR;
                    } catch (Throwable th) {
                        AppMethodBeat.o(124436);
                        return str;
                    }
                }
                AppMethodBeat.o(124436);
                return str;
            } catch (Throwable th2) {
                str = str2;
                AppMethodBeat.o(124436);
                return str;
            }
        }
        str = appVersionName;
        AppMethodBeat.o(124436);
        return str;
    }

    public static int getAppVersionCode(Context context, String str) {
        AppMethodBeat.i(124437);
        if (appVersionCode != 0) {
            int i = appVersionCode;
            AppMethodBeat.o(124437);
            return i;
        } else if (context == null) {
            AppMethodBeat.o(124437);
            return 0;
        } else {
            try {
                int i2 = context.getPackageManager().getPackageInfo(str, 0).versionCode;
                appVersionCode = i2;
                AppMethodBeat.o(124437);
                return i2;
            } catch (Throwable th) {
                AppMethodBeat.o(124437);
                return 0;
            }
        }
    }

    public static boolean isNetworkAvailable(Context context) {
        AppMethodBeat.i(124438);
        if (context != null) {
            ConnectivityManager connectivityManager = (ConnectivityManager) context.getApplicationContext().getSystemService("connectivity");
            if (connectivityManager == null) {
                AppMethodBeat.o(124438);
                return false;
            }
            NetworkInfo activeNetworkInfo = connectivityManager.getActiveNetworkInfo();
            if (activeNetworkInfo == null || !activeNetworkInfo.isAvailable()) {
                AppMethodBeat.o(124438);
                return false;
            } else if (activeNetworkInfo.getState() == State.CONNECTED) {
                AppMethodBeat.o(124438);
                return true;
            } else {
                AppMethodBeat.o(124438);
                return false;
            }
        }
        AppMethodBeat.o(124438);
        return false;
    }

    public static int getNetWorkType(Context context) {
        AppMethodBeat.i(124439);
        if (context == null) {
            AppMethodBeat.o(124439);
            return 0;
        }
        int i;
        try {
            ConnectivityManager connectivityManager = (ConnectivityManager) context.getSystemService("connectivity");
            if (connectivityManager != null) {
                NetworkInfo activeNetworkInfo = connectivityManager.getActiveNetworkInfo();
                if (activeNetworkInfo != null) {
                    switch (activeNetworkInfo.getType()) {
                        case 0:
                            i = 2;
                            try {
                                if (!(activeNetworkInfo.getExtraInfo() == null || "cmnet".equalsIgnoreCase(activeNetworkInfo.getExtraInfo()))) {
                                    i = 3;
                                    break;
                                }
                            } catch (Exception e) {
                                break;
                            }
                        case 1:
                            i = 1;
                            break;
                        default:
                            i = 4;
                            break;
                    }
                    AppMethodBeat.o(124439);
                    return i;
                }
            }
            i = 0;
        } catch (Exception e2) {
            i = 0;
        }
        AppMethodBeat.o(124439);
        return i;
    }

    public static int getWifiNetStrength(Context context) {
        AppMethodBeat.i(124440);
        if (context == null) {
            AppMethodBeat.o(124440);
            return 0;
        }
        try {
            WifiInfo connectionInfo = ((WifiManager) context.getSystemService("wifi")).getConnectionInfo();
            if (connectionInfo == null) {
                AppMethodBeat.o(124440);
                return 0;
            }
            int rssi = connectionInfo.getRssi();
            int calculateSignalLevel;
            if (VERSION.SDK_INT >= 14) {
                calculateSignalLevel = WifiManager.calculateSignalLevel(connectionInfo.getRssi(), UpdateInfoReportManager$UpdateLogConst.ACTION_START_DOWNLOAD);
                AppMethodBeat.o(124440);
                return calculateSignalLevel;
            } else if (rssi <= -100) {
                AppMethodBeat.o(124440);
                return 0;
            } else if (rssi >= -55) {
                AppMethodBeat.o(124440);
                return 100;
            } else {
                calculateSignalLevel = (int) ((((float) (rssi + 100)) * 100.0f) / 45.0f);
                AppMethodBeat.o(124440);
                return calculateSignalLevel;
            }
        } catch (Throwable th) {
            AppMethodBeat.o(124440);
            return 0;
        }
    }

    public static long getRxBytesFromNetwork(Context context) {
        long j = -1;
        AppMethodBeat.i(124441);
        if (context == null) {
            AppMethodBeat.o(124441);
            return -1;
        }
        try {
            context.getClassLoader().loadClass("android.net.TrafficStats");
            if (-1 == -1) {
                j = TrafficStats.getTotalRxBytes();
            }
            AppMethodBeat.o(124441);
            return j;
        } catch (ClassNotFoundException e) {
            AppMethodBeat.o(124441);
            return 0;
        } catch (Throwable th) {
            AppMethodBeat.o(124441);
            return 0;
        }
    }

    public static long getAppInstallTime(Context context) {
        long j = 0;
        AppMethodBeat.i(124442);
        if (context == null) {
            AppMethodBeat.o(124442);
        } else {
            try {
                j = new File(context.getPackageManager().getApplicationInfo(context.getPackageName(), 0).sourceDir).lastModified() / 1000;
                AppMethodBeat.o(124442);
            } catch (NameNotFoundException e) {
                AppMethodBeat.o(124442);
            } catch (Throwable th) {
                AppMethodBeat.o(124442);
            }
        }
        return j;
    }

    public static int getScreenWidth(Context context) {
        AppMethodBeat.i(124443);
        int i;
        if (context == null) {
            AppMethodBeat.o(124443);
            return 0;
        } else if (mScreenWidth != 0) {
            i = mScreenWidth;
            AppMethodBeat.o(124443);
            return i;
        } else {
            try {
                mScreenWidth = context.getResources().getDisplayMetrics().widthPixels;
            } catch (Throwable th) {
            }
            i = mScreenWidth;
            AppMethodBeat.o(124443);
            return i;
        }
    }

    public static int getScreenHeight(Context context) {
        AppMethodBeat.i(124444);
        int i;
        if (context == null) {
            AppMethodBeat.o(124444);
            return 0;
        } else if (mScreenHeight != 0) {
            i = mScreenHeight;
            AppMethodBeat.o(124444);
            return i;
        } else {
            try {
                mScreenHeight = context.getResources().getDisplayMetrics().heightPixels;
            } catch (Throwable th) {
            }
            i = mScreenHeight;
            AppMethodBeat.o(124444);
            return i;
        }
    }

    public static boolean isNetworkTypeMobile(Context context) {
        AppMethodBeat.i(124445);
        if (context == null) {
            AppMethodBeat.o(124445);
            return true;
        }
        ConnectivityManager connectivityManager = (ConnectivityManager) context.getSystemService("connectivity");
        if (connectivityManager != null) {
            NetworkInfo activeNetworkInfo = connectivityManager.getActiveNetworkInfo();
            if (activeNetworkInfo != null) {
                switch (activeNetworkInfo.getType()) {
                    case 0:
                    case 2:
                    case 3:
                    case 4:
                    case 5:
                        AppMethodBeat.o(124445);
                        return true;
                    default:
                        AppMethodBeat.o(124445);
                        return false;
                }
            }
        }
        AppMethodBeat.o(124445);
        return true;
    }

    /* JADX WARNING: Removed duplicated region for block: B:24:0x0066 A:{SYNTHETIC, Splitter:B:24:0x0066} */
    /* JADX WARNING: Removed duplicated region for block: B:27:0x006b A:{Catch:{ Throwable -> 0x006f }} */
    /* JADX WARNING: Removed duplicated region for block: B:32:0x0076 A:{SYNTHETIC, Splitter:B:32:0x0076} */
    /* JADX WARNING: Removed duplicated region for block: B:35:0x007b A:{Catch:{ Throwable -> 0x0084 }} */
    /* JADX WARNING: Removed duplicated region for block: B:32:0x0076 A:{SYNTHETIC, Splitter:B:32:0x0076} */
    /* JADX WARNING: Removed duplicated region for block: B:35:0x007b A:{Catch:{ Throwable -> 0x0084 }} */
    public static int getMarketId(android.content.Context r6) {
        /*
        r2 = 0;
        r0 = -1;
        r5 = 124446; // 0x1e61e float:1.74386E-40 double:6.14845E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r5);
        if (r6 != 0) goto L_0x000e;
    L_0x000a:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
    L_0x000d:
        return r0;
    L_0x000e:
        r1 = r6.getApplicationContext();	 Catch:{ Throwable -> 0x0061, all -> 0x0071 }
        r1 = r1.getAssets();	 Catch:{ Throwable -> 0x0061, all -> 0x0071 }
        r3 = "channel.ini";
        r3 = r1.open(r3);	 Catch:{ Throwable -> 0x0061, all -> 0x0071 }
        r1 = new java.io.BufferedReader;	 Catch:{ Throwable -> 0x008b, all -> 0x0086 }
        r4 = new java.io.InputStreamReader;	 Catch:{ Throwable -> 0x008b, all -> 0x0086 }
        r4.<init>(r3);	 Catch:{ Throwable -> 0x008b, all -> 0x0086 }
        r1.<init>(r4);	 Catch:{ Throwable -> 0x008b, all -> 0x0086 }
        r2 = r1.readLine();	 Catch:{ Throwable -> 0x008e, all -> 0x0089 }
        r4 = android.text.TextUtils.isEmpty(r2);	 Catch:{ Throwable -> 0x008e, all -> 0x0089 }
        if (r4 != 0) goto L_0x0055;
    L_0x0031:
        r4 = "CHANNEL=";
        r4 = r2.contains(r4);	 Catch:{ Throwable -> 0x008e, all -> 0x0089 }
        if (r4 == 0) goto L_0x0055;
    L_0x003a:
        r4 = "=";
        r4 = r2.indexOf(r4);	 Catch:{ Throwable -> 0x008e, all -> 0x0089 }
        r4 = r4 + 1;
        r2 = r2.substring(r4);	 Catch:{ Throwable -> 0x008e, all -> 0x0089 }
        r4 = android.text.TextUtils.isEmpty(r2);	 Catch:{ Throwable -> 0x008e, all -> 0x0089 }
        if (r4 != 0) goto L_0x0055;
    L_0x004d:
        r2 = r2.trim();	 Catch:{ Throwable -> 0x008e, all -> 0x0089 }
        r0 = java.lang.Integer.parseInt(r2);	 Catch:{ Throwable -> 0x008e, all -> 0x0089 }
    L_0x0055:
        if (r3 == 0) goto L_0x005a;
    L_0x0057:
        r3.close();	 Catch:{ Throwable -> 0x0082 }
    L_0x005a:
        r1.close();	 Catch:{ Throwable -> 0x0082 }
    L_0x005d:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
        goto L_0x000d;
    L_0x0061:
        r1 = move-exception;
        r1 = r2;
        r3 = r2;
    L_0x0064:
        if (r3 == 0) goto L_0x0069;
    L_0x0066:
        r3.close();	 Catch:{ Throwable -> 0x006f }
    L_0x0069:
        if (r1 == 0) goto L_0x005d;
    L_0x006b:
        r1.close();	 Catch:{ Throwable -> 0x006f }
        goto L_0x005d;
    L_0x006f:
        r1 = move-exception;
        goto L_0x005d;
    L_0x0071:
        r0 = move-exception;
        r1 = r2;
        r3 = r2;
    L_0x0074:
        if (r3 == 0) goto L_0x0079;
    L_0x0076:
        r3.close();	 Catch:{ Throwable -> 0x0084 }
    L_0x0079:
        if (r1 == 0) goto L_0x007e;
    L_0x007b:
        r1.close();	 Catch:{ Throwable -> 0x0084 }
    L_0x007e:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
        throw r0;
    L_0x0082:
        r1 = move-exception;
        goto L_0x005d;
    L_0x0084:
        r1 = move-exception;
        goto L_0x007e;
    L_0x0086:
        r0 = move-exception;
        r1 = r2;
        goto L_0x0074;
    L_0x0089:
        r0 = move-exception;
        goto L_0x0074;
    L_0x008b:
        r1 = move-exception;
        r1 = r2;
        goto L_0x0064;
    L_0x008e:
        r2 = move-exception;
        goto L_0x0064;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.qqvideo.proxy.common.VcSystemInfo.getMarketId(android.content.Context):int");
    }

    public static int getMCC(Context context) {
        AppMethodBeat.i(124447);
        int i;
        if (mMCC != 0) {
            i = mMCC;
            AppMethodBeat.o(124447);
            return i;
        } else if (context == null) {
            AppMethodBeat.o(124447);
            return 0;
        } else {
            try {
                Configuration configuration = context.getResources().getConfiguration();
                if (configuration != null) {
                    mMCC = configuration.mcc;
                }
                i = mMCC;
                AppMethodBeat.o(124447);
                return i;
            } catch (Throwable th) {
                AppMethodBeat.o(124447);
                return 0;
            }
        }
    }

    public static int getMNC(Context context) {
        AppMethodBeat.i(124448);
        int i;
        if (mMNC != 0) {
            i = mMNC;
            AppMethodBeat.o(124448);
            return i;
        } else if (context == null) {
            AppMethodBeat.o(124448);
            return 0;
        } else {
            try {
                Configuration configuration = context.getResources().getConfiguration();
                if (configuration != null) {
                    mMNC = configuration.mnc;
                }
                i = mMNC;
                AppMethodBeat.o(124448);
                return i;
            } catch (Throwable th) {
                AppMethodBeat.o(124448);
                return 0;
            }
        }
    }

    public static String PrintStack(Throwable th) {
        AppMethodBeat.i(124449);
        if (th == null) {
            AppMethodBeat.o(124449);
            return null;
        }
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        try {
            th.printStackTrace(new PrintStream(byteArrayOutputStream));
            byteArrayOutputStream.close();
        } catch (IOException e) {
        } catch (Throwable th2) {
            byteArrayOutputStream.close();
            AppMethodBeat.o(124449);
        }
        String byteArrayOutputStream2 = byteArrayOutputStream.toString();
        AppMethodBeat.o(124449);
        return byteArrayOutputStream2;
    }

    /* JADX WARNING: Removed duplicated region for block: B:18:0x002c A:{SYNTHETIC, Splitter:B:18:0x002c} */
    public static java.lang.String readSystemStat() {
        /*
        r0 = 0;
        r4 = 124450; // 0x1e622 float:1.74392E-40 double:6.14865E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r4);
        r1 = new java.io.RandomAccessFile;	 Catch:{ Throwable -> 0x001d, all -> 0x0027 }
        r2 = "/proc/stat";
        r3 = "r";
        r1.<init>(r2, r3);	 Catch:{ Throwable -> 0x001d, all -> 0x0027 }
        r0 = r1.readLine();	 Catch:{ Throwable -> 0x003b, all -> 0x0037 }
        r1.close();	 Catch:{ Throwable -> 0x0035 }
    L_0x0019:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r4);
        return r0;
    L_0x001d:
        r1 = move-exception;
        r1 = r0;
    L_0x001f:
        if (r1 == 0) goto L_0x0019;
    L_0x0021:
        r1.close();	 Catch:{ Throwable -> 0x0025 }
        goto L_0x0019;
    L_0x0025:
        r1 = move-exception;
        goto L_0x0019;
    L_0x0027:
        r1 = move-exception;
        r2 = r1;
        r3 = r0;
    L_0x002a:
        if (r3 == 0) goto L_0x002f;
    L_0x002c:
        r3.close();	 Catch:{ Throwable -> 0x0033 }
    L_0x002f:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r4);
        throw r2;
    L_0x0033:
        r0 = move-exception;
        goto L_0x002f;
    L_0x0035:
        r1 = move-exception;
        goto L_0x0019;
    L_0x0037:
        r0 = move-exception;
        r2 = r0;
        r3 = r1;
        goto L_0x002a;
    L_0x003b:
        r2 = move-exception;
        goto L_0x001f;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.qqvideo.proxy.common.VcSystemInfo.readSystemStat():java.lang.String");
    }

    public static int getSystemCpuUsage(String str, String str2) {
        AppMethodBeat.i(124451);
        if (TextUtils.isEmpty(str) || TextUtils.isEmpty(str2)) {
            AppMethodBeat.o(124451);
            return -1;
        }
        float f = -1.0f;
        try {
            String[] split = str.trim().split("\\s+");
            long systemIdleTime = getSystemIdleTime(split);
            long systemUptime = getSystemUptime(split);
            split = str2.trim().split("\\s+");
            long systemIdleTime2 = getSystemIdleTime(split);
            long systemUptime2 = getSystemUptime(split);
            if (systemIdleTime >= 0 && systemUptime >= 0 && systemIdleTime2 >= 0 && systemUptime2 >= 0 && systemUptime2 + systemIdleTime2 > systemUptime + systemIdleTime && systemUptime2 >= systemUptime) {
                f = (((float) (systemUptime2 - systemUptime)) / ((float) ((systemIdleTime2 + systemUptime2) - (systemIdleTime + systemUptime)))) * 100.0f;
            }
        } catch (Throwable th) {
            f = -1.0f;
        }
        int i = (int) f;
        AppMethodBeat.o(124451);
        return i;
    }

    public static long getSystemUptime(String[] strArr) {
        AppMethodBeat.i(124452);
        long j = 0;
        for (int i = 1; i < strArr.length; i++) {
            if (4 != i) {
                try {
                    j += Long.parseLong(strArr[i]);
                } catch (Throwable th) {
                    AppMethodBeat.o(124452);
                    return -1;
                }
            }
        }
        AppMethodBeat.o(124452);
        return j;
    }

    public static long getSystemIdleTime(String[] strArr) {
        AppMethodBeat.i(124453);
        try {
            long parseLong = Long.parseLong(strArr[4]);
            AppMethodBeat.o(124453);
            return parseLong;
        } catch (Throwable th) {
            AppMethodBeat.o(124453);
            return -1;
        }
    }

    public static int getNetworkClass(Context context) {
        AppMethodBeat.i(124454);
        if (context == null) {
            AppMethodBeat.o(124454);
            return 0;
        }
        int networkClass;
        ConnectivityManager connectivityManager = (ConnectivityManager) context.getSystemService("connectivity");
        if (connectivityManager != null) {
            NetworkInfo activeNetworkInfo = connectivityManager.getActiveNetworkInfo();
            if (activeNetworkInfo != null && activeNetworkInfo.isConnected()) {
                switch (activeNetworkInfo.getType()) {
                    case 0:
                        networkClass = getNetworkClass(activeNetworkInfo.getSubtype());
                        break;
                    default:
                        networkClass = 0;
                        break;
                }
                AppMethodBeat.o(124454);
                return networkClass;
            }
        }
        networkClass = 0;
        AppMethodBeat.o(124454);
        return networkClass;
    }

    private static int getNetworkClass(int i) {
        switch (i) {
            case 1:
            case 2:
            case 4:
            case 7:
            case 11:
                return 2;
            case 3:
            case 5:
            case 6:
            case 8:
            case 9:
            case 10:
            case 12:
            case 14:
            case 15:
                return 3;
            case 13:
                return 4;
            default:
                return 0;
        }
    }

    public static String getWiFiMacAddress(Context context) {
        String macAddress;
        AppMethodBeat.i(124455);
        String str = BuildConfig.FLAVOR;
        try {
            macAddress = ((WifiManager) context.getSystemService("wifi")).getConnectionInfo().getMacAddress();
        } catch (Throwable th) {
            macAddress = str;
        }
        AppMethodBeat.o(124455);
        return macAddress;
    }
}
