package com.tencent.ttpic;

import android.graphics.Bitmap;
import android.graphics.PointF;
import com.tencent.a.a;
import com.tencent.filter.BaseFilter;
import com.tencent.filter.GLSLRender;
import com.tencent.filter.e;
import com.tencent.filter.h;
import com.tencent.filter.m.o;
import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.ttpic.baseutils.BitmapUtils;
import com.tencent.ttpic.baseutils.LogUtils;
import com.tencent.ttpic.factory.TTPicFilterFactoryLocal;
import com.tencent.ttpic.filter.AlphaAdjustFilter;
import com.tencent.ttpic.filter.FaceBeautysRealAutoFilter;
import com.tencent.ttpic.filter.FaceColorAndBrightnessFilter;
import com.tencent.ttpic.filter.NewFaceColorFilter;
import com.tencent.ttpic.filter.ThinBodyFilter;
import com.tencent.ttpic.filter.ThinShoulderFilter;
import com.tencent.ttpic.manager.FeatureManager;
import com.tencent.ttpic.model.CameraFilterParamSDK;
import com.tencent.ttpic.util.FrameUtil;
import com.tencent.ttpic.util.VideoGlobalContext;
import java.util.List;

public class PTFilter {
    protected BaseFilter mFilter = new BaseFilter(GLSLRender.bJB);
    protected h mFilterFrame = new h();

    public static class PTAlphaFilter extends PTFilter {
        public PTAlphaFilter() {
            AppMethodBeat.i(80646);
            this.mFilter = new AlphaAdjustFilter();
            AppMethodBeat.o(80646);
        }

        public int init() {
            AppMethodBeat.i(80647);
            int init = super.init();
            this.mFilter.setAdjustParam(0.0f);
            this.mFilter.ApplyGLSLFilter(true, 0.0f, 0.0f);
            AppMethodBeat.o(80647);
            return init;
        }
    }

    public static class PTFaceColorAndBrightnessFilter extends PTFilter {
        public PTFaceColorAndBrightnessFilter() {
            AppMethodBeat.i(80654);
            this.mFilter = new FaceColorAndBrightnessFilter();
            AppMethodBeat.o(80654);
        }

        public void updateCurve(int[] iArr, boolean z) {
            AppMethodBeat.i(80655);
            ((FaceColorAndBrightnessFilter) this.mFilter).updateCurve(iArr, z);
            AppMethodBeat.o(80655);
        }
    }

    public static class PTNewFaceColorFilter extends PTFilter {
        public PTNewFaceColorFilter() {
            AppMethodBeat.i(80662);
            this.mFilter = new NewFaceColorFilter();
            AppMethodBeat.o(80662);
        }

        public int init() {
            AppMethodBeat.i(80663);
            int init = super.init();
            new o("inputImageTexture2", "sh/facecolor_b.png", 33986).initialParams(this.mFilter.getmProgramIds());
            AppMethodBeat.o(80663);
            return init;
        }
    }

    public static class PTSmoothSkin extends PTFilter {
        private CameraFilterParamSDK mBeautyParam;

        public PTSmoothSkin() {
            AppMethodBeat.i(80676);
            this.mFilter = new FaceBeautysRealAutoFilter();
            this.mBeautyParam = new CameraFilterParamSDK();
            setBeautyLevel(1);
            AppMethodBeat.o(80676);
        }

        public void setBeautyLevel(int i) {
            AppMethodBeat.i(80677);
            this.mBeautyParam.smoothLevel = i;
            this.mFilter.setParameterDic(this.mBeautyParam.getSmoothMap());
            AppMethodBeat.o(80677);
        }

        public int getBeautyLevel() {
            return this.mBeautyParam.smoothLevel;
        }
    }

    public static class PTThinBodyFilter extends PTFilter {
        private boolean enable = true;
        private ThinBodyFilter mThinBodyFilter = new ThinBodyFilter();
        private h mThinBodyFrame = new h();
        private float strength = 0.0f;

        public PTThinBodyFilter() {
            AppMethodBeat.i(80678);
            AppMethodBeat.o(80678);
        }

        public int init() {
            AppMethodBeat.i(80679);
            int init = super.init();
            this.mThinBodyFilter.ApplyGLSLFilter();
            AppMethodBeat.o(80679);
            return init;
        }

        public void setEnable(boolean z) {
            AppMethodBeat.i(80680);
            this.mThinBodyFilter.setShowMark(true);
            this.mThinBodyFilter.setEnable(z);
            this.enable = z;
            AppMethodBeat.o(80680);
        }

        public boolean isEnable() {
            return this.enable;
        }

        public void setBodyPoints(List<PointF> list, int i, int i2) {
            AppMethodBeat.i(80681);
            if (list != null && list.size() > 0) {
                this.mThinBodyFilter.setupBodyPoints(list, i, i2);
            }
            AppMethodBeat.o(80681);
        }

        public h process(h hVar, int i, int i2) {
            AppMethodBeat.i(80682);
            if (this.enable) {
                this.mThinBodyFilter.RenderProcess(hVar.texture[0], i, i2, -1, 0.0d, this.mThinBodyFrame);
                hVar = this.mThinBodyFrame;
                AppMethodBeat.o(80682);
                return hVar;
            }
            AppMethodBeat.o(80682);
            return hVar;
        }

        public void setStrength(float f) {
            AppMethodBeat.i(80683);
            this.mThinBodyFilter.setStrength(f);
            this.strength = f;
            AppMethodBeat.o(80683);
        }

        public float getStrength() {
            return this.strength;
        }

        public void destroy() {
            AppMethodBeat.i(80684);
            this.mThinBodyFilter.clearGLSLSelf();
            this.mThinBodyFrame.clear();
            super.destroy();
            AppMethodBeat.o(80684);
        }
    }

    public static class PTThinShoulderFilter extends PTFilter {
        private boolean enable = true;
        private ThinShoulderFilter mThinShoulderFilter = new ThinShoulderFilter();
        private h mThinShoulderFrame = new h();
        private float strength = 0.0f;

        public PTThinShoulderFilter() {
            AppMethodBeat.i(80685);
            AppMethodBeat.o(80685);
        }

        public int init() {
            AppMethodBeat.i(80686);
            int init = super.init();
            this.mThinShoulderFilter.ApplyGLSLFilter();
            AppMethodBeat.o(80686);
            return init;
        }

        public void setEnable(boolean z) {
            AppMethodBeat.i(80687);
            this.mThinShoulderFilter.setShowMark(true);
            this.mThinShoulderFilter.setEnable(z);
            this.enable = z;
            AppMethodBeat.o(80687);
        }

        public boolean isEnable() {
            return this.enable;
        }

        public boolean setBodyPoints(List<PointF> list, int i, int i2) {
            AppMethodBeat.i(80688);
            boolean z = this.mThinShoulderFilter.setupBodyPoints(list, i, i2);
            AppMethodBeat.o(80688);
            return z;
        }

        public h process(h hVar, int i, int i2) {
            AppMethodBeat.i(80689);
            if (this.enable) {
                this.mThinShoulderFilter.RenderProcess(hVar.texture[0], i, i2, -1, 0.0d, this.mThinShoulderFrame);
                hVar = this.mThinShoulderFrame;
                AppMethodBeat.o(80689);
                return hVar;
            }
            AppMethodBeat.o(80689);
            return hVar;
        }

        public void setStrength(float f) {
            AppMethodBeat.i(80690);
            this.mThinShoulderFilter.setStrength(f);
            this.strength = f;
            AppMethodBeat.o(80690);
        }

        public float getStrength() {
            return this.strength;
        }

        public void destroy() {
            AppMethodBeat.i(80691);
            this.mThinShoulderFilter.clearGLSLSelf();
            this.mThinShoulderFrame.clear();
            super.destroy();
            AppMethodBeat.o(80691);
        }
    }

    static {
        AppMethodBeat.i(80708);
        if (FeatureManager.isFilterReady()) {
            try {
                FeatureManager.loadLibrary("image_filter_cpu");
                AppMethodBeat.o(80708);
                return;
            } catch (UnsatisfiedLinkError e) {
                LogUtils.e(e);
                AppMethodBeat.o(80708);
                return;
            } catch (RuntimeException e2) {
                LogUtils.e(e2);
                AppMethodBeat.o(80708);
                return;
            } catch (Exception e3) {
                LogUtils.e(e3);
            }
        }
        AppMethodBeat.o(80708);
    }

    public PTFilter() {
        AppMethodBeat.i(80695);
        AppMethodBeat.o(80695);
    }

    public void setFilter(BaseFilter baseFilter) {
        this.mFilter = baseFilter;
    }

    public BaseFilter getFilter() {
        return this.mFilter;
    }

    public static PTFilter createById(int i, int i2) {
        AppMethodBeat.i(80696);
        PTFilter pTFilter = new PTFilter();
        pTFilter.mFilter = a.createFilter(i);
        pTFilter.mFilter.needFlipBlend = true;
        pTFilter.mFilter.setSrcFilterIndex(-1);
        pTFilter.mFilter.setEffectIndex(i2);
        AppMethodBeat.o(80696);
        return pTFilter;
    }

    @Deprecated
    public static PTFilter createByFile(String str) {
        return null;
    }

    public static PTFilter createByLut(String str) {
        AppMethodBeat.i(80697);
        PTFilter pTFilter = new PTFilter();
        Bitmap decodeSampleBitmap = BitmapUtils.decodeSampleBitmap(VideoGlobalContext.getContext(), str, 1);
        if (decodeSampleBitmap == null) {
            decodeSampleBitmap = TTPicFilterFactoryLocal.getBitmapFromEncryptedFile(str);
        }
        pTFilter.mFilter = TTPicFilterFactoryLocal.lutFilterWithBitmap(decodeSampleBitmap);
        if (pTFilter.mFilter == null) {
            AppMethodBeat.o(80697);
            return null;
        }
        pTFilter.mFilter.needFlipBlend = true;
        pTFilter.mFilter.setSrcFilterIndex(-1);
        pTFilter.mFilterFrame = new h();
        AppMethodBeat.o(80697);
        return pTFilter;
    }

    public static PTFilter createCurve2D(String str) {
        AppMethodBeat.i(80698);
        PTFilter createCurve2D = createCurve2D(str, null);
        AppMethodBeat.o(80698);
        return createCurve2D;
    }

    public static PTFilter createCurve2D(String str, float[] fArr) {
        AppMethodBeat.i(80699);
        PTFilter pTFilter = new PTFilter();
        e eVar = new e(str);
        if (fArr != null) {
            eVar.setMatrix(fArr);
        }
        pTFilter.mFilter = eVar;
        pTFilter.mFilter.needFlipBlend = true;
        pTFilter.mFilter.setSrcFilterIndex(-1);
        pTFilter.mFilterFrame = new h();
        AppMethodBeat.o(80699);
        return pTFilter;
    }

    public static PTFilter createCopyFilter() {
        AppMethodBeat.i(80700);
        PTCopyFilter pTCopyFilter = new PTCopyFilter();
        AppMethodBeat.o(80700);
        return pTCopyFilter;
    }

    public static PTFilter createYUV2RGBAFilter() {
        AppMethodBeat.i(80701);
        PTFilter pTFilter = new PTFilter();
        pTFilter.mFilter = new com.tencent.filter.o();
        AppMethodBeat.o(80701);
        return pTFilter;
    }

    public int init() {
        AppMethodBeat.i(80702);
        this.mFilter.ApplyGLSLFilter(true, 1.0f, 1.0f);
        AppMethodBeat.o(80702);
        return 0;
    }

    public void destroy() {
        AppMethodBeat.i(80703);
        this.mFilter.ClearGLSL();
        this.mFilterFrame.clear();
        AppMethodBeat.o(80703);
    }

    public h process(h hVar) {
        AppMethodBeat.i(80704);
        this.mFilter.RenderProcess(hVar.texture[0], hVar.width, hVar.height, -1, 0.0d, this.mFilterFrame);
        h lastRenderFrame = FrameUtil.getLastRenderFrame(this.mFilterFrame);
        AppMethodBeat.o(80704);
        return lastRenderFrame;
    }

    public h process(h hVar, int i, int i2) {
        AppMethodBeat.i(80705);
        this.mFilter.RenderProcess(hVar.texture[0], i, i2, -1, 0.0d, this.mFilterFrame);
        h lastRenderFrame = FrameUtil.getLastRenderFrame(this.mFilterFrame);
        AppMethodBeat.o(80705);
        return lastRenderFrame;
    }

    public void processToScreen(h hVar, int i, int i2) {
        AppMethodBeat.i(80706);
        this.mFilter.RenderProcess(hVar.texture[0], i, i2, 0, 0.0d, this.mFilterFrame);
        AppMethodBeat.o(80706);
    }

    public void setRenderMode(int i) {
        AppMethodBeat.i(80707);
        this.mFilter.setRenderMode(i);
        AppMethodBeat.o(80707);
    }
}
