package com.tencent.ttpic.device;

import android.annotation.TargetApi;
import android.app.Activity;
import android.app.ActivityManager;
import android.content.ContentResolver;
import android.content.Context;
import android.content.pm.ConfigurationInfo;
import android.content.res.Resources;
import android.graphics.Point;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.os.Build.VERSION;
import android.os.Environment;
import android.os.StatFs;
import android.provider.Settings.System;
import android.telephony.TelephonyManager;
import android.text.TextUtils;
import android.util.DisplayMetrics;
import android.view.Display;
import android.view.KeyCharacterMap;
import android.view.ViewConfiguration;
import android.view.Window;
import android.view.WindowManager.LayoutParams;
import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.tencentmap.mapsdk.map.BuildConfig;
import com.tencent.ttpic.baseutils.ApiHelper;
import com.tencent.ttpic.baseutils.LogUtils;
import com.tencent.ttpic.device.DeviceInstance.SOC_CLASS;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.net.Inet4Address;
import java.net.InetAddress;
import java.net.NetworkInterface;
import java.net.SocketException;
import java.net.UnknownHostException;
import java.util.Enumeration;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class DeviceUtils {
    public static final int COLLAGE_MATERIAL_READ_MAX_SIDE = 720;
    public static final int COLLAGE_READ_LOW_MAX_SIDE = 640;
    public static final int COLLAGE_READ_MAX_SIDE = 720;
    public static final long HIGH_END_CPU_COUNT = 4;
    public static final long HIGH_END_MEMORY_SIZE = 256;
    public static final long HIGH_END_SCREEN_SIZE = 1900800;
    public static final int LAZY_HEIGHT = 854;
    public static final int LAZY_WIDTH = 640;
    public static final int[] LONG_COLLAGE_SAVE_MAX_SIDE = new int[]{640, 560, 480, 400, 320};
    public static final long LOW_END_CPU_COUNT = 1;
    public static final long LOW_END_MEMORY_SIZE = 64;
    public static final long LOW_END_SCREEN_SIZE = 307200;
    private static final int MIN_OPENGL_ES_VERSION = 131072;
    public static final int MIN_STORAGE_SIZE = 52428800;
    public static final int MOBILE_NETWORK_2G = 1;
    public static final int MOBILE_NETWORK_3G = 2;
    public static final int MOBILE_NETWORK_4G = 3;
    public static final int MOBILE_NETWORK_DISCONNECT = 5;
    public static final int MOBILE_NETWORK_UNKNOWN = 4;
    public static final int NET_2G = 2;
    public static final int NET_3G = 3;
    public static final int NET_4G = 4;
    public static final int NET_NONE = 0;
    public static final int NET_OTHER = 5;
    public static final int NET_WIFI = 1;
    public static final int[] STORY_COLLAGE_SAVE_MAX_SHORT_SIDE = new int[]{960, 720, 640, 560, 480, 400, 320};
    private static final String TAG = DeviceUtils.class.getSimpleName();
    public static final int TOPIC_FEED_PUBLISH_MAX_SHORT_SIDE = 640;
    private static boolean mIsAllUnusable = false;
    private static boolean mIsOpenGlEsValid = true;
    private static int sCpuCount = 0;
    private static long sMaxCpuFreq = 0;
    private static int sTotalMemory = 0;

    static {
        AppMethodBeat.i(49928);
        AppMethodBeat.o(49928);
    }

    public static boolean isVeryLowEndDevice() {
        boolean z = false;
        AppMethodBeat.i(49869);
        LogUtils.i(TAG, "[isVeryLowEndDevice] + BEGIN");
        SOC_CLASS deviceSocClass = DeviceInstance.getInstance().getDeviceSocClass(DeviceAttrs.getInstance().str_deviceSocInfo);
        LogUtils.i(TAG, "[isVeryLowEndDevice] socClass = ".concat(String.valueOf(deviceSocClass)));
        if (deviceSocClass != SOC_CLASS.NULL && deviceSocClass == SOC_CLASS.V_LOW) {
            z = true;
        }
        LogUtils.i(TAG, "[isVeryLowEndDevice] + END, isVeryLowDevice = ".concat(String.valueOf(z)));
        AppMethodBeat.o(49869);
        return z;
    }

    public static boolean isSmoothHidden(Context context) {
        AppMethodBeat.i(49870);
        if (isLowEndDevice(context) || isVeryLowEndDevice()) {
            AppMethodBeat.o(49870);
            return true;
        }
        AppMethodBeat.o(49870);
        return false;
    }

    public static boolean isLowEndDevice(Context context) {
        boolean z = true;
        AppMethodBeat.i(49871);
        LogUtils.i(TAG, "[isLowEndDevice] + BEGIN");
        SOC_CLASS deviceSocClass = DeviceInstance.getInstance().getDeviceSocClass(DeviceAttrs.getInstance().str_deviceSocInfo);
        LogUtils.i(TAG, "[isLowEndDevice] socClass = ".concat(String.valueOf(deviceSocClass)));
        if (deviceSocClass == SOC_CLASS.NULL) {
            boolean z2;
            boolean z3;
            int screenWidth = getScreenWidth(context);
            int screenHeight = getScreenHeight(context);
            boolean z4 = ((long) (screenWidth * screenHeight)) <= LOW_END_SCREEN_SIZE;
            LogUtils.d(TAG, "[isLowEndDevice] isLowEndDisplay = " + z4 + ", widthPixels = " + screenWidth + ", heightPixels = " + screenHeight);
            long heapMaxSizeInMb = getHeapMaxSizeInMb(context);
            if (heapMaxSizeInMb <= 64) {
                z2 = true;
            } else {
                z2 = false;
            }
            LogUtils.d(TAG, "[isLowEndDevice] isLowMemory = " + z2 + ", deviceHeapSize(Mb) = " + heapMaxSizeInMb);
            int numCores = getNumCores();
            if (((long) numCores) <= 1) {
                z3 = true;
            } else {
                z3 = false;
            }
            LogUtils.d(TAG, "[isLowEndDevice] isLowCpuCount = " + z3 + ", cpuCount = " + numCores);
            if (!(z4 || z2 || z3)) {
                z = false;
            }
        } else if (deviceSocClass != SOC_CLASS.LOW) {
            z = false;
        }
        LogUtils.i(TAG, "[isLowEndDevice] + END, isLowEndDevice = ".concat(String.valueOf(z)));
        AppMethodBeat.o(49871);
        return z;
    }

    public static boolean isHighEndDevice(Context context) {
        boolean z = true;
        AppMethodBeat.i(49872);
        LogUtils.i(TAG, "[isHighEndDevice] + BEGIN");
        SOC_CLASS deviceSocClass = DeviceInstance.getInstance().getDeviceSocClass(DeviceAttrs.getInstance().str_deviceSocInfo);
        LogUtils.i(TAG, "[isHighEndDevice] socClass = ".concat(String.valueOf(deviceSocClass)));
        if (deviceSocClass == SOC_CLASS.NULL) {
            boolean z2;
            boolean z3;
            int screenWidth = getScreenWidth(context);
            int screenHeight = getScreenHeight(context);
            boolean z4 = ((long) (screenWidth * screenHeight)) >= HIGH_END_SCREEN_SIZE;
            LogUtils.d(TAG, "[isHighEndDevice] isHighDisplay = " + z4 + ", widthPixels = " + screenWidth + ", heightPixels = " + screenHeight);
            long heapMaxSizeInMb = getHeapMaxSizeInMb(context);
            if (heapMaxSizeInMb >= 256) {
                z2 = true;
            } else {
                z2 = false;
            }
            LogUtils.d(TAG, "[isHighEndDevice] isHighMemory = " + z2 + ", deviceHeapSize(Mb) = " + heapMaxSizeInMb);
            int numCores = getNumCores();
            if (((long) numCores) >= 4) {
                z3 = true;
            } else {
                z3 = false;
            }
            LogUtils.d(TAG, "[isHighEndDevice] isHighCpuCount = " + z3 + ", cpuCount = " + numCores);
            if (!(z4 && z2 && z3)) {
                z = false;
            }
        } else if (deviceSocClass != SOC_CLASS.HIGH) {
            z = false;
        }
        LogUtils.i(TAG, "[isHighEndDevice] + END, isHighEndDevice = ".concat(String.valueOf(z)));
        AppMethodBeat.o(49872);
        return z;
    }

    public static boolean isMiddleEndDevice(Context context) {
        boolean z = true;
        AppMethodBeat.i(49873);
        LogUtils.i(TAG, "[isMiddleEndDevice] + BEGIN");
        SOC_CLASS deviceSocClass = DeviceInstance.getInstance().getDeviceSocClass(DeviceAttrs.getInstance().str_deviceSocInfo);
        LogUtils.i(TAG, "[isMiddleEndDevice] socClass = ".concat(String.valueOf(deviceSocClass)));
        if (deviceSocClass != SOC_CLASS.NULL) {
            if (deviceSocClass != SOC_CLASS.NORMAL) {
                z = false;
            }
        } else if (isLowEndDevice(context) || isHighEndDevice(context)) {
            z = false;
        }
        LogUtils.i(TAG, "[isMiddleEndDevice] + END, isMiddleEndDevice = ".concat(String.valueOf(z)));
        AppMethodBeat.o(49873);
        return z;
    }

    public static int getScreenWidth(Context context) {
        AppMethodBeat.i(49874);
        int i = context.getResources().getDisplayMetrics().widthPixels;
        AppMethodBeat.o(49874);
        return i;
    }

    public static int getScreenHeight(Context context) {
        AppMethodBeat.i(49875);
        int i = context.getResources().getDisplayMetrics().heightPixels;
        AppMethodBeat.o(49875);
        return i;
    }

    public static float getScreenRatio(Context context) {
        AppMethodBeat.i(49876);
        int screenWidth = getScreenWidth(context);
        int screenHeight = getScreenHeight(context);
        int max = Math.max(screenWidth, screenHeight);
        screenWidth = Math.min(screenWidth, screenHeight);
        if (NotchInScreenUtils.hasNotchInScreenHw(context)) {
            max -= NotchInScreenUtils.getNotchHeightHw(context);
        }
        float f = (((float) screenWidth) * 1.0f) / ((float) max);
        AppMethodBeat.o(49876);
        return f;
    }

    public static long getHeapMaxSizeInMb(Context context) {
        long memoryClass;
        AppMethodBeat.i(49877);
        long runtimeMaxMemory = getRuntimeMaxMemory(2);
        try {
            ActivityManager activityManager = (ActivityManager) context.getSystemService("activity");
            LogUtils.v(TAG, "getHeapMaxSizeInMb(), heap size(Mb) = " + activityManager.getMemoryClass());
            memoryClass = (long) activityManager.getMemoryClass();
        } catch (Exception e) {
            LogUtils.e(e);
            memoryClass = runtimeMaxMemory;
        }
        AppMethodBeat.o(49877);
        return memoryClass;
    }

    public static long getHeapMaxSizeInKb(Context context) {
        long memoryClass;
        AppMethodBeat.i(49878);
        long runtimeMaxMemory = getRuntimeMaxMemory(1);
        try {
            ActivityManager activityManager = (ActivityManager) context.getSystemService("activity");
            LogUtils.v(TAG, "getHeapMaxSizeInKb(), heap size(Mb) = " + activityManager.getMemoryClass());
            memoryClass = (long) (activityManager.getMemoryClass() * 1024);
        } catch (Exception e) {
            LogUtils.e(e);
            memoryClass = runtimeMaxMemory;
        }
        AppMethodBeat.o(49878);
        return memoryClass;
    }

    public static long getLargeHeapMaxSizeInKb(Context context) {
        long largeMemoryClass;
        AppMethodBeat.i(49879);
        long runtimeMaxMemory = getRuntimeMaxMemory(1);
        try {
            ActivityManager activityManager = (ActivityManager) context.getSystemService("activity");
            LogUtils.v(TAG, "getLargeHeapMaxSizeInKb(), heap size(Mb) = " + activityManager.getLargeMemoryClass());
            largeMemoryClass = (long) (activityManager.getLargeMemoryClass() * 1024);
        } catch (Exception e) {
            LogUtils.e(e);
            largeMemoryClass = runtimeMaxMemory;
        }
        AppMethodBeat.o(49879);
        return largeMemoryClass;
    }

    public static long getHeapRemainSizeInKb(Context context) {
        AppMethodBeat.i(49880);
        long heapMaxSizeInKb = getHeapMaxSizeInKb(context) - getHeapAllocatedSizeInKb();
        LogUtils.v(TAG, "getHeapRemainSizeInKb(), remainSize = " + (((float) heapMaxSizeInKb) / 1024.0f) + "(Mb), " + heapMaxSizeInKb + "(Kb)");
        AppMethodBeat.o(49880);
        return heapMaxSizeInKb;
    }

    public static long getLargeHeapRemainSizeInKb(Context context) {
        AppMethodBeat.i(49881);
        long largeHeapMaxSizeInKb = getLargeHeapMaxSizeInKb(context) - getHeapAllocatedSizeInKb();
        LogUtils.v(TAG, "getLargeHeapRemainSizeInKb(), remainSize = " + (((float) largeHeapMaxSizeInKb) / 1024.0f) + "(Mb), " + largeHeapMaxSizeInKb + "(Kb)");
        AppMethodBeat.o(49881);
        return largeHeapMaxSizeInKb;
    }

    public static long getHeapAllocatedSizeInKb() {
        AppMethodBeat.i(49882);
        long runtimeTotalMemory = getRuntimeTotalMemory(1) - getRuntimeFreeMemory(1);
        LogUtils.v(TAG, "getHeapAllocatedSizeInKb(), heapAllocated = " + (((float) runtimeTotalMemory) / 1024.0f) + "(Mb), " + runtimeTotalMemory + "(Kb)");
        AppMethodBeat.o(49882);
        return runtimeTotalMemory;
    }

    public static float getHeapAllocatedPercent(Context context) {
        AppMethodBeat.i(49883);
        LogUtils.v(TAG, "getHeapAllocatedPercent(), percent = %f", new Object[]{Float.valueOf((((float) getHeapAllocatedSizeInKb()) * 1.0f) / ((float) getHeapMaxSizeInKb(context)))});
        AppMethodBeat.o(49883);
        return (((float) getHeapAllocatedSizeInKb()) * 1.0f) / ((float) getHeapMaxSizeInKb(context));
    }

    private static long getRuntimeMaxMemory(int i) {
        AppMethodBeat.i(49884);
        long maxMemory = Runtime.getRuntime().maxMemory();
        switch (i) {
            case 0:
                maxMemory = Runtime.getRuntime().maxMemory();
                break;
            case 1:
                maxMemory = Runtime.getRuntime().maxMemory() / 1024;
                break;
            case 2:
                maxMemory = (Runtime.getRuntime().maxMemory() / 1024) / 1024;
                break;
        }
        LogUtils.v(TAG, "[getRuntimeMaxMemory] maxMemory = " + ((Runtime.getRuntime().maxMemory() / 1024) / 1024) + "(Mb), " + (Runtime.getRuntime().maxMemory() / 1024) + "(Kb)");
        AppMethodBeat.o(49884);
        return maxMemory;
    }

    public static long getRuntimeRemainSize(int i) {
        AppMethodBeat.i(49885);
        long maxMemory = Runtime.getRuntime().maxMemory() - (getHeapAllocatedSizeInKb() * 1024);
        switch (i) {
            case 1:
                maxMemory /= 1024;
                break;
            case 2:
                maxMemory /= 1048576;
                break;
        }
        LogUtils.v(TAG, "[getRuntimeRemainSize] remainMemory = " + maxMemory + " " + i);
        AppMethodBeat.o(49885);
        return maxMemory;
    }

    private static long getRuntimeTotalMemory(int i) {
        long totalMemory;
        AppMethodBeat.i(49886);
        switch (i) {
            case 0:
                totalMemory = Runtime.getRuntime().totalMemory();
                break;
            case 1:
                totalMemory = Runtime.getRuntime().totalMemory() / 1024;
                break;
            case 2:
                totalMemory = (Runtime.getRuntime().totalMemory() / 1024) / 1024;
                break;
            default:
                totalMemory = Runtime.getRuntime().totalMemory();
                break;
        }
        LogUtils.v(TAG, "[getRuntimeTotalMemory] totalMemory = " + ((Runtime.getRuntime().totalMemory() / 1024) / 1024) + "(Mb), " + (Runtime.getRuntime().totalMemory() / 1024) + "(Kb)");
        AppMethodBeat.o(49886);
        return totalMemory;
    }

    private static long getRuntimeFreeMemory(int i) {
        long freeMemory;
        AppMethodBeat.i(49887);
        switch (i) {
            case 0:
                freeMemory = Runtime.getRuntime().freeMemory();
                break;
            case 1:
                freeMemory = Runtime.getRuntime().freeMemory() / 1024;
                break;
            case 2:
                freeMemory = (Runtime.getRuntime().freeMemory() / 1024) / 1024;
                break;
            default:
                freeMemory = Runtime.getRuntime().freeMemory();
                break;
        }
        LogUtils.v(TAG, "[getRuntimeFreeMemory] freeMemory = " + ((Runtime.getRuntime().freeMemory() / 1024) / 1024) + "(Mb), " + (Runtime.getRuntime().freeMemory() / 1024) + "(Kb)");
        AppMethodBeat.o(49887);
        return freeMemory;
    }

    public static int getNumCores() {
        AppMethodBeat.i(49888);
        int i;
        if (sCpuCount > 0) {
            i = sCpuCount;
            AppMethodBeat.o(49888);
            return i;
        }
        try {
            File[] listFiles = new File("/sys/devices/system/cpu/").listFiles(new 1CpuFilter());
            if (listFiles != null) {
                sCpuCount = listFiles.length;
            } else {
                sCpuCount = 1;
            }
        } catch (Throwable th) {
            LogUtils.e(th);
            sCpuCount = 1;
        }
        LogUtils.v("DeviceUtils", "sCpuCount:" + sCpuCount);
        i = sCpuCount;
        AppMethodBeat.o(49888);
        return i;
    }

    public static long getMaxCpuFreq() {
        AppMethodBeat.i(49889);
        long j;
        if (sMaxCpuFreq > 0) {
            j = sMaxCpuFreq;
            AppMethodBeat.o(49889);
            return j;
        }
        String str = BuildConfig.FLAVOR;
        try {
            InputStream inputStream = new ProcessBuilder(new String[]{"/system/bin/cat", "/sys/devices/system/cpu/cpu0/cpufreq/cpuinfo_max_freq"}).start().getInputStream();
            byte[] bArr = new byte[24];
            while (inputStream.read(bArr) != -1) {
                str = str + new String(bArr);
            }
            inputStream.close();
        } catch (IOException e) {
            LogUtils.e(e);
            str = BuildConfig.FLAVOR;
        }
        str = str.trim();
        if (str == null || str.length() == 0) {
            sMaxCpuFreq = 1;
        } else {
            try {
                sMaxCpuFreq = Long.parseLong(str);
            } catch (NumberFormatException e2) {
                sMaxCpuFreq = 1;
            }
        }
        LogUtils.v("DeviceUtils", "sMaxCpuFreq:" + sMaxCpuFreq);
        j = sMaxCpuFreq;
        AppMethodBeat.o(49889);
        return j;
    }

    /* JADX WARNING: Removed duplicated region for block: B:17:0x0037 A:{SYNTHETIC, Splitter:B:17:0x0037} */
    /* JADX WARNING: Removed duplicated region for block: B:23:0x0041 A:{SYNTHETIC, Splitter:B:23:0x0041} */
    /* JADX WARNING: Removed duplicated region for block: B:29:0x004c A:{SYNTHETIC, Splitter:B:29:0x004c} */
    public static java.lang.String getCpuName() {
        /*
        r0 = 0;
        r5 = 49890; // 0xc2e2 float:6.9911E-41 double:2.4649E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r5);
        r2 = new java.io.FileReader;	 Catch:{ FileNotFoundException -> 0x0033, IOException -> 0x003d, all -> 0x0047 }
        r1 = "/proc/cpuinfo";
        r2.<init>(r1);	 Catch:{ FileNotFoundException -> 0x0033, IOException -> 0x003d, all -> 0x0047 }
        r1 = new java.io.BufferedReader;	 Catch:{ FileNotFoundException -> 0x0033, IOException -> 0x003d, all -> 0x0047 }
        r1.<init>(r2);	 Catch:{ FileNotFoundException -> 0x0033, IOException -> 0x003d, all -> 0x0047 }
        r2 = r1.readLine();	 Catch:{ FileNotFoundException -> 0x005f, IOException -> 0x005d, all -> 0x0059 }
        if (r2 == 0) goto L_0x002c;
    L_0x001a:
        r3 = ":\\s+";
        r4 = 2;
        r2 = r2.split(r3, r4);	 Catch:{ FileNotFoundException -> 0x005f, IOException -> 0x005d, all -> 0x0059 }
        r3 = 1;
        r0 = r2[r3];	 Catch:{ FileNotFoundException -> 0x005f, IOException -> 0x005d, all -> 0x0059 }
        r1.close();	 Catch:{ IOException -> 0x0053 }
    L_0x0028:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
    L_0x002b:
        return r0;
    L_0x002c:
        r1.close();	 Catch:{ IOException -> 0x0055 }
    L_0x002f:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
        goto L_0x002b;
    L_0x0033:
        r1 = move-exception;
        r1 = r0;
    L_0x0035:
        if (r1 == 0) goto L_0x002f;
    L_0x0037:
        r1.close();	 Catch:{ IOException -> 0x003b }
        goto L_0x002f;
    L_0x003b:
        r1 = move-exception;
        goto L_0x002f;
    L_0x003d:
        r1 = move-exception;
        r1 = r0;
    L_0x003f:
        if (r1 == 0) goto L_0x002f;
    L_0x0041:
        r1.close();	 Catch:{ IOException -> 0x0045 }
        goto L_0x002f;
    L_0x0045:
        r1 = move-exception;
        goto L_0x002f;
    L_0x0047:
        r1 = move-exception;
        r2 = r1;
        r3 = r0;
    L_0x004a:
        if (r3 == 0) goto L_0x004f;
    L_0x004c:
        r3.close();	 Catch:{ IOException -> 0x0057 }
    L_0x004f:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
        throw r2;
    L_0x0053:
        r1 = move-exception;
        goto L_0x0028;
    L_0x0055:
        r1 = move-exception;
        goto L_0x002f;
    L_0x0057:
        r0 = move-exception;
        goto L_0x004f;
    L_0x0059:
        r0 = move-exception;
        r2 = r0;
        r3 = r1;
        goto L_0x004a;
    L_0x005d:
        r2 = move-exception;
        goto L_0x003f;
    L_0x005f:
        r2 = move-exception;
        goto L_0x0035;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.ttpic.device.DeviceUtils.getCpuName():java.lang.String");
    }

    public static String getImei(Context context) {
        String deviceId;
        AppMethodBeat.i(49891);
        try {
            deviceId = ((TelephonyManager) context.getSystemService("phone")).getDeviceId();
            if (!TextUtils.isEmpty(deviceId)) {
                LogUtils.i(TAG, "[getImei] IMEI: ".concat(String.valueOf(deviceId)));
                AppMethodBeat.o(49891);
                return deviceId;
            }
        } catch (Throwable th) {
            LogUtils.e(th);
        }
        deviceId = BuildConfig.FLAVOR;
        AppMethodBeat.o(49891);
        return deviceId;
    }

    @TargetApi(18)
    public static long getTotalSize(StatFs statFs) {
        long totalBytes;
        AppMethodBeat.i(49892);
        if (ApiHelper.hasJellyBeanMR2()) {
            totalBytes = statFs.getTotalBytes();
        } else {
            totalBytes = ((long) statFs.getBlockCount()) * ((long) statFs.getBlockSize());
        }
        AppMethodBeat.o(49892);
        return totalBytes;
    }

    @TargetApi(18)
    public static long getAvailableSize(StatFs statFs) {
        long availableBytes;
        AppMethodBeat.i(49893);
        if (ApiHelper.hasJellyBeanMR2()) {
            availableBytes = statFs.getAvailableBytes();
        } else {
            availableBytes = ((long) statFs.getAvailableBlocks()) * ((long) statFs.getBlockSize());
        }
        AppMethodBeat.o(49893);
        return availableBytes;
    }

    public static boolean isExternalStorageAvailable() {
        AppMethodBeat.i(49894);
        try {
            if ("mounted".equals(Environment.getExternalStorageState()) || !Environment.isExternalStorageRemovable()) {
                StatFs statFs = new StatFs(Environment.getExternalStorageDirectory().getAbsolutePath());
                AppMethodBeat.o(49894);
                return true;
            }
            AppMethodBeat.o(49894);
            return false;
        } catch (Exception e) {
            AppMethodBeat.o(49894);
            return false;
        }
    }

    public static boolean isExternalStorageSpaceEnough(long j) {
        AppMethodBeat.i(49895);
        try {
            if (getAvailableSize(new StatFs(Environment.getExternalStorageDirectory().getAbsolutePath())) > j) {
                AppMethodBeat.o(49895);
                return true;
            }
            AppMethodBeat.o(49895);
            return false;
        } catch (IllegalArgumentException e) {
            AppMethodBeat.o(49895);
            return false;
        }
    }

    public static File getExternalFilesDir(Context context) {
        AppMethodBeat.i(49896);
        File externalFilesDir = context.getExternalFilesDir(null);
        if (externalFilesDir == null) {
            externalFilesDir = new File(Environment.getExternalStorageDirectory().getPath() + ("/Android/data/" + context.getPackageName() + "/files/"));
        }
        AppMethodBeat.o(49896);
        return externalFilesDir;
    }

    public static File getExternalFilesDir(Context context, String str) {
        AppMethodBeat.i(49897);
        String str2 = null;
        if (isExternalStorageAvailable() && isExternalStorageSpaceEnough(52428800)) {
            str2 = getExternalFilesDir(context).getPath();
        }
        File file = new File(str2 + File.separator + str);
        try {
            if (file.exists() && file.isFile()) {
                file.delete();
            }
            if (!file.exists()) {
                file.mkdirs();
            }
        } catch (Exception e) {
        }
        AppMethodBeat.o(49897);
        return file;
    }

    public static int getVersionCode(Context context) {
        AppMethodBeat.i(49898);
        try {
            int i = context.getPackageManager().getPackageInfo(context.getPackageName(), 16384).versionCode;
            AppMethodBeat.o(49898);
            return i;
        } catch (Exception e) {
            AppMethodBeat.o(49898);
            return -1;
        }
    }

    public static int getVersionNameCode(Context context) {
        int i = 0;
        AppMethodBeat.i(49899);
        String[] split = getVersionName(context).split("\\.");
        String str = BuildConfig.FLAVOR;
        if (split.length >= 3) {
            str = split[i] + split[1] + split[2];
        }
        try {
            i = Integer.parseInt(str);
            AppMethodBeat.o(49899);
        } catch (Throwable th) {
            LogUtils.e(th);
            AppMethodBeat.o(49899);
        }
        return i;
    }

    public static String getVersionName(Context context) {
        AppMethodBeat.i(49900);
        try {
            String str = context.getPackageManager().getPackageInfo(context.getPackageName(), 0).versionName;
            AppMethodBeat.o(49900);
            return str;
        } catch (Exception e) {
            AppMethodBeat.o(49900);
            return null;
        }
    }

    public static String getBuildVersionName(Context context) {
        AppMethodBeat.i(49901);
        String versionName = getVersionName(context);
        if (TextUtils.isEmpty(versionName)) {
            versionName = BuildConfig.FLAVOR;
            AppMethodBeat.o(49901);
            return versionName;
        }
        versionName = versionName.substring(versionName.lastIndexOf(".") + 1);
        AppMethodBeat.o(49901);
        return versionName;
    }

    public static String getOSVersion() {
        return VERSION.RELEASE;
    }

    public static String getMachineInfo() {
        AppMethodBeat.i(49902);
        String deviceName = DeviceInstance.getInstance().getDeviceName();
        AppMethodBeat.o(49902);
        return deviceName;
    }

    public static boolean isNetworkAvailable(Context context) {
        AppMethodBeat.i(49903);
        ConnectivityManager connectivityManager = (ConnectivityManager) context.getSystemService("connectivity");
        if (connectivityManager == null) {
            AppMethodBeat.o(49903);
            return false;
        }
        NetworkInfo activeNetworkInfo = connectivityManager.getActiveNetworkInfo();
        if (activeNetworkInfo == null || !activeNetworkInfo.isConnectedOrConnecting()) {
            AppMethodBeat.o(49903);
            return false;
        }
        AppMethodBeat.o(49903);
        return true;
    }

    public static boolean isValid(Context context) {
        AppMethodBeat.i(49904);
        mIsOpenGlEsValid = getOpenGlEsVersion(context) >= MIN_OPENGL_ES_VERSION;
        mIsAllUnusable = false;
        if (mIsOpenGlEsValid) {
            AppMethodBeat.o(49904);
            return true;
        }
        AppMethodBeat.o(49904);
        return false;
    }

    public static int getOpenGlEsVersion(Context context) {
        AppMethodBeat.i(49905);
        ConfigurationInfo deviceConfigurationInfo = ((ActivityManager) context.getSystemService("activity")).getDeviceConfigurationInfo();
        if (deviceConfigurationInfo != null) {
            int i = deviceConfigurationInfo.reqGlEsVersion;
            AppMethodBeat.o(49905);
            return i;
        }
        AppMethodBeat.o(49905);
        return 65536;
    }

    public static int getScreenHeightWithNavigationBar(Activity activity) {
        AppMethodBeat.i(49906);
        int screenHeight = getScreenHeight(activity) + getNavigationBarHeight(activity);
        AppMethodBeat.o(49906);
        return screenHeight;
    }

    public static int getNavigationBarHeight(Activity activity) {
        AppMethodBeat.i(49907);
        if (isNavigationBarShow(activity)) {
            Resources resources = activity.getResources();
            int dimensionPixelSize = resources.getDimensionPixelSize(resources.getIdentifier("navigation_bar_height", "dimen", "android"));
            AppMethodBeat.o(49907);
            return dimensionPixelSize;
        }
        AppMethodBeat.o(49907);
        return 0;
    }

    public static boolean isNavigationBarShow(Activity activity) {
        AppMethodBeat.i(49908);
        if (VERSION.SDK_INT >= 17) {
            Display defaultDisplay = activity.getWindowManager().getDefaultDisplay();
            Point point = new Point();
            Point point2 = new Point();
            defaultDisplay.getSize(point);
            defaultDisplay.getRealSize(point2);
            if (point2.y != point.y) {
                AppMethodBeat.o(49908);
                return true;
            }
            AppMethodBeat.o(49908);
            return false;
        }
        boolean hasPermanentMenuKey = ViewConfiguration.get(activity).hasPermanentMenuKey();
        boolean deviceHasKey = KeyCharacterMap.deviceHasKey(4);
        if (hasPermanentMenuKey || deviceHasKey) {
            AppMethodBeat.o(49908);
            return false;
        }
        AppMethodBeat.o(49908);
        return true;
    }

    public static String getScreenSize(Context context) {
        AppMethodBeat.i(49909);
        DisplayMetrics displayMetrics = context.getResources().getDisplayMetrics();
        String str = displayMetrics.widthPixels + "*" + displayMetrics.heightPixels;
        AppMethodBeat.o(49909);
        return str;
    }

    public static boolean veryLargeScreen(Context context) {
        AppMethodBeat.i(49910);
        if (getScreenHeight(context) * getScreenWidth(context) >= 2073600) {
            AppMethodBeat.o(49910);
            return true;
        }
        AppMethodBeat.o(49910);
        return false;
    }

    public static String getLocalIpAddress() {
        String trim;
        AppMethodBeat.i(49911);
        try {
            if (NetworkInterface.getNetworkInterfaces() != null) {
                Enumeration networkInterfaces = NetworkInterface.getNetworkInterfaces();
                while (networkInterfaces.hasMoreElements()) {
                    if (networkInterfaces != null) {
                        NetworkInterface networkInterface = (NetworkInterface) networkInterfaces.nextElement();
                        if (networkInterface != null) {
                            Enumeration inetAddresses = networkInterface.getInetAddresses();
                            while (inetAddresses.hasMoreElements()) {
                                InetAddress inetAddress = (InetAddress) inetAddresses.nextElement();
                                try {
                                    if (!(inetAddress.isLoopbackAddress() || !(inetAddress instanceof Inet4Address) || Inet4Address.getByName(inetAddress.getHostAddress()) == null || inetAddress.getHostAddress().equals("null") || inetAddress.getHostAddress() == null)) {
                                        trim = inetAddress.getHostAddress().trim();
                                        AppMethodBeat.o(49911);
                                        return trim;
                                    }
                                } catch (UnknownHostException e) {
                                }
                            }
                            continue;
                        } else {
                            continue;
                        }
                    }
                }
            }
        } catch (SocketException e2) {
            LogUtils.e(e2);
        }
        trim = BuildConfig.FLAVOR;
        AppMethodBeat.o(49911);
        return trim;
    }

    /* JADX WARNING: Removed duplicated region for block: B:39:0x0099  */
    /* JADX WARNING: Removed duplicated region for block: B:38:0x0095  */
    /* JADX WARNING: Removed duplicated region for block: B:48:0x00b9  */
    /* JADX WARNING: Removed duplicated region for block: B:47:0x00b5  */
    public static java.lang.String getLocalRealIpAddress() {
        /*
        r3 = 0;
        r9 = -1;
        r8 = 49912; // 0xc2f8 float:6.9942E-41 double:2.466E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r8);
        r5 = java.net.NetworkInterface.getNetworkInterfaces();	 Catch:{ SocketException -> 0x008c, all -> 0x00ac }
        r0 = 0;
        r4 = r0;
        r1 = r3;
        r2 = r3;
    L_0x0010:
        if (r5 == 0) goto L_0x006e;
    L_0x0012:
        r0 = r5.hasMoreElements();	 Catch:{ SocketException -> 0x00cf, all -> 0x00cc }
        if (r0 == 0) goto L_0x006e;
    L_0x0018:
        if (r4 != 0) goto L_0x006e;
    L_0x001a:
        r0 = r5.nextElement();	 Catch:{ SocketException -> 0x00cf, all -> 0x00cc }
        r0 = (java.net.NetworkInterface) r0;	 Catch:{ SocketException -> 0x00cf, all -> 0x00cc }
        r3 = r0.getInetAddresses();	 Catch:{ SocketException -> 0x00cf, all -> 0x00cc }
    L_0x0024:
        r0 = r3.hasMoreElements();	 Catch:{ SocketException -> 0x00cf, all -> 0x00cc }
        if (r0 == 0) goto L_0x0010;
    L_0x002a:
        r0 = r3.nextElement();	 Catch:{ SocketException -> 0x00cf, all -> 0x00cc }
        r0 = (java.net.InetAddress) r0;	 Catch:{ SocketException -> 0x00cf, all -> 0x00cc }
        r6 = r0.isSiteLocalAddress();	 Catch:{ SocketException -> 0x00cf, all -> 0x00cc }
        if (r6 != 0) goto L_0x0050;
    L_0x0036:
        r6 = r0.isLoopbackAddress();	 Catch:{ SocketException -> 0x00cf, all -> 0x00cc }
        if (r6 != 0) goto L_0x0050;
    L_0x003c:
        r6 = r0.getHostAddress();	 Catch:{ SocketException -> 0x00cf, all -> 0x00cc }
        r7 = ":";
        r6 = r6.indexOf(r7);	 Catch:{ SocketException -> 0x00cf, all -> 0x00cc }
        if (r6 != r9) goto L_0x0050;
    L_0x0049:
        r1 = r0.getHostAddress();	 Catch:{ SocketException -> 0x00cf, all -> 0x00cc }
        r0 = 1;
        r4 = r0;
        goto L_0x0010;
    L_0x0050:
        r6 = r0.isSiteLocalAddress();	 Catch:{ SocketException -> 0x00cf, all -> 0x00cc }
        if (r6 == 0) goto L_0x0024;
    L_0x0056:
        r6 = r0.isLoopbackAddress();	 Catch:{ SocketException -> 0x00cf, all -> 0x00cc }
        if (r6 != 0) goto L_0x0024;
    L_0x005c:
        r6 = r0.getHostAddress();	 Catch:{ SocketException -> 0x00cf, all -> 0x00cc }
        r7 = ":";
        r6 = r6.indexOf(r7);	 Catch:{ SocketException -> 0x00cf, all -> 0x00cc }
        if (r6 != r9) goto L_0x0024;
    L_0x0069:
        r2 = r0.getHostAddress();	 Catch:{ SocketException -> 0x00cf, all -> 0x00cc }
        goto L_0x0024;
    L_0x006e:
        r0 = android.text.TextUtils.isEmpty(r1);
        if (r0 != 0) goto L_0x0079;
    L_0x0074:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        r0 = r1;
    L_0x0078:
        return r0;
    L_0x0079:
        r0 = getExternalLocalIpAddress();
        r1 = android.text.TextUtils.isEmpty(r0);
        if (r1 != 0) goto L_0x0087;
    L_0x0083:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        goto L_0x0078;
    L_0x0087:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        r0 = r2;
        goto L_0x0078;
    L_0x008c:
        r0 = move-exception;
        r0 = r3;
        r2 = r3;
    L_0x008f:
        r1 = android.text.TextUtils.isEmpty(r0);
        if (r1 != 0) goto L_0x0099;
    L_0x0095:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        goto L_0x0078;
    L_0x0099:
        r0 = getExternalLocalIpAddress();
        r1 = android.text.TextUtils.isEmpty(r0);
        if (r1 != 0) goto L_0x00a7;
    L_0x00a3:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        goto L_0x0078;
    L_0x00a7:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        r0 = r2;
        goto L_0x0078;
    L_0x00ac:
        r0 = move-exception;
        r0 = r3;
        r2 = r3;
    L_0x00af:
        r1 = android.text.TextUtils.isEmpty(r0);
        if (r1 != 0) goto L_0x00b9;
    L_0x00b5:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        goto L_0x0078;
    L_0x00b9:
        r0 = getExternalLocalIpAddress();
        r1 = android.text.TextUtils.isEmpty(r0);
        if (r1 != 0) goto L_0x00c7;
    L_0x00c3:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        goto L_0x0078;
    L_0x00c7:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        r0 = r2;
        goto L_0x0078;
    L_0x00cc:
        r0 = move-exception;
        r0 = r1;
        goto L_0x00af;
    L_0x00cf:
        r0 = move-exception;
        r0 = r1;
        goto L_0x008f;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.ttpic.device.DeviceUtils.getLocalRealIpAddress():java.lang.String");
    }

    public static boolean isMobileNetwork(Context context) {
        AppMethodBeat.i(49913);
        if (context == null) {
            AppMethodBeat.o(49913);
            return false;
        }
        ConnectivityManager connectivityManager = (ConnectivityManager) context.getSystemService("connectivity");
        if (connectivityManager == null) {
            AppMethodBeat.o(49913);
            return false;
        }
        NetworkInfo networkInfo = connectivityManager.getNetworkInfo(0);
        if (networkInfo != null && networkInfo.isAvailable() && networkInfo.isConnected()) {
            AppMethodBeat.o(49913);
            return true;
        }
        AppMethodBeat.o(49913);
        return false;
    }

    public static boolean isWifiNetwork(Context context) {
        AppMethodBeat.i(49914);
        if (context == null) {
            AppMethodBeat.o(49914);
            return false;
        }
        ConnectivityManager connectivityManager = (ConnectivityManager) context.getSystemService("connectivity");
        if (connectivityManager == null) {
            AppMethodBeat.o(49914);
            return false;
        }
        NetworkInfo networkInfo = connectivityManager.getNetworkInfo(1);
        if (networkInfo != null && networkInfo.isAvailable() && networkInfo.isConnected()) {
            AppMethodBeat.o(49914);
            return true;
        }
        AppMethodBeat.o(49914);
        return false;
    }

    public static int getNetworkType(Context context) {
        AppMethodBeat.i(49915);
        int i = 5;
        try {
            if (isNetworkAvailable(context)) {
                if (!isWifiNetwork(context)) {
                    switch (getMobileNetworkType(context)) {
                        case 1:
                            i = 2;
                            break;
                        case 2:
                            i = 3;
                            break;
                        case 3:
                            i = 4;
                            break;
                    }
                }
                i = 1;
            } else {
                i = 0;
            }
        } catch (Exception e) {
            LogUtils.e(e);
        }
        AppMethodBeat.o(49915);
        return i;
    }

    public static int getMobileNetworkType(Context context) {
        AppMethodBeat.i(49916);
        if (context == null) {
            AppMethodBeat.o(49916);
            return 4;
        }
        ConnectivityManager connectivityManager = (ConnectivityManager) context.getSystemService("connectivity");
        if (connectivityManager == null) {
            AppMethodBeat.o(49916);
            return 4;
        }
        NetworkInfo networkInfo = connectivityManager.getNetworkInfo(0);
        if (networkInfo != null && networkInfo.isAvailable() && networkInfo.isConnected()) {
            switch (networkInfo.getSubtype()) {
                case 1:
                case 2:
                case 4:
                    AppMethodBeat.o(49916);
                    return 1;
                case 5:
                case 6:
                case 8:
                case 9:
                case 10:
                case 12:
                case 15:
                    AppMethodBeat.o(49916);
                    return 2;
                case 13:
                    AppMethodBeat.o(49916);
                    return 3;
                default:
                    AppMethodBeat.o(49916);
                    return 4;
            }
        }
        AppMethodBeat.o(49916);
        return 5;
    }

    public static String getNetworkTypeName(Context context) {
        AppMethodBeat.i(49917);
        String str;
        switch (getNetworkType(context)) {
            case 0:
                str = "none";
                AppMethodBeat.o(49917);
                return str;
            case 1:
                str = "wifi";
                AppMethodBeat.o(49917);
                return str;
            case 2:
                str = "2G";
                AppMethodBeat.o(49917);
                return str;
            case 3:
                str = "3G";
                AppMethodBeat.o(49917);
                return str;
            case 4:
                str = "4G";
                AppMethodBeat.o(49917);
                return str;
            default:
                str = "unknow";
                AppMethodBeat.o(49917);
                return str;
        }
    }

    public static String getExternalLocalIpAddress() {
        AppMethodBeat.i(49918);
        String fetchExternalIpProviderHTML = fetchExternalIpProviderHTML("http://checkip.dyndns.org/");
        if (fetchExternalIpProviderHTML == null) {
            AppMethodBeat.o(49918);
            return null;
        }
        fetchExternalIpProviderHTML = parse(fetchExternalIpProviderHTML);
        AppMethodBeat.o(49918);
        return fetchExternalIpProviderHTML;
    }

    /* JADX WARNING: Removed duplicated region for block: B:23:0x0058 A:{SYNTHETIC, Splitter:B:23:0x0058} */
    /* JADX WARNING: Removed duplicated region for block: B:26:0x005d A:{Catch:{ Exception -> 0x0095 }} */
    /* JADX WARNING: Removed duplicated region for block: B:31:0x006a A:{SYNTHETIC, Splitter:B:31:0x006a} */
    /* JADX WARNING: Removed duplicated region for block: B:34:0x006f A:{Catch:{ Exception -> 0x0073 }} */
    /* JADX WARNING: Removed duplicated region for block: B:39:0x007b A:{SYNTHETIC, Splitter:B:39:0x007b} */
    /* JADX WARNING: Removed duplicated region for block: B:42:0x0080 A:{Catch:{ Exception -> 0x0087 }} */
    /* JADX WARNING: Removed duplicated region for block: B:23:0x0058 A:{SYNTHETIC, Splitter:B:23:0x0058} */
    /* JADX WARNING: Removed duplicated region for block: B:26:0x005d A:{Catch:{ Exception -> 0x0095 }} */
    /* JADX WARNING: Removed duplicated region for block: B:31:0x006a A:{SYNTHETIC, Splitter:B:31:0x006a} */
    /* JADX WARNING: Removed duplicated region for block: B:34:0x006f A:{Catch:{ Exception -> 0x0073 }} */
    /* JADX WARNING: Removed duplicated region for block: B:39:0x007b A:{SYNTHETIC, Splitter:B:39:0x007b} */
    /* JADX WARNING: Removed duplicated region for block: B:42:0x0080 A:{Catch:{ Exception -> 0x0087 }} */
    private static java.lang.String fetchExternalIpProviderHTML(java.lang.String r8) {
        /*
        r7 = 1024; // 0x400 float:1.435E-42 double:5.06E-321;
        r2 = 0;
        r6 = 49919; // 0xc2ff float:6.9951E-41 double:2.46633E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r6);
        r0 = new java.net.URL;	 Catch:{ MalformedURLException -> 0x0053, IOException -> 0x0065, all -> 0x0075 }
        r0.<init>(r8);	 Catch:{ MalformedURLException -> 0x0053, IOException -> 0x0065, all -> 0x0075 }
        r0 = r0.openConnection();	 Catch:{ MalformedURLException -> 0x0053, IOException -> 0x0065, all -> 0x0075 }
        r0 = (java.net.HttpURLConnection) r0;	 Catch:{ MalformedURLException -> 0x0053, IOException -> 0x0065, all -> 0x0075 }
        r1 = 1;
        java.net.HttpURLConnection.setFollowRedirects(r1);	 Catch:{ MalformedURLException -> 0x0097, IOException -> 0x0090, all -> 0x0089 }
        r1 = "GET";
        r0.setRequestMethod(r1);	 Catch:{ MalformedURLException -> 0x0097, IOException -> 0x0090, all -> 0x0089 }
        r1 = "User-Agent";
        r3 = "Mozilla/4.0 (compatible; MSIE 6.0; Windows 2000)";
        r0.setRequestProperty(r1, r3);	 Catch:{ MalformedURLException -> 0x0097, IOException -> 0x0090, all -> 0x0089 }
        r3 = r0.getInputStream();	 Catch:{ MalformedURLException -> 0x0097, IOException -> 0x0090, all -> 0x0089 }
        r1 = 1024; // 0x400 float:1.435E-42 double:5.06E-321;
        r4 = new byte[r1];	 Catch:{ MalformedURLException -> 0x009a, IOException -> 0x0093, all -> 0x008d }
        r1 = 0;
    L_0x0030:
        if (r1 >= r7) goto L_0x003c;
    L_0x0032:
        r5 = 1024 - r1;
        r5 = r3.read(r4, r1, r5);	 Catch:{ MalformedURLException -> 0x009a, IOException -> 0x0093, all -> 0x008d }
        if (r5 < 0) goto L_0x003c;
    L_0x003a:
        r1 = r1 + r5;
        goto L_0x0030;
    L_0x003c:
        r1 = new java.lang.String;	 Catch:{ MalformedURLException -> 0x009a, IOException -> 0x0093, all -> 0x008d }
        r5 = "UTF-8";
        r1.<init>(r4, r5);	 Catch:{ MalformedURLException -> 0x009a, IOException -> 0x0093, all -> 0x008d }
        if (r3 == 0) goto L_0x0049;
    L_0x0046:
        r3.close();	 Catch:{ Exception -> 0x009d }
    L_0x0049:
        if (r0 == 0) goto L_0x004e;
    L_0x004b:
        r0.disconnect();	 Catch:{ Exception -> 0x009d }
    L_0x004e:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r6);
        r0 = r1;
    L_0x0052:
        return r0;
    L_0x0053:
        r0 = move-exception;
        r0 = r2;
        r1 = r2;
    L_0x0056:
        if (r1 == 0) goto L_0x005b;
    L_0x0058:
        r1.close();	 Catch:{ Exception -> 0x0095 }
    L_0x005b:
        if (r0 == 0) goto L_0x0060;
    L_0x005d:
        r0.disconnect();	 Catch:{ Exception -> 0x0095 }
    L_0x0060:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r6);
        r0 = r2;
        goto L_0x0052;
    L_0x0065:
        r0 = move-exception;
        r0 = r2;
        r3 = r2;
    L_0x0068:
        if (r3 == 0) goto L_0x006d;
    L_0x006a:
        r3.close();	 Catch:{ Exception -> 0x0073 }
    L_0x006d:
        if (r0 == 0) goto L_0x0060;
    L_0x006f:
        r0.disconnect();	 Catch:{ Exception -> 0x0073 }
        goto L_0x0060;
    L_0x0073:
        r0 = move-exception;
        goto L_0x0060;
    L_0x0075:
        r0 = move-exception;
        r1 = r0;
        r4 = r2;
        r3 = r2;
    L_0x0079:
        if (r3 == 0) goto L_0x007e;
    L_0x007b:
        r3.close();	 Catch:{ Exception -> 0x0087 }
    L_0x007e:
        if (r4 == 0) goto L_0x0083;
    L_0x0080:
        r4.disconnect();	 Catch:{ Exception -> 0x0087 }
    L_0x0083:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r6);
        throw r1;
    L_0x0087:
        r0 = move-exception;
        goto L_0x0083;
    L_0x0089:
        r1 = move-exception;
        r4 = r0;
        r3 = r2;
        goto L_0x0079;
    L_0x008d:
        r1 = move-exception;
        r4 = r0;
        goto L_0x0079;
    L_0x0090:
        r1 = move-exception;
        r3 = r2;
        goto L_0x0068;
    L_0x0093:
        r1 = move-exception;
        goto L_0x0068;
    L_0x0095:
        r0 = move-exception;
        goto L_0x0060;
    L_0x0097:
        r1 = move-exception;
        r1 = r2;
        goto L_0x0056;
    L_0x009a:
        r1 = move-exception;
        r1 = r3;
        goto L_0x0056;
    L_0x009d:
        r0 = move-exception;
        goto L_0x004e;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.ttpic.device.DeviceUtils.fetchExternalIpProviderHTML(java.lang.String):java.lang.String");
    }

    private static String parse(String str) {
        AppMethodBeat.i(49920);
        Matcher matcher = Pattern.compile("(\\d{1,3})[.](\\d{1,3})[.](\\d{1,3})[.](\\d{1,3})", 2).matcher(str);
        if (matcher.find()) {
            String group = matcher.group(0);
            AppMethodBeat.o(49920);
            return group;
        }
        AppMethodBeat.o(49920);
        return null;
    }

    public static boolean canWriteFile(String str) {
        AppMethodBeat.i(49921);
        if (TextUtils.isEmpty(str)) {
            AppMethodBeat.o(49921);
            return false;
        }
        if (!str.endsWith(File.separator)) {
            str = str.substring(0, str.lastIndexOf(File.separator));
        }
        File file = new File(str + File.separator + "test_temp.txt");
        try {
            if (file.exists()) {
                file.delete();
            }
            file.createNewFile();
            file.delete();
            AppMethodBeat.o(49921);
            return true;
        } catch (Exception e) {
            file.delete();
            AppMethodBeat.o(49921);
            return false;
        }
    }

    public static float getWindowScreenBrightness(Window window) {
        AppMethodBeat.i(49922);
        float f = window.getAttributes().screenBrightness;
        AppMethodBeat.o(49922);
        return f;
    }

    public static void setWindowScreenBrightness(Window window, float f) {
        AppMethodBeat.i(49923);
        LayoutParams attributes = window.getAttributes();
        attributes.screenBrightness = f;
        window.setAttributes(attributes);
        AppMethodBeat.o(49923);
    }

    public static int getSystemScreenBrightness(ContentResolver contentResolver) {
        AppMethodBeat.i(49924);
        int i = 0;
        try {
            i = System.getInt(contentResolver, "screen_brightness");
        } catch (Exception e) {
            LogUtils.e(e);
        }
        AppMethodBeat.o(49924);
        return i;
    }

    public static int getSystemScreenMode(ContentResolver contentResolver) {
        AppMethodBeat.i(49925);
        int i = -1;
        try {
            i = System.getInt(contentResolver, "screen_brightness_mode");
        } catch (Exception e) {
            LogUtils.e(e);
        }
        AppMethodBeat.o(49925);
        return i;
    }

    public static void setSystemScreenMode(ContentResolver contentResolver, int i) {
        AppMethodBeat.i(49926);
        try {
            System.putInt(contentResolver, "screen_brightness_mode", i);
            contentResolver.notifyChange(System.getUriFor("screen_brightness_mode"), null);
            AppMethodBeat.o(49926);
        } catch (Exception e) {
            LogUtils.e(e);
            AppMethodBeat.o(49926);
        }
    }

    public static void setSystemScreenBrightness(ContentResolver contentResolver, int i) {
        AppMethodBeat.i(49927);
        try {
            System.putInt(contentResolver, "screen_brightness", i);
            AppMethodBeat.o(49927);
        } catch (Exception e) {
            LogUtils.e(e);
            AppMethodBeat.o(49927);
        }
    }
}
