package org.xwalk.core;

import android.app.ActivityManager;
import android.app.ActivityManager.RunningAppProcessInfo;
import android.content.ContentResolver;
import android.content.Context;
import android.content.SharedPreferences;
import android.content.SharedPreferences.Editor;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.content.pm.PackageManager.NameNotFoundException;
import android.os.Process;
import android.telephony.TelephonyManager;
import android.webkit.WebView;
import com.tencent.map.lib.mapstructure.MapRouteSectionWithName;
import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.rtmp.TXLiveConstants;
import com.tencent.tencentmap.mapsdk.map.BuildConfig;
import com.tencent.ttpic.FilterEnum4Shaka;
import com.tencent.xweb.WebView.d;
import com.tencent.xweb.c.k;
import com.tencent.xweb.e;
import com.tencent.xweb.m;
import com.tencent.xweb.util.b;
import com.tencent.xweb.util.f;
import dalvik.system.DexClassLoader;
import java.io.Closeable;
import java.io.File;
import java.lang.reflect.Method;
import java.security.MessageDigest;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Random;

public class XWalkEnvironment {
    private static final String APK_DIR = "apk";
    public static final String DOWNLOAD_CONFIG_URL = "https://dldir1.qq.com/weixin/android/wxweb/updateConfig.xml";
    public static final String DOWNLOAD_PLUGIN_UPDATE_CONFIG_URL = "http://dldir1.qq.com/weixin/android/wxweb/plugin/pluginUpdateConfig.xml";
    public static final String DOWNLOAD_PLUGIN_UPDATE_TEST_CONFIG_DEFAULT_URL = "http://dldir1.qq.com/weixin/android/wxweb/plugin/pluginUpdateConfig_test.xml";
    public static final String DOWNLOAD_X86_CONFIG_URL = "https://dldir1.qq.com/weixin/android/wxweb/updateConfig_x86.xml";
    public static final int LOCAL_TEST_VERSION = 100000;
    public static final String LOCAL_TEST_ZIP_NAME = "runtime_package.zip";
    public static final String[] MANDATORY_RESOURCES = new String[]{XWALK_CORE_CLASSES_DEX, "icudtl.dat", "xwalk.pak", "xwalk_100_percent.pak", "xweb_fullscreen_video.js"};
    private static final String META_XWALK_DOWNCONFIG_URL = "xwalk_downconfig_url";
    public static final String MM_PACKAGE_NAME = "com.tencent.mm";
    private static final String OPTIMIZED_DEX_DIR = "dex";
    private static final String PACKAGE_RE = "[a-z]+\\.[a-z0-9]+\\.[a-z0-9]+.*";
    private static final String PATCH_ZIP_TEMP_DECOMPRESS_DIR = "patch_temp_decompress";
    public static final int SDK_SUPPORT_INVOKE_NOTIFY_MIN_APKVERSION = 153;
    public static final int SDK_SUPPORT_INVOKE_RUNTIME_MIN_APKVERSION = 255;
    public static final int SDK_SUPPORT_MIN_APKVERSION = 49;
    public static final int SDK_VERSION = 190301;
    private static final int SPECIAL_TEST_USER_ID = 10001;
    private static final String SP_KEY_DEVICE_RD = "sNDeviceRd";
    private static final String SP_KEY_FILE_READER_RECORD = "xwalk_reader_record";
    private static final String SP_KEY_GRAY_VALUE = "GRAY_VALUE";
    private static final String SP_KEY_GRAY_VALUE_TEST = "TEST_GRAY_VALUE";
    private static final String SP_KEY_IP_TYPE = "IP_TYPE";
    public static final String SP_KEY_PLUGIN_AVAILABLE_VERSION = "availableVersion";
    private static final String SP_KEY_PLUGIN_TEST_CONFIG_URL = "XWEB_PLUGIN_TEST_CONFIG_URL";
    public static final String SP_KEY_PLUGIN_UPDATE_CONFIG_LAST_FETCH_TIME = "nLastFetchPluginConfigTime";
    public static final String SP_KEY_PLUGIN_UPDATE_PROCESS_ID = "nUpdatingProcessId";
    private static final String SP_NAME_PLUGIN_UPDATE_INFO = "xwalk_plugin_update_info";
    private static final String SP_NAME_PLUGIN_VERSION_INFO_PREFIX = "xwalk_plugin_version_info_";
    private static final String SP_NAME_VERSION_INFO = "XWALKINFOS";
    private static final String TAG = "XWalkEnvironment";
    public static final int TEST_APK_START_VERSION = 100000;
    public static String UPDATEINFOTAG = "xwalk_update_info";
    public static final String XWALK_CORE_APK_NAME = "base.apk";
    public static final String XWALK_CORE_CLASSES_DEX = "classes.dex";
    private static final String XWALK_CORE_EXTRACTED_DIR = "extracted_xwalkcore";
    public static final String XWALK_CORE_FILELIST_CONFIG_NAME = "filelist.config";
    private static final String XWALK_CORE_NAME_PREFIX = "xwalk_";
    private static final String XWALK_CORE_PATCH_CONFIG_NAME = "patch.config";
    private static final String XWALK_CORE_PATCH_NAME = "patch.zip";
    public static final String[] XWALK_CORE_PROVIDER_LIST = new String[]{MM_PACKAGE_NAME};
    private static final String XWALK_CORE_RES_FILELIST_CONFIG_NAME = "reslist.config";
    private static final String XWALK_CORE_ZIP_NAME = "base.zip";
    public static final String XWALK_ENV_MAP_KEY_ISGPVERSION = "isgpversion";
    public static final String XWALK_ENV_MAP_KEY_PROCESSNAME = "processname";
    public static final int XWALK_GET_FROM_PROVIDER_MAX_COUNT = 2;
    private static final String XWALK_PLUGIN_BASE_DIR = "xwalkplugin";
    public static final String XWALK_PLUGIN_NAME_FILE_READER = "FileReader";
    public static final String XWALK_PLUGIN_NAME_FULL_SCREEN_VIDEO = "FullScreenVideo";
    private static final String XWALK_PLUGIN_UPDATE_CONFIG_NAME = "pluginUpdateConfig.xml";
    private static final String XWALK_UPDATE_CONFIG_DIR = "xwalkconfig";
    private static final String ZIP_DIR = "zip";
    private static Context sApplicationContext;
    private static String sApplicationName;
    private static int sAvailableVersion = -1;
    static boolean sBHasInitedSafePsProvider = false;
    static boolean sBIsIpTypeChanged = false;
    private static String sDeviceAbi;
    private static Boolean sIsDownloadMode = Boolean.TRUE;
    private static Boolean sIsDownloadModeUpdate = Boolean.TRUE;
    private static boolean sIsForbidDownloadCode = false;
    private static boolean sIsPluginInited = false;
    private static Boolean sIsXWalkVerify;
    static Method sMMKVMethod;
    static int sNChromiuVersion = -1;
    static int sNDeviceRd = 0;
    static int sPid = Process.myPid();
    private static String sRuntimeAbi;
    static e sSPProvider = null;
    static String sStrCurentProcessName;
    static String sStrDeviceId = null;
    private static String sStrTempUpdateConfigUrl;
    private static String sStrVersionDetail;
    private static boolean sUsingCustomContext = false;
    private static String sXWalkApkUrl;
    private static String sXWalkDownConfigUrl;
    static HashMap<String, Object> sXWebArgs;
    static int s_grayValue = 0;

    static {
        AppMethodBeat.i(4296);
        AppMethodBeat.o(4296);
    }

    public static void init(Context context) {
        AppMethodBeat.i(4199);
        if (context == null || sApplicationContext != null) {
            AppMethodBeat.o(4199);
            return;
        }
        sApplicationContext = context.getApplicationContext();
        if (sAvailableVersion == -1) {
            sAvailableVersion = getSharedPreferencesForVersionInfo().getInt(SP_KEY_PLUGIN_AVAILABLE_VERSION, -1);
            sStrVersionDetail = getSharedPreferencesForVersionInfo().getString("versionDetail", BuildConfig.FLAVOR);
            if (sAvailableVersion != -1) {
                getSharedPreferences().edit().putString("XWALK_CORE_EXTRACTED_DIR", getExtractedCoreDir(sAvailableVersion)).commit();
            }
        }
        if (!sIsPluginInited) {
            sIsPluginInited = initXWalkPlugins();
        }
        m.jy(context);
        AppMethodBeat.o(4199);
    }

    private static boolean initXWalkPlugins() {
        AppMethodBeat.i(4200);
        boolean dVP = com.tencent.xweb.xwalk.a.e.dVP();
        AppMethodBeat.o(4200);
        return dVP;
    }

    public static boolean isForbidDownloadCode() {
        return sIsForbidDownloadCode;
    }

    public static void setIsForbidDownloadCode(boolean z) {
        AppMethodBeat.i(4201);
        sIsForbidDownloadCode = z;
        addXWalkInitializeLog(TAG, "setIsForbidDownloadCode: " + sIsForbidDownloadCode);
        AppMethodBeat.o(4201);
    }

    static void initSafePsProvider() {
        AppMethodBeat.i(4202);
        if (sBHasInitedSafePsProvider) {
            AppMethodBeat.o(4202);
            return;
        }
        try {
            sMMKVMethod = Class.forName("com.tencent.mm.cj.b").getMethod("getMMKV", new Class[]{Context.class, String.class, Integer.TYPE, Boolean.TYPE});
        } catch (Exception e) {
        }
        if (sMMKVMethod == null) {
            f.nI(178);
            Log.e(TAG, "initSafePsProvider failed");
        } else {
            Log.i(TAG, "initSafePsProvider suscsess");
        }
        sBHasInitedSafePsProvider = true;
        AppMethodBeat.o(4202);
    }

    public static synchronized void setXWebInitArgs(HashMap hashMap) {
        synchronized (XWalkEnvironment.class) {
            sXWebArgs = hashMap;
        }
    }

    public static synchronized Object getXWebInitArgs(String str) {
        Object obj;
        synchronized (XWalkEnvironment.class) {
            AppMethodBeat.i(4203);
            if (sXWebArgs == null || !sXWebArgs.containsKey(str)) {
                obj = null;
                AppMethodBeat.o(4203);
            } else {
                obj = sXWebArgs.get(str);
                AppMethodBeat.o(4203);
            }
        }
        return obj;
    }

    public static synchronized boolean getXWebInitArgs(String str, boolean z) {
        synchronized (XWalkEnvironment.class) {
            AppMethodBeat.i(4204);
            Object xWebInitArgs = getXWebInitArgs(str);
            if (xWebInitArgs == null) {
                AppMethodBeat.o(4204);
            } else {
                try {
                    z = Boolean.valueOf(xWebInitArgs.toString()).booleanValue();
                    AppMethodBeat.o(4204);
                } catch (Exception e) {
                    Log.e(TAG, "getXWebInitArgs boolean parse failed");
                    AppMethodBeat.o(4204);
                }
            }
        }
        return z;
    }

    public static SharedPreferences getProcessSafePreferences(String str, int i) {
        AppMethodBeat.i(4205);
        SharedPreferences sharedPreferences = sApplicationContext.getSharedPreferences(str, i);
        AppMethodBeat.o(4205);
        return sharedPreferences;
    }

    public static synchronized void setSharedPreferenceProvider(e eVar) {
        synchronized (XWalkEnvironment.class) {
            if (eVar != null) {
                sSPProvider = eVar;
            }
        }
    }

    public static SharedPreferences getMMKVSharedPreferences(String str) {
        AppMethodBeat.i(4206);
        SharedPreferences mMKVSharedPreferencesEx = getMMKVSharedPreferencesEx(str, 4, false);
        AppMethodBeat.o(4206);
        return mMKVSharedPreferencesEx;
    }

    public static SharedPreferences getMMKVSharedTransportOld(String str) {
        AppMethodBeat.i(4207);
        SharedPreferences mMKVSharedPreferencesEx = getMMKVSharedPreferencesEx(str, 4, true);
        AppMethodBeat.o(4207);
        return mMKVSharedPreferencesEx;
    }

    public static SharedPreferences getMMKVSharedPreferencesEx(String str, int i, boolean z) {
        SharedPreferences x;
        AppMethodBeat.i(4208);
        if (sSPProvider != null) {
            try {
                e eVar = sSPProvider;
                getApplicationContext();
                x = eVar.x(str, i, z);
            } catch (Exception e) {
                Log.e(TAG, "got sp from mmkv callback failed " + e.getMessage());
                x = null;
            }
            if (x != null) {
                AppMethodBeat.o(4208);
                return x;
            }
            f.nI(176);
        } else {
            f.nI(177);
        }
        initSafePsProvider();
        if (sMMKVMethod == null) {
            x = sApplicationContext.getSharedPreferences(str, i);
            AppMethodBeat.o(4208);
            return x;
        }
        try {
            Object invoke = sMMKVMethod.invoke(null, new Object[]{getApplicationContext(), str, Integer.valueOf(i), Boolean.valueOf(z)});
            if (invoke == null || !(invoke instanceof SharedPreferences)) {
                Log.e(TAG, "get mmmkv from reflection failed");
                f.nI(179);
                x = sApplicationContext.getSharedPreferences(str, i);
                AppMethodBeat.o(4208);
                return x;
            }
            x = (SharedPreferences) invoke;
            AppMethodBeat.o(4208);
            return x;
        } catch (Exception e2) {
        }
    }

    public static SharedPreferences getSharedPreferencesForUpdateConfig() {
        AppMethodBeat.i(4209);
        SharedPreferences processSafePreferences = getProcessSafePreferences("UPDATEINFOTAG", 4);
        AppMethodBeat.o(4209);
        return processSafePreferences;
    }

    public static SharedPreferences getSharedPreferencesForVersionInfo() {
        AppMethodBeat.i(4210);
        SharedPreferences sharedPreferences = sApplicationContext.getSharedPreferences(SP_NAME_VERSION_INFO, 4);
        AppMethodBeat.o(4210);
        return sharedPreferences;
    }

    public static SharedPreferences getSharedPreferencesForLog() {
        AppMethodBeat.i(4211);
        if (sApplicationContext == null) {
            AppMethodBeat.o(4211);
            return null;
        }
        SharedPreferences mMKVSharedPreferencesEx = getMMKVSharedPreferencesEx("UPDATELOG", 4, true);
        AppMethodBeat.o(4211);
        return mMKVSharedPreferencesEx;
    }

    public static SharedPreferences getSharedPreferencesForPluginUpdateInfo() {
        AppMethodBeat.i(4212);
        if (sApplicationContext == null) {
            AppMethodBeat.o(4212);
            return null;
        }
        SharedPreferences processSafePreferences = getProcessSafePreferences(SP_NAME_PLUGIN_UPDATE_INFO, 4);
        AppMethodBeat.o(4212);
        return processSafePreferences;
    }

    public static SharedPreferences getSharedPreferencesForPluginVersionInfo(String str) {
        AppMethodBeat.i(4213);
        if (sApplicationContext == null) {
            AppMethodBeat.o(4213);
            return null;
        }
        SharedPreferences processSafePreferences = getProcessSafePreferences(SP_NAME_PLUGIN_VERSION_INFO_PREFIX.concat(String.valueOf(str)), 4);
        AppMethodBeat.o(4213);
        return processSafePreferences;
    }

    public static SharedPreferences getSharedPreferencesForFileReaderRecord() {
        AppMethodBeat.i(4214);
        if (sApplicationContext == null) {
            AppMethodBeat.o(4214);
            return null;
        }
        SharedPreferences processSafePreferences = getProcessSafePreferences(SP_KEY_FILE_READER_RECORD, 4);
        AppMethodBeat.o(4214);
        return processSafePreferences;
    }

    public static String getPluginUpdateConfigFilePath() {
        AppMethodBeat.i(4215);
        String str;
        if (sApplicationContext == null) {
            str = BuildConfig.FLAVOR;
            AppMethodBeat.o(4215);
            return str;
        }
        str = getUpdateConfigDir() + File.separator + XWALK_PLUGIN_UPDATE_CONFIG_NAME;
        AppMethodBeat.o(4215);
        return str;
    }

    public static String getPluginBaseDir() {
        AppMethodBeat.i(4216);
        String str;
        if (sApplicationContext == null) {
            str = BuildConfig.FLAVOR;
            AppMethodBeat.o(4216);
            return str;
        }
        str = sApplicationContext.getDir(XWALK_PLUGIN_BASE_DIR, 0).getAbsolutePath();
        AppMethodBeat.o(4216);
        return str;
    }

    public static Context getApplicationContext() {
        return sApplicationContext;
    }

    public static SharedPreferences getSharedPreferences() {
        AppMethodBeat.i(4217);
        SharedPreferences sharedPreferences = sApplicationContext.getSharedPreferences("libxwalkcore", 4);
        AppMethodBeat.o(4217);
        return sharedPreferences;
    }

    public static boolean isCurrentVersionSupportExtendPluginForAppbrand() {
        AppMethodBeat.i(4218);
        if (!hasAvailableVersion() || getAvailableVersion() < 300) {
            AppMethodBeat.o(4218);
            return false;
        }
        AppMethodBeat.o(4218);
        return true;
    }

    public static boolean isCurrentVersionSupportMapExtendPluginForAppbrand() {
        AppMethodBeat.i(4219);
        if (hasAvailableVersion() && getFeatureSupport(FilterEnum4Shaka.MIC_SHAKA_YANG_GUANG)) {
            AppMethodBeat.o(4219);
            return true;
        }
        AppMethodBeat.o(4219);
        return false;
    }

    public static boolean isCurrentVersionSupportCustomContext() {
        AppMethodBeat.i(4220);
        if (hasAvailableVersion() && getFeatureSupport(TXLiveConstants.PUSH_EVT_ROOM_USERLIST)) {
            AppMethodBeat.o(4220);
            return true;
        }
        AppMethodBeat.o(4220);
        return false;
    }

    public static void setUsingCustomContext(boolean z) {
        AppMethodBeat.i(4221);
        sUsingCustomContext = z;
        Log.i(TAG, "setUsingCustomContext usingCustomContext:".concat(String.valueOf(z)));
        AppMethodBeat.o(4221);
    }

    public static boolean getUsingCustomContext() {
        return sUsingCustomContext;
    }

    private static boolean getFeatureSupport(int i) {
        AppMethodBeat.i(4222);
        boolean booleanValue = ((Boolean) k.f(d.ANb).excute("STR_CMD_FEATURE_SUPPORT", new Object[]{Integer.valueOf(i)})).booleanValue();
        AppMethodBeat.o(4222);
        return booleanValue;
    }

    public static boolean hasAvailableVersion() {
        AppMethodBeat.i(4223);
        if (49 > getAvailableVersion()) {
            AppMethodBeat.o(4223);
            return false;
        }
        AppMethodBeat.o(4223);
        return true;
    }

    public static int getAvailableVersion() {
        return sAvailableVersion;
    }

    public static int getInstalledNewstVersion() {
        AppMethodBeat.i(4224);
        int i = getSharedPreferencesForVersionInfo().getInt(SP_KEY_PLUGIN_AVAILABLE_VERSION, -1);
        AppMethodBeat.o(4224);
        return i;
    }

    public static int getInstalledNewstVersion(Context context) {
        AppMethodBeat.i(4225);
        if (context == null) {
            AppMethodBeat.o(4225);
            return 0;
        }
        int i = context.getSharedPreferences(SP_NAME_VERSION_INFO, 4).getInt(SP_KEY_PLUGIN_AVAILABLE_VERSION, -1);
        AppMethodBeat.o(4225);
        return i;
    }

    public static String getAvailableVersionDetail() {
        return sStrVersionDetail;
    }

    public static boolean setAvailableVersion(int i, String str) {
        AppMethodBeat.i(4226);
        Log.i(TAG, "setAvailableVersion:".concat(String.valueOf(i)));
        Editor edit = getSharedPreferencesForVersionInfo().edit();
        edit.putInt(SP_KEY_PLUGIN_AVAILABLE_VERSION, i);
        edit.putString("versionDetail", str);
        boolean commit = edit.commit();
        addXWalkInitializeLog(TAG, "set xwalk version to " + i + " suc = " + commit);
        AppMethodBeat.o(4226);
        return commit;
    }

    public static String getVesionDir(int i) {
        AppMethodBeat.i(4227);
        String absolutePath = sApplicationContext.getDir(XWALK_CORE_NAME_PREFIX.concat(String.valueOf(i)), 0).getAbsolutePath();
        File file = new File(absolutePath);
        if (!file.exists()) {
            file.mkdirs();
        }
        AppMethodBeat.o(4227);
        return absolutePath;
    }

    public static void clearAllVersion(Context context) {
        AppMethodBeat.i(4228);
        if (context == null || context.getApplicationInfo() == null || context.getApplicationInfo().dataDir == null) {
            AppMethodBeat.o(4228);
            return;
        }
        File[] listFiles = new File(context.getApplicationInfo().dataDir).listFiles();
        if (listFiles == null) {
            AppMethodBeat.o(4228);
            return;
        }
        for (File file : listFiles) {
            if (file.getName().startsWith("app_xwalk_") && file.isDirectory()) {
                b.avl(file.getAbsolutePath());
            }
        }
        setAvailableVersion(-1, BuildConfig.FLAVOR);
        AppMethodBeat.o(4228);
    }

    public static void addXWalkInitializeLog(String str, String str2) {
        AppMethodBeat.i(4229);
        addXWalkInitializeLog(str + ": " + str2);
        AppMethodBeat.o(4229);
    }

    public static void addXWalkInitializeLog(String str) {
        AppMethodBeat.i(4230);
        if (str == null || str.isEmpty()) {
            AppMethodBeat.o(4230);
            return;
        }
        Log.i("XWalkUpdater", str);
        String str2 = sPid + ":" + new SimpleDateFormat("MM-dd hh:mm:ss").format(new Date()) + " : " + str;
        SharedPreferences sharedPreferencesForLog = getSharedPreferencesForLog();
        String string = sharedPreferencesForLog.getString("log", BuildConfig.FLAVOR);
        if (string.length() > 10240) {
            string = string.substring(0, 5120);
        }
        sharedPreferencesForLog.edit().putString("log", str2 + "\n" + string).apply();
        AppMethodBeat.o(4230);
    }

    public static int getGrayValue() {
        AppMethodBeat.i(4231);
        int i;
        if (s_grayValue != 0) {
            i = s_grayValue;
            AppMethodBeat.o(4231);
            return i;
        }
        try {
            i = getSharedPreferences().getInt(SP_KEY_GRAY_VALUE_TEST, -1);
            s_grayValue = i;
            if (i <= 0) {
                s_grayValue = getSharedPreferences().getInt(SP_KEY_GRAY_VALUE, -1);
            }
            if (s_grayValue <= 0) {
                s_grayValue = getDeviceRd();
            }
        } catch (Exception e) {
            Log.e(TAG, "match gray rate exception: " + e.getMessage());
        }
        i = s_grayValue;
        AppMethodBeat.o(4231);
        return i;
    }

    public static String getXWalkInitializeLog() {
        AppMethodBeat.i(4232);
        SharedPreferences sharedPreferencesForLog = getSharedPreferencesForLog();
        String str;
        if (sharedPreferencesForLog == null) {
            str = BuildConfig.FLAVOR;
            AppMethodBeat.o(4232);
            return str;
        }
        str = sharedPreferencesForLog.getString("log", BuildConfig.FLAVOR);
        AppMethodBeat.o(4232);
        return str;
    }

    public static String getUpdateConfigDir() {
        AppMethodBeat.i(4233);
        String absolutePath = sApplicationContext.getDir(XWALK_UPDATE_CONFIG_DIR, 0).getAbsolutePath();
        AppMethodBeat.o(4233);
        return absolutePath;
    }

    public static String getUpdateConfigFullPath() {
        AppMethodBeat.i(4234);
        String str = getUpdateConfigDir() + File.separator + "updateConfg.xml";
        AppMethodBeat.o(4234);
        return str;
    }

    public static String getExtractedCoreDir(int i) {
        AppMethodBeat.i(4235);
        String str = getVesionDir(i) + File.separator + XWALK_CORE_EXTRACTED_DIR;
        File file = new File(str);
        if (!file.exists()) {
            file.mkdirs();
        }
        AppMethodBeat.o(4235);
        return str;
    }

    public static String getExtractedCoreFile(int i, String str) {
        AppMethodBeat.i(4236);
        String str2 = getVesionDir(i) + File.separator + XWALK_CORE_EXTRACTED_DIR;
        File file = new File(str2);
        if (!file.exists()) {
            file.mkdirs();
        }
        str2 = str2 + File.separator + str;
        AppMethodBeat.o(4236);
        return str2;
    }

    public static String getOptimizedDexDir(int i) {
        AppMethodBeat.i(4237);
        String str = getVesionDir(i) + File.separator + OPTIMIZED_DEX_DIR;
        File file = new File(str);
        if (!file.exists()) {
            file.mkdirs();
        }
        AppMethodBeat.o(4237);
        return str;
    }

    public static String getDownloadZipDir(int i) {
        AppMethodBeat.i(4238);
        String str = getVesionDir(i) + File.separator + ZIP_DIR;
        File file = new File(str);
        if (!file.exists()) {
            file.mkdirs();
        }
        str = str + File.separator + XWALK_CORE_ZIP_NAME;
        AppMethodBeat.o(4238);
        return str;
    }

    public static String getPatchZipTempDecompressPath(int i) {
        AppMethodBeat.i(4239);
        String str = getVesionDir(i) + File.separator + PATCH_ZIP_TEMP_DECOMPRESS_DIR;
        File file = new File(str);
        if (!file.exists()) {
            file.mkdirs();
        }
        AppMethodBeat.o(4239);
        return str;
    }

    public static String getPatchZipTempDecompressFilePath(int i, String str) {
        AppMethodBeat.i(4240);
        String str2 = getVesionDir(i) + File.separator + PATCH_ZIP_TEMP_DECOMPRESS_DIR;
        File file = new File(str2);
        if (!file.exists()) {
            file.mkdirs();
        }
        str2 = str2 + File.separator + str;
        AppMethodBeat.o(4240);
        return str2;
    }

    public static String getDownloadZipFileListConfig(int i) {
        AppMethodBeat.i(4241);
        String extractedCoreFile = getExtractedCoreFile(i, XWALK_CORE_FILELIST_CONFIG_NAME);
        AppMethodBeat.o(4241);
        return extractedCoreFile;
    }

    public static String getDownloadResFileListConfig(int i) {
        AppMethodBeat.i(4242);
        String extractedCoreFile = getExtractedCoreFile(i, XWALK_CORE_RES_FILELIST_CONFIG_NAME);
        AppMethodBeat.o(4242);
        return extractedCoreFile;
    }

    public static String getPatchFileListConfig(int i) {
        AppMethodBeat.i(4243);
        String patchZipTempDecompressFilePath = getPatchZipTempDecompressFilePath(i, XWALK_CORE_FILELIST_CONFIG_NAME);
        AppMethodBeat.o(4243);
        return patchZipTempDecompressFilePath;
    }

    public static String getPatchConfig(int i) {
        AppMethodBeat.i(4244);
        String patchZipTempDecompressFilePath = getPatchZipTempDecompressFilePath(i, XWALK_CORE_PATCH_CONFIG_NAME);
        AppMethodBeat.o(4244);
        return patchZipTempDecompressFilePath;
    }

    public static String getDownloadApkDir(int i) {
        AppMethodBeat.i(4245);
        String str = getVesionDir(i) + File.separator + APK_DIR;
        File file = new File(str);
        if (!file.exists()) {
            file.mkdirs();
        }
        AppMethodBeat.o(4245);
        return str;
    }

    public static String getDownloadApkPath(int i) {
        AppMethodBeat.i(4246);
        String str = getVesionDir(i) + File.separator + APK_DIR;
        File file = new File(str);
        if (!file.exists()) {
            file.mkdirs();
        }
        str = str + File.separator + XWALK_CORE_APK_NAME;
        AppMethodBeat.o(4246);
        return str;
    }

    public static String getDownloadPatchPath(int i) {
        AppMethodBeat.i(4247);
        String str = getVesionDir(i) + File.separator + APK_DIR;
        File file = new File(str);
        if (!file.exists()) {
            file.mkdirs();
        }
        str = str + File.separator + XWALK_CORE_PATCH_NAME;
        AppMethodBeat.o(4247);
        return str;
    }

    public static String getClassDexFilePath(int i) {
        AppMethodBeat.i(4248);
        String str = getExtractedCoreDir(i) + File.separator + XWALK_CORE_CLASSES_DEX;
        AppMethodBeat.o(4248);
        return str;
    }

    public static boolean isInTestMode() {
        AppMethodBeat.i(4249);
        String testDownLoadUrl = getTestDownLoadUrl(getApplicationContext());
        if (testDownLoadUrl == null || testDownLoadUrl.isEmpty()) {
            AppMethodBeat.o(4249);
            return false;
        }
        AppMethodBeat.o(4249);
        return true;
    }

    public static int getChromiunVersion() {
        AppMethodBeat.i(4250);
        if (sNChromiuVersion < 0) {
            sNChromiuVersion = _getChromiunVersion();
        }
        int i = sNChromiuVersion;
        AppMethodBeat.o(4250);
        return i;
    }

    public static int safeGetChromiunVersion() {
        int verFromVersionName;
        AppMethodBeat.i(4251);
        if (sNChromiuVersion < 0) {
            try {
                PackageInfo packageInfo = getApplicationContext().getPackageManager().getPackageInfo("com.google.android.webview", 0);
                if (packageInfo != null) {
                    verFromVersionName = getVerFromVersionName(packageInfo.versionName);
                    if (verFromVersionName > 0) {
                        sNChromiuVersion = verFromVersionName;
                        AppMethodBeat.o(4251);
                        return verFromVersionName;
                    }
                }
            } catch (Exception e) {
                Log.e(TAG, "Android System WebView is not found");
            }
        }
        verFromVersionName = sNChromiuVersion;
        AppMethodBeat.o(4251);
        return verFromVersionName;
    }

    static int _getChromiunVersion() {
        int verFromVersionName;
        AppMethodBeat.i(4252);
        try {
            PackageInfo packageInfo = getApplicationContext().getPackageManager().getPackageInfo("com.google.android.webview", 0);
            if (packageInfo != null) {
                verFromVersionName = getVerFromVersionName(packageInfo.versionName);
                if (verFromVersionName > 0) {
                    AppMethodBeat.o(4252);
                    return verFromVersionName;
                }
            }
        } catch (Exception e) {
            Log.e(TAG, "Android System WebView is not found");
        }
        try {
            String userAgentString = new WebView(getApplicationContext()).getSettings().getUserAgentString();
            if (userAgentString != null) {
                String[] split = userAgentString.split("Chrome/");
                if (split == null || split.length == 0 || (split.length == 1 && split[0].length() == userAgentString.length())) {
                    AppMethodBeat.o(4252);
                    return 0;
                }
                verFromVersionName = getVerFromVersionName(split[1]);
                AppMethodBeat.o(4252);
                return verFromVersionName;
            }
        } catch (Exception e2) {
            Log.e(TAG, "Android System WebView is not found");
        }
        AppMethodBeat.o(4252);
        return 0;
    }

    static int getVerFromVersionName(String str) {
        int i = 0;
        AppMethodBeat.i(4253);
        if (str == null || str.isEmpty()) {
            AppMethodBeat.o(4253);
        } else {
            try {
                i = Integer.parseInt(str.split("\\.")[0]);
                AppMethodBeat.o(4253);
            } catch (Exception e) {
                Log.e(TAG, "parse to int error str is :".concat(String.valueOf(str)));
                AppMethodBeat.o(4253);
            }
        }
        return i;
    }

    public static String getTestDownLoadUrl(Context context) {
        AppMethodBeat.i(4254);
        String string = context.getSharedPreferences("TESTXWEB", 4).getString("XWEB_TEST_CONFIG_URL", BuildConfig.FLAVOR);
        AppMethodBeat.o(4254);
        return string;
    }

    public static void setTestDownLoadUrl(Context context, String str) {
        AppMethodBeat.i(4255);
        sXWalkDownConfigUrl = null;
        if (str == null || str.isEmpty()) {
            context.getSharedPreferences("TESTXWEB", 4).edit().putString("XWEB_TEST_CONFIG_URL", BuildConfig.FLAVOR).commit();
            getXWalkUpdateConfigUrl();
            AppMethodBeat.o(4255);
            return;
        }
        context.getSharedPreferences("TESTXWEB", 4).edit().putString("XWEB_TEST_CONFIG_URL", str).commit();
        getXWalkUpdateConfigUrl();
        AppMethodBeat.o(4255);
    }

    public static synchronized void setTempUpdateConfigUrl(String str) {
        synchronized (XWalkEnvironment.class) {
            sStrTempUpdateConfigUrl = str;
        }
    }

    public static synchronized String getTempUpdateConfigUrl() {
        String str;
        synchronized (XWalkEnvironment.class) {
            str = sStrTempUpdateConfigUrl;
        }
        return str;
    }

    public static String getXWalkUpdateConfigUrl() {
        AppMethodBeat.i(4256);
        String testDownLoadUrl = getTestDownLoadUrl(getApplicationContext());
        sXWalkDownConfigUrl = testDownLoadUrl;
        if (testDownLoadUrl == null || sXWalkDownConfigUrl.trim().isEmpty()) {
            testDownLoadUrl = getTempUpdateConfigUrl();
            sXWalkDownConfigUrl = testDownLoadUrl;
            if (testDownLoadUrl != null && !sXWalkDownConfigUrl.trim().isEmpty()) {
                addXWalkInitializeLog("use temp config url : " + sXWalkDownConfigUrl);
            } else if (isIaDevice()) {
                sXWalkDownConfigUrl = DOWNLOAD_X86_CONFIG_URL;
            } else {
                sXWalkDownConfigUrl = DOWNLOAD_CONFIG_URL;
            }
        } else {
            addXWalkInitializeLog("use test config url : " + sXWalkDownConfigUrl);
        }
        Log.i(TAG, "use update config url = " + sXWalkDownConfigUrl);
        testDownLoadUrl = sXWalkDownConfigUrl;
        AppMethodBeat.o(4256);
        return testDownLoadUrl;
    }

    public static SharedPreferences getSharedPreferencesForTestXWeb() {
        AppMethodBeat.i(4257);
        if (sApplicationContext == null) {
            Log.e(TAG, "getSharedPreferencesForTestXWeb context is null");
            AppMethodBeat.o(4257);
            return null;
        }
        SharedPreferences sharedPreferences = sApplicationContext.getSharedPreferences("TESTXWEB", 4);
        AppMethodBeat.o(4257);
        return sharedPreferences;
    }

    public static String getPluginConfigUrl() {
        AppMethodBeat.i(4258);
        SharedPreferences sharedPreferencesForTestXWeb = getSharedPreferencesForTestXWeb();
        String str;
        if (sharedPreferencesForTestXWeb == null) {
            Log.e(TAG, "getPluginConfigUrl sp is null, use default");
            str = DOWNLOAD_PLUGIN_UPDATE_CONFIG_URL;
            AppMethodBeat.o(4258);
            return str;
        }
        str = sharedPreferencesForTestXWeb.getString(SP_KEY_PLUGIN_TEST_CONFIG_URL, BuildConfig.FLAVOR);
        if (str.trim().isEmpty()) {
            addXWalkInitializeLog("plugin use release config url");
            Log.i(TAG, "plugin use release config url: http://dldir1.qq.com/weixin/android/wxweb/plugin/pluginUpdateConfig.xml");
            str = DOWNLOAD_PLUGIN_UPDATE_CONFIG_URL;
            AppMethodBeat.o(4258);
            return str;
        }
        addXWalkInitializeLog("plugin use test config url");
        Log.i(TAG, "plugin use test config url: ".concat(String.valueOf(str)));
        AppMethodBeat.o(4258);
        return str;
    }

    public static boolean hasPluginTestConfigUrl() {
        AppMethodBeat.i(4259);
        SharedPreferences sharedPreferencesForTestXWeb = getSharedPreferencesForTestXWeb();
        if (sharedPreferencesForTestXWeb == null) {
            Log.e(TAG, "hasPluginTestConfigUrl sp is null");
            AppMethodBeat.o(4259);
            return false;
        } else if (sharedPreferencesForTestXWeb.getString(SP_KEY_PLUGIN_TEST_CONFIG_URL, BuildConfig.FLAVOR).trim().isEmpty()) {
            AppMethodBeat.o(4259);
            return false;
        } else {
            AppMethodBeat.o(4259);
            return true;
        }
    }

    public static boolean setPluginTestConfigUrl(String str) {
        AppMethodBeat.i(4260);
        SharedPreferences sharedPreferencesForTestXWeb = getSharedPreferencesForTestXWeb();
        if (sharedPreferencesForTestXWeb == null) {
            Log.e(TAG, "setPluginTestConfigUrl sp is null");
            AppMethodBeat.o(4260);
            return false;
        }
        Editor edit = sharedPreferencesForTestXWeb.edit();
        if (str == null || str.trim().isEmpty()) {
            edit.remove(SP_KEY_PLUGIN_TEST_CONFIG_URL);
        } else {
            edit.putString(SP_KEY_PLUGIN_TEST_CONFIG_URL, str);
        }
        boolean commit = edit.commit();
        AppMethodBeat.o(4260);
        return commit;
    }

    public static String getApplicationName() {
        AppMethodBeat.i(4261);
        if (sApplicationName == null) {
            try {
                PackageManager packageManager = sApplicationContext.getPackageManager();
                sApplicationName = (String) packageManager.getApplicationLabel(packageManager.getApplicationInfo(sApplicationContext.getPackageName(), 0));
            } catch (NameNotFoundException e) {
            }
            if (sApplicationName == null || sApplicationName.isEmpty() || sApplicationName.matches(PACKAGE_RE)) {
                sApplicationName = "this application";
            }
            Log.d(TAG, "Crosswalk application name: " + sApplicationName);
        }
        String str = sApplicationName;
        AppMethodBeat.o(4261);
        return str;
    }

    public static boolean isDownloadMode() {
        AppMethodBeat.i(4262);
        boolean booleanValue = sIsDownloadMode.booleanValue();
        AppMethodBeat.o(4262);
        return booleanValue;
    }

    public static boolean isDownloadModeUpdate() {
        AppMethodBeat.i(4263);
        boolean booleanValue = sIsDownloadModeUpdate.booleanValue();
        AppMethodBeat.o(4263);
        return booleanValue;
    }

    public static boolean isIaDevice() {
        AppMethodBeat.i(4264);
        String deviceAbi = getDeviceAbi();
        if (deviceAbi.equals("x86") || deviceAbi.equals("x86_64")) {
            AppMethodBeat.o(4264);
            return true;
        }
        AppMethodBeat.o(4264);
        return false;
    }

    public static boolean is64bitDevice() {
        AppMethodBeat.i(4265);
        String deviceAbi = getDeviceAbi();
        if (deviceAbi.equals("arm64-v8a") || deviceAbi.equals("x86_64")) {
            AppMethodBeat.o(4265);
            return true;
        }
        AppMethodBeat.o(4265);
        return false;
    }

    public static boolean is64bitApp() {
        AppMethodBeat.i(4266);
        String runtimeAbi = getRuntimeAbi();
        if (runtimeAbi.equals("arm64-v8a") || runtimeAbi.equals("x86_64")) {
            AppMethodBeat.o(4266);
            return true;
        }
        AppMethodBeat.o(4266);
        return false;
    }

    /* JADX WARNING: Missing block: B:50:0x00f9, code skipped:
            if (r4.equals("x86") != false) goto L_0x0032;
     */
    public static java.lang.String getRuntimeAbi() {
        /*
        r3 = 2;
        r2 = 1;
        r0 = 0;
        r1 = -1;
        r7 = 4267; // 0x10ab float:5.98E-42 double:2.108E-320;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r7);
        r4 = sRuntimeAbi;
        if (r4 != 0) goto L_0x00da;
    L_0x000d:
        r4 = android.os.Build.VERSION.SDK_INT;	 Catch:{ NoSuchFieldError -> 0x001e }
        r5 = 21;
        if (r4 < r5) goto L_0x0049;
    L_0x0013:
        r4 = new java.lang.NoSuchFieldError;	 Catch:{ NoSuchFieldError -> 0x001e }
        r4.<init>();	 Catch:{ NoSuchFieldError -> 0x001e }
        r5 = 4267; // 0x10ab float:5.98E-42 double:2.108E-320;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);	 Catch:{ NoSuchFieldError -> 0x001e }
        throw r4;	 Catch:{ NoSuchFieldError -> 0x001e }
    L_0x001e:
        r4 = move-exception;
        r4 = "os.arch";
        r4 = java.lang.System.getProperty(r4);
        r4 = r4.toLowerCase();
        r5 = r4.hashCode();
        switch(r5) {
            case -1409295825: goto L_0x0139;
            case -1221096139: goto L_0x015e;
            case -806050265: goto L_0x012d;
            case -738963905: goto L_0x0145;
            case 117046: goto L_0x0121;
            case 117110: goto L_0x00f2;
            case 3178856: goto L_0x0109;
            case 3181739: goto L_0x00fd;
            case 3222903: goto L_0x0115;
            case 93084186: goto L_0x0178;
            case 93086174: goto L_0x016b;
            case 145444210: goto L_0x0151;
            default: goto L_0x0031;
        };
    L_0x0031:
        r0 = r1;
    L_0x0032:
        switch(r0) {
            case 0: goto L_0x0185;
            case 1: goto L_0x0185;
            case 2: goto L_0x0185;
            case 3: goto L_0x0185;
            case 4: goto L_0x018c;
            case 5: goto L_0x018c;
            case 6: goto L_0x01a0;
            case 7: goto L_0x01a0;
            case 8: goto L_0x01a0;
            case 9: goto L_0x01a7;
            case 10: goto L_0x01a7;
            case 11: goto L_0x01a7;
            default: goto L_0x0035;
        };
    L_0x0035:
        r0 = new java.lang.RuntimeException;
        r1 = "Unexpected os.arch: ";
        r2 = java.lang.String.valueOf(r4);
        r1 = r1.concat(r2);
        r0.<init>(r1);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r7);
        throw r0;
    L_0x0049:
        r4 = android.os.Build.CPU_ABI;	 Catch:{ NoSuchFieldError -> 0x001e }
        r5 = r4.toLowerCase();	 Catch:{ NoSuchFieldError -> 0x001e }
        r4 = r5.hashCode();	 Catch:{ NoSuchFieldError -> 0x001e }
        switch(r4) {
            case -806050265: goto L_0x009c;
            case -738963905: goto L_0x0070;
            case 117110: goto L_0x0091;
            case 145444210: goto L_0x007b;
            case 1431565292: goto L_0x0086;
            default: goto L_0x0056;
        };	 Catch:{ NoSuchFieldError -> 0x001e }
    L_0x0056:
        r4 = r1;
    L_0x0057:
        switch(r4) {
            case 0: goto L_0x00a7;
            case 1: goto L_0x00a7;
            case 2: goto L_0x00e0;
            case 3: goto L_0x00e6;
            case 4: goto L_0x00ec;
            default: goto L_0x005a;
        };	 Catch:{ NoSuchFieldError -> 0x001e }
    L_0x005a:
        r4 = new java.lang.RuntimeException;	 Catch:{ NoSuchFieldError -> 0x001e }
        r6 = "Unexpected CPU_ABI: ";
        r5 = java.lang.String.valueOf(r5);	 Catch:{ NoSuchFieldError -> 0x001e }
        r5 = r6.concat(r5);	 Catch:{ NoSuchFieldError -> 0x001e }
        r4.<init>(r5);	 Catch:{ NoSuchFieldError -> 0x001e }
        r5 = 4267; // 0x10ab float:5.98E-42 double:2.108E-320;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);	 Catch:{ NoSuchFieldError -> 0x001e }
        throw r4;	 Catch:{ NoSuchFieldError -> 0x001e }
    L_0x0070:
        r4 = "armeabi";
        r4 = r5.equals(r4);	 Catch:{ NoSuchFieldError -> 0x001e }
        if (r4 == 0) goto L_0x0056;
    L_0x0079:
        r4 = r0;
        goto L_0x0057;
    L_0x007b:
        r4 = "armeabi-v7a";
        r4 = r5.equals(r4);	 Catch:{ NoSuchFieldError -> 0x001e }
        if (r4 == 0) goto L_0x0056;
    L_0x0084:
        r4 = r2;
        goto L_0x0057;
    L_0x0086:
        r4 = "arm64-v8a";
        r4 = r5.equals(r4);	 Catch:{ NoSuchFieldError -> 0x001e }
        if (r4 == 0) goto L_0x0056;
    L_0x008f:
        r4 = r3;
        goto L_0x0057;
    L_0x0091:
        r4 = "x86";
        r4 = r5.equals(r4);	 Catch:{ NoSuchFieldError -> 0x001e }
        if (r4 == 0) goto L_0x0056;
    L_0x009a:
        r4 = 3;
        goto L_0x0057;
    L_0x009c:
        r4 = "x86_64";
        r4 = r5.equals(r4);	 Catch:{ NoSuchFieldError -> 0x001e }
        if (r4 == 0) goto L_0x0056;
    L_0x00a5:
        r4 = 4;
        goto L_0x0057;
    L_0x00a7:
        r4 = "armeabi-v7a";
        sRuntimeAbi = r4;	 Catch:{ NoSuchFieldError -> 0x001e }
    L_0x00ac:
        r0 = sRuntimeAbi;
        r1 = "armeabi-v7a";
        r0 = r0.equals(r1);
        if (r0 == 0) goto L_0x01bb;
    L_0x00b7:
        r0 = isIaDevice();
        if (r0 == 0) goto L_0x00c2;
    L_0x00bd:
        r0 = "x86";
        sRuntimeAbi = r0;
    L_0x00c2:
        r0 = "XWalkEnvironment";
        r1 = new java.lang.StringBuilder;
        r2 = "Runtime ABI: ";
        r1.<init>(r2);
        r2 = sRuntimeAbi;
        r1 = r1.append(r2);
        r1 = r1.toString();
        org.xwalk.core.Log.d(r0, r1);
    L_0x00da:
        r0 = sRuntimeAbi;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r7);
        return r0;
    L_0x00e0:
        r4 = "arm64-v8a";
        sRuntimeAbi = r4;	 Catch:{ NoSuchFieldError -> 0x001e }
        goto L_0x00ac;
    L_0x00e6:
        r4 = "x86";
        sRuntimeAbi = r4;	 Catch:{ NoSuchFieldError -> 0x001e }
        goto L_0x00ac;
    L_0x00ec:
        r4 = "x86_64";
        sRuntimeAbi = r4;	 Catch:{ NoSuchFieldError -> 0x001e }
        goto L_0x00ac;
    L_0x00f2:
        r2 = "x86";
        r2 = r4.equals(r2);
        if (r2 == 0) goto L_0x0031;
    L_0x00fb:
        goto L_0x0032;
    L_0x00fd:
        r0 = "i686";
        r0 = r4.equals(r0);
        if (r0 == 0) goto L_0x0031;
    L_0x0106:
        r0 = r2;
        goto L_0x0032;
    L_0x0109:
        r0 = "i386";
        r0 = r4.equals(r0);
        if (r0 == 0) goto L_0x0031;
    L_0x0112:
        r0 = r3;
        goto L_0x0032;
    L_0x0115:
        r0 = "ia32";
        r0 = r4.equals(r0);
        if (r0 == 0) goto L_0x0031;
    L_0x011e:
        r0 = 3;
        goto L_0x0032;
    L_0x0121:
        r0 = "x64";
        r0 = r4.equals(r0);
        if (r0 == 0) goto L_0x0031;
    L_0x012a:
        r0 = 4;
        goto L_0x0032;
    L_0x012d:
        r0 = "x86_64";
        r0 = r4.equals(r0);
        if (r0 == 0) goto L_0x0031;
    L_0x0136:
        r0 = 5;
        goto L_0x0032;
    L_0x0139:
        r0 = "armv7l";
        r0 = r4.equals(r0);
        if (r0 == 0) goto L_0x0031;
    L_0x0142:
        r0 = 6;
        goto L_0x0032;
    L_0x0145:
        r0 = "armeabi";
        r0 = r4.equals(r0);
        if (r0 == 0) goto L_0x0031;
    L_0x014e:
        r0 = 7;
        goto L_0x0032;
    L_0x0151:
        r0 = "armeabi-v7a";
        r0 = r4.equals(r0);
        if (r0 == 0) goto L_0x0031;
    L_0x015a:
        r0 = 8;
        goto L_0x0032;
    L_0x015e:
        r0 = "aarch64";
        r0 = r4.equals(r0);
        if (r0 == 0) goto L_0x0031;
    L_0x0167:
        r0 = 9;
        goto L_0x0032;
    L_0x016b:
        r0 = "armv8";
        r0 = r4.equals(r0);
        if (r0 == 0) goto L_0x0031;
    L_0x0174:
        r0 = 10;
        goto L_0x0032;
    L_0x0178:
        r0 = "arm64";
        r0 = r4.equals(r0);
        if (r0 == 0) goto L_0x0031;
    L_0x0181:
        r0 = 11;
        goto L_0x0032;
    L_0x0185:
        r0 = "x86";
        sRuntimeAbi = r0;
        goto L_0x00ac;
    L_0x018c:
        r0 = is64bitDevice();
        if (r0 == 0) goto L_0x0199;
    L_0x0192:
        r0 = "x86_64";
        sRuntimeAbi = r0;
        goto L_0x00ac;
    L_0x0199:
        r0 = "x86";
        sRuntimeAbi = r0;
        goto L_0x00ac;
    L_0x01a0:
        r0 = "armeabi-v7a";
        sRuntimeAbi = r0;
        goto L_0x00ac;
    L_0x01a7:
        r0 = is64bitDevice();
        if (r0 == 0) goto L_0x01b4;
    L_0x01ad:
        r0 = "arm64-v8a";
        sRuntimeAbi = r0;
        goto L_0x00ac;
    L_0x01b4:
        r0 = "armeabi-v7a";
        sRuntimeAbi = r0;
        goto L_0x00ac;
    L_0x01bb:
        r0 = sRuntimeAbi;
        r1 = "arm64-v8a";
        r0 = r0.equals(r1);
        if (r0 == 0) goto L_0x00c2;
    L_0x01c6:
        r0 = isIaDevice();
        if (r0 == 0) goto L_0x00c2;
    L_0x01cc:
        r0 = "x86_64";
        sRuntimeAbi = r0;
        goto L_0x00c2;
        */
        throw new UnsupportedOperationException("Method not decompiled: org.xwalk.core.XWalkEnvironment.getRuntimeAbi():java.lang.String");
    }

    public static int getDeviceRd() {
        int i;
        AppMethodBeat.i(4268);
        if (sNDeviceRd <= 0) {
            i = getSharedPreferences().getInt(SP_KEY_DEVICE_RD, -1);
            sNDeviceRd = i;
            if (i <= 0) {
                sNDeviceRd = new Random().nextInt(10000000) + 1;
                getSharedPreferences().edit().putInt(SP_KEY_DEVICE_RD, sNDeviceRd).apply();
            }
        }
        i = (sNDeviceRd % 10000) + 1;
        AppMethodBeat.o(4268);
        return i;
    }

    public static void setGrayValueForTest(int i) {
        AppMethodBeat.i(4269);
        if (i != SPECIAL_TEST_USER_ID) {
            s_grayValue = i % 10000;
        }
        getSharedPreferences().edit().putInt(SP_KEY_GRAY_VALUE_TEST, s_grayValue).commit();
        AppMethodBeat.o(4269);
    }

    public static void setIpType(int i) {
        AppMethodBeat.i(4270);
        int ipType = getIpType();
        if (i != ipType) {
            getSharedPreferences().edit().putInt(SP_KEY_IP_TYPE, i).commit();
            addXWalkInitializeLog("setIpType", " to  ".concat(String.valueOf(i)));
            if (ipType == 0 && i == 1) {
                f.nI(197);
            } else if (ipType == 1 && i == 0) {
                f.nI(198);
            }
            if (ipType > 0 || i > 0) {
                sBIsIpTypeChanged = true;
                k.f(d.ANb).excute("STR_CMD_SET_RECHECK_COMMAND", null);
            }
        }
        AppMethodBeat.o(4270);
    }

    public static int getIpType() {
        AppMethodBeat.i(4271);
        int i = getSharedPreferences().getInt(SP_KEY_IP_TYPE, -2);
        AppMethodBeat.o(4271);
        return i;
    }

    public static int getUserType() {
        AppMethodBeat.i(4272);
        int ipType = getIpType();
        AppMethodBeat.o(4272);
        return ipType;
    }

    public static void setGrayValueByUserId(int i) {
        AppMethodBeat.i(4273);
        if (i == 0) {
            AppMethodBeat.o(4273);
            return;
        }
        try {
            byte[] digest = MessageDigest.getInstance("MD5").digest("xweb_gray_value".concat(String.valueOf(4294967295L & ((long) i))).getBytes());
            if (digest == null || digest.length <= 3) {
                AppMethodBeat.o(4273);
                return;
            }
            int i2 = ((digest[0] & 127) << 24) | (((digest[3] & SDK_SUPPORT_INVOKE_RUNTIME_MIN_APKVERSION) | ((digest[2] & SDK_SUPPORT_INVOKE_RUNTIME_MIN_APKVERSION) << 8)) | ((digest[1] & SDK_SUPPORT_INVOKE_RUNTIME_MIN_APKVERSION) << 16));
            if (i2 == 0) {
                AppMethodBeat.o(4273);
                return;
            }
            s_grayValue = (i2 % 10000) + 1;
            i2 = getSharedPreferences().getInt(SP_KEY_GRAY_VALUE, -1);
            getSharedPreferences().edit().putInt(SP_KEY_GRAY_VALUE, s_grayValue).commit();
            if (i2 != s_grayValue) {
                Log.i(TAG, "gray value changed to " + s_grayValue);
                k.f(d.ANb).excute("STR_CMD_SET_RECHECK_COMMAND", null);
            }
            AppMethodBeat.o(4273);
        } catch (Exception e) {
            s_grayValue = 0;
        }
    }

    public static String getDeviceId() {
        AppMethodBeat.i(4274);
        if (sStrDeviceId == null) {
            try {
                TelephonyManager telephonyManager = (TelephonyManager) getApplicationContext().getSystemService("phone");
                if (telephonyManager == null) {
                    sStrDeviceId = BuildConfig.FLAVOR;
                } else {
                    sStrDeviceId = telephonyManager.getDeviceId();
                }
            } catch (Exception e) {
                sStrDeviceId = BuildConfig.FLAVOR;
                Log.e(TAG, "getDeviceId failed " + e.getMessage());
            }
        }
        String str = sStrDeviceId;
        AppMethodBeat.o(4274);
        return str;
    }

    static void tryClose(Closeable closeable) {
        AppMethodBeat.i(4275);
        if (closeable == null) {
            AppMethodBeat.o(4275);
            return;
        }
        if (closeable != null) {
            try {
                closeable.close();
            } catch (Exception e) {
                Log.e(TAG, "closeable close  failed " + e.getMessage());
                AppMethodBeat.o(4275);
                return;
            }
        }
        AppMethodBeat.o(4275);
    }

    /* JADX WARNING: Removed duplicated region for block: B:32:0x00d5  */
    /* JADX WARNING: Removed duplicated region for block: B:18:0x0064  */
    /* JADX WARNING: Removed duplicated region for block: B:18:0x0064  */
    /* JADX WARNING: Removed duplicated region for block: B:32:0x00d5  */
    /* JADX WARNING: Removed duplicated region for block: B:32:0x00d5  */
    /* JADX WARNING: Removed duplicated region for block: B:18:0x0064  */
    public static java.lang.String getDeviceAbi() {
        /*
        r2 = 0;
        r6 = 4276; // 0x10b4 float:5.992E-42 double:2.1126E-320;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r6);
        r0 = sDeviceAbi;
        if (r0 != 0) goto L_0x0060;
    L_0x000a:
        r0 = android.os.Build.VERSION.SDK_INT;	 Catch:{ Exception -> 0x006b, NoSuchFieldError -> 0x0087 }
        r1 = 21;
        if (r0 < r1) goto L_0x001b;
    L_0x0010:
        r0 = android.os.Build.SUPPORTED_ABIS;	 Catch:{ Exception -> 0x006b, NoSuchFieldError -> 0x0087 }
        r1 = 0;
        r0 = r0[r1];	 Catch:{ Exception -> 0x006b, NoSuchFieldError -> 0x0087 }
        r0 = r0.toLowerCase();	 Catch:{ Exception -> 0x006b, NoSuchFieldError -> 0x0087 }
        sDeviceAbi = r0;	 Catch:{ Exception -> 0x006b, NoSuchFieldError -> 0x0087 }
    L_0x001b:
        r0 = sDeviceAbi;
        if (r0 != 0) goto L_0x0048;
    L_0x001f:
        r0 = java.lang.Runtime.getRuntime();	 Catch:{ Exception -> 0x00a4, all -> 0x00c8 }
        r1 = "getprop ro.product.cpu.abi";
        r0 = r0.exec(r1);	 Catch:{ Exception -> 0x00a4, all -> 0x00c8 }
        r3 = new java.io.InputStreamReader;	 Catch:{ Exception -> 0x00a4, all -> 0x00c8 }
        r0 = r0.getInputStream();	 Catch:{ Exception -> 0x00a4, all -> 0x00c8 }
        r3.<init>(r0);	 Catch:{ Exception -> 0x00a4, all -> 0x00c8 }
        r1 = new java.io.BufferedReader;	 Catch:{ Exception -> 0x00e0, all -> 0x00db }
        r1.<init>(r3);	 Catch:{ Exception -> 0x00e0, all -> 0x00db }
        r0 = r1.readLine();	 Catch:{ Exception -> 0x00e3 }
        r0 = r0.toLowerCase();	 Catch:{ Exception -> 0x00e3 }
        sDeviceAbi = r0;	 Catch:{ Exception -> 0x00e3 }
        tryClose(r3);
        tryClose(r1);
    L_0x0048:
        r0 = "XWalkEnvironment";
        r1 = new java.lang.StringBuilder;
        r2 = "Device ABI: ";
        r1.<init>(r2);
        r2 = sDeviceAbi;
        r1 = r1.append(r2);
        r1 = r1.toString();
        org.xwalk.core.Log.d(r0, r1);
    L_0x0060:
        r0 = sDeviceAbi;
        if (r0 != 0) goto L_0x00d5;
    L_0x0064:
        r0 = "";
        com.tencent.matrix.trace.core.AppMethodBeat.o(r6);
    L_0x006a:
        return r0;
    L_0x006b:
        r0 = move-exception;
        r1 = "XWalkEnvironment";
        r3 = new java.lang.StringBuilder;
        r4 = "Build.SUPPORTED_ABIS excpet ";
        r3.<init>(r4);
        r0 = r0.getMessage();
        r0 = r3.append(r0);
        r0 = r0.toString();
        org.xwalk.core.Log.e(r1, r0);
        goto L_0x001b;
    L_0x0087:
        r0 = move-exception;
        r1 = "XWalkEnvironment";
        r3 = new java.lang.StringBuilder;
        r4 = "Build.SUPPORTED_ABIS NoSuchFieldError ";
        r3.<init>(r4);
        r0 = r0.getMessage();
        r0 = r3.append(r0);
        r0 = r0.toString();
        org.xwalk.core.Log.e(r1, r0);
        goto L_0x001b;
    L_0x00a4:
        r0 = move-exception;
        r1 = r2;
        r3 = r2;
    L_0x00a7:
        r2 = "XWalkEnvironment";
        r4 = new java.lang.StringBuilder;	 Catch:{ all -> 0x00de }
        r5 = "Device ABI: ";
        r4.<init>(r5);	 Catch:{ all -> 0x00de }
        r0 = r0.getMessage();	 Catch:{ all -> 0x00de }
        r0 = r4.append(r0);	 Catch:{ all -> 0x00de }
        r0 = r0.toString();	 Catch:{ all -> 0x00de }
        org.xwalk.core.Log.e(r2, r0);	 Catch:{ all -> 0x00de }
        tryClose(r3);
        tryClose(r1);
        goto L_0x0048;
    L_0x00c8:
        r0 = move-exception;
        r1 = r2;
        r3 = r2;
    L_0x00cb:
        tryClose(r3);
        tryClose(r1);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r6);
        throw r0;
    L_0x00d5:
        r0 = sDeviceAbi;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r6);
        goto L_0x006a;
    L_0x00db:
        r0 = move-exception;
        r1 = r2;
        goto L_0x00cb;
    L_0x00de:
        r0 = move-exception;
        goto L_0x00cb;
    L_0x00e0:
        r0 = move-exception;
        r1 = r2;
        goto L_0x00a7;
    L_0x00e3:
        r0 = move-exception;
        goto L_0x00a7;
        */
        throw new UnsupportedOperationException("Method not decompiled: org.xwalk.core.XWalkEnvironment.getDeviceAbi():java.lang.String");
    }

    private static String getApplicationMetaData(String str) {
        AppMethodBeat.i(4277);
        try {
            String obj = sApplicationContext.getPackageManager().getApplicationInfo(sApplicationContext.getPackageName(), MapRouteSectionWithName.kMaxRoadNameLength).metaData.get(str).toString();
            AppMethodBeat.o(4277);
            return obj;
        } catch (NameNotFoundException | NullPointerException e) {
            AppMethodBeat.o(4277);
            return null;
        }
    }

    public static boolean checkApiVersionAvailable(int i) {
        AppMethodBeat.i(4278);
        try {
            String extractedCoreDir = getExtractedCoreDir(i);
            String classDexFilePath = getClassDexFilePath(i);
            if (new File(classDexFilePath).exists()) {
                try {
                    Class loadClass = new DexClassLoader(classDexFilePath, getOptimizedDexDir(i), extractedCoreDir, ClassLoader.getSystemClassLoader()).loadClass("org.xwalk.core.internal.XWalkCoreVersion");
                    classDexFilePath = BuildConfig.FLAVOR;
                    try {
                        classDexFilePath = (String) new ReflectField(loadClass, "XWALK_BUILD_VERSION").get();
                    } catch (RuntimeException e) {
                    }
                    int intValue = ((Integer) new ReflectField(loadClass, "API_VERSION").get()).intValue();
                    Log.d(TAG, "[Lib Version] build:" + classDexFilePath + ", api:" + intValue + ", min_api:" + ((Integer) new ReflectField(loadClass, "MIN_API_VERSION").get()).intValue());
                    AppMethodBeat.o(4278);
                    return true;
                } catch (Exception e2) {
                    AppMethodBeat.o(4278);
                    return false;
                }
            }
            AppMethodBeat.o(4278);
            return false;
        } catch (Exception e3) {
            AppMethodBeat.o(4278);
            return false;
        }
    }

    public static boolean checkApiVersionAllFileExist(int i) {
        AppMethodBeat.i(4279);
        if (checkApiVersionExtractResourceExist(i) && checkApiVersionBaseApkExist(i)) {
            AppMethodBeat.o(4279);
            return true;
        }
        AppMethodBeat.o(4279);
        return false;
    }

    public static boolean checkApiVersionBaseApkExist(int i) {
        AppMethodBeat.i(4280);
        if (new File(getDownloadApkPath(i)).exists()) {
            AppMethodBeat.o(4280);
            return true;
        }
        AppMethodBeat.o(4280);
        return false;
    }

    private static boolean checkApiVersionExtractResourceExist(int i) {
        AppMethodBeat.i(4281);
        for (String str : MANDATORY_RESOURCES) {
            if (!str.equals("xweb_fullscreen_video.js")) {
                File file = new File(getExtractedCoreDir(i) + str);
                if (!file.exists()) {
                    Log.i(TAG, "XWalkEnvironment checkApiVersionExtractResourceExist not exist Version:" + i + ", resource name:" + str + ", Path:" + file.getAbsolutePath());
                    AppMethodBeat.o(4281);
                    return false;
                }
            }
        }
        AppMethodBeat.o(4281);
        return true;
    }

    public static boolean delApiVersion(int i) {
        AppMethodBeat.i(4282);
        boolean avl = b.avl(getVesionDir(i));
        AppMethodBeat.o(4282);
        return avl;
    }

    public static String getProcessName() {
        AppMethodBeat.i(4283);
        String str;
        if (sStrCurentProcessName != null) {
            str = sStrCurentProcessName;
            AppMethodBeat.o(4283);
            return str;
        }
        Object xWebInitArgs = getXWebInitArgs(XWALK_ENV_MAP_KEY_PROCESSNAME);
        if (xWebInitArgs != null) {
            str = xWebInitArgs.toString();
            sStrCurentProcessName = str;
            AppMethodBeat.o(4283);
            return str;
        }
        Context applicationContext = getApplicationContext();
        int myPid = Process.myPid();
        if (applicationContext == null) {
            AppMethodBeat.o(4283);
            return null;
        }
        ActivityManager activityManager = (ActivityManager) applicationContext.getSystemService("activity");
        if (activityManager != null) {
            List<RunningAppProcessInfo> runningAppProcesses = activityManager.getRunningAppProcesses();
            if (runningAppProcesses != null && !runningAppProcesses.isEmpty()) {
                for (RunningAppProcessInfo runningAppProcessInfo : runningAppProcesses) {
                    if (runningAppProcessInfo.pid == myPid) {
                        sStrCurentProcessName = runningAppProcessInfo.processName;
                        break;
                    }
                }
            }
        }
        str = sStrCurentProcessName;
        AppMethodBeat.o(4283);
        return str;
    }

    public static ContentResolver getContentResolver() {
        AppMethodBeat.i(4284);
        if (sApplicationContext == null) {
            Log.e(TAG, "getContentResolver sApplicationContext is null");
            AppMethodBeat.o(4284);
            return null;
        }
        ContentResolver contentResolver = sApplicationContext.getContentResolver();
        AppMethodBeat.o(4284);
        return contentResolver;
    }

    public static Context getPackageContext(String str) {
        Context context = null;
        AppMethodBeat.i(4285);
        if (sApplicationContext == null) {
            Log.e(TAG, "getTargetPackageContext sApplicationContext is null");
            AppMethodBeat.o(4285);
        } else {
            try {
                context = sApplicationContext.createPackageContext(str, 2);
            } catch (Exception e) {
                Log.e(TAG, e.getMessage());
            }
            AppMethodBeat.o(4285);
        }
        return context;
    }

    public static boolean isSelfProvider() {
        AppMethodBeat.i(4286);
        if (sApplicationContext == null) {
            Log.e(TAG, "isSelfProvider sApplicationContext is null");
            AppMethodBeat.o(4286);
            return true;
        }
        boolean isProvider = isProvider(sApplicationContext.getPackageName());
        AppMethodBeat.o(4286);
        return isProvider;
    }

    public static boolean isProvider(String str) {
        AppMethodBeat.i(4287);
        if (str == null || str.isEmpty()) {
            Log.e(TAG, "isProvider packageName is null or empty");
            AppMethodBeat.o(4287);
            return false;
        }
        for (String equals : XWALK_CORE_PROVIDER_LIST) {
            if (equals.equals(str)) {
                AppMethodBeat.o(4287);
                return true;
            }
        }
        AppMethodBeat.o(4287);
        return false;
    }

    public static String getPackageName() {
        AppMethodBeat.i(4288);
        String str;
        if (sApplicationContext == null) {
            Log.e(TAG, "getPackageName sApplicationContext is null");
            str = BuildConfig.FLAVOR;
            AppMethodBeat.o(4288);
            return str;
        }
        str = sApplicationContext.getPackageName();
        AppMethodBeat.o(4288);
        return str;
    }

    public static String getVesionDir(Context context, int i) {
        AppMethodBeat.i(4289);
        String str;
        if (context == null) {
            Log.e(TAG, "getVersionDir with context, context is null");
            str = BuildConfig.FLAVOR;
            AppMethodBeat.o(4289);
            return str;
        }
        str = context.getDir(XWALK_CORE_NAME_PREFIX.concat(String.valueOf(i)), 0).getAbsolutePath();
        AppMethodBeat.o(4289);
        return str;
    }

    public static String getDownloadApkPath(Context context, int i) {
        AppMethodBeat.i(4290);
        String str;
        if (context == null) {
            Log.e(TAG, "getDownloadApkPath with context, context is null");
            str = BuildConfig.FLAVOR;
            AppMethodBeat.o(4290);
            return str;
        }
        str = getVesionDir(context, i);
        if (str.isEmpty()) {
            Log.e(TAG, "getDownloadApkPath with context, versionDir is empty");
            str = BuildConfig.FLAVOR;
            AppMethodBeat.o(4290);
            return str;
        }
        str = str + File.separator + APK_DIR + File.separator + XWALK_CORE_APK_NAME;
        AppMethodBeat.o(4290);
        return str;
    }

    public static String getExtractedCoreFile(Context context, int i, String str) {
        AppMethodBeat.i(4291);
        String str2;
        if (context == null) {
            Log.e(TAG, "getExtractedCoreFile with context, context is null");
            str2 = BuildConfig.FLAVOR;
            AppMethodBeat.o(4291);
            return str2;
        }
        str2 = getVesionDir(context, i);
        if (str2.isEmpty()) {
            Log.e(TAG, "getExtractedCoreFile with context, versionDir is empty");
            str2 = BuildConfig.FLAVOR;
            AppMethodBeat.o(4291);
            return str2;
        }
        str2 = str2 + File.separator + XWALK_CORE_EXTRACTED_DIR + File.separator + str;
        AppMethodBeat.o(4291);
        return str2;
    }

    public static String getPatchZipTempDecompressFilePath(Context context, int i, String str) {
        AppMethodBeat.i(4292);
        String str2;
        if (context == null) {
            Log.e(TAG, "getPatchZipTempDecompressFilePath with context, context is null");
            str2 = BuildConfig.FLAVOR;
            AppMethodBeat.o(4292);
            return str2;
        }
        str2 = getVesionDir(context, i);
        if (str2.isEmpty()) {
            Log.e(TAG, "getPatchZipTempDecompressFilePath with context, versionDir is empty");
            str2 = BuildConfig.FLAVOR;
            AppMethodBeat.o(4292);
            return str2;
        }
        str2 = str2 + File.separator + PATCH_ZIP_TEMP_DECOMPRESS_DIR + File.separator + str;
        AppMethodBeat.o(4292);
        return str2;
    }

    public static String getDownloadZipFileListConfig(Context context, int i) {
        AppMethodBeat.i(4293);
        String extractedCoreFile = getExtractedCoreFile(context, i, XWALK_CORE_FILELIST_CONFIG_NAME);
        AppMethodBeat.o(4293);
        return extractedCoreFile;
    }

    public static String getPatchFileListConfig(Context context, int i) {
        AppMethodBeat.i(4294);
        String patchZipTempDecompressFilePath = getPatchZipTempDecompressFilePath(context, i, XWALK_CORE_FILELIST_CONFIG_NAME);
        AppMethodBeat.o(4294);
        return patchZipTempDecompressFilePath;
    }

    public static int readAvailableVersionFromSP(Context context) {
        AppMethodBeat.i(4295);
        if (context == null) {
            Log.e(TAG, "readAvailableVersionFromSP context is null");
            AppMethodBeat.o(4295);
            return -1;
        }
        SharedPreferences sharedPreferences = context.getSharedPreferences(SP_NAME_VERSION_INFO, 4);
        if (sharedPreferences == null) {
            Log.e(TAG, "readAvailableVersionFromSP sp is null");
            AppMethodBeat.o(4295);
            return -1;
        }
        int i = sharedPreferences.getInt(SP_KEY_PLUGIN_AVAILABLE_VERSION, -1);
        AppMethodBeat.o(4295);
        return i;
    }

    public static boolean isTestVersion(int i) {
        return i >= 100000;
    }
}
