package org.xwalk.core;

import android.content.ContentResolver;
import android.content.Context;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager.NameNotFoundException;
import android.content.res.AssetFileDescriptor;
import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.tencentmap.mapsdk.map.BuildConfig;
import com.tencent.xweb.XWebCoreContentProvider;
import com.tencent.xweb.util.BSpatch;
import com.tencent.xweb.util.b;
import com.tencent.xweb.util.d;
import com.tencent.xweb.util.f;
import com.tencent.xweb.xwalk.b.c.a;
import dalvik.system.DexClassLoader;
import java.io.BufferedReader;
import java.io.Closeable;
import java.io.File;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.Map.Entry;

public class XWalkUpdater {
    private static final String ANDROID_MARKET_DETAILS = "market://details?id=";
    public static final int ERROR_DOPATCH_FAILED = -3;
    public static final int ERROR_DOPATCH_MD5_FAILED = -4;
    public static final int ERROR_DOWNLOAD_FAILED = -1;
    public static final int ERROR_DOWNLOAD_MD5_FAILED = -2;
    public static final int ERROR_EXTRACT_RESOURCE_FAILED = -5;
    public static final int ERROR_EXTRACT_RESOURCE_FAILED_FOR_RETRY = -12;
    public static final int ERROR_NONE = 0;
    public static final int ERROR_SET_VERNUM = -101;
    public static final int ERROR_SHARED_MODE_EXCEED_MAX_COUNT = -7;
    public static final int ERROR_SHARED_MODE_FORCE_DOWNLOAD = -6;
    public static final int ERROR_SHARED_MODE_NO_CONTENT_RESOLVER = -8;
    public static final int ERROR_SHARED_MODE_NO_PROVIDER = -9;
    public static final int ERROR_SHARED_MODE_OTHER = -11;
    public static final int ERROR_SHARED_MODE_TRY_AGAIN = -10;
    private static final String GOOGLE_PLAY_PACKAGE = "com.android.vending";
    private static final int RES_EXTRACTOR_MAXTIMES = 1;
    private static final String TAG = "XWalkLib";
    public static final int UPDATE_BIZ_TYPE_RUNTIME_PACKAGE = 1;
    public static final int UPDATE_BIZ_TYPE_RUNTIME_PATCH = 2;
    private static int mCurrentTimeForRetryRes = 0;
    private XWalkBackgroundUpdateListener mBackgroundUpdateListener;
    private Runnable mCancelCommand;
    private Context mContext;
    private XWalkDialogManager mDialogManager;
    private Runnable mDownloadCommand;
    private XWalkUpdateListener mUpdateListener;

    public static class UpdateConfig {
        public int apkVer = -1;
        public boolean bTryUseSharedCore;
        public boolean bUseCdn;
        public String downUrl;
        public String downloadFileMd5;
        public boolean isMatchMd5 = false;
        public boolean isPatchUpdate;
        public String patchEndFileMd5;
        public String versionDetail;

        public UpdateConfig(String str, boolean z, int i) {
            AppMethodBeat.i(85911);
            this.isPatchUpdate = z;
            this.downUrl = str;
            this.apkVer = i;
            if (checkValid()) {
                AppMethodBeat.o(85911);
                return;
            }
            RuntimeException runtimeException = new RuntimeException("royle:UpdateConfig is not valid");
            AppMethodBeat.o(85911);
            throw runtimeException;
        }

        public UpdateConfig(String str, boolean z, String str2, String str3, int i) {
            AppMethodBeat.i(85912);
            this.downloadFileMd5 = str;
            this.isPatchUpdate = z;
            this.patchEndFileMd5 = str2;
            this.downUrl = str3;
            this.apkVer = i;
            if (checkValid()) {
                AppMethodBeat.o(85912);
                return;
            }
            RuntimeException runtimeException = new RuntimeException("royle:UpdateConfig is not valid");
            AppMethodBeat.o(85912);
            throw runtimeException;
        }

        public String getDownloadPath() {
            AppMethodBeat.i(85913);
            String downloadPatchPath;
            if (!checkValid()) {
                RuntimeException runtimeException = new RuntimeException("royle:UpdateConfig is not valid");
                AppMethodBeat.o(85913);
                throw runtimeException;
            } else if (this.isPatchUpdate) {
                downloadPatchPath = XWalkEnvironment.getDownloadPatchPath(this.apkVer);
                AppMethodBeat.o(85913);
                return downloadPatchPath;
            } else {
                downloadPatchPath = XWalkEnvironment.getDownloadZipDir(this.apkVer);
                AppMethodBeat.o(85913);
                return downloadPatchPath;
            }
        }

        public int getUpdateBizType() {
            if (this.isPatchUpdate) {
                return 2;
            }
            return 1;
        }

        public boolean checkValid() {
            AppMethodBeat.i(85914);
            if (this.isMatchMd5 && (this.downloadFileMd5 == null || this.downloadFileMd5.isEmpty())) {
                AppMethodBeat.o(85914);
                return false;
            } else if (this.downUrl == null || this.downUrl.isEmpty()) {
                AppMethodBeat.o(85914);
                return false;
            } else if (this.apkVer == -1) {
                AppMethodBeat.o(85914);
                return false;
            } else if (this.isMatchMd5 && this.isPatchUpdate && (this.patchEndFileMd5 == null || this.patchEndFileMd5.isEmpty())) {
                AppMethodBeat.o(85914);
                return false;
            } else {
                AppMethodBeat.o(85914);
                return true;
            }
        }

        public String getLogSelf() {
            AppMethodBeat.i(85915);
            String str;
            if (checkValid()) {
                str = "UpdateConfig isMatchMd5:" + this.isMatchMd5 + " downloadFileMd5:" + this.downloadFileMd5 + ",isPatchUpdate:" + this.isPatchUpdate + ",downUrl:" + this.downUrl + ",apkVer:" + this.apkVer + ",useCDN:" + this.bUseCdn + ",downloadPath:" + getDownloadPath() + ".";
                AppMethodBeat.o(85915);
                return str;
            }
            str = "UpdateConfig is not valid";
            AppMethodBeat.o(85915);
            return str;
        }
    }

    public XWalkUpdater(XWalkUpdateListener xWalkUpdateListener, Context context) {
        AppMethodBeat.i(85916);
        this.mUpdateListener = xWalkUpdateListener;
        this.mContext = context;
        this.mDialogManager = new XWalkDialogManager(context);
        AppMethodBeat.o(85916);
    }

    public XWalkUpdater(XWalkUpdateListener xWalkUpdateListener, Context context, XWalkDialogManager xWalkDialogManager) {
        this.mUpdateListener = xWalkUpdateListener;
        this.mContext = context;
        this.mDialogManager = xWalkDialogManager;
    }

    public XWalkUpdater(XWalkBackgroundUpdateListener xWalkBackgroundUpdateListener, Context context) {
        this.mBackgroundUpdateListener = xWalkBackgroundUpdateListener;
        this.mContext = context;
    }

    public boolean updateXWalkRuntime(UpdateConfig updateConfig) {
        AppMethodBeat.i(85917);
        if (XWalkLibraryLoader.isDownloading()) {
            XWalkInitializer.addXWalkInitializeLog(TAG, "Other initialization or download is proceeding");
            AppMethodBeat.o(85917);
            return false;
        } else if (this.mBackgroundUpdateListener == null) {
            XWalkInitializer.addXWalkInitializeLog(TAG, "Update listener is null");
            AppMethodBeat.o(85917);
            return false;
        } else if (updateConfig == null || !updateConfig.checkValid()) {
            XWalkInitializer.addXWalkInitializeLog(TAG, "royle:XWalkUpdater updateXWalkRuntime updateConfig is not valid");
            f.dVd();
            AppMethodBeat.o(85917);
            return false;
        } else {
            XWalkInitializer.addXWalkInitializeLog(TAG, "start download apk");
            XWalkLibraryLoader.startHttpDownload(new BackgroundListener(this, updateConfig), this.mContext, updateConfig);
            AppMethodBeat.o(85917);
            return true;
        }
    }

    public synchronized ErrorInfo updateRuntimeFromProvider(a aVar) {
        ErrorInfo errorInfo;
        AppMethodBeat.i(85918);
        XWalkInitializer.addXWalkInitializeLog("updateFromProvider target ver " + aVar.ATn);
        ErrorInfo errorInfo2 = new ErrorInfo();
        errorInfo2.targetVer = aVar.ATn;
        if (!aVar.bTryUseSharedCore) {
            XWalkInitializer.addXWalkInitializeLog("updateFromProvider force download");
            errorInfo2.errorCode = -6;
            AppMethodBeat.o(85918);
            errorInfo = errorInfo2;
        } else if (aVar.ATy >= 2) {
            XWalkInitializer.addXWalkInitializeLog("updateFromProvider exceed max count");
            errorInfo2.errorCode = -7;
            AppMethodBeat.o(85918);
            errorInfo = errorInfo2;
        } else {
            ContentResolver contentResolver = XWalkEnvironment.getContentResolver();
            if (contentResolver == null) {
                XWalkInitializer.addXWalkInitializeLog("updateFromProvider content resolver null");
                errorInfo2.errorCode = -8;
                AppMethodBeat.o(85918);
                errorInfo = errorInfo2;
            } else {
                UpdateConfig dWe = aVar.dWe();
                Object obj = null;
                for (String str : XWalkEnvironment.XWALK_CORE_PROVIDER_LIST) {
                    if (isProviderExist(contentResolver, str)) {
                        obj = 1;
                        XWalkInitializer.addXWalkInitializeLog("updateFromProvider find ".concat(String.valueOf(str)));
                        Map tryGetFileList = tryGetFileList(contentResolver, str, dWe.apkVer);
                        if (tryGetFileList == null) {
                            XWalkInitializer.addXWalkInitializeLog("updateFromProvider read fileList failed");
                            errorInfo2.readFileListFailedCount++;
                        } else if (tryGetFileList.size() == 0) {
                            XWalkInitializer.addXWalkInitializeLog("updateFromProvider no matched version");
                            errorInfo2.noMatchedVersionCount++;
                        } else if (tryCopyVersion(contentResolver, str, dWe.apkVer, tryGetFileList, errorInfo2)) {
                            int intValue = extractResource(dWe).intValue();
                            if (intValue == 0) {
                                errorInfo2.errorCode = 0;
                                AppMethodBeat.o(85918);
                                errorInfo = errorInfo2;
                                break;
                            } else if (intValue == -5) {
                                errorInfo2.extractFailedCount++;
                            } else if (intValue == -12) {
                                errorInfo2.extractRetryFailedCount++;
                            } else if (intValue == ERROR_SET_VERNUM) {
                                errorInfo2.setVersionFailedCount++;
                            }
                        } else {
                            continue;
                        }
                    }
                }
                if (obj == null) {
                    XWalkInitializer.addXWalkInitializeLog("updateFromProvider no provider");
                    errorInfo2.errorCode = -9;
                    AppMethodBeat.o(85918);
                    errorInfo = errorInfo2;
                } else {
                    if (!XWalkEnvironment.hasAvailableVersion() || aVar.ATy + 1 >= 2) {
                        XWalkInitializer.addXWalkInitializeLog("updateFromProvider failed, do not try again");
                        errorInfo2.errorCode = -11;
                    } else {
                        XWalkInitializer.addXWalkInitializeLog("updateFromProvider failed, can try again");
                        errorInfo2.errorCode = -10;
                    }
                    AppMethodBeat.o(85918);
                    errorInfo = errorInfo2;
                }
            }
        }
        return errorInfo;
    }

    private static boolean isProviderExist(ContentResolver contentResolver, String str) {
        boolean z = true;
        boolean z2 = false;
        AppMethodBeat.i(85919);
        if (contentResolver == null || str == null || str.isEmpty()) {
            AppMethodBeat.o(85919);
            return z2;
        }
        try {
            b.a(contentResolver.openAssetFileDescriptor(XWebCoreContentProvider.b(str, XWalkEnvironment.getPackageName(), 1, 0, BuildConfig.FLAVOR), BuildConfig.FLAVOR));
        } catch (Exception e) {
            b.a(null);
            z = z2;
        } catch (Throwable th) {
            b.a(null);
            AppMethodBeat.o(85919);
        }
        AppMethodBeat.o(85919);
        return z;
    }

    private static Map<String, String> tryGetFileList(ContentResolver contentResolver, String str, int i) {
        Exception e;
        Closeable closeable;
        Closeable closeable2;
        Throwable th;
        AppMethodBeat.i(85920);
        Map<String, String> hashMap = new HashMap();
        AssetFileDescriptor openAssetFileDescriptor;
        try {
            openAssetFileDescriptor = contentResolver.openAssetFileDescriptor(XWebCoreContentProvider.b(str, XWalkEnvironment.getPackageName(), 2, i, XWalkEnvironment.XWALK_CORE_FILELIST_CONFIG_NAME), BuildConfig.FLAVOR);
            if (openAssetFileDescriptor == null) {
                try {
                    XWalkInitializer.addXWalkInitializeLog("tryGetFileList no file list");
                    b.tryClose(null);
                    b.tryClose(null);
                    b.a(openAssetFileDescriptor);
                    AppMethodBeat.o(85920);
                    return hashMap;
                } catch (Exception e2) {
                    e = e2;
                    closeable = null;
                    closeable2 = null;
                    try {
                        XWalkInitializer.addXWalkInitializeLog("tryGetFileList error: " + e.getMessage());
                        b.tryClose(closeable);
                        b.tryClose(closeable2);
                        b.a(openAssetFileDescriptor);
                        AppMethodBeat.o(85920);
                        return null;
                    } catch (Throwable th2) {
                        th = th2;
                        b.tryClose(closeable);
                        b.tryClose(closeable2);
                        b.a(openAssetFileDescriptor);
                        AppMethodBeat.o(85920);
                        throw th;
                    }
                } catch (Throwable th3) {
                    th = th3;
                    closeable = null;
                    closeable2 = null;
                    b.tryClose(closeable);
                    b.tryClose(closeable2);
                    b.a(openAssetFileDescriptor);
                    AppMethodBeat.o(85920);
                    throw th;
                }
            }
            File file = new File(XWalkEnvironment.getExtractedCoreFile(i, XWalkEnvironment.XWALK_CORE_FILELIST_CONFIG_NAME));
            if (file.exists()) {
                file.delete();
            }
            closeable = new PrintWriter(file);
            try {
                closeable2 = new BufferedReader(new InputStreamReader(openAssetFileDescriptor.createInputStream()));
                while (true) {
                    try {
                        String readLine = closeable2.readLine();
                        if (readLine != null) {
                            closeable.println(readLine);
                            if (!readLine.isEmpty()) {
                                String[] split = readLine.split(":");
                                if (!(split.length != 2 || split[0] == null || split[0].isEmpty() || split[1] == null || split[1].isEmpty())) {
                                    hashMap.put(split[0], split[1]);
                                }
                            }
                        } else {
                            closeable.flush();
                            b.tryClose(closeable);
                            b.tryClose(closeable2);
                            b.a(openAssetFileDescriptor);
                            AppMethodBeat.o(85920);
                            return hashMap;
                        }
                    } catch (Exception e3) {
                        e = e3;
                        XWalkInitializer.addXWalkInitializeLog("tryGetFileList error: " + e.getMessage());
                        b.tryClose(closeable);
                        b.tryClose(closeable2);
                        b.a(openAssetFileDescriptor);
                        AppMethodBeat.o(85920);
                        return null;
                    }
                }
            } catch (Exception e4) {
                e = e4;
                closeable2 = null;
                XWalkInitializer.addXWalkInitializeLog("tryGetFileList error: " + e.getMessage());
                b.tryClose(closeable);
                b.tryClose(closeable2);
                b.a(openAssetFileDescriptor);
                AppMethodBeat.o(85920);
                return null;
            } catch (Throwable th4) {
                th = th4;
                closeable2 = null;
                b.tryClose(closeable);
                b.tryClose(closeable2);
                b.a(openAssetFileDescriptor);
                AppMethodBeat.o(85920);
                throw th;
            }
        } catch (Exception e5) {
            e = e5;
            closeable = null;
            closeable2 = null;
            openAssetFileDescriptor = null;
        } catch (Throwable th5) {
            th = th5;
            closeable = null;
            closeable2 = null;
            openAssetFileDescriptor = null;
            b.tryClose(closeable);
            b.tryClose(closeable2);
            b.a(openAssetFileDescriptor);
            AppMethodBeat.o(85920);
            throw th;
        }
    }

    private static boolean tryCopyVersion(ContentResolver contentResolver, String str, int i, Map<String, String> map, ErrorInfo errorInfo) {
        AppMethodBeat.i(85921);
        try {
            for (Entry entry : map.entrySet()) {
                String str2 = (String) entry.getKey();
                String str3 = (String) entry.getValue();
                AssetFileDescriptor openAssetFileDescriptor = contentResolver.openAssetFileDescriptor(XWebCoreContentProvider.b(str, XWalkEnvironment.getPackageName(), 2, i, str2), BuildConfig.FLAVOR);
                if (openAssetFileDescriptor == null) {
                    errorInfo.copyFailedCount++;
                    XWalkInitializer.addXWalkInitializeLog("tryCopyVersion no file ".concat(String.valueOf(str2)));
                    AppMethodBeat.o(85921);
                    return false;
                }
                File file;
                if (XWalkEnvironment.XWALK_CORE_APK_NAME.equals(str2)) {
                    file = new File(XWalkEnvironment.getDownloadApkPath(i));
                } else {
                    file = new File(XWalkEnvironment.getExtractedCoreFile(i, str2));
                }
                if (!b.a(openAssetFileDescriptor, file)) {
                    errorInfo.copyFailedCount++;
                    XWalkInitializer.addXWalkInitializeLog("tryCopyVersion copy error");
                    AppMethodBeat.o(85921);
                    return false;
                } else if (!d.gA(file.getAbsolutePath(), str3)) {
                    XWalkInitializer.addXWalkInitializeLog("tryCopyVersion md5 error ".concat(String.valueOf(str2)));
                    errorInfo.md5FailedCount++;
                    if (file.exists()) {
                        file.delete();
                    }
                    AppMethodBeat.o(85921);
                    return false;
                }
            }
            AppMethodBeat.o(85921);
            return true;
        } catch (Exception e) {
            XWalkInitializer.addXWalkInitializeLog("tryCopyVersion copy error:" + e.getMessage());
            errorInfo.copyFailedCount++;
            AppMethodBeat.o(85921);
            return false;
        }
    }

    public static void updateLocalXWalkRuntime() {
        AppMethodBeat.i(85922);
        onHandleFile(new UpdateConfig(XWalkEnvironment.LOCAL_TEST_ZIP_NAME, false, 100000));
        AppMethodBeat.o(85922);
    }

    public void cancelXWalkRuntimeDownload() {
        AppMethodBeat.i(85923);
        if (XWalkLibraryLoader.isDownloading()) {
            XWalkInitializer.addXWalkInitializeLog(TAG, "canceled download apk");
            XWalkLibraryLoader.cancelHttpDownload();
        }
        AppMethodBeat.o(85923);
    }

    public boolean dismissDialog() {
        AppMethodBeat.i(85924);
        if (this.mDialogManager == null || !this.mDialogManager.isShowingDialog()) {
            AppMethodBeat.o(85924);
            return false;
        }
        this.mDialogManager.dismissDialog();
        AppMethodBeat.o(85924);
        return true;
    }

    public boolean cancelBackgroundDownload() {
        AppMethodBeat.i(85925);
        boolean cancelHttpDownload = XWalkLibraryLoader.cancelHttpDownload();
        AppMethodBeat.o(85925);
        return cancelHttpDownload;
    }

    public static Integer onHandleFile(UpdateConfig updateConfig) {
        AppMethodBeat.i(85926);
        String downloadPath = updateConfig.getDownloadPath();
        Log.d(TAG, "Download mode extract dir: ".concat(String.valueOf(XWalkEnvironment.getExtractedCoreDir(updateConfig.apkVer))));
        Integer valueOf;
        if (!updateConfig.isMatchMd5 || d.gA(downloadPath, updateConfig.downloadFileMd5)) {
            if (updateConfig.isPatchUpdate) {
                if (!onDoPatch(downloadPath, XWalkEnvironment.getInstalledNewstVersion(), updateConfig.apkVer)) {
                    XWalkInitializer.addXWalkInitializeLog(TAG, "patch update mode ,but patch error");
                    valueOf = Integer.valueOf(-3);
                    AppMethodBeat.o(85926);
                    return valueOf;
                } else if (!updateConfig.isMatchMd5 || FileListMD5Checker.checkFileListMd5(updateConfig.apkVer, XWalkEnvironment.getPatchFileListConfig(updateConfig.apkVer))) {
                    XWalkInitializer.addXWalkInitializeLog(TAG, "do patch sucsess");
                } else {
                    XWalkInitializer.addXWalkInitializeLog(TAG, "patch update mode, but md5 not match");
                    f.nI(36);
                    valueOf = Integer.valueOf(-4);
                    AppMethodBeat.o(85926);
                    return valueOf;
                }
            } else if (!XWalkDecompressor.decompressDownloadFullZip(downloadPath, updateConfig.apkVer)) {
                f.nI(32);
                valueOf = Integer.valueOf(-5);
                AppMethodBeat.o(85926);
                return valueOf;
            } else if (updateConfig.isMatchMd5 && !FileListMD5Checker.checkFileListMd5(updateConfig.apkVer, XWalkEnvironment.getDownloadZipFileListConfig(updateConfig.apkVer))) {
                XWalkInitializer.addXWalkInitializeLog(TAG, "patch update mode, but md5 not match");
                f.nI(33);
                valueOf = Integer.valueOf(-4);
                AppMethodBeat.o(85926);
                return valueOf;
            }
            valueOf = extractResource(updateConfig);
            AppMethodBeat.o(85926);
            return valueOf;
        }
        XWalkInitializer.addXWalkInitializeLog(TAG, "downloaded apk md5 check failed");
        valueOf = Integer.valueOf(-2);
        AppMethodBeat.o(85926);
        return valueOf;
    }

    private static Integer extractResource(UpdateConfig updateConfig) {
        AppMethodBeat.i(85927);
        while (true) {
            String extractedCoreDir = XWalkEnvironment.getExtractedCoreDir(updateConfig.apkVer);
            Integer valueOf;
            if (!XWalkDecompressor.extractResource(XWalkEnvironment.getDownloadApkPath(updateConfig.apkVer), extractedCoreDir)) {
                XWalkInitializer.addXWalkInitializeLog(TAG, "extract faield");
                valueOf = Integer.valueOf(-5);
                AppMethodBeat.o(85927);
                return valueOf;
            } else if (checkExtractResFileLengtgAndMd5(XWalkEnvironment.getDownloadResFileListConfig(updateConfig.apkVer), extractedCoreDir, updateConfig.apkVer)) {
                XWalkInitializer.addXWalkInitializeLog(TAG, "checkExtractResFileLengtgAndMd5 success!!!!");
                if (!generateOptDex(updateConfig.apkVer)) {
                    f.nI(251);
                    if ("true".equalsIgnoreCase(com.tencent.xweb.a.iG("update_need_check_dex", "tools"))) {
                        valueOf = Integer.valueOf(ERROR_SET_VERNUM);
                        AppMethodBeat.o(85927);
                        return valueOf;
                    }
                }
                boolean availableVersion = XWalkEnvironment.setAvailableVersion(updateConfig.apkVer, updateConfig.versionDetail);
                XWalkInitializer.addXWalkInitializeLog(TAG, "do update sucsess");
                if (availableVersion) {
                    valueOf = Integer.valueOf(0);
                    AppMethodBeat.o(85927);
                    return valueOf;
                }
                XWalkInitializer.addXWalkInitializeLog(TAG, "set version failed");
                valueOf = Integer.valueOf(ERROR_SET_VERNUM);
                AppMethodBeat.o(85927);
                return valueOf;
            } else if (mCurrentTimeForRetryRes <= 0) {
                XWalkInitializer.addXWalkInitializeLog(TAG, "checkExtractResFileLengtgAndMd5 failed retry extractResource");
                mCurrentTimeForRetryRes++;
            } else {
                XWalkInitializer.addXWalkInitializeLog(TAG, "checkResourceLengthAndMd5 failed can not retry!!!!!!!!!! mCurrentTimeForRetryRes = " + mCurrentTimeForRetryRes);
                valueOf = Integer.valueOf(-12);
                AppMethodBeat.o(85927);
                return valueOf;
            }
        }
    }

    private static boolean generateOptDex(int i) {
        AppMethodBeat.i(85928);
        try {
            DexClassLoader dexClassLoader = new DexClassLoader(XWalkEnvironment.getClassDexFilePath(i), XWalkEnvironment.getOptimizedDexDir(i), XWalkEnvironment.getExtractedCoreDir(i), ClassLoader.getSystemClassLoader());
            AppMethodBeat.o(85928);
            return true;
        } catch (Exception e) {
            XWalkInitializer.addXWalkInitializeLog(TAG, "dex output error");
            AppMethodBeat.o(85928);
            return false;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:78:0x0182 A:{SYNTHETIC, Splitter:B:78:0x0182} */
    /* JADX WARNING: Removed duplicated region for block: B:81:0x0187 A:{SYNTHETIC, Splitter:B:81:0x0187} */
    /* JADX WARNING: Removed duplicated region for block: B:84:0x018c A:{SYNTHETIC, Splitter:B:84:0x018c} */
    /* JADX WARNING: Removed duplicated region for block: B:96:0x01bc A:{SYNTHETIC, Splitter:B:96:0x01bc} */
    /* JADX WARNING: Removed duplicated region for block: B:99:0x01c1 A:{SYNTHETIC, Splitter:B:99:0x01c1} */
    /* JADX WARNING: Removed duplicated region for block: B:102:0x01c6 A:{SYNTHETIC, Splitter:B:102:0x01c6} */
    /* JADX WARNING: Removed duplicated region for block: B:78:0x0182 A:{SYNTHETIC, Splitter:B:78:0x0182} */
    /* JADX WARNING: Removed duplicated region for block: B:81:0x0187 A:{SYNTHETIC, Splitter:B:81:0x0187} */
    /* JADX WARNING: Removed duplicated region for block: B:84:0x018c A:{SYNTHETIC, Splitter:B:84:0x018c} */
    /* JADX WARNING: Removed duplicated region for block: B:78:0x0182 A:{SYNTHETIC, Splitter:B:78:0x0182} */
    /* JADX WARNING: Removed duplicated region for block: B:81:0x0187 A:{SYNTHETIC, Splitter:B:81:0x0187} */
    /* JADX WARNING: Removed duplicated region for block: B:84:0x018c A:{SYNTHETIC, Splitter:B:84:0x018c} */
    /* JADX WARNING: Removed duplicated region for block: B:96:0x01bc A:{SYNTHETIC, Splitter:B:96:0x01bc} */
    /* JADX WARNING: Removed duplicated region for block: B:99:0x01c1 A:{SYNTHETIC, Splitter:B:99:0x01c1} */
    /* JADX WARNING: Removed duplicated region for block: B:102:0x01c6 A:{SYNTHETIC, Splitter:B:102:0x01c6} */
    /* JADX WARNING: Removed duplicated region for block: B:96:0x01bc A:{SYNTHETIC, Splitter:B:96:0x01bc} */
    /* JADX WARNING: Removed duplicated region for block: B:99:0x01c1 A:{SYNTHETIC, Splitter:B:99:0x01c1} */
    /* JADX WARNING: Removed duplicated region for block: B:102:0x01c6 A:{SYNTHETIC, Splitter:B:102:0x01c6} */
    public static boolean checkExtractResFileLengtgAndMd5(java.lang.String r11, java.lang.String r12, int r13) {
        /*
        r3 = 0;
        r10 = 85929; // 0x14fa9 float:1.20412E-40 double:4.24546E-319;
        r0 = 1;
        r1 = 0;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r10);
        r2 = new java.io.File;	 Catch:{ Exception -> 0x0162, all -> 0x01b6 }
        r2.<init>(r11);	 Catch:{ Exception -> 0x0162, all -> 0x01b6 }
        r4 = r2.exists();	 Catch:{ Exception -> 0x0162, all -> 0x01b6 }
        if (r4 != 0) goto L_0x0073;
    L_0x0014:
        r2 = org.xwalk.core.XWalkEnvironment.isTestVersion(r13);	 Catch:{ Exception -> 0x0162, all -> 0x01b6 }
        if (r2 != 0) goto L_0x001e;
    L_0x001a:
        r2 = 362; // 0x16a float:5.07E-43 double:1.79E-321;
        if (r13 >= r2) goto L_0x0036;
    L_0x001e:
        r2 = r0;
    L_0x001f:
        if (r2 == 0) goto L_0x0038;
    L_0x0021:
        r2 = "XWalkLib";
        r4 = "resConfigPath not exist ,maybe old runtime";
        r5 = java.lang.String.valueOf(r11);	 Catch:{ Exception -> 0x0162, all -> 0x01b6 }
        r4 = r4.concat(r5);	 Catch:{ Exception -> 0x0162, all -> 0x01b6 }
        org.xwalk.core.XWalkInitializer.addXWalkInitializeLog(r2, r4);	 Catch:{ Exception -> 0x0162, all -> 0x01b6 }
        com.tencent.matrix.trace.core.AppMethodBeat.o(r10);
    L_0x0035:
        return r0;
    L_0x0036:
        r2 = r1;
        goto L_0x001f;
    L_0x0038:
        r4 = 79;
        com.tencent.xweb.util.f.nI(r4);	 Catch:{ Exception -> 0x0162, all -> 0x01b6 }
        r2 = "XWalkLib";
        r4 = "resConfigPath not exist ";
        r5 = java.lang.String.valueOf(r11);	 Catch:{ Exception -> 0x0162, all -> 0x01b6 }
        r4 = r4.concat(r5);	 Catch:{ Exception -> 0x0162, all -> 0x01b6 }
        org.xwalk.core.XWalkInitializer.addXWalkInitializeLog(r2, r4);	 Catch:{ Exception -> 0x0162, all -> 0x01b6 }
        r2 = "true";
        r4 = "dis_res_config_file_check";
        r5 = "tools";
        r4 = com.tencent.xweb.a.iG(r4, r5);	 Catch:{ Exception -> 0x0162, all -> 0x01b6 }
        r2 = r2.equalsIgnoreCase(r4);	 Catch:{ Exception -> 0x0162, all -> 0x01b6 }
        if (r2 == 0) goto L_0x006e;
    L_0x0061:
        r2 = "XWalkLib";
        r4 = "dis_res_config_file_check ";
        org.xwalk.core.XWalkInitializer.addXWalkInitializeLog(r2, r4);	 Catch:{ Exception -> 0x0162, all -> 0x01b6 }
        com.tencent.matrix.trace.core.AppMethodBeat.o(r10);
        goto L_0x0035;
    L_0x006e:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r10);
        r0 = r1;
        goto L_0x0035;
    L_0x0073:
        r5 = new java.io.FileInputStream;	 Catch:{ Exception -> 0x0162, all -> 0x01b6 }
        r5.<init>(r2);	 Catch:{ Exception -> 0x0162, all -> 0x01b6 }
        r4 = new java.io.InputStreamReader;	 Catch:{ Exception -> 0x01f7, all -> 0x01ee }
        r4.<init>(r5);	 Catch:{ Exception -> 0x01f7, all -> 0x01ee }
        r2 = new java.io.BufferedReader;	 Catch:{ Exception -> 0x01fc, all -> 0x01f2 }
        r2.<init>(r4);	 Catch:{ Exception -> 0x01fc, all -> 0x01f2 }
    L_0x0082:
        r3 = r2.readLine();	 Catch:{ Exception -> 0x0200 }
        if (r3 == 0) goto L_0x0133;
    L_0x0088:
        if (r3 == 0) goto L_0x0082;
    L_0x008a:
        r6 = r3.isEmpty();	 Catch:{ Exception -> 0x0200 }
        if (r6 != 0) goto L_0x0082;
    L_0x0090:
        r6 = ":";
        r3 = r3.split(r6);	 Catch:{ Exception -> 0x0200 }
        if (r3 == 0) goto L_0x0082;
    L_0x0099:
        r6 = r3.length;	 Catch:{ Exception -> 0x0200 }
        r7 = 2;
        if (r6 != r7) goto L_0x0082;
    L_0x009d:
        r6 = 0;
        r6 = r3[r6];	 Catch:{ Exception -> 0x0200 }
        if (r6 == 0) goto L_0x0082;
    L_0x00a2:
        r6 = 0;
        r6 = r3[r6];	 Catch:{ Exception -> 0x0200 }
        r6 = r6.isEmpty();	 Catch:{ Exception -> 0x0200 }
        if (r6 != 0) goto L_0x0082;
    L_0x00ab:
        r6 = 1;
        r6 = r3[r6];	 Catch:{ Exception -> 0x0200 }
        if (r6 == 0) goto L_0x0082;
    L_0x00b0:
        r6 = 1;
        r6 = r3[r6];	 Catch:{ Exception -> 0x0200 }
        r6 = r6.isEmpty();	 Catch:{ Exception -> 0x0200 }
        if (r6 != 0) goto L_0x0082;
    L_0x00b9:
        r6 = new java.io.File;	 Catch:{ Exception -> 0x0200 }
        r7 = 0;
        r7 = r3[r7];	 Catch:{ Exception -> 0x0200 }
        r6.<init>(r12, r7);	 Catch:{ Exception -> 0x0200 }
        r7 = com.tencent.xweb.util.d.v(r6);	 Catch:{ Exception -> 0x0200 }
        r8 = 1;
        r8 = r3[r8];	 Catch:{ Exception -> 0x0200 }
        r8 = r7.equalsIgnoreCase(r8);	 Catch:{ Exception -> 0x0200 }
        if (r8 != 0) goto L_0x0082;
    L_0x00ce:
        r0 = "XWalkLib";
        r8 = new java.lang.StringBuilder;	 Catch:{ Exception -> 0x0200 }
        r9 = "Exception unpacking required pak resources: ";
        r8.<init>(r9);	 Catch:{ Exception -> 0x0200 }
        r9 = 0;
        r9 = r3[r9];	 Catch:{ Exception -> 0x0200 }
        r8 = r8.append(r9);	 Catch:{ Exception -> 0x0200 }
        r9 = " expected md5 = ";
        r8 = r8.append(r9);	 Catch:{ Exception -> 0x0200 }
        r9 = 1;
        r3 = r3[r9];	 Catch:{ Exception -> 0x0200 }
        r3 = r8.append(r3);	 Catch:{ Exception -> 0x0200 }
        r8 = " outputmd5 = %s";
        r3 = r3.append(r8);	 Catch:{ Exception -> 0x0200 }
        r3 = r3.append(r7);	 Catch:{ Exception -> 0x0200 }
        r3 = r3.toString();	 Catch:{ Exception -> 0x0200 }
        org.xwalk.core.XWalkInitializer.addXWalkInitializeLog(r0, r3);	 Catch:{ Exception -> 0x0200 }
        r6.delete();	 Catch:{ Exception -> 0x0200 }
        r5.close();	 Catch:{ Exception -> 0x0112 }
    L_0x0106:
        r4.close();	 Catch:{ Exception -> 0x011d }
    L_0x0109:
        r2.close();	 Catch:{ Exception -> 0x0128 }
    L_0x010c:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r10);
        r0 = r1;
        goto L_0x0035;
    L_0x0112:
        r0 = move-exception;
        r0 = "XWalkLib";
        r3 = "checkExtractResFileLengtgAndMd5 close inputStream failed";
        org.xwalk.core.Log.e(r0, r3);
        goto L_0x0106;
    L_0x011d:
        r0 = move-exception;
        r0 = "XWalkLib";
        r3 = "checkExtractResFileLengtgAndMd5 close inputreader failed";
        org.xwalk.core.Log.e(r0, r3);
        goto L_0x0109;
    L_0x0128:
        r0 = move-exception;
        r0 = "XWalkLib";
        r2 = "checkExtractResFileLengtgAndMd5 close buffreader failed";
        org.xwalk.core.Log.e(r0, r2);
        goto L_0x010c;
    L_0x0133:
        r5.close();	 Catch:{ Exception -> 0x0141 }
    L_0x0136:
        r4.close();	 Catch:{ Exception -> 0x014c }
    L_0x0139:
        r2.close();	 Catch:{ Exception -> 0x0157 }
    L_0x013c:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r10);
        goto L_0x0035;
    L_0x0141:
        r1 = move-exception;
        r1 = "XWalkLib";
        r3 = "checkExtractResFileLengtgAndMd5 close inputStream failed";
        org.xwalk.core.Log.e(r1, r3);
        goto L_0x0136;
    L_0x014c:
        r1 = move-exception;
        r1 = "XWalkLib";
        r3 = "checkExtractResFileLengtgAndMd5 close inputreader failed";
        org.xwalk.core.Log.e(r1, r3);
        goto L_0x0139;
    L_0x0157:
        r1 = move-exception;
        r1 = "XWalkLib";
        r2 = "checkExtractResFileLengtgAndMd5 close buffreader failed";
        org.xwalk.core.Log.e(r1, r2);
        goto L_0x013c;
    L_0x0162:
        r0 = move-exception;
        r2 = r3;
        r4 = r3;
        r5 = r3;
    L_0x0166:
        r3 = "XWalkLib";
        r6 = new java.lang.StringBuilder;	 Catch:{ all -> 0x01f5 }
        r7 = "checkFileListMd5 error:";
        r6.<init>(r7);	 Catch:{ all -> 0x01f5 }
        r0 = r0.getMessage();	 Catch:{ all -> 0x01f5 }
        r0 = r6.append(r0);	 Catch:{ all -> 0x01f5 }
        r0 = r0.toString();	 Catch:{ all -> 0x01f5 }
        org.xwalk.core.Log.e(r3, r0);	 Catch:{ all -> 0x01f5 }
        if (r5 == 0) goto L_0x0185;
    L_0x0182:
        r5.close();	 Catch:{ Exception -> 0x0195 }
    L_0x0185:
        if (r4 == 0) goto L_0x018a;
    L_0x0187:
        r4.close();	 Catch:{ Exception -> 0x01a0 }
    L_0x018a:
        if (r2 == 0) goto L_0x018f;
    L_0x018c:
        r2.close();	 Catch:{ Exception -> 0x01ab }
    L_0x018f:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r10);
        r0 = r1;
        goto L_0x0035;
    L_0x0195:
        r0 = move-exception;
        r0 = "XWalkLib";
        r3 = "checkExtractResFileLengtgAndMd5 close inputStream failed";
        org.xwalk.core.Log.e(r0, r3);
        goto L_0x0185;
    L_0x01a0:
        r0 = move-exception;
        r0 = "XWalkLib";
        r3 = "checkExtractResFileLengtgAndMd5 close inputreader failed";
        org.xwalk.core.Log.e(r0, r3);
        goto L_0x018a;
    L_0x01ab:
        r0 = move-exception;
        r0 = "XWalkLib";
        r2 = "checkExtractResFileLengtgAndMd5 close buffreader failed";
        org.xwalk.core.Log.e(r0, r2);
        goto L_0x018f;
    L_0x01b6:
        r0 = move-exception;
        r2 = r3;
        r4 = r3;
        r5 = r3;
    L_0x01ba:
        if (r5 == 0) goto L_0x01bf;
    L_0x01bc:
        r5.close();	 Catch:{ Exception -> 0x01cd }
    L_0x01bf:
        if (r4 == 0) goto L_0x01c4;
    L_0x01c1:
        r4.close();	 Catch:{ Exception -> 0x01d8 }
    L_0x01c4:
        if (r2 == 0) goto L_0x01c9;
    L_0x01c6:
        r2.close();	 Catch:{ Exception -> 0x01e3 }
    L_0x01c9:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r10);
        throw r0;
    L_0x01cd:
        r1 = move-exception;
        r1 = "XWalkLib";
        r3 = "checkExtractResFileLengtgAndMd5 close inputStream failed";
        org.xwalk.core.Log.e(r1, r3);
        goto L_0x01bf;
    L_0x01d8:
        r1 = move-exception;
        r1 = "XWalkLib";
        r3 = "checkExtractResFileLengtgAndMd5 close inputreader failed";
        org.xwalk.core.Log.e(r1, r3);
        goto L_0x01c4;
    L_0x01e3:
        r1 = move-exception;
        r1 = "XWalkLib";
        r2 = "checkExtractResFileLengtgAndMd5 close buffreader failed";
        org.xwalk.core.Log.e(r1, r2);
        goto L_0x01c9;
    L_0x01ee:
        r0 = move-exception;
        r2 = r3;
        r4 = r3;
        goto L_0x01ba;
    L_0x01f2:
        r0 = move-exception;
        r2 = r3;
        goto L_0x01ba;
    L_0x01f5:
        r0 = move-exception;
        goto L_0x01ba;
    L_0x01f7:
        r0 = move-exception;
        r2 = r3;
        r4 = r3;
        goto L_0x0166;
    L_0x01fc:
        r0 = move-exception;
        r2 = r3;
        goto L_0x0166;
    L_0x0200:
        r0 = move-exception;
        goto L_0x0166;
        */
        throw new UnsupportedOperationException("Method not decompiled: org.xwalk.core.XWalkUpdater.checkExtractResFileLengtgAndMd5(java.lang.String, java.lang.String, int):boolean");
    }

    public static boolean onDoPatch(String str, int i, int i2) {
        AppMethodBeat.i(85930);
        Log.i(TAG, "onDoPatch:" + str + ",currentVersion:" + i + ",newVersion:" + i2);
        if (!new File(str).exists()) {
            Log.e(TAG, "onDoPatch no patch zip file");
            AppMethodBeat.o(85930);
            return false;
        } else if (XWalkDecompressor.decompressDownloadPatchZip(str, XWalkEnvironment.getPatchZipTempDecompressPath(i2))) {
            ArrayList patchFileConfigList = PatchFileConfigParser.getPatchFileConfigList(i2);
            if (patchFileConfigList == null) {
                Log.e(TAG, "onDoPatch patchFileConfigList = null");
                f.nI(38);
                AppMethodBeat.o(85930);
                return false;
            } else if (b.iI(XWalkEnvironment.getExtractedCoreDir(i), XWalkEnvironment.getExtractedCoreDir(i2))) {
                PatchFileConfig patchFileConfig;
                Log.i(TAG, "onDoPatch copy all extraced file finished");
                ArrayList arrayList = new ArrayList();
                Iterator it = patchFileConfigList.iterator();
                while (it.hasNext()) {
                    patchFileConfig = (PatchFileConfig) it.next();
                    if (patchFileConfig.isTypeAdd()) {
                        arrayList.add(patchFileConfig);
                    }
                }
                Iterator it2 = arrayList.iterator();
                while (it2.hasNext()) {
                    patchFileConfig = (PatchFileConfig) it2.next();
                    if (b.copyFile(XWalkEnvironment.getPatchZipTempDecompressFilePath(i2, patchFileConfig.originalFileName), XWalkEnvironment.getExtractedCoreFile(i2, patchFileConfig.originalFileName))) {
                        Log.i(TAG, "onDoPatch add file:".concat(String.valueOf(patchFileConfig)));
                    } else {
                        Log.e(TAG, "onDoPatch add file error:".concat(String.valueOf(patchFileConfig)));
                        f.nI(40);
                        AppMethodBeat.o(85930);
                        return false;
                    }
                }
                Log.i(TAG, "onDoPatch add file finished");
                arrayList = new ArrayList();
                it = patchFileConfigList.iterator();
                while (it.hasNext()) {
                    patchFileConfig = (PatchFileConfig) it.next();
                    if (patchFileConfig.isTypeRemove()) {
                        arrayList.add(patchFileConfig);
                    }
                }
                it2 = arrayList.iterator();
                while (it2.hasNext()) {
                    patchFileConfig = (PatchFileConfig) it2.next();
                    if (b.deleteFile(XWalkEnvironment.getExtractedCoreFile(i2, patchFileConfig.originalFileName))) {
                        Log.i(TAG, "onDoPatch delete file:".concat(String.valueOf(patchFileConfig)));
                    } else {
                        Log.e(TAG, "onDoPatch delete file error:".concat(String.valueOf(patchFileConfig)));
                        f.nI(41);
                    }
                }
                Log.i(TAG, "onDoPatch remove file finished");
                arrayList = new ArrayList();
                Iterator it3 = patchFileConfigList.iterator();
                while (it3.hasNext()) {
                    patchFileConfig = (PatchFileConfig) it3.next();
                    if (patchFileConfig.isTypeModify()) {
                        arrayList.add(patchFileConfig);
                    }
                }
                it3 = arrayList.iterator();
                while (it3.hasNext()) {
                    patchFileConfig = (PatchFileConfig) it3.next();
                    if (patchFileConfig.isExtractedFile()) {
                        if (BSpatch.aH(XWalkEnvironment.getExtractedCoreFile(i2, patchFileConfig.originalFileName), XWalkEnvironment.getPatchZipTempDecompressFilePath(i2, patchFileConfig.patchFileName), XWalkEnvironment.getExtractedCoreFile(i2, patchFileConfig.originalFileName)) < 0) {
                            Log.e(TAG, "onDoPatch patch error file:".concat(String.valueOf(patchFileConfig)));
                            AppMethodBeat.o(85930);
                            return false;
                        }
                        Log.i(TAG, "onDoPatch patch file finished");
                    }
                }
                Log.i(TAG, "onDoPatch patch file finished");
                it3 = arrayList.iterator();
                while (it3.hasNext()) {
                    patchFileConfig = (PatchFileConfig) it3.next();
                    if (patchFileConfig.isOriginalFileTypeApk()) {
                        if (BSpatch.aH(XWalkEnvironment.getDownloadApkPath(i), XWalkEnvironment.getPatchZipTempDecompressFilePath(i2, patchFileConfig.patchFileName), XWalkEnvironment.getDownloadApkPath(i2)) < 0) {
                            Log.e(TAG, "onDoPatch apk patch error file:".concat(String.valueOf(patchFileConfig)));
                            AppMethodBeat.o(85930);
                            return false;
                        }
                        Log.i(TAG, "onDoPatch apk patch finished");
                        AppMethodBeat.o(85930);
                        return true;
                    }
                }
                Log.i(TAG, "onDoPatch apk patch finished");
                AppMethodBeat.o(85930);
                return true;
            } else {
                Log.e(TAG, "onDoPatch copy all extraced file error");
                f.nI(39);
                AppMethodBeat.o(85930);
                return false;
            }
        } else {
            Log.e(TAG, "onDoPatch decompress zip error");
            f.nI(37);
            AppMethodBeat.o(85930);
            return false;
        }
    }

    private boolean verifyDownloadedXWalkRuntime(String str) {
        AppMethodBeat.i(85931);
        PackageInfo packageArchiveInfo = this.mContext.getPackageManager().getPackageArchiveInfo(str, 64);
        if (packageArchiveInfo == null) {
            Log.e(TAG, "The downloaded XWalkRuntimeLib.apk is invalid!");
            AppMethodBeat.o(85931);
            return false;
        }
        try {
            PackageInfo packageInfo = this.mContext.getPackageManager().getPackageInfo(this.mContext.getPackageName(), 64);
            if (packageArchiveInfo.signatures == null || packageInfo.signatures == null) {
                Log.e(TAG, "No signature in package info");
                AppMethodBeat.o(85931);
                return false;
            } else if (packageArchiveInfo.signatures.length != packageInfo.signatures.length) {
                Log.e(TAG, "signatures length not equal");
                AppMethodBeat.o(85931);
                return false;
            } else {
                int i = 0;
                while (i < packageArchiveInfo.signatures.length) {
                    Log.d(TAG, "Checking signature ".concat(String.valueOf(i)));
                    if (packageInfo.signatures[i].equals(packageArchiveInfo.signatures[i])) {
                        i++;
                    } else {
                        Log.e(TAG, "signatures do not match");
                        AppMethodBeat.o(85931);
                        return false;
                    }
                }
                Log.d(TAG, "Signature check passed");
                AppMethodBeat.o(85931);
                return true;
            }
        } catch (NameNotFoundException e) {
            AppMethodBeat.o(85931);
            return false;
        }
    }
}
