package com.facebook.appevents.internal;

import android.app.Activity;
import android.app.Application;
import android.content.Context;
import android.hardware.Sensor;
import android.hardware.SensorManager;
import com.facebook.FacebookSdk;
import com.facebook.appevents.codeless.CodelessMatcher;
import com.facebook.appevents.codeless.ViewIndexer;
import com.facebook.appevents.codeless.ViewIndexingTrigger;
import com.facebook.appevents.internal.SourceApplicationInfo.Factory;
import com.facebook.internal.FetchedAppSettings;
import com.facebook.internal.FetchedAppSettingsManager;
import com.facebook.internal.Utility;
import com.tencent.matrix.trace.core.AppMethodBeat;
import java.util.UUID;
import java.util.concurrent.Executors;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.ScheduledFuture;
import java.util.concurrent.atomic.AtomicBoolean;
import java.util.concurrent.atomic.AtomicInteger;

public class ActivityLifecycleTracker {
    private static final String INCORRECT_IMPL_WARNING = "Unexpected activity pause without a matching activity resume. Logging data may be incorrect. Make sure you call activateApp from your Application's onCreate method";
    private static final long INTERRUPTION_THRESHOLD_MILLISECONDS = 1000;
    private static final String TAG = ActivityLifecycleTracker.class.getCanonicalName();
    private static String appId;
    private static final CodelessMatcher codelessMatcher = new CodelessMatcher();
    private static long currentActivityAppearTime;
    private static volatile ScheduledFuture currentFuture;
    private static final Object currentFutureLock = new Object();
    private static volatile SessionInfo currentSession;
    private static String deviceSessionID = null;
    private static AtomicInteger foregroundActivityCount = new AtomicInteger(0);
    private static Boolean isAppIndexingEnabled = Boolean.FALSE;
    private static volatile Boolean isCheckingSession = Boolean.FALSE;
    private static SensorManager sensorManager;
    private static final ScheduledExecutorService singleThreadExecutor = Executors.newSingleThreadScheduledExecutor();
    private static AtomicBoolean tracking = new AtomicBoolean(false);
    private static ViewIndexer viewIndexer;
    private static final ViewIndexingTrigger viewIndexingTrigger = new ViewIndexingTrigger();

    static /* synthetic */ void access$100(Activity activity) {
        AppMethodBeat.i(72157);
        onActivityPaused(activity);
        AppMethodBeat.o(72157);
    }

    static /* synthetic */ int access$400() {
        AppMethodBeat.i(72158);
        int sessionTimeoutInSeconds = getSessionTimeoutInSeconds();
        AppMethodBeat.o(72158);
        return sessionTimeoutInSeconds;
    }

    static {
        AppMethodBeat.i(72159);
        AppMethodBeat.o(72159);
    }

    public static void startTracking(Application application, String str) {
        AppMethodBeat.i(72146);
        if (tracking.compareAndSet(false, true)) {
            appId = str;
            application.registerActivityLifecycleCallbacks(new 1());
            AppMethodBeat.o(72146);
            return;
        }
        AppMethodBeat.o(72146);
    }

    public static boolean isTracking() {
        AppMethodBeat.i(72147);
        boolean z = tracking.get();
        AppMethodBeat.o(72147);
        return z;
    }

    public static UUID getCurrentSessionGuid() {
        AppMethodBeat.i(72148);
        if (currentSession != null) {
            UUID sessionId = currentSession.getSessionId();
            AppMethodBeat.o(72148);
            return sessionId;
        }
        AppMethodBeat.o(72148);
        return null;
    }

    public static void onActivityCreated(Activity activity) {
        AppMethodBeat.i(72149);
        System.currentTimeMillis();
        activity.getApplicationContext();
        Utility.getActivityName(activity);
        Factory.create(activity);
        singleThreadExecutor.execute(new 2());
        AppMethodBeat.o(72149);
    }

    public static void onActivityResumed(Activity activity) {
        AppMethodBeat.i(72150);
        foregroundActivityCount.incrementAndGet();
        cancelCurrentTask();
        long currentTimeMillis = System.currentTimeMillis();
        currentActivityAppearTime = currentTimeMillis;
        String activityName = Utility.getActivityName(activity);
        codelessMatcher.add(activity);
        singleThreadExecutor.execute(new 3(currentTimeMillis, activityName));
        Context applicationContext = activity.getApplicationContext();
        String applicationId = FacebookSdk.getApplicationId();
        FetchedAppSettings appSettingsWithoutQuery = FetchedAppSettingsManager.getAppSettingsWithoutQuery(applicationId);
        if (appSettingsWithoutQuery != null && appSettingsWithoutQuery.getCodelessSetupEnabled()) {
            SensorManager sensorManager = (SensorManager) applicationContext.getSystemService("sensor");
            sensorManager = sensorManager;
            if (sensorManager == null) {
                AppMethodBeat.o(72150);
                return;
            }
            Sensor defaultSensor = sensorManager.getDefaultSensor(1);
            viewIndexer = new ViewIndexer(activity);
            viewIndexingTrigger.setOnShakeListener(new 4(appSettingsWithoutQuery, applicationId));
            sensorManager.registerListener(viewIndexingTrigger, defaultSensor, 2);
            if (appSettingsWithoutQuery != null && appSettingsWithoutQuery.getCodelessEventsEnabled()) {
                viewIndexer.schedule();
            }
        }
        AppMethodBeat.o(72150);
    }

    private static void onActivityPaused(Activity activity) {
        AppMethodBeat.i(72151);
        if (foregroundActivityCount.decrementAndGet() < 0) {
            foregroundActivityCount.set(0);
        }
        cancelCurrentTask();
        long currentTimeMillis = System.currentTimeMillis();
        String activityName = Utility.getActivityName(activity);
        codelessMatcher.remove(activity);
        singleThreadExecutor.execute(new 5(currentTimeMillis, activityName));
        if (viewIndexer != null) {
            viewIndexer.unschedule();
        }
        if (sensorManager != null) {
            sensorManager.unregisterListener(viewIndexingTrigger);
        }
        AppMethodBeat.o(72151);
    }

    private static int getSessionTimeoutInSeconds() {
        AppMethodBeat.i(72152);
        FetchedAppSettings appSettingsWithoutQuery = FetchedAppSettingsManager.getAppSettingsWithoutQuery(FacebookSdk.getApplicationId());
        int defaultAppEventsSessionTimeoutInSeconds;
        if (appSettingsWithoutQuery == null) {
            defaultAppEventsSessionTimeoutInSeconds = Constants.getDefaultAppEventsSessionTimeoutInSeconds();
            AppMethodBeat.o(72152);
            return defaultAppEventsSessionTimeoutInSeconds;
        }
        defaultAppEventsSessionTimeoutInSeconds = appSettingsWithoutQuery.getSessionTimeoutInSeconds();
        AppMethodBeat.o(72152);
        return defaultAppEventsSessionTimeoutInSeconds;
    }

    private static void cancelCurrentTask() {
        AppMethodBeat.i(72153);
        synchronized (currentFutureLock) {
            try {
                if (currentFuture != null) {
                    currentFuture.cancel(false);
                }
                currentFuture = null;
            } finally {
                while (true) {
                }
                AppMethodBeat.o(72153);
            }
        }
    }

    public static void checkCodelessSession(String str) {
        AppMethodBeat.i(72154);
        if (isCheckingSession.booleanValue()) {
            AppMethodBeat.o(72154);
            return;
        }
        isCheckingSession = Boolean.TRUE;
        FacebookSdk.getExecutor().execute(new 6(str));
        AppMethodBeat.o(72154);
    }

    public static String getCurrentDeviceSessionID() {
        AppMethodBeat.i(72155);
        if (deviceSessionID == null) {
            deviceSessionID = UUID.randomUUID().toString();
        }
        String str = deviceSessionID;
        AppMethodBeat.o(72155);
        return str;
    }

    public static boolean getIsAppIndexingEnabled() {
        AppMethodBeat.i(72156);
        boolean booleanValue = isAppIndexingEnabled.booleanValue();
        AppMethodBeat.o(72156);
        return booleanValue;
    }

    public static void updateAppIndexing(Boolean bool) {
        isAppIndexingEnabled = bool;
    }
}
