package com.samsung.android.sdk.look.bezelinteraction;

import android.content.ComponentName;
import android.content.Context;
import android.os.IBinder;
import android.os.RemoteException;
import android.os.ServiceManager;
import com.samsung.android.bezelinteraction.BezelEvent;
import com.samsung.android.bezelinteraction.IBezelManager;
import com.samsung.android.bezelinteraction.IBezelManager.Stub;
import com.tencent.matrix.trace.core.AppMethodBeat;
import java.util.Iterator;
import java.util.concurrent.CopyOnWriteArrayList;

public final class SlookBezelInteraction {
    public static final String SERVICE_NAME = "BezelInteractionService";
    private static final String TAG = "SlookBezelInteraction";
    private static Context mContext = null;
    private static IBezelManager mService = null;
    private final CopyOnWriteArrayList<BezelListenerDelegate> mListenerDelegates = new CopyOnWriteArrayList();

    public interface BezelListener {
        void onItemSelected(BezelEvent bezelEvent);
    }

    public SlookBezelInteraction(Context context) {
        AppMethodBeat.i(117204);
        mContext = context;
        getService();
        AppMethodBeat.o(117204);
    }

    private synchronized IBezelManager getService() {
        IBezelManager iBezelManager;
        AppMethodBeat.i(117205);
        if (mService == null) {
            mService = Stub.asInterface(ServiceManager.getService(SERVICE_NAME));
        } else if (!mService.asBinder().isBinderAlive()) {
            mService = Stub.asInterface(ServiceManager.getService(SERVICE_NAME));
        }
        iBezelManager = mService;
        AppMethodBeat.o(117205);
        return iBezelManager;
    }

    public final void registerListener(BezelListener bezelListener) {
        AppMethodBeat.i(117206);
        if (bezelListener == null) {
            AppMethodBeat.o(117206);
            return;
        }
        synchronized (this.mListenerDelegates) {
            try {
                IBinder iBinder;
                Iterator it = this.mListenerDelegates.iterator();
                while (it.hasNext()) {
                    iBinder = (BezelListenerDelegate) it.next();
                    if (iBinder.getListener().equals(bezelListener)) {
                        break;
                    }
                }
                iBinder = null;
                if (iBinder == null) {
                    iBinder = new BezelListenerDelegate(bezelListener, null);
                    this.mListenerDelegates.add(iBinder);
                }
                try {
                    IBezelManager service = getService();
                    if (service != null) {
                        service.registerCallback(iBinder, new ComponentName(mContext.getPackageName(), mContext.getClass().getCanonicalName()));
                    }
                } catch (RemoteException e) {
                }
            } finally {
                while (true) {
                }
                AppMethodBeat.o(117206);
            }
        }
    }

    public final void unregisterListener(BezelListener bezelListener) {
        AppMethodBeat.i(117207);
        if (bezelListener == null) {
            AppMethodBeat.o(117207);
            return;
        }
        synchronized (this.mListenerDelegates) {
            try {
                IBinder iBinder;
                Iterator it = this.mListenerDelegates.iterator();
                while (it.hasNext()) {
                    iBinder = (BezelListenerDelegate) it.next();
                    if (iBinder.getListener().equals(bezelListener)) {
                        break;
                    }
                }
                iBinder = null;
                if (iBinder == null) {
                } else {
                    try {
                        IBezelManager service = getService();
                        if (service != null && service.unregisterCallback(iBinder)) {
                            this.mListenerDelegates.remove(iBinder);
                            iBinder.mHandler = null;
                            iBinder.mListener = null;
                        }
                    } catch (RemoteException e) {
                    }
                    AppMethodBeat.o(117207);
                }
            } finally {
                while (true) {
                }
                AppMethodBeat.o(117207);
            }
        }
    }

    public final void enableBezelInteraction(boolean z) {
        AppMethodBeat.i(117208);
        try {
            IBezelManager service = getService();
            if (service != null) {
                service.enableBezelInteraction(z);
            }
            AppMethodBeat.o(117208);
        } catch (RemoteException e) {
            AppMethodBeat.o(117208);
        }
    }
}
