package com.tencent.mm.plugin.mmsight.segment;

import android.graphics.Bitmap;
import android.graphics.Bitmap.Config;
import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.mm.sdk.platformtools.ab;
import java.io.FileDescriptor;
import java.nio.ByteBuffer;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Locale;
import java.util.Map;
import java.util.Map.Entry;

public class FFmpegMetadataRetriever {
    public static final String METADATA_CHAPTER_COUNT = "chapter_count";
    public static final String METADATA_KEY_ALBUM = "album";
    public static final String METADATA_KEY_ALBUM_ARTIST = "album_artist";
    public static final String METADATA_KEY_ARTIST = "artist";
    public static final String METADATA_KEY_AUDIO_CODEC = "audio_codec";
    public static final String METADATA_KEY_CHAPTER_END_TIME = "chapter_end_time";
    public static final String METADATA_KEY_CHAPTER_START_TIME = "chapter_start_time";
    public static final String METADATA_KEY_COMMENT = "comment";
    public static final String METADATA_KEY_COMPOSER = "composer";
    public static final String METADATA_KEY_COPYRIGHT = "copyright";
    public static final String METADATA_KEY_CREATION_TIME = "creation_time";
    public static final String METADATA_KEY_DATE = "date";
    public static final String METADATA_KEY_DISC = "disc";
    public static final String METADATA_KEY_DURATION = "duration";
    public static final String METADATA_KEY_ENCODED_BY = "encoded_by";
    public static final String METADATA_KEY_ENCODER = "encoder";
    public static final String METADATA_KEY_FILENAME = "filename";
    public static final String METADATA_KEY_FILESIZE = "filesize";
    public static final String METADATA_KEY_FRAMERATE = "framerate";
    public static final String METADATA_KEY_GENRE = "genre";
    public static final String METADATA_KEY_ICY_METADATA = "icy_metadata";
    public static final String METADATA_KEY_LANGUAGE = "language";
    public static final String METADATA_KEY_PERFORMER = "performer";
    public static final String METADATA_KEY_PUBLISHER = "publisher";
    public static final String METADATA_KEY_SERVICE_NAME = "service_name";
    public static final String METADATA_KEY_SERVICE_PROVIDER = "service_provider";
    public static final String METADATA_KEY_TITLE = "title";
    public static final String METADATA_KEY_TRACK = "track";
    public static final String METADATA_KEY_VARIANT_BITRATE = "bitrate";
    public static final String METADATA_KEY_VIDEO_CODEC = "video_codec";
    public static final String METADATA_KEY_VIDEO_HEIGHT = "video_height";
    public static final String METADATA_KEY_VIDEO_ROTATION = "rotate";
    public static final String METADATA_KEY_VIDEO_WIDTH = "video_width";
    public static final int OPTION_CLOSEST = 3;
    public static final int OPTION_CLOSEST_SYNC = 2;
    public static final int OPTION_NEXT_SYNC = 1;
    public static final int OPTION_PREVIOUS_SYNC = 0;
    private static final String TAG = "FFmpegMetadataRetriever";
    private long mNativeContext;
    private Bitmap reuse;

    private native byte[] _getFrameAtTime(long j, int i);

    private native byte[] _getScaledFrameAtTime(long j, int i, int i2, int i3);

    private native void _setDataSource(String str, String[] strArr, String[] strArr2);

    private native void native_finalize();

    private final native HashMap<String, String> native_getMetadata(boolean z, boolean z2, HashMap<String, String> hashMap);

    private static native void native_init();

    private native void native_setup();

    public native String extractMetadata(String str);

    public native String extractMetadataFromChapter(String str, int i);

    public native void release();

    public native void setDataSource(FileDescriptor fileDescriptor, long j, long j2);

    static {
        AppMethodBeat.i(3627);
        native_init();
        AppMethodBeat.o(3627);
    }

    public FFmpegMetadataRetriever() {
        AppMethodBeat.i(3609);
        native_setup();
        AppMethodBeat.o(3609);
    }

    public void setDataSource(String str) {
        AppMethodBeat.i(3610);
        _setDataSource(str, null, null);
        AppMethodBeat.o(3610);
    }

    public void setDataSource(String str, Map<String, String> map) {
        AppMethodBeat.i(3611);
        int i = 0;
        String[] strArr = new String[map.size()];
        String[] strArr2 = new String[map.size()];
        Iterator it = map.entrySet().iterator();
        while (true) {
            int i2 = i;
            if (it.hasNext()) {
                Entry entry = (Entry) it.next();
                strArr[i2] = (String) entry.getKey();
                strArr2[i2] = (String) entry.getValue();
                i = i2 + 1;
            } else {
                _setDataSource(str, strArr, strArr2);
                AppMethodBeat.o(3611);
                return;
            }
        }
    }

    public void setDataSource(FileDescriptor fileDescriptor) {
        AppMethodBeat.i(3612);
        setDataSource(fileDescriptor, 0, 576460752303423487L);
        AppMethodBeat.o(3612);
    }

    /* JADX WARNING: Removed duplicated region for block: B:37:0x007c A:{SYNTHETIC, Splitter:B:37:0x007c} */
    public void setDataSource(android.content.Context r9, android.net.Uri r10) {
        /*
        r8 = this;
        r7 = 3613; // 0xe1d float:5.063E-42 double:1.785E-320;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r7);
        if (r10 != 0) goto L_0x0010;
    L_0x0007:
        r0 = new java.lang.IllegalArgumentException;
        r0.<init>();
        com.tencent.matrix.trace.core.AppMethodBeat.o(r7);
        throw r0;
    L_0x0010:
        r0 = r10.getScheme();
        if (r0 == 0) goto L_0x001f;
    L_0x0016:
        r1 = "file";
        r0 = r0.equals(r1);
        if (r0 == 0) goto L_0x002a;
    L_0x001f:
        r0 = r10.getPath();
        r8.setDataSource(r0);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r7);
    L_0x0029:
        return;
    L_0x002a:
        r0 = 0;
        r1 = r9.getContentResolver();	 Catch:{ SecurityException -> 0x0061, all -> 0x00b0 }
        r2 = "r";
        r6 = r1.openAssetFileDescriptor(r10, r2);	 Catch:{ FileNotFoundException -> 0x0055 }
        if (r6 != 0) goto L_0x0063;
    L_0x0038:
        r0 = new java.lang.IllegalArgumentException;	 Catch:{ SecurityException -> 0x0043, all -> 0x0078 }
        r0.<init>();	 Catch:{ SecurityException -> 0x0043, all -> 0x0078 }
        r1 = 3613; // 0xe1d float:5.063E-42 double:1.785E-320;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r1);	 Catch:{ SecurityException -> 0x0043, all -> 0x0078 }
        throw r0;	 Catch:{ SecurityException -> 0x0043, all -> 0x0078 }
    L_0x0043:
        r0 = move-exception;
        r0 = r6;
    L_0x0045:
        if (r0 == 0) goto L_0x004a;
    L_0x0047:
        r0.close();	 Catch:{ IOException -> 0x00ac }
    L_0x004a:
        r0 = r10.toString();
        r8.setDataSource(r0);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r7);
        goto L_0x0029;
    L_0x0055:
        r1 = move-exception;
        r1 = new java.lang.IllegalArgumentException;	 Catch:{ SecurityException -> 0x0061, all -> 0x00b0 }
        r1.<init>();	 Catch:{ SecurityException -> 0x0061, all -> 0x00b0 }
        r2 = 3613; // 0xe1d float:5.063E-42 double:1.785E-320;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r2);	 Catch:{ SecurityException -> 0x0061, all -> 0x00b0 }
        throw r1;	 Catch:{ SecurityException -> 0x0061, all -> 0x00b0 }
    L_0x0061:
        r1 = move-exception;
        goto L_0x0045;
    L_0x0063:
        r1 = r6.getFileDescriptor();	 Catch:{ SecurityException -> 0x0043, all -> 0x0078 }
        r0 = r1.valid();	 Catch:{ SecurityException -> 0x0043, all -> 0x0078 }
        if (r0 != 0) goto L_0x0083;
    L_0x006d:
        r0 = new java.lang.IllegalArgumentException;	 Catch:{ SecurityException -> 0x0043, all -> 0x0078 }
        r0.<init>();	 Catch:{ SecurityException -> 0x0043, all -> 0x0078 }
        r1 = 3613; // 0xe1d float:5.063E-42 double:1.785E-320;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r1);	 Catch:{ SecurityException -> 0x0043, all -> 0x0078 }
        throw r0;	 Catch:{ SecurityException -> 0x0043, all -> 0x0078 }
    L_0x0078:
        r0 = move-exception;
        r1 = r0;
    L_0x007a:
        if (r6 == 0) goto L_0x007f;
    L_0x007c:
        r6.close();	 Catch:{ IOException -> 0x00ae }
    L_0x007f:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r7);
        throw r1;
    L_0x0083:
        r2 = r6.getDeclaredLength();	 Catch:{ SecurityException -> 0x0043, all -> 0x0078 }
        r4 = 0;
        r0 = (r2 > r4 ? 1 : (r2 == r4 ? 0 : -1));
        if (r0 >= 0) goto L_0x0099;
    L_0x008d:
        r8.setDataSource(r1);	 Catch:{ SecurityException -> 0x0043, all -> 0x0078 }
    L_0x0090:
        if (r6 == 0) goto L_0x0095;
    L_0x0092:
        r6.close();	 Catch:{ IOException -> 0x00a6 }
    L_0x0095:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r7);
        goto L_0x0029;
    L_0x0099:
        r2 = r6.getStartOffset();	 Catch:{ SecurityException -> 0x0043, all -> 0x0078 }
        r4 = r6.getDeclaredLength();	 Catch:{ SecurityException -> 0x0043, all -> 0x0078 }
        r0 = r8;
        r0.setDataSource(r1, r2, r4);	 Catch:{ SecurityException -> 0x0043, all -> 0x0078 }
        goto L_0x0090;
    L_0x00a6:
        r0 = move-exception;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r7);
        goto L_0x0029;
    L_0x00ac:
        r0 = move-exception;
        goto L_0x004a;
    L_0x00ae:
        r0 = move-exception;
        goto L_0x007f;
    L_0x00b0:
        r1 = move-exception;
        r6 = r0;
        goto L_0x007a;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.mm.plugin.mmsight.segment.FFmpegMetadataRetriever.setDataSource(android.content.Context, android.net.Uri):void");
    }

    public a getMetadata() {
        boolean z = false;
        AppMethodBeat.i(3614);
        a aVar = new a(this);
        HashMap native_getMetadata = native_getMetadata(false, false, null);
        if (native_getMetadata == null) {
            AppMethodBeat.o(3614);
            return null;
        }
        if (native_getMetadata != null) {
            aVar.oxG = native_getMetadata;
            z = true;
        }
        if (z) {
            AppMethodBeat.o(3614);
            return aVar;
        }
        AppMethodBeat.o(3614);
        return null;
    }

    public Bitmap getFrameAtTime(long j, int i) {
        AppMethodBeat.i(3615);
        if (i < 0 || i > 3) {
            IllegalArgumentException illegalArgumentException = new IllegalArgumentException("Unsupported option: ".concat(String.valueOf(i)));
            AppMethodBeat.o(3615);
            throw illegalArgumentException;
        }
        Bitmap bitmap = null;
        byte[] _getFrameAtTime = _getFrameAtTime(j, i);
        if (_getFrameAtTime != null) {
            bitmap = getBitmapFromPixels(_getFrameAtTime, -1, -1);
        }
        AppMethodBeat.o(3615);
        return bitmap;
    }

    public Bitmap getFrameAtTime(long j) {
        AppMethodBeat.i(3616);
        Bitmap bitmap = null;
        byte[] _getFrameAtTime = _getFrameAtTime(j, 2);
        if (_getFrameAtTime != null) {
            bitmap = getBitmapFromPixels(_getFrameAtTime, -1, -1);
        }
        AppMethodBeat.o(3616);
        return bitmap;
    }

    public Bitmap getFrameAtTime() {
        AppMethodBeat.i(3617);
        Bitmap frameAtTime = getFrameAtTime(-1, 2);
        AppMethodBeat.o(3617);
        return frameAtTime;
    }

    public Bitmap getScaledFrameAtTime(long j, int i, int i2, int i3) {
        AppMethodBeat.i(3618);
        if (i < 0 || i > 3) {
            IllegalArgumentException illegalArgumentException = new IllegalArgumentException("Unsupported option: ".concat(String.valueOf(i)));
            AppMethodBeat.o(3618);
            throw illegalArgumentException;
        }
        Bitmap bitmap = null;
        byte[] _getScaledFrameAtTime = _getScaledFrameAtTime(j, i, i2, i3);
        if (_getScaledFrameAtTime != null) {
            bitmap = getBitmapFromPixels(_getScaledFrameAtTime, i2, i3);
        }
        AppMethodBeat.o(3618);
        return bitmap;
    }

    public Bitmap getScaledFrameAtTime(long j, int i, int i2) {
        AppMethodBeat.i(3619);
        Bitmap bitmap = null;
        byte[] _getScaledFrameAtTime = _getScaledFrameAtTime(j, 0, i, i2);
        if (_getScaledFrameAtTime != null) {
            bitmap = getBitmapFromPixels(_getScaledFrameAtTime, i, i2);
        }
        AppMethodBeat.o(3619);
        return bitmap;
    }

    public void reuseBitmap(Bitmap bitmap) {
        AppMethodBeat.i(3620);
        if (bitmap == null) {
            AppMethodBeat.o(3620);
            return;
        }
        if (this.reuse != null) {
            this.reuse.recycle();
        }
        this.reuse = bitmap;
        AppMethodBeat.o(3620);
    }

    private Bitmap getBitmapFromPixels(byte[] bArr, int i, int i2) {
        AppMethodBeat.i(3621);
        if (bArr == null || bArr.length == 0) {
            AppMethodBeat.o(3621);
            return null;
        }
        if (i == -1) {
            i = getVideoWidth();
        }
        if (i2 == -1) {
            i2 = getVideoHeight();
        }
        if (i <= 0 || i2 <= 0) {
            IllegalStateException illegalStateException = new IllegalStateException(String.format(Locale.CHINA, "Can not get bitmap width and height [%d, %d]", new Object[]{Integer.valueOf(i), Integer.valueOf(i2)}));
            AppMethodBeat.o(3621);
            throw illegalStateException;
        }
        Bitmap bitmap = this.reuse;
        if (bitmap == null) {
            bitmap = Bitmap.createBitmap(i, i2, Config.ARGB_8888);
        }
        bitmap.copyPixelsFromBuffer(ByteBuffer.wrap(bArr));
        AppMethodBeat.o(3621);
        return bitmap;
    }

    public int getVideoWidth() {
        int i = 0;
        AppMethodBeat.i(3622);
        try {
            String extractMetadata = extractMetadata(METADATA_KEY_VIDEO_ROTATION);
            if ("90".equals(extractMetadata) || "270".equals(extractMetadata)) {
                extractMetadata = extractMetadata(METADATA_KEY_VIDEO_HEIGHT);
            } else {
                extractMetadata = extractMetadata(METADATA_KEY_VIDEO_WIDTH);
            }
            i = Integer.valueOf(extractMetadata).intValue();
        } catch (Exception e) {
            ab.e(TAG, "can not get video width %s", new Object[]{e.getMessage()});
        }
        AppMethodBeat.o(3622);
        return i;
    }

    public int getVideoRotation() {
        int i = 0;
        AppMethodBeat.i(3623);
        try {
            i = Integer.valueOf(extractMetadata(METADATA_KEY_VIDEO_ROTATION)).intValue();
        } catch (Exception e) {
            ab.e(TAG, "can not get video rotation. %s", new Object[]{e.getMessage()});
        }
        AppMethodBeat.o(3623);
        return i;
    }

    public int getVideoHeight() {
        int i = 0;
        AppMethodBeat.i(3624);
        try {
            String extractMetadata;
            String extractMetadata2 = extractMetadata(METADATA_KEY_VIDEO_ROTATION);
            if ("90".equals(extractMetadata2) || "270".equals(extractMetadata2)) {
                extractMetadata = extractMetadata(METADATA_KEY_VIDEO_WIDTH);
            } else {
                extractMetadata = extractMetadata(METADATA_KEY_VIDEO_HEIGHT);
            }
            ab.d(TAG, "video height %s rotate %s", new Object[]{extractMetadata, extractMetadata2});
            i = Integer.valueOf(extractMetadata).intValue();
        } catch (Exception e) {
            ab.e(TAG, "can not get video height %s", new Object[]{e.getMessage()});
        }
        AppMethodBeat.o(3624);
        return i;
    }

    public byte[] getScaledFrameAtTimeUndecoded(long j, int i, int i2) {
        AppMethodBeat.i(3625);
        byte[] _getScaledFrameAtTime = _getScaledFrameAtTime(j, 2, i, i2);
        AppMethodBeat.o(3625);
        return _getScaledFrameAtTime;
    }

    /* Access modifiers changed, original: protected */
    public void finalize() {
        AppMethodBeat.i(3626);
        try {
            native_finalize();
        } catch (Exception e) {
            ab.e(TAG, "do nothing");
        } finally {
            super.finalize();
            AppMethodBeat.o(3626);
        }
    }
}
