package com.tencent.qqmusic.mediaplayer;

import android.media.AudioTrack;
import android.os.Handler;
import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.qqmusic.mediaplayer.BaseDecodeDataComponent.HandleDecodeDataCallback;
import com.tencent.qqmusic.mediaplayer.util.Logger;
import com.tencent.qqmusic.mediaplayer.utils.AudioUtil;
import java.util.List;

public class StaticDecodeDataComponent extends BaseDecodeDataComponent {
    private static final String TAG = "StaticDecodeDataComponent";
    private int mAllBufferSize;
    private List<BufferInfo> mAllPcmBufferList;
    private int mBitDept;
    private boolean mHasTerminal;
    private boolean mIsfirstStarted;

    StaticDecodeDataComponent(CorePlayer corePlayer, PlayerStateRunner playerStateRunner, AudioInformation audioInformation, PlayerCallback playerCallback, HandleDecodeDataCallback handleDecodeDataCallback, Handler handler, int i) {
        super(corePlayer, playerStateRunner, audioInformation, playerCallback, handleDecodeDataCallback, handler, i);
        this.mBitDept = 2;
        this.mHasTerminal = false;
        this.mBuffSize = 8192;
    }

    /* Access modifiers changed, original: 0000 */
    public int getAudioStreamType() {
        return 0;
    }

    /* Access modifiers changed, original: 0000 */
    public long getCurPosition() {
        AppMethodBeat.i(104509);
        AudioTrack audioTrack = this.mAudioTrack;
        long j;
        if (audioTrack == null || audioTrack.getState() == 0) {
            j = this.mCurPosition;
            AppMethodBeat.o(104509);
            return j;
        }
        this.mCurPosition = (long) BaseDecodeDataComponent.getAudioTrackPosition(0, audioTrack);
        j = this.mCurPosition;
        AppMethodBeat.o(104509);
        return j;
    }

    /* Access modifiers changed, original: 0000 */
    public void handleDecodeData() {
        AppMethodBeat.i(104510);
        if (this.mInformation != null) {
            try {
                if (0 == this.mInformation.getSampleRate()) {
                    Logger.e(TAG, "failed to getSampleRate");
                    this.mStateRunner.transfer(Integer.valueOf(9));
                    callExceptionCallback(91, 63);
                    AppMethodBeat.o(104510);
                    return;
                }
                this.mHasInit = true;
                if (!decodeAllData()) {
                    Logger.e(TAG, "failed to decodeAllData");
                    this.mStateRunner.transfer(Integer.valueOf(9));
                    AppMethodBeat.o(104510);
                } else if (!createAudioTrack()) {
                    Logger.e(TAG, "failed to createAudioTrack");
                    this.mStateRunner.transfer(Integer.valueOf(9));
                    AppMethodBeat.o(104510);
                } else if (!writeAudioTrack() && !this.mHasTerminal) {
                    Logger.e(TAG, "failed to writeAudioTrack");
                    this.mStateRunner.transfer(Integer.valueOf(9));
                    AppMethodBeat.o(104510);
                } else if (this.mHasTerminal) {
                    this.mStateRunner.transfer(Integer.valueOf(7));
                    AppMethodBeat.o(104510);
                } else {
                    this.mStateRunner.transfer(Integer.valueOf(2));
                    this.mIsfirstStarted = false;
                    initAudioListeners(this.mInformation.getPlaySample(), getBytesPerSampleInPlay(this.mInformation.getBitDept()), this.mInformation.getChannels());
                    postRunnable(new 1(this), 20);
                    Logger.i(TAG, axiliary("prepared. waiting..."));
                    this.mSignalControl.doWait();
                    Logger.i(TAG, axiliary("woke after preparing"));
                    playAudioTrack();
                    AppMethodBeat.o(104510);
                }
            } catch (SoNotFindException e) {
                Logger.e(TAG, e);
            }
        } else {
            Logger.e(TAG, axiliary("不留痕迹的退出 时机：获取Information时 step = 3"));
            this.mStateRunner.transfer(Integer.valueOf(9));
            callExceptionCallback(91, 63);
            AppMethodBeat.o(104510);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:18:0x0076  */
    private boolean decodeAllData() {
        /*
        r9 = this;
        r7 = 9;
        r6 = 91;
        r3 = 1;
        r8 = 104511; // 0x1983f float:1.46451E-40 double:5.16353E-319;
        r2 = 0;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r8);
        r0 = new java.util.ArrayList;
        r0.<init>();
        r9.mAllPcmBufferList = r0;
    L_0x0013:
        r0 = r9.mCorePlayer;
        r0 = r0.mIsExit;
        if (r0 != 0) goto L_0x006e;
    L_0x0019:
        r0 = new com.tencent.qqmusic.mediaplayer.BufferInfo;
        r0.<init>();
        r1 = r9.mBuffSize;
        r0.setByteBufferCapacity(r1);
        r1 = r9.mHandleDecodeDataCallback;	 Catch:{ SoNotFindException -> 0x0041, Throwable -> 0x0099 }
        r4 = r9.mBuffSize;	 Catch:{ SoNotFindException -> 0x0041, Throwable -> 0x0099 }
        r5 = r0.byteBuffer;	 Catch:{ SoNotFindException -> 0x0041, Throwable -> 0x0099 }
        r1 = r1.pullDecodeData(r4, r5);	 Catch:{ SoNotFindException -> 0x0041, Throwable -> 0x0099 }
        r4 = 1;
        r9.mHasDecode = r4;	 Catch:{ SoNotFindException -> 0x0041, Throwable -> 0x0099 }
        if (r1 <= 0) goto L_0x005a;
    L_0x0032:
        r0.bufferSize = r1;	 Catch:{ SoNotFindException -> 0x0041, Throwable -> 0x0099 }
        r1 = r9.mAllPcmBufferList;	 Catch:{ SoNotFindException -> 0x0041, Throwable -> 0x0099 }
        r1.add(r0);	 Catch:{ SoNotFindException -> 0x0041, Throwable -> 0x0099 }
        r0 = r9.mHasDecodeSuccess;	 Catch:{ SoNotFindException -> 0x0041, Throwable -> 0x0099 }
        if (r0 != 0) goto L_0x0013;
    L_0x003d:
        r0 = 1;
        r9.mHasDecodeSuccess = r0;	 Catch:{ SoNotFindException -> 0x0041, Throwable -> 0x0099 }
        goto L_0x0013;
    L_0x0041:
        r0 = move-exception;
        r1 = "StaticDecodeDataComponent";
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r1, r0);
        r0 = r9.mStateRunner;
        r1 = java.lang.Integer.valueOf(r7);
        r0.transfer(r1);
        r0 = 62;
        r9.callExceptionCallback(r6, r0);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
    L_0x0059:
        return r2;
    L_0x005a:
        if (r1 != 0) goto L_0x008e;
    L_0x005c:
        r1 = r9.mBuffSize;	 Catch:{ SoNotFindException -> 0x0041, Throwable -> 0x0099 }
        r0.bufferSize = r1;	 Catch:{ SoNotFindException -> 0x0041, Throwable -> 0x0099 }
        r1 = r9.mAllPcmBufferList;	 Catch:{ SoNotFindException -> 0x0041, Throwable -> 0x0099 }
        r1.add(r0);	 Catch:{ SoNotFindException -> 0x0041, Throwable -> 0x0099 }
        r0 = "StaticDecodeDataComponent";
        r1 = "static decode end";
        com.tencent.qqmusic.mediaplayer.util.Logger.i(r0, r1);	 Catch:{ SoNotFindException -> 0x0041, Throwable -> 0x0099 }
    L_0x006e:
        r0 = r9.mAllPcmBufferList;
        r0 = r0.isEmpty();
        if (r0 != 0) goto L_0x00fa;
    L_0x0076:
        r0 = r9.mAllPcmBufferList;
        r4 = r0.iterator();
        r1 = r2;
    L_0x007d:
        r0 = r4.hasNext();
        if (r0 == 0) goto L_0x00b2;
    L_0x0083:
        r0 = r4.next();
        r0 = (com.tencent.qqmusic.mediaplayer.BufferInfo) r0;
        r0 = r0.bufferSize;
        r0 = r0 + r1;
        r1 = r0;
        goto L_0x007d;
    L_0x008e:
        r0 = r9.mHandleDecodeDataCallback;	 Catch:{ SoNotFindException -> 0x0041, Throwable -> 0x0099 }
        r3 = 91;
        r0.onPullDecodeDataEndOrFailed(r1, r3);	 Catch:{ SoNotFindException -> 0x0041, Throwable -> 0x0099 }
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        goto L_0x0059;
    L_0x0099:
        r0 = move-exception;
        r1 = "StaticDecodeDataComponent";
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r1, r0);
        r0 = r9.mStateRunner;
        r1 = java.lang.Integer.valueOf(r7);
        r0.transfer(r1);
        r0 = 67;
        r9.callExceptionCallback(r6, r0);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        goto L_0x0059;
    L_0x00b2:
        r0 = "StaticDecodeDataComponent";
        r4 = "static totalBufferSize = ";
        r5 = java.lang.String.valueOf(r1);
        r4 = r4.concat(r5);
        com.tencent.qqmusic.mediaplayer.util.Logger.i(r0, r4);
        r0 = r9.mDecodeBufferInfo;
        r0.setByteBufferCapacity(r1);
        r0 = r9.mAllPcmBufferList;
        r4 = r0.iterator();
        r1 = r2;
    L_0x00cf:
        r0 = r4.hasNext();
        if (r0 == 0) goto L_0x00fa;
    L_0x00d5:
        r0 = r4.next();
        r0 = (com.tencent.qqmusic.mediaplayer.BufferInfo) r0;
        r5 = r0.byteBuffer;
        r6 = r9.mDecodeBufferInfo;
        r6 = r6.byteBuffer;
        r7 = r0.bufferSize;
        java.lang.System.arraycopy(r5, r2, r6, r1, r7);
        r5 = r0.bufferSize;
        r1 = r1 + r5;
        r5 = r9.mDecodeBufferInfo;
        r6 = r5.bufferSize;
        r7 = r0.bufferSize;
        r6 = r6 + r7;
        r5.bufferSize = r6;
        r5 = r9.mAllBufferSize;
        r0 = r0.bufferSize;
        r0 = r0 + r5;
        r9.mAllBufferSize = r0;
        goto L_0x00cf;
    L_0x00fa:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        r2 = r3;
        goto L_0x0059;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.qqmusic.mediaplayer.StaticDecodeDataComponent.decodeAllData():boolean");
    }

    private boolean createAudioTrack() {
        int i = 3;
        AppMethodBeat.i(104512);
        Logger.d(TAG, axiliary("createAudioTrack"));
        if (this.mInformation == null) {
            Logger.e(TAG, axiliary("不留痕迹的退出 时机：获取Information时 step = 3"));
            this.mStateRunner.transfer(Integer.valueOf(9));
            callExceptionCallback(91, 63);
            AppMethodBeat.o(104512);
            return false;
        }
        if (!this.mStateRunner.isEqual(new Integer[]{Integer.valueOf(3)})) {
            Logger.e(TAG, axiliary("mState is not preparing"));
            callExceptionCallback(91, 54);
            AppMethodBeat.o(104512);
            return false;
        } else if (this.mInformation.getSampleRate() <= 0) {
            Logger.e(TAG, axiliary("mInformation.getSampleRate() failed"));
            callExceptionCallback(91, 64);
            AppMethodBeat.o(104512);
            return false;
        } else {
            int i2 = 12;
            int channels = this.mInformation.getChannels();
            if (channels == 1) {
                i2 = 4;
            } else if (channels == 2) {
                i2 = 12;
            } else if (channels == 6) {
                i2 = 252;
            } else if (channels == 8) {
                i2 = 1020;
            }
            this.mPlaySample = this.mInformation.getSampleRate();
            this.mBitDept = this.mInformation.getBitDept();
            while (this.mPlaySample > MAX_PLAY_SAMPLE_RATE) {
                this.mPlaySample /= 2;
            }
            if (CAN_USE_FLOAT_IN_HI_RES && this.mBitDept >= 3) {
                this.mPlayBitDepth = this.mBitDept;
                this.isUseFloatInHiRes = true;
                if (this.mPlaySample != this.mInformation.getSampleRate()) {
                    Logger.i(TAG, axiliary("will use float resampled pcm for Hi-Res, bitDept: " + this.mBitDept + ", origin sample rate: " + this.mInformation.getSampleRate() + ", target sample rate: " + this.mPlaySample));
                } else {
                    Logger.i(TAG, axiliary("will use float pcm for Hi-Res, bitDept: " + this.mBitDept + ", sample rate: " + this.mPlaySample));
                }
            } else if (!CAN_USE_FLOAT_IN_HI_RES && this.mBitDept >= 3) {
                this.mPlayBitDepth = 2;
                if (this.mPlaySample != this.mInformation.getSampleRate()) {
                    Logger.i(TAG, axiliary("will use byte pcm resampled and bitDept converted, origin bitDept: " + this.mBitDept + ", target bitDept: " + this.mPlayBitDepth + ", origin sample rate: " + this.mInformation.getSampleRate() + ", target sample rate: " + this.mPlaySample));
                } else {
                    Logger.i(TAG, axiliary("will use byte pcm with bitDept converted, origin bitDept: " + this.mBitDept + ", target bitDept: " + this.mPlayBitDepth));
                }
            } else if (this.mPlaySample != this.mInformation.getSampleRate()) {
                this.mPlayBitDepth = this.mBitDept;
                Logger.i(TAG, axiliary("will use byte pcm resampled, bitDept: " + this.mBitDept + ", origin sample rate: " + this.mInformation.getSampleRate() + ", target sample rate: " + this.mPlaySample));
            } else {
                this.mPlayBitDepth = 2;
                Logger.i(TAG, axiliary("will use normal byte pcm, bitDept: " + this.mBitDept + ", sample rate: " + this.mPlaySample));
            }
            if (this.mBitDept != 1) {
                if (this.mBitDept == 2) {
                    i = 2;
                } else if (this.isUseFloatInHiRes) {
                    i = 4;
                } else {
                    i = 2;
                }
            }
            Logger.d(TAG, axiliary(String.format("mPlaySample: %d, playChannel: %d", new Object[]{Long.valueOf(this.mPlaySample), Integer.valueOf(channels)})));
            try {
                this.mAudioTrack = new AudioTrack(3, (int) this.mPlaySample, i2, i, this.mAllBufferSize, 0);
                if (this.mAudioTrack.getState() == 2) {
                    Logger.d(TAG, axiliary("new AudioTrack succeed"));
                }
            } catch (Throwable th) {
                Logger.e(TAG, th);
            }
            if (this.mAudioTrack == null || this.mAudioTrack.getState() != 2) {
                this.mCreateAudioTrackFail = true;
                Logger.e(TAG, axiliary("create audioTrack fail mCreateAudioTrackFail = true"));
                this.mAudioTrack = null;
                this.mStateRunner.transfer(Integer.valueOf(9));
                callExceptionCallback(91, 66);
                AppMethodBeat.o(104512);
                return false;
            }
            Logger.d(TAG, axiliary("create audioTrack success"));
            AppMethodBeat.o(104512);
            return true;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:35:0x017a  */
    /* JADX WARNING: Removed duplicated region for block: B:17:0x0062  */
    private boolean writeAudioTrack() {
        /*
        r8 = this;
        r7 = 91;
        r6 = 9;
        r2 = 1;
        r5 = 104513; // 0x19841 float:1.46454E-40 double:5.16363E-319;
        r1 = 0;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r5);
        r0 = r8.mDecodeBufferInfo;
        r0 = r0.byteBuffer;
        if (r0 == 0) goto L_0x0189;
    L_0x0012:
        r0 = r8.mAudioTrack;
        if (r0 == 0) goto L_0x0189;
    L_0x0016:
        r0 = r8.mDecodeBufferInfo;
        r3 = r8.mNewBitDepthBufferInfo;
        r8.handleHighBitDept(r0, r3);
        r0 = r8.mNewBitDepthBufferInfo;
        r3 = r8.mReSampleBufferInfo;
        r8.handleHighSample(r0, r3);
        r0 = r8.isUseFloatInHiRes;
        if (r0 == 0) goto L_0x00b2;
    L_0x0028:
        r0 = r8.mReSampleBufferInfo;
        r3 = r8.mFloatBufferInfo;
        r8.convertBytePcmToFloatPcm(r0, r3);
        r0 = r8.mFloatBufferInfo;
        r3 = r8.mFloatBufferInfo;
        r8.processAudioListeners(r0, r3);
    L_0x0036:
        r8.mHasTerminal = r1;
        r0 = r8.mTerminalAudioEffectList;
        r0 = r0.size();
        r0 = r0 + -1;
        r3 = r0;
    L_0x0041:
        if (r3 < 0) goto L_0x005e;
    L_0x0043:
        r0 = r8.mTerminalAudioEffectList;
        r0 = r0.get(r3);
        r0 = (com.tencent.qqmusic.mediaplayer.audiofx.IAudioListener) r0;
        r4 = r0.isEnabled();
        if (r4 == 0) goto L_0x00c3;
    L_0x0051:
        r3 = r8.isUseFloatInHiRes;
        if (r3 == 0) goto L_0x00bb;
    L_0x0055:
        r3 = r8.mFloatBufferInfo;
        r4 = r8.mFloatBufferInfo;
        r0.onPcm(r3, r4);
    L_0x005c:
        r8.mHasTerminal = r2;
    L_0x005e:
        r0 = r8.mHasTerminal;
        if (r0 != 0) goto L_0x017a;
    L_0x0062:
        r0 = r8.isUseFloatInHiRes;
        if (r0 == 0) goto L_0x00fc;
    L_0x0066:
        r0 = r8.mAudioTrack;
        r3 = r8.mFloatBufferInfo;
        r3 = r3.floatBuffer;
        r4 = r8.mFloatBufferInfo;
        r4 = r4.bufferSize;
        r0 = r0.write(r3, r1, r4, r1);
        if (r0 >= 0) goto L_0x00c8;
    L_0x0076:
        r2 = "StaticDecodeDataComponent";
        r3 = new java.lang.StringBuilder;
        r4 = "mAudioTrack write float failed: ";
        r3.<init>(r4);
        r0 = r3.append(r0);
        r3 = ", expect: ";
        r0 = r0.append(r3);
        r3 = r8.mFloatBufferInfo;
        r3 = r3.bufferSize;
        r0 = r0.append(r3);
        r0 = r0.toString();
        r0 = r8.axiliary(r0);
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r2, r0);
        r0 = r8.mStateRunner;
        r2 = java.lang.Integer.valueOf(r6);
        r0.transfer(r2);
        r0 = 102; // 0x66 float:1.43E-43 double:5.04E-322;
        r8.callExceptionCallback(r7, r0);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
        r0 = r1;
    L_0x00b1:
        return r0;
    L_0x00b2:
        r0 = r8.mReSampleBufferInfo;
        r3 = r8.mDTSBufferInfo;
        r8.processAudioListeners(r0, r3);
        goto L_0x0036;
    L_0x00bb:
        r3 = r8.mDTSBufferInfo;
        r4 = r8.mDTSBufferInfo;
        r0.onPcm(r3, r4);
        goto L_0x005c;
    L_0x00c3:
        r0 = r3 + -1;
        r3 = r0;
        goto L_0x0041;
    L_0x00c8:
        r1 = r8.mFloatBufferInfo;
        r1 = r1.bufferSize;
        if (r0 == r1) goto L_0x00f7;
    L_0x00ce:
        r1 = "StaticDecodeDataComponent";
        r3 = new java.lang.StringBuilder;
        r4 = "mAudioTrack write float not equal: ";
        r3.<init>(r4);
        r0 = r3.append(r0);
        r3 = ", expect: ";
        r0 = r0.append(r3);
        r3 = r8.mFloatBufferInfo;
        r3 = r3.bufferSize;
        r0 = r0.append(r3);
        r0 = r0.toString();
        r0 = r8.axiliary(r0);
        com.tencent.qqmusic.mediaplayer.util.Logger.w(r1, r0);
    L_0x00f7:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
        r0 = r2;
        goto L_0x00b1;
    L_0x00fc:
        r0 = r8.mAudioTrack;
        r3 = r8.mDTSBufferInfo;
        r3 = r3.byteBuffer;
        r4 = r8.mDTSBufferInfo;
        r4 = r4.bufferSize;
        r0 = r0.write(r3, r1, r4);
        if (r0 >= 0) goto L_0x0149;
    L_0x010c:
        r2 = "StaticDecodeDataComponent";
        r3 = new java.lang.StringBuilder;
        r4 = "mAudioTrack write bytes failed: ";
        r3.<init>(r4);
        r0 = r3.append(r0);
        r3 = ", expect: ";
        r0 = r0.append(r3);
        r3 = r8.mDTSBufferInfo;
        r3 = r3.bufferSize;
        r0 = r0.append(r3);
        r0 = r0.toString();
        r0 = r8.axiliary(r0);
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r2, r0);
        r0 = r8.mStateRunner;
        r2 = java.lang.Integer.valueOf(r6);
        r0.transfer(r2);
        r0 = 102; // 0x66 float:1.43E-43 double:5.04E-322;
        r8.callExceptionCallback(r7, r0);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
        r0 = r1;
        goto L_0x00b1;
    L_0x0149:
        r1 = r8.mDTSBufferInfo;
        r1 = r1.bufferSize;
        if (r0 == r1) goto L_0x00f7;
    L_0x014f:
        r1 = "StaticDecodeDataComponent";
        r3 = new java.lang.StringBuilder;
        r4 = "mAudioTrack write bytes not equal: ";
        r3.<init>(r4);
        r0 = r3.append(r0);
        r3 = ", expect: ";
        r0 = r0.append(r3);
        r3 = r8.mDTSBufferInfo;
        r3 = r3.bufferSize;
        r0 = r0.append(r3);
        r0 = r0.toString();
        r0 = r8.axiliary(r0);
        com.tencent.qqmusic.mediaplayer.util.Logger.w(r1, r0);
        goto L_0x00f7;
    L_0x017a:
        r0 = "StaticDecodeDataComponent";
        r2 = "mTerminalAudioEffectList has blocked";
        com.tencent.qqmusic.mediaplayer.util.Logger.i(r0, r2);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
        r0 = r1;
        goto L_0x00b1;
    L_0x0189:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
        r0 = r1;
        goto L_0x00b1;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.qqmusic.mediaplayer.StaticDecodeDataComponent.writeAudioTrack():boolean");
    }

    public void playAudioTrack() {
        AppMethodBeat.i(104514);
        this.mAudioTrack.reloadStaticData();
        while (!this.mCorePlayer.mIsExit) {
            if (!isPaused()) {
                if (isIdle()) {
                    break;
                } else if (isError()) {
                    Logger.e(TAG, "static play error");
                    AppMethodBeat.o(104514);
                    return;
                } else if (isStopped()) {
                    if (this.mAudioTrack.getPlayState() != 1) {
                        this.mAudioTrack.stop();
                    }
                    postRunnable(new 3(this), 20);
                    AppMethodBeat.o(104514);
                    return;
                } else if (isCompleted()) {
                    this.mCorePlayer.mIsExit = true;
                    AppMethodBeat.o(104514);
                    return;
                } else if (isPlaying()) {
                    if (this.mAudioTrack.getPlayState() == 2) {
                        this.mAudioTrack.play();
                    } else if (this.mAudioTrack.getPlayState() == 1) {
                        if (!this.mIsfirstStarted) {
                            this.mIsfirstStarted = true;
                            this.mAudioTrack.play();
                            this.mCallback.playerStarted(this.mCorePlayer);
                        }
                    } else if ((((long) AudioUtil.getPlaybackHeadPositionSafely(this.mAudioTrack)) * ((long) this.mInformation.getChannels())) * ((long) getBytesPerSampleInPlay(this.mInformation.getBitDept())) >= ((long) this.mAllBufferSize)) {
                        this.mStateRunner.transfer(Integer.valueOf(7));
                        Logger.i(TAG, "static play completed");
                        postRunnable(new 4(this), 20);
                    }
                }
            } else {
                if (this.mAudioTrack.getPlayState() != 2) {
                    this.mAudioTrack.pause();
                }
                postRunnable(new 2(this), 20);
                doWaitForPaused();
            }
        }
        AppMethodBeat.o(104514);
    }
}
