package com.tencent.qqmusic.mediaplayer.seektable.flac;

import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.qqmusic.mediaplayer.seektable.InvalidBoxException;
import com.tencent.qqmusic.mediaplayer.seektable.Parsable;
import com.tencent.qqmusic.mediaplayer.seektable.ParsableInputStreamWrapper;
import com.tencent.qqmusic.mediaplayer.seektable.SeekTable;
import com.tencent.qqmusic.mediaplayer.upstream.IDataSource;
import java.util.Arrays;
import java.util.HashSet;

public class FlacSeekTable implements SeekTable {
    private static final int SEEK_POINT_SIZE = 18;
    private static final byte TYPE_SEEKTABLE = (byte) 3;
    private static final byte TYPE_STREAMINFO = (byte) 0;
    private long firstFrameOffset;
    private long[] offsets;
    private long[] sampleNumbers;
    private int sampleRate = 0;

    static /* synthetic */ boolean access$200(Parsable parsable) {
        AppMethodBeat.i(128528);
        boolean seekToFirstFrame = seekToFirstFrame(parsable);
        AppMethodBeat.o(128528);
        return seekToFirstFrame;
    }

    public FlacSeekTable(int i) {
        this.sampleRate = i;
    }

    public long[] getOffsetRangeOfSample(int i) {
        AppMethodBeat.i(128521);
        long[] jArr;
        if (binarySearchFloor(this.sampleNumbers, (long) i, true, true) + 1 >= this.offsets.length) {
            jArr = new long[]{this.firstFrameOffset + this.offsets[binarySearchFloor(this.sampleNumbers, (long) i, true, true)], -1};
            AppMethodBeat.o(128521);
            return jArr;
        }
        jArr = new long[]{this.firstFrameOffset + this.offsets[binarySearchFloor(this.sampleNumbers, (long) i, true, true)], this.firstFrameOffset + this.offsets[binarySearchFloor(this.sampleNumbers, (long) i, true, true) + 1]};
        AppMethodBeat.o(128521);
        return jArr;
    }

    public void parse(IDataSource iDataSource) {
        AppMethodBeat.i(128522);
        ParsableInputStreamWrapper parsableInputStreamWrapper = new ParsableInputStreamWrapper(iDataSource);
        if (seekToFlac(parsableInputStreamWrapper)) {
            if (walkThrough(parsableInputStreamWrapper, this.sampleRate == 0 ? new BlockHandler[]{new SeektableHandler(this), new StreamInfoHandler(this)} : new BlockHandler[]{new SeektableHandler(this)})) {
                AppMethodBeat.o(128522);
                return;
            }
            InvalidBoxException invalidBoxException = new InvalidBoxException("lack one or more critical BLOCK(s) to create seek table!");
            AppMethodBeat.o(128522);
            throw invalidBoxException;
        }
        AppMethodBeat.o(128522);
    }

    public long seek(long j) {
        AppMethodBeat.i(128523);
        int binarySearchFloor = binarySearchFloor(this.sampleNumbers, (long) ((int) (Math.round(((double) j) / 1000.0d) * ((long) this.sampleRate))), true, true);
        long j2 = this.offsets[binarySearchFloor] + this.firstFrameOffset;
        AppMethodBeat.o(128523);
        return j2;
    }

    private static boolean seekToFlac(Parsable parsable) {
        AppMethodBeat.i(128524);
        byte[] bArr = new byte[4];
        parsable.readBytes(bArr, 0, 4);
        if (bArr[0] == (byte) 73 && bArr[1] == (byte) 68 && bArr[2] == (byte) 51) {
            parsable.skip(2);
            parsable.skip((long) Id3Util.unsynchsafe(parsable.readInt()));
            parsable.readBytes(bArr, 0, 4);
        }
        if (bArr[0] == (byte) 102 && bArr[1] == (byte) 76 && bArr[2] == (byte) 97 && bArr[3] == (byte) 67) {
            AppMethodBeat.o(128524);
            return true;
        }
        AppMethodBeat.o(128524);
        return false;
    }

    private static boolean walkThrough(Parsable parsable, BlockHandler... blockHandlerArr) {
        AppMethodBeat.i(128525);
        byte[] bArr = new byte[1];
        byte[] bArr2 = new byte[3];
        HashSet hashSet = new HashSet();
        while (hashSet.size() < blockHandlerArr.length && parsable.available() > 0) {
            parsable.readBytes(bArr, 0, 1);
            int i = bArr[0] & 127;
            boolean z = false;
            for (BlockHandler blockHandler : blockHandlerArr) {
                z = blockHandler.handle(parsable, i);
                if (z) {
                    hashSet.add(Integer.valueOf(blockHandler.hashCode()));
                    break;
                }
            }
            if (!z) {
                if (((bArr[0] & 255) >> 7) == 1) {
                    break;
                }
                parsable.readBytes(bArr2, 0, 3);
                parsable.skip((long) BytesUtil.from(bArr2));
            }
        }
        if (hashSet.size() == blockHandlerArr.length) {
            AppMethodBeat.o(128525);
            return true;
        }
        AppMethodBeat.o(128525);
        return false;
    }

    private static boolean seekToFirstFrame(Parsable parsable) {
        boolean z = false;
        AppMethodBeat.i(128526);
        byte[] bArr = new byte[1];
        byte[] bArr2 = new byte[3];
        boolean z2 = false;
        while (parsable.available() > 0) {
            if (z2) {
                byte[] bArr3 = new byte[2];
                parsable.readBytes(bArr3, 0, 2);
                if ((bArr3[0] & 255) == 255 && ((bArr3[1] & 255) >> 2) == 62) {
                    z = true;
                }
                AppMethodBeat.o(128526);
                return z;
            }
            parsable.readBytes(bArr, 0, 1);
            if (((bArr[0] & 255) >> 7) == 1) {
                z2 = true;
            }
            parsable.readBytes(bArr2, 0, 3);
            parsable.skip((long) BytesUtil.from(bArr2));
        }
        AppMethodBeat.o(128526);
        return z;
    }

    private static int binarySearchFloor(long[] jArr, long j, boolean z, boolean z2) {
        AppMethodBeat.i(128527);
        int binarySearch = Arrays.binarySearch(jArr, j);
        if (binarySearch < 0) {
            binarySearch = -(binarySearch + 2);
        } else if (!z) {
            binarySearch--;
        }
        if (z2) {
            binarySearch = Math.max(0, binarySearch);
            AppMethodBeat.o(128527);
            return binarySearch;
        }
        AppMethodBeat.o(128527);
        return binarySearch;
    }
}
