package com.tencent.tmassistantsdk.downloadservice;

import android.content.Context;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.net.Uri;
import android.os.PowerManager.WakeLock;
import android.text.TextUtils;
import com.tencent.map.geolocation.internal.TencentExtraKeys;
import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.mm.sdk.platformtools.ab;
import com.tencent.tmassistantsdk.common.TMAssistantDownloadSDKContentType;
import com.tencent.tmassistantsdk.storage.TMAssistantFile;
import com.tencent.tmassistantsdk.util.GlobalUtil;
import com.tencent.tmassistantsdk.util.TMLog;
import java.io.File;
import java.net.URI;
import java.net.URLDecoder;
import java.net.URLEncoder;

public class DownloadHelper {
    public static final int PHONE = 1;
    public static final float SAVE_FATOR = 1.5f;
    public static final long SAVE_LENGTH = 104857600;
    public static final int SDCARD = 2;
    public static final String TAG = DownloadHelper.class.getSimpleName();
    public static final int UNKNOWN = 0;

    static {
        AppMethodBeat.i(75713);
        AppMethodBeat.o(75713);
    }

    public static WakeLock getWakeLock() {
        return null;
    }

    public static String correctURL(String str) {
        AppMethodBeat.i(75700);
        String trim = str.replace("\r", "").replace("\n", "").trim();
        String str2 = new String(trim);
        try {
            Uri parse = Uri.parse(trim);
            String lastPathSegment = parse.getLastPathSegment();
            if (lastPathSegment != null && lastPathSegment.length() > 0) {
                str2 = str2.replace(lastPathSegment, URLEncoder.encode(parse.getLastPathSegment()).replace("+", "%20"));
            }
        } catch (Exception e) {
            ab.printErrStackTrace(TAG, e, "", new Object[0]);
        }
        AppMethodBeat.o(75700);
        return str2;
    }

    public static String genAPKFileName(String str) {
        AppMethodBeat.i(75701);
        if (str.contains(".apk")) {
            CharSequence trim = str.trim().substring(str.lastIndexOf("/") + 1).trim();
            if (trim.contains("?")) {
                trim = trim.substring(0, trim.lastIndexOf("?"));
            }
            if (!TextUtils.isEmpty(trim)) {
                TMLog.i(TAG, "file name = ".concat(String.valueOf(trim)));
                String renameAPKFileName = renameAPKFileName(trim);
                AppMethodBeat.o(75701);
                return renameAPKFileName;
            }
        }
        AppMethodBeat.o(75701);
        return null;
    }

    public static String decodeFileName(String str) {
        AppMethodBeat.i(75702);
        if (str != null) {
            String decode = URLDecoder.decode(str);
            AppMethodBeat.o(75702);
            return decode;
        }
        AppMethodBeat.o(75702);
        return null;
    }

    public static String correctFileName(String str) {
        AppMethodBeat.i(75703);
        String replace = str.replace("?", "_").replace("*", "_").replace(" ", "_").replace("$", "_").replace("&", "_").replace("@", "_").replace("#", "_").replace("<", "_").replace(">", "_").replace("|", "_").replace(":", "_").replace("/", "_").replace("\\", "_").replace("\"", "_");
        AppMethodBeat.o(75703);
        return replace;
    }

    public static String renameAPKFileName(String str) {
        AppMethodBeat.i(75704);
        if (str == null) {
            AppMethodBeat.o(75704);
            return null;
        }
        int lastIndexOf = str.lastIndexOf(46);
        if (lastIndexOf <= 0 || lastIndexOf == str.length() - 1) {
            AppMethodBeat.o(75704);
            return str;
        }
        String str2;
        String[] strArr = new String[]{str.substring(0, lastIndexOf), str.substring(lastIndexOf, str.length())};
        int i = 0;
        do {
            if (i == 0) {
                str2 = str;
            } else {
                str2 = strArr[0] + "(" + i + ")" + strArr[1];
            }
            i++;
        } while (new File(TMAssistantFile.getSavePathRootDir() + File.separator + str2).exists());
        AppMethodBeat.o(75704);
        return str2;
    }

    public static boolean isValidURL(String str) {
        boolean z = false;
        AppMethodBeat.i(75705);
        try {
            URI uri = new URI(correctURL(str));
            z = true;
        } catch (Throwable th) {
            ab.printErrStackTrace(TAG, th, "", new Object[0]);
        }
        AppMethodBeat.o(75705);
        return z;
    }

    public static String generateFileNameFromURL(String str, String str2) {
        AppMethodBeat.i(75706);
        String calcMD5AsString = GlobalUtil.calcMD5AsString(str);
        if (TextUtils.isEmpty(calcMD5AsString)) {
            calcMD5AsString = Integer.toString(Math.abs(str.hashCode()));
        }
        String str3 = "";
        if (!TextUtils.isEmpty(str2)) {
            if (str2.equals(TMAssistantDownloadSDKContentType.CONTENT_TYPE_APK)) {
                str3 = ".apk";
            } else if (str2.equals(TMAssistantDownloadSDKContentType.CONTENT_TYPE_APKDIFF)) {
                str3 = ".diff";
            } else if (str2.equals(TMAssistantDownloadSDKContentType.CONTENT_TYPE_OTHERS)) {
                str3 = ".other";
            }
        }
        calcMD5AsString = calcMD5AsString + str3;
        AppMethodBeat.o(75706);
        return calcMD5AsString;
    }

    public static synchronized String getNetStatus() {
        String str;
        synchronized (DownloadHelper.class) {
            AppMethodBeat.i(75707);
            Context context = GlobalUtil.getInstance().getContext();
            if (context == null) {
                str = "";
                AppMethodBeat.o(75707);
            } else {
                try {
                    if (context.checkCallingOrSelfPermission("android.permission.ACCESS_NETWORK_STATE") != 0) {
                        str = "";
                        AppMethodBeat.o(75707);
                    } else {
                        NetworkInfo activeNetworkInfo = ((ConnectivityManager) context.getSystemService("connectivity")).getActiveNetworkInfo();
                        if (activeNetworkInfo == null) {
                            str = "";
                            AppMethodBeat.o(75707);
                        } else if (activeNetworkInfo.getType() == 1) {
                            str = TencentExtraKeys.LOCATION_SOURCE_WIFI;
                            AppMethodBeat.o(75707);
                        } else {
                            str = activeNetworkInfo.getExtraInfo();
                            if (str == null) {
                                str = "";
                                AppMethodBeat.o(75707);
                            } else {
                                str = str.toLowerCase();
                                TMLog.v(TAG, "netInfo  =  ".concat(String.valueOf(str)));
                                AppMethodBeat.o(75707);
                            }
                        }
                    }
                } catch (Exception e) {
                    str = "";
                    AppMethodBeat.o(75707);
                }
            }
        }
        return str;
    }

    public static boolean isNetworkConncted() {
        AppMethodBeat.i(75708);
        Context context = GlobalUtil.getInstance().getContext();
        if (context == null) {
            TMLog.w(TAG, "GlobalUtil.getInstance().getContext() == null.");
            AppMethodBeat.o(75708);
            return false;
        }
        boolean isAvailable;
        NetworkInfo activeNetworkInfo = ((ConnectivityManager) context.getSystemService("connectivity")).getActiveNetworkInfo();
        if (activeNetworkInfo != null) {
            isAvailable = activeNetworkInfo.isAvailable();
        } else {
            isAvailable = false;
        }
        AppMethodBeat.o(75708);
        return isAvailable;
    }

    public static boolean isDownloadFileExisted(String str, String str2) {
        boolean z = false;
        AppMethodBeat.i(75709);
        try {
            if (new File(TMAssistantFile.getSaveFilePath(generateFileNameFromURL(str, str2))).exists()) {
                z = true;
            }
        } catch (Exception e) {
            ab.printErrStackTrace(TAG, e, "", new Object[0]);
        } catch (Throwable th) {
            AppMethodBeat.o(75709);
        }
        AppMethodBeat.o(75709);
        return z;
    }

    public static boolean isDownloadFileExisted(String str) {
        boolean z = false;
        AppMethodBeat.i(75710);
        if (str == null) {
            AppMethodBeat.o(75710);
        } else {
            try {
                if (new File(TMAssistantFile.getSaveFilePath(str)).exists()) {
                    z = true;
                }
            } catch (Exception e) {
                ab.printErrStackTrace(TAG, e, "", new Object[0]);
            } catch (Throwable th) {
                AppMethodBeat.o(75710);
            }
            AppMethodBeat.o(75710);
        }
        return z;
    }

    /* JADX WARNING: Missing block: B:3:0x002f, code skipped:
            if (r2 < 0) goto L_0x0031;
     */
    /* JADX WARNING: Missing block: B:14:0x007a, code skipped:
            if (r2 >= 0) goto L_0x007c;
     */
    public static boolean isSpaceEnough(java.lang.String r13, long r14) {
        /*
        r10 = 4;
        r5 = 0;
        r4 = 1;
        r0 = 0;
        r8 = 75711; // 0x127bf float:1.06094E-40 double:3.7406E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r8);
        r2 = -1;
        r6 = getStorePosition(r13);
        if (r6 != r4) goto L_0x0046;
    L_0x0014:
        r2 = android.os.Environment.getDataDirectory();
        r3 = new android.os.StatFs;
        r2 = r2.getPath();
        r3.<init>(r2);
        r2 = r3.getBlockSize();
        r6 = (long) r2;
        r2 = r3.getAvailableBlocks();
        r2 = (long) r2;
        r2 = r2 - r10;
        r2 = r2 * r6;
        r6 = (r2 > r0 ? 1 : (r2 == r0 ? 0 : -1));
        if (r6 >= 0) goto L_0x007c;
    L_0x0031:
        r2 = (float) r14;
        r3 = 1069547520; // 0x3fc00000 float:1.5 double:5.28426686E-315;
        r2 = r2 * r3;
        r2 = (long) r2;
        r6 = 104857600; // 0x6400000 float:3.6111186E-35 double:5.1806538E-316;
        r6 = (r2 > r6 ? 1 : (r2 == r6 ? 0 : -1));
        if (r6 <= 0) goto L_0x0083;
    L_0x003d:
        r0 = (r0 > r2 ? 1 : (r0 == r2 ? 0 : -1));
        if (r0 < 0) goto L_0x007e;
    L_0x0041:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        r0 = r4;
    L_0x0045:
        return r0;
    L_0x0046:
        r7 = 2;
        if (r6 != r7) goto L_0x007c;
    L_0x0049:
        r2 = "mounted";
        r3 = android.os.Environment.getExternalStorageState();
        r2 = r2.equals(r3);
        if (r2 == 0) goto L_0x0031;
    L_0x0056:
        r2 = android.os.Environment.getExternalStorageDirectory();
        r2 = r2.getPath();
        r3 = new java.io.File;
        r3.<init>(r2);
        r2 = new android.os.StatFs;
        r3 = r3.getPath();
        r2.<init>(r3);
        r3 = r2.getBlockSize();
        r6 = (long) r3;
        r2 = r2.getAvailableBlocks();
        r2 = (long) r2;
        r2 = r2 - r10;
        r2 = r2 * r6;
        r6 = (r2 > r0 ? 1 : (r2 == r0 ? 0 : -1));
        if (r6 < 0) goto L_0x0031;
    L_0x007c:
        r0 = r2;
        goto L_0x0031;
    L_0x007e:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        r0 = r5;
        goto L_0x0045;
    L_0x0083:
        r2 = 104857600; // 0x6400000 float:3.6111186E-35 double:5.1806538E-316;
        r0 = (r0 > r2 ? 1 : (r0 == r2 ? 0 : -1));
        if (r0 < 0) goto L_0x008f;
    L_0x008a:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        r0 = r4;
        goto L_0x0045;
    L_0x008f:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        r0 = r5;
        goto L_0x0045;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.tmassistantsdk.downloadservice.DownloadHelper.isSpaceEnough(java.lang.String, long):boolean");
    }

    public static int getStorePosition(String str) {
        AppMethodBeat.i(75712);
        if (TextUtils.isEmpty(str)) {
            AppMethodBeat.o(75712);
            return 0;
        } else if (str != null && str.startsWith("/data")) {
            AppMethodBeat.o(75712);
            return 1;
        } else if (TMAssistantFile.isSDCardExistAndCanWrite()) {
            AppMethodBeat.o(75712);
            return 2;
        } else {
            AppMethodBeat.o(75712);
            return 0;
        }
    }
}
