package com.tencent.ttpic.recorder;

import android.annotation.TargetApi;
import android.content.res.AssetFileDescriptor;
import android.graphics.SurfaceTexture;
import android.media.MediaCodec;
import android.media.MediaCodec.BufferInfo;
import android.media.MediaExtractor;
import android.media.MediaFormat;
import android.os.Handler;
import android.os.HandlerThread;
import android.text.TextUtils;
import android.view.Surface;
import com.tencent.filter.h;
import com.tencent.filter.o;
import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.ttpic.util.BenchUtil;
import com.tencent.ttpic.util.VideoGlobalContext;
import com.tencent.util.i;
import com.tencent.view.g;
import java.io.IOException;
import java.nio.ByteBuffer;

@TargetApi(18)
public class ActVideoDecoder {
    private static final String TAG = ActVideoDecoder.class.getSimpleName();
    private static final int TIMEOUT_MS = 2500;
    private static final int TIMEOUT_US = 10000;
    private BufferInfo info = new BufferInfo();
    private ByteBuffer[] inputBuffers;
    private volatile boolean isDecoding;
    private boolean isEOS = false;
    private long mCurFrameIndex = -1;
    private MediaCodec mDecoder;
    private Surface mDecoderSurface;
    private int mDstTex;
    private long mDuration;
    private MediaExtractor mExtractor;
    private String mFilename;
    private h mFrame = new h();
    private boolean mFrameAvailable;
    private Handler mHandler;
    private boolean mHasNewFrame;
    private int mHeight;
    private final Object mInitLock = new Object();
    private boolean mInited;
    private long mLastFrameIndex = -1;
    private o mSurfaceTexFilter = new o();
    private SurfaceTexture mSurfaceTexture;
    private int mTempTex;
    private final float[] mTransformMatrix = new float[16];
    private final Object mUpdateFrameLock = new Object();
    private int mWidth;

    static /* synthetic */ int access$700(ActVideoDecoder actVideoDecoder) {
        AppMethodBeat.i(83691);
        int decodeNext = actVideoDecoder.decodeNext();
        AppMethodBeat.o(83691);
        return decodeNext;
    }

    static {
        AppMethodBeat.i(83692);
        AppMethodBeat.o(83692);
    }

    public ActVideoDecoder(String str, int i) {
        AppMethodBeat.i(83681);
        this.mFilename = str;
        this.mDstTex = i;
        this.mTempTex = g.dSO();
        this.mSurfaceTexFilter.ApplyGLSLFilter();
        this.mSurfaceTexFilter.nativeSetRotationAndFlip(0, 0, 1);
        HandlerThread handlerThread = new HandlerThread("ActVideoDecoder rt");
        handlerThread.start();
        this.mHandler = new Handler(handlerThread.getLooper());
        this.mHandler.post(new 1(this));
        synchronized (this.mInitLock) {
            while (!this.mInited) {
                try {
                    try {
                        this.mInitLock.wait();
                    } catch (InterruptedException e) {
                    }
                } finally {
                    while (true) {
                    }
                    AppMethodBeat.o(83681);
                }
            }
        }
        this.mDecoderSurface = new Surface(this.mSurfaceTexture);
        this.mExtractor = new MediaExtractor();
        try {
            setExtractorDataSource(this.mExtractor, this.mFilename);
            prepare();
        } catch (IOException e2) {
            AppMethodBeat.o(83681);
        }
    }

    private static void setExtractorDataSource(MediaExtractor mediaExtractor, String str) {
        AppMethodBeat.i(83682);
        if (str.startsWith("assets://")) {
            AssetFileDescriptor openFd = VideoGlobalContext.getContext().getAssets().openFd(str.substring(9));
            mediaExtractor.setDataSource(openFd.getFileDescriptor(), openFd.getStartOffset(), openFd.getLength());
            openFd.close();
            AppMethodBeat.o(83682);
            return;
        }
        mediaExtractor.setDataSource(str);
        AppMethodBeat.o(83682);
    }

    private void prepare() {
        AppMethodBeat.i(83683);
        for (int i = 0; i < this.mExtractor.getTrackCount(); i++) {
            MediaFormat trackFormat = this.mExtractor.getTrackFormat(i);
            String string = trackFormat.getString("mime");
            if (string.startsWith("video/")) {
                this.mExtractor.selectTrack(i);
                i.k(TAG, "extractor video track selected");
                this.mWidth = trackFormat.getInteger("width");
                this.mHeight = trackFormat.getInteger("height");
                this.mDuration = trackFormat.getLong("durationUs") / 1000;
                i.k(TAG, "width = " + this.mWidth + ", height = " + this.mHeight + ", mDuration = " + this.mDuration);
                this.mDecoder = MediaCodec.createDecoderByType(string);
                trackFormat.setInteger("max-input-size", 0);
                this.mDecoder.configure(trackFormat, this.mDecoderSurface, null, 0);
                break;
            }
        }
        if (this.mDecoder == null) {
            i.m(TAG, "Can't find video info!");
            AppMethodBeat.o(83683);
            return;
        }
        try {
            this.mDecoder.start();
            this.inputBuffers = this.mDecoder.getInputBuffers();
        } catch (Exception e) {
        }
        this.isEOS = false;
        AppMethodBeat.o(83683);
    }

    /* JADX WARNING: Missing block: B:29:0x00db, code skipped:
            r7 = r0;
     */
    private int decodeNext() {
        /*
        r9 = this;
        r0 = 83684; // 0x146e4 float:1.17266E-40 double:4.13454E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r0);
        r0 = r9.mDecoder;
        if (r0 != 0) goto L_0x0025;
    L_0x000a:
        r0 = com.tencent.ttpic.gles.GLConfig.DEBUG;
        if (r0 == 0) goto L_0x001d;
    L_0x000e:
        r0 = new java.lang.RuntimeException;
        r1 = "ActVideoDecoder init fail!";
        r0.<init>(r1);
        r1 = 83684; // 0x146e4 float:1.17266E-40 double:4.13454E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r1);
        throw r0;
    L_0x001d:
        r0 = -1;
        r1 = 83684; // 0x146e4 float:1.17266E-40 double:4.13454E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r1);
    L_0x0024:
        return r0;
    L_0x0025:
        r8 = 0;
        r0 = 0;
        r7 = r0;
    L_0x0028:
        r0 = java.lang.Thread.interrupted();
        if (r0 != 0) goto L_0x00de;
    L_0x002e:
        r0 = "[decodeNext] dequeueInputBuffer";
        com.tencent.ttpic.util.BenchUtil.benchStart(r0);
        r0 = r9.isEOS;
        if (r0 != 0) goto L_0x0064;
    L_0x0038:
        r0 = r9.mDecoder;
        r2 = 10000; // 0x2710 float:1.4013E-41 double:4.9407E-320;
        r1 = r0.dequeueInputBuffer(r2);
        if (r1 < 0) goto L_0x0064;
    L_0x0042:
        r0 = r9.inputBuffers;
        r0 = r0[r1];
        r2 = r9.mExtractor;
        r3 = 0;
        r3 = r2.readSampleData(r0, r3);
        if (r3 >= 0) goto L_0x00ac;
    L_0x004f:
        r0 = TAG;
        r2 = "extractor read sample to EOS";
        com.tencent.util.i.k(r0, r2);
        r0 = r9.mDecoder;
        r2 = 0;
        r3 = 0;
        r4 = 0;
        r6 = 4;
        r0.queueInputBuffer(r1, r2, r3, r4, r6);
        r0 = 1;
        r9.isEOS = r0;
    L_0x0064:
        r0 = "[decodeNext] dequeueInputBuffer";
        com.tencent.ttpic.util.BenchUtil.benchEnd(r0);
        r0 = "[decodeNext] wait";
        com.tencent.ttpic.util.BenchUtil.benchStart(r0);
        r0 = r9.mDecoder;
        r1 = r9.info;
        r2 = 10000; // 0x2710 float:1.4013E-41 double:4.9407E-320;
        r0 = r0.dequeueOutputBuffer(r1, r2);
        r1 = "[decodeNext] wait";
        com.tencent.ttpic.util.BenchUtil.benchEnd(r1);
        r1 = r9.info;
        r1 = r1.flags;
        r1 = r1 & 4;
        if (r1 != 0) goto L_0x00de;
    L_0x0088:
        switch(r0) {
            case -3: goto L_0x0028;
            case -2: goto L_0x0028;
            case -1: goto L_0x00bf;
            default: goto L_0x008b;
        };
    L_0x008b:
        r2 = r9.mCurFrameIndex;
        r4 = 1;
        r2 = r2 + r4;
        r9.mCurFrameIndex = r2;
        r2 = r9.mCurFrameIndex;
        r4 = r9.mLastFrameIndex;
        r1 = (r2 > r4 ? 1 : (r2 == r4 ? 0 : -1));
        if (r1 != 0) goto L_0x00d4;
    L_0x009a:
        r1 = 1;
        r9.mHasNewFrame = r1;
        r1 = r9.mDecoder;
        r2 = 1;
        r1.releaseOutputBuffer(r0, r2);
        r0 = r8;
    L_0x00a4:
        r1 = 83684; // 0x146e4 float:1.17266E-40 double:4.13454E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r1);
        goto L_0x0024;
    L_0x00ac:
        r0 = r9.mDecoder;
        r2 = 0;
        r4 = r9.mExtractor;
        r4 = r4.getSampleTime();
        r6 = 0;
        r0.queueInputBuffer(r1, r2, r3, r4, r6);
        r0 = r9.mExtractor;
        r0.advance();
        goto L_0x0064;
    L_0x00bf:
        r0 = r7 + 1;
        r1 = 10;
        if (r0 <= r1) goto L_0x00db;
    L_0x00c5:
        r0 = new java.lang.StringBuilder;
        r1 = "dequeueOutputBuffer timed out! eos = ";
        r0.<init>(r1);
        r1 = r9.isEOS;
        r0.append(r1);
        r0 = -1;
        goto L_0x00a4;
    L_0x00d4:
        r1 = r9.mDecoder;
        r2 = 0;
        r1.releaseOutputBuffer(r0, r2);
        r0 = r7;
    L_0x00db:
        r7 = r0;
        goto L_0x0028;
    L_0x00de:
        r0 = r8;
        goto L_0x00a4;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.ttpic.recorder.ActVideoDecoder.decodeNext():int");
    }

    public void decodeFrame(long j) {
        AppMethodBeat.i(83685);
        if (this.mDecoderSurface == null) {
            RuntimeException runtimeException = new RuntimeException("You haven't set surfaceTexture?!");
            AppMethodBeat.o(83685);
            throw runtimeException;
        } else if (j <= this.mLastFrameIndex) {
            AppMethodBeat.o(83685);
        } else {
            this.mLastFrameIndex = j;
            try {
                BenchUtil.benchStart(TAG + "[decodeNext]");
                decodeNext();
                BenchUtil.benchEnd(TAG + "[decodeNext]");
                AppMethodBeat.o(83685);
            } catch (Exception e) {
                i.a(TAG, "decodeNext error: ", e);
                AppMethodBeat.o(83685);
            }
        }
    }

    public void decodeFrameAsync(long j) {
        AppMethodBeat.i(83686);
        if (this.mDecoderSurface == null) {
            RuntimeException runtimeException = new RuntimeException("You haven't set surfaceTexture?!");
            AppMethodBeat.o(83686);
            throw runtimeException;
        } else if (this.isDecoding || j <= this.mLastFrameIndex) {
            AppMethodBeat.o(83686);
        } else {
            this.isDecoding = true;
            this.mLastFrameIndex = j;
            this.mHandler.post(new 2(this));
            AppMethodBeat.o(83686);
        }
    }

    /* JADX WARNING: Missing block: B:23:0x005c, code skipped:
            com.tencent.ttpic.util.BenchUtil.benchEnd(TAG + "[updateFrame] wait");
            com.tencent.ttpic.util.BenchUtil.benchStart(TAG + "[updateFrame] render");
     */
    /* JADX WARNING: Missing block: B:25:?, code skipped:
            r11.mSurfaceTexture.updateTexImage();
     */
    /* JADX WARNING: Missing block: B:31:?, code skipped:
            return r0;
     */
    public boolean updateFrame() {
        /*
        r11 = this;
        r0 = 0;
        r10 = 83687; // 0x146e7 float:1.1727E-40 double:4.1347E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r10);
        r9 = r11.mHasNewFrame;
        r1 = r11.mHasNewFrame;
        if (r1 == 0) goto L_0x00d1;
    L_0x000d:
        r1 = new java.lang.StringBuilder;
        r1.<init>();
        r2 = TAG;
        r1 = r1.append(r2);
        r2 = "[updateFrame] wait";
        r1 = r1.append(r2);
        r1 = r1.toString();
        com.tencent.ttpic.util.BenchUtil.benchStart(r1);
        r1 = r11.mUpdateFrameLock;
        monitor-enter(r1);
    L_0x0029:
        r2 = r11.mFrameAvailable;	 Catch:{ all -> 0x0052 }
        if (r2 != 0) goto L_0x0058;
    L_0x002d:
        r2 = r11.mUpdateFrameLock;	 Catch:{ InterruptedException -> 0x0045 }
        r4 = 2500; // 0x9c4 float:3.503E-42 double:1.235E-320;
        r2.wait(r4);	 Catch:{ InterruptedException -> 0x0045 }
        r2 = r11.mFrameAvailable;	 Catch:{ InterruptedException -> 0x0045 }
        if (r2 != 0) goto L_0x0029;
    L_0x0038:
        r2 = TAG;	 Catch:{ InterruptedException -> 0x0045 }
        r3 = "frame wait timed out";
        com.tencent.ttpic.baseutils.LogUtils.e(r2, r3);	 Catch:{ InterruptedException -> 0x0045 }
        monitor-exit(r1);	 Catch:{ all -> 0x0052 }
        com.tencent.matrix.trace.core.AppMethodBeat.o(r10);
    L_0x0044:
        return r0;
    L_0x0045:
        r0 = move-exception;
        r2 = new java.lang.RuntimeException;	 Catch:{ all -> 0x0052 }
        r2.<init>(r0);	 Catch:{ all -> 0x0052 }
        r0 = 83687; // 0x146e7 float:1.1727E-40 double:4.1347E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r0);	 Catch:{ all -> 0x0052 }
        throw r2;	 Catch:{ all -> 0x0052 }
    L_0x0052:
        r0 = move-exception;
        monitor-exit(r1);	 Catch:{ all -> 0x0052 }
        com.tencent.matrix.trace.core.AppMethodBeat.o(r10);
        throw r0;
    L_0x0058:
        r2 = 0;
        r11.mFrameAvailable = r2;	 Catch:{ all -> 0x0052 }
        monitor-exit(r1);	 Catch:{ all -> 0x0052 }
        r1 = new java.lang.StringBuilder;
        r1.<init>();
        r2 = TAG;
        r1 = r1.append(r2);
        r2 = "[updateFrame] wait";
        r1 = r1.append(r2);
        r1 = r1.toString();
        com.tencent.ttpic.util.BenchUtil.benchEnd(r1);
        r1 = new java.lang.StringBuilder;
        r1.<init>();
        r2 = TAG;
        r1 = r1.append(r2);
        r2 = "[updateFrame] render";
        r1 = r1.append(r2);
        r1 = r1.toString();
        com.tencent.ttpic.util.BenchUtil.benchStart(r1);
        r1 = r11.mSurfaceTexture;	 Catch:{ Exception -> 0x00d7 }
        r1.updateTexImage();	 Catch:{ Exception -> 0x00d7 }
    L_0x0093:
        r1 = r11.mSurfaceTexture;
        r2 = r11.mTransformMatrix;
        r1.getTransformMatrix(r2);
        r1 = r11.mSurfaceTexFilter;
        r2 = r11.mTransformMatrix;
        r1.nativeUpdateMatrix(r2);
        r1 = r11.mSurfaceTexFilter;
        r2 = r11.mTempTex;
        r3 = r11.getWidth();
        r4 = r11.getHeight();
        r5 = r11.mDstTex;
        r6 = 0;
        r8 = r11.mFrame;
        r1.RenderProcess(r2, r3, r4, r5, r6, r8);
        r11.mHasNewFrame = r0;
        r0 = new java.lang.StringBuilder;
        r0.<init>();
        r1 = TAG;
        r0 = r0.append(r1);
        r1 = "[updateFrame] render";
        r0 = r0.append(r1);
        r0 = r0.toString();
        com.tencent.ttpic.util.BenchUtil.benchEnd(r0);
    L_0x00d1:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r10);
        r0 = r9;
        goto L_0x0044;
    L_0x00d7:
        r1 = move-exception;
        goto L_0x0093;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.ttpic.recorder.ActVideoDecoder.updateFrame():boolean");
    }

    public void reset() {
        AppMethodBeat.i(83688);
        try {
            if (this.mExtractor != null) {
                this.mExtractor.seekTo(0, 0);
            }
            if (this.mDecoder != null) {
                this.mDecoder.flush();
            }
        } catch (Exception e) {
            if (!TextUtils.isEmpty(e.getMessage())) {
                i.k(TAG, e.getMessage());
            }
        }
        this.isEOS = false;
        this.mCurFrameIndex = -1;
        this.mLastFrameIndex = -1;
        AppMethodBeat.o(83688);
    }

    public void resetAsync() {
        AppMethodBeat.i(83689);
        if (this.mHandler != null) {
            this.mHandler.post(new 3(this));
        }
        AppMethodBeat.o(83689);
    }

    public void release() {
        AppMethodBeat.i(83690);
        g.Sk(this.mTempTex);
        this.mSurfaceTexFilter.clearGLSLSelf();
        this.mFrame.clear();
        if (this.mDecoderSurface != null) {
            this.mDecoderSurface.release();
        }
        if (this.mExtractor != null) {
            this.mExtractor.release();
        }
        if (this.mDecoder != null) {
            this.mDecoder.stop();
            this.mDecoder.release();
            i.j(TAG, "mDecoder stop and release");
            this.mDecoder = null;
        }
        if (this.mHandler != null) {
            this.mHandler.removeCallbacksAndMessages(null);
            this.mHandler.post(new 4(this));
        }
        AppMethodBeat.o(83690);
    }

    public boolean isLive() {
        return this.mDecoder != null;
    }

    public int getWidth() {
        return this.mWidth;
    }

    public int getHeight() {
        return this.mHeight;
    }

    public long getDuration() {
        return this.mDuration;
    }
}
