package com.facebook.internal;

import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.os.Looper;
import com.facebook.FacebookException;
import com.tencent.matrix.trace.core.AppMethodBeat;
import java.lang.reflect.Method;

public class AttributionIdentifiers {
    private static final String ANDROID_ID_COLUMN_NAME = "androidid";
    private static final String ATTRIBUTION_ID_COLUMN_NAME = "aid";
    private static final String ATTRIBUTION_ID_CONTENT_PROVIDER = "com.facebook.katana.provider.AttributionIdProvider";
    private static final String ATTRIBUTION_ID_CONTENT_PROVIDER_WAKIZASHI = "com.facebook.wakizashi.provider.AttributionIdProvider";
    private static final int CONNECTION_RESULT_SUCCESS = 0;
    private static final long IDENTIFIER_REFRESH_INTERVAL_MILLIS = 3600000;
    private static final String LIMIT_TRACKING_COLUMN_NAME = "limit_tracking";
    private static final String TAG = AttributionIdentifiers.class.getCanonicalName();
    private static AttributionIdentifiers recentlyFetchedIdentifiers;
    private String androidAdvertiserId;
    private String androidInstallerPackage;
    private String attributionId;
    private long fetchTime;
    private boolean limitTracking;

    static {
        AppMethodBeat.i(72243);
        AppMethodBeat.o(72243);
    }

    private static AttributionIdentifiers getAndroidId(Context context) {
        AppMethodBeat.i(72237);
        AttributionIdentifiers androidIdViaReflection = getAndroidIdViaReflection(context);
        if (androidIdViaReflection == null) {
            androidIdViaReflection = getAndroidIdViaService(context);
            if (androidIdViaReflection == null) {
                androidIdViaReflection = new AttributionIdentifiers();
            }
        }
        AppMethodBeat.o(72237);
        return androidIdViaReflection;
    }

    private static AttributionIdentifiers getAndroidIdViaReflection(Context context) {
        AppMethodBeat.i(72238);
        try {
            if (Looper.myLooper() == Looper.getMainLooper()) {
                FacebookException facebookException = new FacebookException("getAndroidId cannot be called on the main thread.");
                AppMethodBeat.o(72238);
                throw facebookException;
            }
            Method methodQuietly = Utility.getMethodQuietly("com.google.android.gms.common.GooglePlayServicesUtil", "isGooglePlayServicesAvailable", new Class[]{Context.class});
            if (methodQuietly == null) {
                AppMethodBeat.o(72238);
                return null;
            }
            Object invokeMethodQuietly = Utility.invokeMethodQuietly(null, methodQuietly, new Object[]{context});
            if ((invokeMethodQuietly instanceof Integer) && ((Integer) invokeMethodQuietly).intValue() == 0) {
                methodQuietly = Utility.getMethodQuietly("com.google.android.gms.ads.identifier.AdvertisingIdClient", "getAdvertisingIdInfo", new Class[]{Context.class});
                if (methodQuietly == null) {
                    AppMethodBeat.o(72238);
                    return null;
                }
                Object invokeMethodQuietly2 = Utility.invokeMethodQuietly(null, methodQuietly, new Object[]{context});
                if (invokeMethodQuietly2 == null) {
                    AppMethodBeat.o(72238);
                    return null;
                }
                methodQuietly = Utility.getMethodQuietly(invokeMethodQuietly2.getClass(), "getId", new Class[0]);
                Method methodQuietly2 = Utility.getMethodQuietly(invokeMethodQuietly2.getClass(), "isLimitAdTrackingEnabled", new Class[0]);
                if (methodQuietly == null || methodQuietly2 == null) {
                    AppMethodBeat.o(72238);
                    return null;
                }
                AttributionIdentifiers attributionIdentifiers = new AttributionIdentifiers();
                attributionIdentifiers.androidAdvertiserId = (String) Utility.invokeMethodQuietly(invokeMethodQuietly2, methodQuietly, new Object[0]);
                attributionIdentifiers.limitTracking = ((Boolean) Utility.invokeMethodQuietly(invokeMethodQuietly2, methodQuietly2, new Object[0])).booleanValue();
                AppMethodBeat.o(72238);
                return attributionIdentifiers;
            }
            AppMethodBeat.o(72238);
            return null;
        } catch (Exception e) {
            Utility.logd("android_id", e);
            AppMethodBeat.o(72238);
            return null;
        }
    }

    private static AttributionIdentifiers getAndroidIdViaService(Context context) {
        AppMethodBeat.i(72239);
        GoogleAdServiceConnection googleAdServiceConnection = new GoogleAdServiceConnection(null);
        Intent intent = new Intent("com.google.android.gms.ads.identifier.service.START");
        intent.setPackage("com.google.android.gms");
        if (context.bindService(intent, googleAdServiceConnection, 1)) {
            try {
                GoogleAdInfo googleAdInfo = new GoogleAdInfo(googleAdServiceConnection.getBinder());
                AttributionIdentifiers attributionIdentifiers = new AttributionIdentifiers();
                attributionIdentifiers.androidAdvertiserId = googleAdInfo.getAdvertiserId();
                attributionIdentifiers.limitTracking = googleAdInfo.isTrackingLimited();
                context.unbindService(googleAdServiceConnection);
                AppMethodBeat.o(72239);
                return attributionIdentifiers;
            } catch (Exception e) {
                Utility.logd("android_id", e);
                context.unbindService(googleAdServiceConnection);
            } catch (Throwable th) {
                context.unbindService(googleAdServiceConnection);
                AppMethodBeat.o(72239);
            }
        }
        AppMethodBeat.o(72239);
        return null;
    }

    /* JADX WARNING: Removed duplicated region for block: B:49:0x010a  */
    /* JADX WARNING: Removed duplicated region for block: B:44:0x00fd  */
    public static com.facebook.internal.AttributionIdentifiers getAttributionIdentifiers(android.content.Context r9) {
        /*
        r6 = 0;
        r8 = 72240; // 0x11a30 float:1.0123E-40 double:3.56913E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r8);
        android.os.Looper.myLooper();
        android.os.Looper.getMainLooper();
        r0 = recentlyFetchedIdentifiers;
        if (r0 == 0) goto L_0x0027;
    L_0x0011:
        r0 = java.lang.System.currentTimeMillis();
        r2 = recentlyFetchedIdentifiers;
        r2 = r2.fetchTime;
        r0 = r0 - r2;
        r2 = 3600000; // 0x36ee80 float:5.044674E-39 double:1.7786363E-317;
        r0 = (r0 > r2 ? 1 : (r0 == r2 ? 0 : -1));
        if (r0 >= 0) goto L_0x0027;
    L_0x0021:
        r0 = recentlyFetchedIdentifiers;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
    L_0x0026:
        return r0;
    L_0x0027:
        r7 = getAndroidId(r9);
        r0 = 3;
        r2 = new java.lang.String[r0];	 Catch:{ Exception -> 0x00e0, all -> 0x0106 }
        r0 = 0;
        r1 = "aid";
        r2[r0] = r1;	 Catch:{ Exception -> 0x00e0, all -> 0x0106 }
        r0 = 1;
        r1 = "androidid";
        r2[r0] = r1;	 Catch:{ Exception -> 0x00e0, all -> 0x0106 }
        r0 = 2;
        r1 = "limit_tracking";
        r2[r0] = r1;	 Catch:{ Exception -> 0x00e0, all -> 0x0106 }
        r0 = r9.getPackageManager();	 Catch:{ Exception -> 0x00e0, all -> 0x0106 }
        r1 = "com.facebook.katana.provider.AttributionIdProvider";
        r3 = 0;
        r0 = r0.resolveContentProvider(r1, r3);	 Catch:{ Exception -> 0x00e0, all -> 0x0106 }
        if (r0 == 0) goto L_0x0067;
    L_0x004e:
        r0 = "content://com.facebook.katana.provider.AttributionIdProvider";
        r1 = android.net.Uri.parse(r0);	 Catch:{ Exception -> 0x00e0, all -> 0x0106 }
    L_0x0055:
        r0 = getInstallerPackageName(r9);	 Catch:{ Exception -> 0x00e0, all -> 0x0106 }
        if (r0 == 0) goto L_0x005d;
    L_0x005b:
        r7.androidInstallerPackage = r0;	 Catch:{ Exception -> 0x00e0, all -> 0x0106 }
    L_0x005d:
        if (r1 != 0) goto L_0x007d;
    L_0x005f:
        r0 = cacheAndReturnIdentifiers(r7);	 Catch:{ Exception -> 0x00e0, all -> 0x0106 }
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        goto L_0x0026;
    L_0x0067:
        r0 = r9.getPackageManager();	 Catch:{ Exception -> 0x00e0, all -> 0x0106 }
        r1 = "com.facebook.wakizashi.provider.AttributionIdProvider";
        r3 = 0;
        r0 = r0.resolveContentProvider(r1, r3);	 Catch:{ Exception -> 0x00e0, all -> 0x0106 }
        if (r0 == 0) goto L_0x0115;
    L_0x0075:
        r0 = "content://com.facebook.wakizashi.provider.AttributionIdProvider";
        r1 = android.net.Uri.parse(r0);	 Catch:{ Exception -> 0x00e0, all -> 0x0106 }
        goto L_0x0055;
    L_0x007d:
        r0 = r9.getContentResolver();	 Catch:{ Exception -> 0x00e0, all -> 0x0106 }
        r3 = 0;
        r4 = 0;
        r5 = 0;
        r1 = r0.query(r1, r2, r3, r4, r5);	 Catch:{ Exception -> 0x00e0, all -> 0x0106 }
        if (r1 == 0) goto L_0x0090;
    L_0x008a:
        r0 = r1.moveToFirst();	 Catch:{ Exception -> 0x0113 }
        if (r0 != 0) goto L_0x009d;
    L_0x0090:
        r0 = cacheAndReturnIdentifiers(r7);	 Catch:{ Exception -> 0x0113 }
        if (r1 == 0) goto L_0x0099;
    L_0x0096:
        r1.close();
    L_0x0099:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        goto L_0x0026;
    L_0x009d:
        r0 = "aid";
        r0 = r1.getColumnIndex(r0);	 Catch:{ Exception -> 0x0113 }
        r2 = "androidid";
        r2 = r1.getColumnIndex(r2);	 Catch:{ Exception -> 0x0113 }
        r3 = "limit_tracking";
        r3 = r1.getColumnIndex(r3);	 Catch:{ Exception -> 0x0113 }
        r0 = r1.getString(r0);	 Catch:{ Exception -> 0x0113 }
        r7.attributionId = r0;	 Catch:{ Exception -> 0x0113 }
        if (r2 <= 0) goto L_0x00d2;
    L_0x00ba:
        if (r3 <= 0) goto L_0x00d2;
    L_0x00bc:
        r0 = r7.getAndroidAdvertiserId();	 Catch:{ Exception -> 0x0113 }
        if (r0 != 0) goto L_0x00d2;
    L_0x00c2:
        r0 = r1.getString(r2);	 Catch:{ Exception -> 0x0113 }
        r7.androidAdvertiserId = r0;	 Catch:{ Exception -> 0x0113 }
        r0 = r1.getString(r3);	 Catch:{ Exception -> 0x0113 }
        r0 = java.lang.Boolean.parseBoolean(r0);	 Catch:{ Exception -> 0x0113 }
        r7.limitTracking = r0;	 Catch:{ Exception -> 0x0113 }
    L_0x00d2:
        if (r1 == 0) goto L_0x00d7;
    L_0x00d4:
        r1.close();
    L_0x00d7:
        r0 = cacheAndReturnIdentifiers(r7);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        goto L_0x0026;
    L_0x00e0:
        r0 = move-exception;
        r1 = r6;
    L_0x00e2:
        r2 = TAG;	 Catch:{ all -> 0x0111 }
        r3 = new java.lang.StringBuilder;	 Catch:{ all -> 0x0111 }
        r4 = "Caught unexpected exception in getAttributionId(): ";
        r3.<init>(r4);	 Catch:{ all -> 0x0111 }
        r0 = r0.toString();	 Catch:{ all -> 0x0111 }
        r0 = r3.append(r0);	 Catch:{ all -> 0x0111 }
        r0 = r0.toString();	 Catch:{ all -> 0x0111 }
        com.facebook.internal.Utility.logd(r2, r0);	 Catch:{ all -> 0x0111 }
        if (r1 == 0) goto L_0x0100;
    L_0x00fd:
        r1.close();
    L_0x0100:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        r0 = r6;
        goto L_0x0026;
    L_0x0106:
        r0 = move-exception;
        r1 = r6;
    L_0x0108:
        if (r1 == 0) goto L_0x010d;
    L_0x010a:
        r1.close();
    L_0x010d:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        throw r0;
    L_0x0111:
        r0 = move-exception;
        goto L_0x0108;
    L_0x0113:
        r0 = move-exception;
        goto L_0x00e2;
    L_0x0115:
        r1 = r6;
        goto L_0x0055;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.facebook.internal.AttributionIdentifiers.getAttributionIdentifiers(android.content.Context):com.facebook.internal.AttributionIdentifiers");
    }

    private static AttributionIdentifiers cacheAndReturnIdentifiers(AttributionIdentifiers attributionIdentifiers) {
        AppMethodBeat.i(72241);
        attributionIdentifiers.fetchTime = System.currentTimeMillis();
        recentlyFetchedIdentifiers = attributionIdentifiers;
        AppMethodBeat.o(72241);
        return attributionIdentifiers;
    }

    public String getAttributionId() {
        return this.attributionId;
    }

    public String getAndroidAdvertiserId() {
        return this.androidAdvertiserId;
    }

    public String getAndroidInstallerPackage() {
        return this.androidInstallerPackage;
    }

    public boolean isTrackingLimited() {
        return this.limitTracking;
    }

    private static String getInstallerPackageName(Context context) {
        AppMethodBeat.i(72242);
        PackageManager packageManager = context.getPackageManager();
        if (packageManager != null) {
            String installerPackageName = packageManager.getInstallerPackageName(context.getPackageName());
            AppMethodBeat.o(72242);
            return installerPackageName;
        }
        AppMethodBeat.o(72242);
        return null;
    }
}
