package com.facebook.share.widget;

import android.app.Activity;
import android.content.Context;
import android.os.Bundle;
import android.support.v4.app.Fragment;
import com.facebook.AccessToken;
import com.facebook.FacebookCallback;
import com.facebook.appevents.AppEventsLogger;
import com.facebook.internal.AppCall;
import com.facebook.internal.CallbackManagerImpl;
import com.facebook.internal.CallbackManagerImpl.RequestCodeOffset;
import com.facebook.internal.DialogFeature;
import com.facebook.internal.DialogPresenter;
import com.facebook.internal.FacebookDialogBase;
import com.facebook.internal.FacebookDialogBase.ModeHandler;
import com.facebook.internal.FragmentWrapper;
import com.facebook.internal.Utility;
import com.facebook.share.Sharer;
import com.facebook.share.Sharer.Result;
import com.facebook.share.internal.CameraEffectFeature;
import com.facebook.share.internal.OpenGraphActionDialogFeature;
import com.facebook.share.internal.ShareContentValidation;
import com.facebook.share.internal.ShareDialogFeature;
import com.facebook.share.internal.ShareInternalUtility;
import com.facebook.share.internal.ShareStoryFeature;
import com.facebook.share.model.ShareCameraEffectContent;
import com.facebook.share.model.ShareContent;
import com.facebook.share.model.ShareLinkContent;
import com.facebook.share.model.ShareMediaContent;
import com.facebook.share.model.ShareOpenGraphContent;
import com.facebook.share.model.SharePhotoContent;
import com.facebook.share.model.ShareStoryContent;
import com.facebook.share.model.ShareVideoContent;
import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.tmassistantsdk.downloadservice.DownloadInfo;
import java.util.ArrayList;
import java.util.List;

public final class ShareDialog extends FacebookDialogBase<ShareContent, Result> implements Sharer {
    private static final int DEFAULT_REQUEST_CODE = RequestCodeOffset.Share.toRequestCode();
    private static final String FEED_DIALOG = "feed";
    private static final String TAG = ShareDialog.class.getSimpleName();
    private static final String WEB_OG_SHARE_DIALOG = "share_open_graph";
    public static final String WEB_SHARE_DIALOG = "share";
    private boolean isAutomaticMode;
    private boolean shouldFailOnDataError;

    class NativeHandler extends ModeHandler {
        private NativeHandler() {
            super(ShareDialog.this);
        }

        public Object getMode() {
            return Mode.NATIVE;
        }

        public boolean canShow(ShareContent shareContent, boolean z) {
            AppMethodBeat.i(97691);
            if (shareContent == null || (shareContent instanceof ShareCameraEffectContent) || (shareContent instanceof ShareStoryContent)) {
                AppMethodBeat.o(97691);
                return false;
            }
            int i;
            if (z) {
                i = 1;
            } else {
                if (shareContent.getShareHashtag() != null) {
                    i = DialogPresenter.canPresentNativeDialogWithFeature(ShareDialogFeature.HASHTAG);
                } else {
                    i = 1;
                }
                if ((shareContent instanceof ShareLinkContent) && !Utility.isNullOrEmpty(((ShareLinkContent) shareContent).getQuote())) {
                    i &= DialogPresenter.canPresentNativeDialogWithFeature(ShareDialogFeature.LINK_SHARE_QUOTES);
                }
            }
            if (i == 0 || !ShareDialog.access$500(shareContent.getClass())) {
                AppMethodBeat.o(97691);
                return false;
            }
            AppMethodBeat.o(97691);
            return true;
        }

        public AppCall createAppCall(ShareContent shareContent) {
            AppMethodBeat.i(97692);
            ShareDialog.access$700(ShareDialog.this, ShareDialog.access$600(ShareDialog.this), shareContent, Mode.NATIVE);
            ShareContentValidation.validateForNativeShare(shareContent);
            AppCall createBaseAppCall = ShareDialog.this.createBaseAppCall();
            DialogPresenter.setupAppCallForNativeDialog(createBaseAppCall, new 1(this, createBaseAppCall, shareContent, ShareDialog.this.getShouldFailOnDataError()), ShareDialog.access$800(shareContent.getClass()));
            AppMethodBeat.o(97692);
            return createBaseAppCall;
        }
    }

    static /* synthetic */ Activity access$1000(ShareDialog shareDialog) {
        AppMethodBeat.i(97734);
        Activity activityContext = shareDialog.getActivityContext();
        AppMethodBeat.o(97734);
        return activityContext;
    }

    static /* synthetic */ Activity access$1100(ShareDialog shareDialog) {
        AppMethodBeat.i(97735);
        Activity activityContext = shareDialog.getActivityContext();
        AppMethodBeat.o(97735);
        return activityContext;
    }

    static /* synthetic */ boolean access$500(Class cls) {
        AppMethodBeat.i(97729);
        boolean canShowNative = canShowNative(cls);
        AppMethodBeat.o(97729);
        return canShowNative;
    }

    static /* synthetic */ Activity access$600(ShareDialog shareDialog) {
        AppMethodBeat.i(97730);
        Activity activityContext = shareDialog.getActivityContext();
        AppMethodBeat.o(97730);
        return activityContext;
    }

    static /* synthetic */ void access$700(ShareDialog shareDialog, Context context, ShareContent shareContent, Mode mode) {
        AppMethodBeat.i(97731);
        shareDialog.logDialogShare(context, shareContent, mode);
        AppMethodBeat.o(97731);
    }

    static /* synthetic */ DialogFeature access$800(Class cls) {
        AppMethodBeat.i(97732);
        DialogFeature feature = getFeature(cls);
        AppMethodBeat.o(97732);
        return feature;
    }

    static /* synthetic */ boolean access$900(ShareContent shareContent) {
        AppMethodBeat.i(97733);
        boolean canShowWebCheck = canShowWebCheck(shareContent);
        AppMethodBeat.o(97733);
        return canShowWebCheck;
    }

    static {
        AppMethodBeat.i(97736);
        AppMethodBeat.o(97736);
    }

    public static void show(Activity activity, ShareContent shareContent) {
        AppMethodBeat.i(97706);
        new ShareDialog(activity).show(shareContent);
        AppMethodBeat.o(97706);
    }

    public static void show(Fragment fragment, ShareContent shareContent) {
        AppMethodBeat.i(97707);
        show(new FragmentWrapper(fragment), shareContent);
        AppMethodBeat.o(97707);
    }

    public static void show(android.app.Fragment fragment, ShareContent shareContent) {
        AppMethodBeat.i(97708);
        show(new FragmentWrapper(fragment), shareContent);
        AppMethodBeat.o(97708);
    }

    private static void show(FragmentWrapper fragmentWrapper, ShareContent shareContent) {
        AppMethodBeat.i(97709);
        new ShareDialog(fragmentWrapper).show(shareContent);
        AppMethodBeat.o(97709);
    }

    public static boolean canShow(Class<? extends ShareContent> cls) {
        AppMethodBeat.i(97710);
        if (canShowWebTypeCheck(cls) || canShowNative(cls)) {
            AppMethodBeat.o(97710);
            return true;
        }
        AppMethodBeat.o(97710);
        return false;
    }

    private static boolean canShowNative(Class<? extends ShareContent> cls) {
        AppMethodBeat.i(97711);
        DialogFeature feature = getFeature(cls);
        if (feature == null || !DialogPresenter.canPresentNativeDialogWithFeature(feature)) {
            AppMethodBeat.o(97711);
            return false;
        }
        AppMethodBeat.o(97711);
        return true;
    }

    private static boolean canShowWebTypeCheck(Class<? extends ShareContent> cls) {
        AppMethodBeat.i(97712);
        if (ShareLinkContent.class.isAssignableFrom(cls) || ShareOpenGraphContent.class.isAssignableFrom(cls) || (SharePhotoContent.class.isAssignableFrom(cls) && AccessToken.isCurrentAccessTokenActive())) {
            AppMethodBeat.o(97712);
            return true;
        }
        AppMethodBeat.o(97712);
        return false;
    }

    private static boolean canShowWebCheck(ShareContent shareContent) {
        AppMethodBeat.i(97713);
        if (canShowWebTypeCheck(shareContent.getClass())) {
            if (shareContent instanceof ShareOpenGraphContent) {
                try {
                    ShareInternalUtility.toJSONObjectForWeb((ShareOpenGraphContent) shareContent);
                } catch (Exception e) {
                    Utility.logd(TAG, "canShow returned false because the content of the Opem Graph object can't be shared via the web dialog", e);
                    AppMethodBeat.o(97713);
                    return false;
                }
            }
            AppMethodBeat.o(97713);
            return true;
        }
        AppMethodBeat.o(97713);
        return false;
    }

    public ShareDialog(Activity activity) {
        super(activity, DEFAULT_REQUEST_CODE);
        AppMethodBeat.i(97714);
        this.shouldFailOnDataError = false;
        this.isAutomaticMode = true;
        ShareInternalUtility.registerStaticShareCallback(DEFAULT_REQUEST_CODE);
        AppMethodBeat.o(97714);
    }

    public ShareDialog(Fragment fragment) {
        this(new FragmentWrapper(fragment));
        AppMethodBeat.i(97715);
        AppMethodBeat.o(97715);
    }

    public ShareDialog(android.app.Fragment fragment) {
        this(new FragmentWrapper(fragment));
        AppMethodBeat.i(97716);
        AppMethodBeat.o(97716);
    }

    private ShareDialog(FragmentWrapper fragmentWrapper) {
        super(fragmentWrapper, DEFAULT_REQUEST_CODE);
        AppMethodBeat.i(97717);
        this.shouldFailOnDataError = false;
        this.isAutomaticMode = true;
        ShareInternalUtility.registerStaticShareCallback(DEFAULT_REQUEST_CODE);
        AppMethodBeat.o(97717);
    }

    ShareDialog(Activity activity, int i) {
        super(activity, i);
        AppMethodBeat.i(97718);
        this.shouldFailOnDataError = false;
        this.isAutomaticMode = true;
        ShareInternalUtility.registerStaticShareCallback(i);
        AppMethodBeat.o(97718);
    }

    ShareDialog(Fragment fragment, int i) {
        this(new FragmentWrapper(fragment), i);
        AppMethodBeat.i(97719);
        AppMethodBeat.o(97719);
    }

    ShareDialog(android.app.Fragment fragment, int i) {
        this(new FragmentWrapper(fragment), i);
        AppMethodBeat.i(97720);
        AppMethodBeat.o(97720);
    }

    private ShareDialog(FragmentWrapper fragmentWrapper, int i) {
        super(fragmentWrapper, i);
        AppMethodBeat.i(97721);
        this.shouldFailOnDataError = false;
        this.isAutomaticMode = true;
        ShareInternalUtility.registerStaticShareCallback(i);
        AppMethodBeat.o(97721);
    }

    public final void registerCallbackImpl(CallbackManagerImpl callbackManagerImpl, FacebookCallback<Result> facebookCallback) {
        AppMethodBeat.i(97722);
        ShareInternalUtility.registerSharerCallback(getRequestCode(), callbackManagerImpl, facebookCallback);
        AppMethodBeat.o(97722);
    }

    public final boolean getShouldFailOnDataError() {
        return this.shouldFailOnDataError;
    }

    public final void setShouldFailOnDataError(boolean z) {
        this.shouldFailOnDataError = z;
    }

    public final boolean canShow(ShareContent shareContent, Mode mode) {
        Object mode2;
        AppMethodBeat.i(97723);
        if (mode2 == Mode.AUTOMATIC) {
            mode2 = BASE_AUTOMATIC_MODE;
        }
        boolean canShowImpl = canShowImpl(shareContent, mode2);
        AppMethodBeat.o(97723);
        return canShowImpl;
    }

    public final void show(ShareContent shareContent, Mode mode) {
        Object mode2;
        AppMethodBeat.i(97724);
        this.isAutomaticMode = mode2 == Mode.AUTOMATIC;
        if (this.isAutomaticMode) {
            mode2 = BASE_AUTOMATIC_MODE;
        }
        showImpl(shareContent, mode2);
        AppMethodBeat.o(97724);
    }

    public final AppCall createBaseAppCall() {
        AppMethodBeat.i(97725);
        AppCall appCall = new AppCall(getRequestCode());
        AppMethodBeat.o(97725);
        return appCall;
    }

    public final List<ModeHandler> getOrderedModeHandlers() {
        AppMethodBeat.i(97726);
        ArrayList arrayList = new ArrayList();
        arrayList.add(new NativeHandler());
        arrayList.add(new FeedHandler(this, null));
        arrayList.add(new WebShareHandler(this, null));
        arrayList.add(new CameraEffectHandler(this, null));
        arrayList.add(new ShareStoryHandler(this, null));
        AppMethodBeat.o(97726);
        return arrayList;
    }

    private static DialogFeature getFeature(Class<? extends ShareContent> cls) {
        AppMethodBeat.i(97727);
        DialogFeature dialogFeature;
        if (ShareLinkContent.class.isAssignableFrom(cls)) {
            ShareDialogFeature shareDialogFeature = ShareDialogFeature.SHARE_DIALOG;
            AppMethodBeat.o(97727);
            return shareDialogFeature;
        } else if (SharePhotoContent.class.isAssignableFrom(cls)) {
            dialogFeature = ShareDialogFeature.PHOTOS;
            AppMethodBeat.o(97727);
            return dialogFeature;
        } else if (ShareVideoContent.class.isAssignableFrom(cls)) {
            dialogFeature = ShareDialogFeature.VIDEO;
            AppMethodBeat.o(97727);
            return dialogFeature;
        } else if (ShareOpenGraphContent.class.isAssignableFrom(cls)) {
            dialogFeature = OpenGraphActionDialogFeature.OG_ACTION_DIALOG;
            AppMethodBeat.o(97727);
            return dialogFeature;
        } else if (ShareMediaContent.class.isAssignableFrom(cls)) {
            dialogFeature = ShareDialogFeature.MULTIMEDIA;
            AppMethodBeat.o(97727);
            return dialogFeature;
        } else if (ShareCameraEffectContent.class.isAssignableFrom(cls)) {
            dialogFeature = CameraEffectFeature.SHARE_CAMERA_EFFECT;
            AppMethodBeat.o(97727);
            return dialogFeature;
        } else if (ShareStoryContent.class.isAssignableFrom(cls)) {
            dialogFeature = ShareStoryFeature.SHARE_STORY_ASSET;
            AppMethodBeat.o(97727);
            return dialogFeature;
        } else {
            AppMethodBeat.o(97727);
            return null;
        }
    }

    private void logDialogShare(Context context, ShareContent shareContent, Mode mode) {
        String str;
        String str2;
        AppMethodBeat.i(97728);
        if (this.isAutomaticMode) {
            mode = Mode.AUTOMATIC;
        }
        switch (1.$SwitchMap$com$facebook$share$widget$ShareDialog$Mode[mode.ordinal()]) {
            case 1:
                str = "automatic";
                break;
            case 2:
                str = "web";
                break;
            case 3:
                str = "native";
                break;
            default:
                str = "unknown";
                break;
        }
        DialogFeature feature = getFeature(shareContent.getClass());
        if (feature == ShareDialogFeature.SHARE_DIALOG) {
            str2 = DownloadInfo.STATUS;
        } else if (feature == ShareDialogFeature.PHOTOS) {
            str2 = "photo";
        } else if (feature == ShareDialogFeature.VIDEO) {
            str2 = "video";
        } else if (feature == OpenGraphActionDialogFeature.OG_ACTION_DIALOG) {
            str2 = "open_graph";
        } else {
            str2 = "unknown";
        }
        AppEventsLogger newLogger = AppEventsLogger.newLogger(context);
        Bundle bundle = new Bundle();
        bundle.putString("fb_share_dialog_show", str);
        bundle.putString("fb_share_dialog_content_type", str2);
        newLogger.logSdkEvent("fb_share_dialog_show", null, bundle);
        AppMethodBeat.o(97728);
    }
}
