package com.google.android.gms.common.util;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import com.tencent.matrix.trace.core.AppMethodBeat;
import java.io.File;
import java.nio.charset.Charset;
import javax.annotation.Nullable;

public final class DbUtils {
    private DbUtils() {
    }

    public static void clearDatabase(SQLiteDatabase sQLiteDatabase) {
        AppMethodBeat.i(90149);
        zza(sQLiteDatabase, "table", "sqlite_sequence", "android_metadata");
        zza(sQLiteDatabase, "trigger", new String[0]);
        zza(sQLiteDatabase, "view", new String[0]);
        AppMethodBeat.o(90149);
    }

    public static long countCurrentRowBytes(Cursor cursor) {
        AppMethodBeat.i(90162);
        long countCurrentRowBytes = countCurrentRowBytes(cursor, Charset.forName("UTF-8"));
        AppMethodBeat.o(90162);
        return countCurrentRowBytes;
    }

    public static long countCurrentRowBytes(Cursor cursor, Charset charset) {
        AppMethodBeat.i(90161);
        long j = 0;
        for (int i = 0; i < cursor.getColumnCount(); i++) {
            switch (cursor.getType(i)) {
                case 0:
                case 1:
                case 2:
                    j += 4;
                    break;
                case 3:
                    j += (long) cursor.getString(i).getBytes(charset).length;
                    break;
                case 4:
                    j += (long) cursor.getBlob(i).length;
                    break;
                default:
                    break;
            }
        }
        AppMethodBeat.o(90161);
        return j;
    }

    public static long getDatabaseSize(Context context, String str) {
        AppMethodBeat.i(90160);
        try {
            File databasePath = context.getDatabasePath(str);
            if (databasePath != null) {
                long length = databasePath.length();
                AppMethodBeat.o(90160);
                return length;
            }
        } catch (SecurityException e) {
            String str2 = "Failed to get db size for ";
            String valueOf = String.valueOf(str);
            if (valueOf.length() != 0) {
                str2.concat(valueOf);
            } else {
                valueOf = new String(str2);
            }
        }
        AppMethodBeat.o(90160);
        return 0;
    }

    @Nullable
    public static Integer getIntegerFromCursor(Cursor cursor, int i) {
        AppMethodBeat.i(90152);
        Integer integerFromCursor = getIntegerFromCursor(cursor, i, null);
        AppMethodBeat.o(90152);
        return integerFromCursor;
    }

    @Nullable
    public static Integer getIntegerFromCursor(Cursor cursor, int i, @Nullable Integer num) {
        AppMethodBeat.i(90151);
        if (i < 0 || cursor.isNull(i)) {
            AppMethodBeat.o(90151);
            return num;
        }
        num = Integer.valueOf(cursor.getInt(i));
        AppMethodBeat.o(90151);
        return num;
    }

    @Nullable
    public static Long getLongFromCursor(Cursor cursor, int i) {
        AppMethodBeat.i(90154);
        Long longFromCursor = getLongFromCursor(cursor, i, null);
        AppMethodBeat.o(90154);
        return longFromCursor;
    }

    @Nullable
    public static Long getLongFromCursor(Cursor cursor, int i, @Nullable Long l) {
        AppMethodBeat.i(90153);
        if (i < 0 || cursor.isNull(i)) {
            AppMethodBeat.o(90153);
            return l;
        }
        l = Long.valueOf(cursor.getLong(i));
        AppMethodBeat.o(90153);
        return l;
    }

    @Nullable
    public static String getStringFromCursor(Cursor cursor, int i) {
        AppMethodBeat.i(90156);
        String stringFromCursor = getStringFromCursor(cursor, i, null);
        AppMethodBeat.o(90156);
        return stringFromCursor;
    }

    @Nullable
    public static String getStringFromCursor(Cursor cursor, int i, @Nullable String str) {
        AppMethodBeat.i(90155);
        if (i < 0 || cursor.isNull(i)) {
            AppMethodBeat.o(90155);
            return str;
        }
        str = cursor.getString(i);
        AppMethodBeat.o(90155);
        return str;
    }

    public static void putIntegerIntoContentValues(ContentValues contentValues, String str, @Nullable Integer num) {
        AppMethodBeat.i(90157);
        if (num != null) {
            contentValues.put(str, num);
            AppMethodBeat.o(90157);
            return;
        }
        contentValues.putNull(str);
        AppMethodBeat.o(90157);
    }

    public static void putLongIntoContentValues(ContentValues contentValues, String str, @Nullable Long l) {
        AppMethodBeat.i(90158);
        if (l != null) {
            contentValues.put(str, l);
            AppMethodBeat.o(90158);
            return;
        }
        contentValues.putNull(str);
        AppMethodBeat.o(90158);
    }

    public static void putStringIntoContentValues(ContentValues contentValues, String str, @Nullable String str2) {
        AppMethodBeat.i(90159);
        if (str2 != null) {
            contentValues.put(str, str2);
            AppMethodBeat.o(90159);
            return;
        }
        contentValues.putNull(str);
        AppMethodBeat.o(90159);
    }

    /* JADX WARNING: Removed duplicated region for block: B:24:0x009e  */
    private static void zza(android.database.sqlite.SQLiteDatabase r9, java.lang.String r10, java.lang.String... r11) {
        /*
        r4 = 1;
        r5 = 0;
        r6 = 0;
        r8 = 90150; // 0x16026 float:1.26327E-40 double:4.454E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r8);
        r0 = "table";
        r0 = r0.equals(r10);
        if (r0 != 0) goto L_0x0024;
    L_0x0012:
        r0 = "view";
        r0 = r0.equals(r10);
        if (r0 != 0) goto L_0x0024;
    L_0x001b:
        r0 = "trigger";
        r0 = r0.equals(r10);
        if (r0 == 0) goto L_0x00a7;
    L_0x0024:
        r0 = r4;
    L_0x0025:
        com.google.android.gms.common.internal.Preconditions.checkArgument(r0);
        r1 = "SQLITE_MASTER";
        r2 = new java.lang.String[r4];
        r0 = "name";
        r2[r6] = r0;
        r3 = "type == ?";
        r4 = new java.lang.String[r4];
        r4[r6] = r10;
        r0 = r9;
        r6 = r5;
        r7 = r5;
        r2 = r0.query(r1, r2, r3, r4, r5, r6, r7);
        r0 = com.google.android.gms.common.util.CollectionUtils.setOf(r11);	 Catch:{ Throwable -> 0x0092, all -> 0x00c0 }
    L_0x0044:
        r1 = r2.moveToNext();	 Catch:{ Throwable -> 0x0092, all -> 0x00c0 }
        if (r1 == 0) goto L_0x00aa;
    L_0x004a:
        r1 = 0;
        r1 = r2.getString(r1);	 Catch:{ Throwable -> 0x0092, all -> 0x00c0 }
        r3 = r0.contains(r1);	 Catch:{ Throwable -> 0x0092, all -> 0x00c0 }
        if (r3 != 0) goto L_0x0044;
    L_0x0055:
        r3 = java.lang.String.valueOf(r10);	 Catch:{ Throwable -> 0x0092, all -> 0x00c0 }
        r3 = r3.length();	 Catch:{ Throwable -> 0x0092, all -> 0x00c0 }
        r3 = r3 + 8;
        r4 = java.lang.String.valueOf(r1);	 Catch:{ Throwable -> 0x0092, all -> 0x00c0 }
        r4 = r4.length();	 Catch:{ Throwable -> 0x0092, all -> 0x00c0 }
        r3 = r3 + r4;
        r4 = new java.lang.StringBuilder;	 Catch:{ Throwable -> 0x0092, all -> 0x00c0 }
        r4.<init>(r3);	 Catch:{ Throwable -> 0x0092, all -> 0x00c0 }
        r3 = "DROP ";
        r3 = r4.append(r3);	 Catch:{ Throwable -> 0x0092, all -> 0x00c0 }
        r3 = r3.append(r10);	 Catch:{ Throwable -> 0x0092, all -> 0x00c0 }
        r4 = " '";
        r3 = r3.append(r4);	 Catch:{ Throwable -> 0x0092, all -> 0x00c0 }
        r1 = r3.append(r1);	 Catch:{ Throwable -> 0x0092, all -> 0x00c0 }
        r3 = "'";
        r1 = r1.append(r3);	 Catch:{ Throwable -> 0x0092, all -> 0x00c0 }
        r1 = r1.toString();	 Catch:{ Throwable -> 0x0092, all -> 0x00c0 }
        r9.execSQL(r1);	 Catch:{ Throwable -> 0x0092, all -> 0x00c0 }
        goto L_0x0044;
    L_0x0092:
        r0 = move-exception;
        r1 = 90150; // 0x16026 float:1.26327E-40 double:4.454E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r1);	 Catch:{ all -> 0x009a }
        throw r0;	 Catch:{ all -> 0x009a }
    L_0x009a:
        r1 = move-exception;
        r5 = r0;
    L_0x009c:
        if (r2 == 0) goto L_0x00a3;
    L_0x009e:
        if (r5 == 0) goto L_0x00b8;
    L_0x00a0:
        r2.close();	 Catch:{ Throwable -> 0x00b3 }
    L_0x00a3:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        throw r1;
    L_0x00a7:
        r0 = r6;
        goto L_0x0025;
    L_0x00aa:
        if (r2 == 0) goto L_0x00bc;
    L_0x00ac:
        r2.close();
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
    L_0x00b2:
        return;
    L_0x00b3:
        r0 = move-exception;
        com.google.android.gms.internal.stable.zzk.zza(r5, r0);
        goto L_0x00a3;
    L_0x00b8:
        r2.close();
        goto L_0x00a3;
    L_0x00bc:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        goto L_0x00b2;
    L_0x00c0:
        r0 = move-exception;
        r1 = r0;
        goto L_0x009c;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.google.android.gms.common.util.DbUtils.zza(android.database.sqlite.SQLiteDatabase, java.lang.String, java.lang.String[]):void");
    }
}
