package com.tencent.qqmusic.mediaplayer.upstream;

import android.annotation.SuppressLint;
import android.os.Looper;
import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.qqmusic.mediaplayer.AudioFormat.AudioType;
import com.tencent.qqmusic.mediaplayer.DataRangeTracker;
import com.tencent.qqmusic.mediaplayer.downstream.IDataSink;
import com.tencent.qqmusic.mediaplayer.formatdetector.FormatDetector;
import com.tencent.qqmusic.mediaplayer.perf.Collectable;
import com.tencent.qqmusic.mediaplayer.perf.ErrorUploadCollector;
import com.tencent.qqmusic.mediaplayer.perf.PlayerInfoCollector;
import com.tencent.qqmusic.mediaplayer.upstream.Loader.Factory;
import com.tencent.qqmusic.mediaplayer.util.Logger;
import java.util.Timer;
import java.util.TimerTask;

public class CacheDataSource implements Collectable, IDataSource {
    private static final int CHUNK_LOAD_BUFFER_SIZE = 8192;
    private static final int DISCONTINUITY_THRESHOLD = 8192;
    static final long NO_RESET_PENDING = Long.MIN_VALUE;
    private static final int PROFILE_ending = 10;
    private static final int PROFILE_isCached = 8;
    private static final int PROFILE_lock = 5;
    private static final int PROFILE_onBufferEnd = 7;
    private static final int PROFILE_onBufferStarted = 4;
    private static final int PROFILE_onBytesTransferred = 9;
    private static final int PROFILE_onBytesTransferring = 3;
    private static final int PROFILE_onReadContinuity = 1;
    private static final int PROFILE_onReadDiscontinuity = 2;
    private static final int PROFILE_readAt = 6;
    private static final int PROFILE_total = 0;
    private static final int READ_WAIT_TIMEOUT = 30000;
    private static final String TAG = "CacheDataSource";
    private static final String[] profiles = new String[]{"total", "onReadContinuity", "onReadDiscontinuity", "onBytesTransferring", "onBufferStarted", "lock", "readAt", "onBufferEnd", "isCached", "onBytesTransferred", "ending"};
    private final IDataSource cacheSource;
    private final DataRangeTracker cachedDataTracker;
    private long[] costs;
    private long currentLoadStartPosition;
    private Chunk currentLoadingChunk;
    private Listener listener;
    private boolean loadFinished;
    private final Loader loader;
    private long nextContinuousPosition;
    private boolean opened;
    protected long pendingRestartPositionByte;
    protected long pendingStartPositionByte;
    private TimerTask pendingTask;
    private Timer restartHandler;

    static /* synthetic */ void access$100(CacheDataSource cacheDataSource, long j) {
        AppMethodBeat.i(104537);
        cacheDataSource.restartLoading(j);
        AppMethodBeat.o(104537);
    }

    static /* synthetic */ boolean access$200(CacheDataSource cacheDataSource) {
        AppMethodBeat.i(104538);
        boolean startLoadingIfNeeded = cacheDataSource.startLoadingIfNeeded();
        AppMethodBeat.o(104538);
        return startLoadingIfNeeded;
    }

    static /* synthetic */ void access$900(CacheDataSource cacheDataSource, long j, long j2) {
        AppMethodBeat.i(104539);
        cacheDataSource.scheduleRestart(j, j2);
        AppMethodBeat.o(104539);
    }

    public CacheDataSource(IDataSource iDataSource, IDataSource iDataSource2, IDataSink iDataSink, Looper looper) {
        this(iDataSource2, new 1(looper, iDataSource, iDataSink));
        AppMethodBeat.i(104521);
        AppMethodBeat.o(104521);
    }

    public CacheDataSource(IDataSource iDataSource, Factory factory) {
        AppMethodBeat.i(104522);
        this.currentLoadStartPosition = NO_RESET_PENDING;
        this.costs = new long[profiles.length];
        this.cacheSource = iDataSource;
        this.cachedDataTracker = new DataRangeTracker();
        this.opened = false;
        this.loadFinished = false;
        this.loader = factory.createLoader(new LoaderListener(this, null));
        AppMethodBeat.o(104522);
    }

    public void setListener(Listener listener) {
        this.listener = listener;
    }

    public boolean isCacheFileComplete() {
        AppMethodBeat.i(104523);
        long continuousEnd = this.cachedDataTracker.getContinuousEnd();
        if (continuousEnd == -1 || continuousEnd != this.loader.getUpstreamSize() - 1) {
            AppMethodBeat.o(104523);
            return false;
        }
        AppMethodBeat.o(104523);
        return true;
    }

    public Loader getLoader() {
        return this.loader;
    }

    public boolean wait(int i, long j) {
        AppMethodBeat.i(104524);
        boolean lock = this.cachedDataTracker.lock(0, i, j);
        AppMethodBeat.o(104524);
        return lock;
    }

    public void open() {
        AppMethodBeat.i(104525);
        Logger.i(TAG, "[open] enter.");
        if (this.opened) {
            AppMethodBeat.o(104525);
            return;
        }
        this.nextContinuousPosition = 0;
        this.pendingRestartPositionByte = NO_RESET_PENDING;
        this.cacheSource.open();
        this.loader.prepare();
        startLoadingIfNeeded();
        if (this.listener != null) {
            this.listener.onTransferStart();
        }
        this.opened = true;
        Logger.i(TAG, "[open] exit");
        AppMethodBeat.o(104525);
    }

    /* JADX WARNING: Removed duplicated region for block: B:30:0x00ce A:{Catch:{ InterruptedException -> 0x0130, Throwable -> 0x0035, all -> 0x004e }} */
    /* JADX WARNING: Exception block dominator not found, dom blocks: [B:2:0x000d, B:6:0x0036, B:39:0x0110] */
    /* JADX WARNING: Missing block: B:5:0x0035, code skipped:
            r0 = move-exception;
     */
    /* JADX WARNING: Missing block: B:7:?, code skipped:
            com.tencent.qqmusic.mediaplayer.util.Logger.e(TAG, "[readAt] error occurred: ".concat(java.lang.String.valueOf(r10)), r0);
            com.tencent.matrix.trace.core.AppMethodBeat.o(104526);
     */
    /* JADX WARNING: Missing block: B:10:0x004f, code skipped:
            com.tencent.matrix.trace.core.AppMethodBeat.o(104526);
     */
    /* JADX WARNING: Missing block: B:46:0x0130, code skipped:
            r0 = move-exception;
     */
    /* JADX WARNING: Missing block: B:47:0x0131, code skipped:
            r1 = new java.io.IOException("interrupted!", r0);
            com.tencent.matrix.trace.core.AppMethodBeat.o(104526);
     */
    /* JADX WARNING: Missing block: B:48:0x013f, code skipped:
            throw r1;
     */
    public int readAt(long r10, byte[] r12, int r13, int r14) {
        /*
        r9 = this;
        r0 = 104526; // 0x1984e float:1.46472E-40 double:5.16427E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r0);
        r0 = -1;
        r2 = 0;
        r1 = (r10 > r2 ? 1 : (r10 == r2 ? 0 : -1));
        if (r1 >= 0) goto L_0x0056;
    L_0x000d:
        r0 = "CacheDataSource";
        r1 = "[readAt] invalid position: ";
        r2 = java.lang.String.valueOf(r10);	 Catch:{ Throwable -> 0x0035 }
        r1 = r1.concat(r2);	 Catch:{ Throwable -> 0x0035 }
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r0, r1);	 Catch:{ Throwable -> 0x0035 }
        r0 = new java.io.IOException;	 Catch:{ Throwable -> 0x0035 }
        r1 = "invalid position: ";
        r2 = java.lang.String.valueOf(r10);	 Catch:{ Throwable -> 0x0035 }
        r1 = r1.concat(r2);	 Catch:{ Throwable -> 0x0035 }
        r0.<init>(r1);	 Catch:{ Throwable -> 0x0035 }
        r1 = 104526; // 0x1984e float:1.46472E-40 double:5.16427E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r1);	 Catch:{ Throwable -> 0x0035 }
        throw r0;	 Catch:{ Throwable -> 0x0035 }
    L_0x0035:
        r0 = move-exception;
        r1 = "CacheDataSource";
        r2 = "[readAt] error occurred: ";
        r3 = java.lang.String.valueOf(r10);	 Catch:{ all -> 0x004e }
        r2 = r2.concat(r3);	 Catch:{ all -> 0x004e }
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r1, r2, r0);	 Catch:{ all -> 0x004e }
        r1 = 104526; // 0x1984e float:1.46472E-40 double:5.16427E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r1);	 Catch:{ all -> 0x004e }
        throw r0;	 Catch:{ all -> 0x004e }
    L_0x004e:
        r0 = move-exception;
        r1 = 104526; // 0x1984e float:1.46472E-40 double:5.16427E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r1);
        throw r0;
    L_0x0056:
        r1 = r9.cachedDataTracker;	 Catch:{ Throwable -> 0x0035 }
        r2 = r9.getSize();	 Catch:{ Throwable -> 0x0035 }
        r1.setFileTotalSize(r2);	 Catch:{ Throwable -> 0x0035 }
        r1 = r9.isCached(r10, r14);	 Catch:{ Throwable -> 0x0035 }
        r2 = r9.nextContinuousPosition;	 Catch:{ Throwable -> 0x0035 }
        r2 = (r10 > r2 ? 1 : (r10 == r2 ? 0 : -1));
        if (r2 != 0) goto L_0x00df;
    L_0x0069:
        r9.onReadContinuity(r10);	 Catch:{ Throwable -> 0x0035 }
    L_0x006c:
        r2 = r9.listener;	 Catch:{ Throwable -> 0x0035 }
        if (r2 == 0) goto L_0x0076;
    L_0x0070:
        r2 = r9.listener;	 Catch:{ Throwable -> 0x0035 }
        r4 = (long) r14;	 Catch:{ Throwable -> 0x0035 }
        r2.onBytesTransferring(r10, r4);	 Catch:{ Throwable -> 0x0035 }
    L_0x0076:
        if (r1 == 0) goto L_0x0082;
    L_0x0078:
        r1 = r9.cacheSource;	 Catch:{ Throwable -> 0x0035 }
        r5 = 0;
        r2 = r10;
        r4 = r12;
        r6 = r14;
        r0 = r1.readAt(r2, r4, r5, r6);	 Catch:{ Throwable -> 0x0035 }
    L_0x0082:
        if (r0 >= 0) goto L_0x014f;
    L_0x0084:
        r0 = r9.loader;	 Catch:{ Throwable -> 0x0035 }
        r0 = r0.isLoading();	 Catch:{ Throwable -> 0x0035 }
        if (r0 != 0) goto L_0x0107;
    L_0x008c:
        r1 = r9.cacheSource;	 Catch:{ Throwable -> 0x0035 }
        r5 = 0;
        r2 = r10;
        r4 = r12;
        r6 = r14;
        r0 = r1.readAt(r2, r4, r5, r6);	 Catch:{ Throwable -> 0x0035 }
        r1 = "CacheDataSource";
        r2 = new java.lang.StringBuilder;	 Catch:{ Throwable -> 0x0035 }
        r3 = "[readAt] load not started: ";
        r2.<init>(r3);	 Catch:{ Throwable -> 0x0035 }
        r2 = r2.append(r10);	 Catch:{ Throwable -> 0x0035 }
        r3 = ", size: ";
        r2 = r2.append(r3);	 Catch:{ Throwable -> 0x0035 }
        r2 = r2.append(r14);	 Catch:{ Throwable -> 0x0035 }
        r3 = ", read: ";
        r2 = r2.append(r3);	 Catch:{ Throwable -> 0x0035 }
        r2 = r2.append(r0);	 Catch:{ Throwable -> 0x0035 }
        r2 = r2.toString();	 Catch:{ Throwable -> 0x0035 }
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r1, r2);	 Catch:{ Throwable -> 0x0035 }
        r8 = r0;
    L_0x00c3:
        if (r8 <= 0) goto L_0x0140;
    L_0x00c5:
        r0 = (long) r8;	 Catch:{ Throwable -> 0x0035 }
        r0 = r0 + r10;
        r9.nextContinuousPosition = r0;	 Catch:{ Throwable -> 0x0035 }
    L_0x00c9:
        r0 = 0;
    L_0x00ca:
        r1 = r9.listener;	 Catch:{ Throwable -> 0x0035 }
        if (r1 == 0) goto L_0x00d8;
    L_0x00ce:
        if (r0 == 0) goto L_0x0148;
    L_0x00d0:
        r1 = r9.listener;	 Catch:{ Throwable -> 0x0035 }
        r4 = (long) r14;	 Catch:{ Throwable -> 0x0035 }
        r6 = (long) r8;	 Catch:{ Throwable -> 0x0035 }
        r2 = r10;
        r1.onBytesTransferError(r2, r4, r6);	 Catch:{ Throwable -> 0x0035 }
    L_0x00d8:
        r0 = 104526; // 0x1984e float:1.46472E-40 double:5.16427E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r0);
        return r8;
    L_0x00df:
        r2 = "CacheDataSource";
        r3 = new java.lang.StringBuilder;	 Catch:{ Throwable -> 0x0035 }
        r4 = "[readAt] onReadDiscontinuity. expected: ";
        r3.<init>(r4);	 Catch:{ Throwable -> 0x0035 }
        r4 = r9.nextContinuousPosition;	 Catch:{ Throwable -> 0x0035 }
        r3 = r3.append(r4);	 Catch:{ Throwable -> 0x0035 }
        r4 = ", actual: ";
        r3 = r3.append(r4);	 Catch:{ Throwable -> 0x0035 }
        r3 = r3.append(r10);	 Catch:{ Throwable -> 0x0035 }
        r3 = r3.toString();	 Catch:{ Throwable -> 0x0035 }
        com.tencent.qqmusic.mediaplayer.util.Logger.i(r2, r3);	 Catch:{ Throwable -> 0x0035 }
        r9.onReadDiscontinuity(r10, r1);	 Catch:{ Throwable -> 0x0035 }
        goto L_0x006c;
    L_0x0107:
        r0 = r9.listener;	 Catch:{ Throwable -> 0x0035 }
        if (r0 == 0) goto L_0x0110;
    L_0x010b:
        r0 = r9.listener;	 Catch:{ Throwable -> 0x0035 }
        r0.onBufferStarted(r10);	 Catch:{ Throwable -> 0x0035 }
    L_0x0110:
        r0 = r9.cachedDataTracker;	 Catch:{ InterruptedException -> 0x0130 }
        r4 = r9.getBufferTimeout(r10, r14);	 Catch:{ InterruptedException -> 0x0130 }
        r1 = r10;
        r3 = r14;
        r0.lock(r1, r3, r4);	 Catch:{ InterruptedException -> 0x0130 }
        r0 = r9.listener;	 Catch:{ Throwable -> 0x0035 }
        if (r0 == 0) goto L_0x0124;
    L_0x011f:
        r0 = r9.listener;	 Catch:{ Throwable -> 0x0035 }
        r0.onBufferEnded();	 Catch:{ Throwable -> 0x0035 }
    L_0x0124:
        r1 = r9.cacheSource;	 Catch:{ Throwable -> 0x0035 }
        r5 = 0;
        r2 = r10;
        r4 = r12;
        r6 = r14;
        r0 = r1.readAt(r2, r4, r5, r6);	 Catch:{ Throwable -> 0x0035 }
        r8 = r0;
        goto L_0x00c3;
    L_0x0130:
        r0 = move-exception;
        r1 = new java.io.IOException;	 Catch:{ Throwable -> 0x0035 }
        r2 = "interrupted!";
        r1.<init>(r2, r0);	 Catch:{ Throwable -> 0x0035 }
        r0 = 104526; // 0x1984e float:1.46472E-40 double:5.16427E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.o(r0);	 Catch:{ Throwable -> 0x0035 }
        throw r1;	 Catch:{ Throwable -> 0x0035 }
    L_0x0140:
        if (r8 >= 0) goto L_0x0144;
    L_0x0142:
        r0 = 1;
        goto L_0x00ca;
    L_0x0144:
        if (r14 == 0) goto L_0x00c9;
    L_0x0146:
        r0 = 1;
        goto L_0x00ca;
    L_0x0148:
        r0 = r9.listener;	 Catch:{ Throwable -> 0x0035 }
        r2 = (long) r8;	 Catch:{ Throwable -> 0x0035 }
        r0.onBytesTransferred(r10, r2);	 Catch:{ Throwable -> 0x0035 }
        goto L_0x00d8;
    L_0x014f:
        r8 = r0;
        goto L_0x00c3;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.qqmusic.mediaplayer.upstream.CacheDataSource.readAt(long, byte[], int, int):int");
    }

    public long getSize() {
        AppMethodBeat.i(104527);
        long upstreamSize = this.loader.getUpstreamSize();
        AppMethodBeat.o(104527);
        return upstreamSize;
    }

    public AudioType getAudioType() {
        AppMethodBeat.i(104528);
        AudioType audioFormat = FormatDetector.getAudioFormat(this, false);
        AppMethodBeat.o(104528);
        return audioFormat;
    }

    public void close() {
        AppMethodBeat.i(104529);
        Logger.i(TAG, "[close] enter.");
        if (this.opened) {
            this.cachedDataTracker.abandonLock();
            try {
                this.loader.shutdown();
            } catch (InterruptedException e) {
            }
            this.cacheSource.close();
            if (this.listener != null) {
                this.listener.onTransferEnd();
            }
            reportProfiling();
            this.opened = false;
            Logger.i(TAG, "[close] exit");
            AppMethodBeat.o(104529);
            return;
        }
        AppMethodBeat.o(104529);
    }

    private void reportProfiling() {
    }

    public synchronized boolean continueLoadIfNeeded() {
        boolean z = false;
        synchronized (this) {
            AppMethodBeat.i(104530);
            if (!this.opened) {
                Logger.w(TAG, "[continueLoadIfNeeded] not opened!");
                AppMethodBeat.o(104530);
            } else if (this.pendingRestartPositionByte == NO_RESET_PENDING) {
                AppMethodBeat.o(104530);
            } else if (this.loadFinished) {
                AppMethodBeat.o(104530);
            } else {
                long j = this.pendingRestartPositionByte;
                this.pendingRestartPositionByte = NO_RESET_PENDING;
                scheduleRestart(j, 0);
                Logger.i(TAG, "[continueLoadIfNeeded] schedule restart from: ".concat(String.valueOf(j)));
                z = true;
                AppMethodBeat.o(104530);
            }
        }
        return z;
    }

    /* Access modifiers changed, original: protected */
    public long getBufferTimeout(long j, int i) {
        return 30000;
    }

    private void onReadDiscontinuity(long j, boolean z) {
        AppMethodBeat.i(104531);
        if (j == this.currentLoadStartPosition) {
            Logger.i(TAG, "[onReadDiscontinuity] same same position as current load. skip.");
            AppMethodBeat.o(104531);
            return;
        }
        long j2 = j - this.currentLoadStartPosition;
        if (j2 < 0 || j2 >= 8192) {
            long max;
            synchronized (this.cachedDataTracker) {
                try {
                    max = Math.max(j, this.cachedDataTracker.findStart(j));
                } finally {
                    while (true) {
                    }
                    AppMethodBeat.o(104531);
                }
            }
            if (this.currentLoadStartPosition == max) {
                Logger.i(TAG, "[onReadDiscontinuity] loadStartPosition is the same as current load. skip.");
                return;
            }
            j2 = max - this.currentLoadStartPosition;
            if (j2 >= 0 && j2 < 8192) {
                Logger.i(TAG, "[onReadDiscontinuity] loadStartPosition diff is too small(" + j2 + "). skip.");
                AppMethodBeat.o(104531);
                return;
            } else if (max == getSize()) {
                Logger.i(TAG, "[onReadDiscontinuity] no need to load from end. skip.");
                AppMethodBeat.o(104531);
                return;
            } else {
                Chunk chunk = this.currentLoadingChunk;
                if (z && chunk != null && chunk.contains(max)) {
                    Logger.i(TAG, String.format("[onReadDiscontinuity] position is cached and loadStartPosition(%d) is under loading(%s). skip.", new Object[]{Long.valueOf(max), chunk}));
                    AppMethodBeat.o(104531);
                    return;
                }
                restartLoading(max);
                AppMethodBeat.o(104531);
                return;
            }
        }
        Logger.i(TAG, "[onReadDiscontinuity] position diff is too small(" + j2 + "). skip.");
        AppMethodBeat.o(104531);
    }

    private void onReadContinuity(long j) {
    }

    private synchronized boolean startLoadingIfNeeded() {
        boolean z;
        AppMethodBeat.i(104532);
        if (this.loadFinished) {
            z = false;
            AppMethodBeat.o(104532);
        } else {
            Chunk chunk;
            long j = this.pendingStartPositionByte;
            this.pendingStartPositionByte = NO_RESET_PENDING;
            if (this.opened) {
                if (j == NO_RESET_PENDING) {
                    IllegalStateException illegalStateException = new IllegalStateException("pendingStartPositionByte must be set!");
                    AppMethodBeat.o(104532);
                    throw illegalStateException;
                }
                Logger.i(TAG, "[startLoadingIfNeeded] restart a pending load: ".concat(String.valueOf(j)));
                chunk = new Chunk(8192, j, -1);
            } else if (j == NO_RESET_PENDING) {
                Logger.i(TAG, "[startLoadingIfNeeded] start a fresh load");
                chunk = new Chunk(8192, 0, -1);
            } else {
                Logger.i(TAG, "[startLoadingIfNeeded] start a pending load: ".concat(String.valueOf(j)));
                chunk = new Chunk(8192, j, -1);
            }
            this.currentLoadingChunk = chunk;
            this.currentLoadStartPosition = chunk.start;
            this.cachedDataTracker.unblock();
            this.loader.startLoading(chunk);
            z = true;
            AppMethodBeat.o(104532);
        }
        return z;
    }

    private synchronized void restartLoading(long j) {
        AppMethodBeat.i(104533);
        Logger.i(TAG, "[restartLoading] from: ".concat(String.valueOf(j)));
        this.pendingStartPositionByte = j;
        this.loadFinished = false;
        if (this.loader.isLoading()) {
            this.cachedDataTracker.block();
            this.loader.cancelLoading();
            AppMethodBeat.o(104533);
        } else {
            clearState();
            startLoadingIfNeeded();
            AppMethodBeat.o(104533);
        }
    }

    private boolean isCached(long j, int i) {
        AppMethodBeat.i(104534);
        long upstreamSize = this.loader.getUpstreamSize();
        if (upstreamSize > 0 && ((long) i) + j > upstreamSize - 1) {
            i = (int) ((upstreamSize - j) - 1);
            if (i < 0) {
                j += (long) i;
                i = 0;
            }
        }
        boolean isCached = this.cachedDataTracker.isCached(j, i);
        AppMethodBeat.o(104534);
        return isCached;
    }

    private void clearState() {
        this.loadFinished = false;
    }

    @SuppressLint({"DefaultLocale"})
    private synchronized void scheduleRestart(long j, long j2) {
        AppMethodBeat.i(104535);
        Logger.i(TAG, String.format("[scheduleRestart] position: %d, delay: %d", new Object[]{Long.valueOf(j), Long.valueOf(j2)}));
        if (this.restartHandler == null) {
            this.restartHandler = new Timer("CacheDataSource.Restart");
        }
        if (this.pendingTask != null) {
            this.pendingTask.cancel();
            this.restartHandler.purge();
        }
        this.pendingTask = new 2(this, j);
        this.restartHandler.schedule(this.pendingTask, j2);
        AppMethodBeat.o(104535);
    }

    public void accept(PlayerInfoCollector playerInfoCollector) {
        int i;
        int i2 = 1;
        AppMethodBeat.i(104536);
        long j = 0;
        for (i = 1; i < profiles.length; i++) {
            j += this.costs[i];
        }
        double length = ((double) (this.costs[0] - j)) / ((double) this.costs.length);
        long[] jArr = new long[this.costs.length];
        System.arraycopy(this.costs, 0, jArr, 0, this.costs.length);
        for (i = 1; i < jArr.length; i++) {
            jArr[i] = Math.max(jArr[i] - ((long) length), 0);
        }
        while (i2 < profiles.length) {
            playerInfoCollector.putLong("CacheDataSource." + profiles[i2], jArr[i2] / 1000000);
            i2++;
        }
        AppMethodBeat.o(104536);
    }

    public void accept(ErrorUploadCollector errorUploadCollector) {
    }
}
