package com.tencent.soter.core.biometric;

import android.annotation.SuppressLint;
import android.content.Context;
import android.os.CancellationSignal;
import android.os.Handler;
import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.soter.core.biometric.FaceManager.AuthenticationCallback;
import com.tencent.soter.core.c.d;

@SuppressLint({"NewApi"})
final class FaceidManagerProxy {
    public static final String FACEMANAGER_FACTORY_CLASS_NAME = "com.tencent.soter.core.biometric.SoterFaceManagerFactory";
    private static final String TAG = "Soter.FaceidManagerProxy";

    FaceidManagerProxy() {
    }

    static /* synthetic */ CryptoObject access$000(FaceManager$CryptoObject faceManager$CryptoObject) {
        AppMethodBeat.i(72947);
        CryptoObject unwrapCryptoObject = unwrapCryptoObject(faceManager$CryptoObject);
        AppMethodBeat.o(72947);
        return unwrapCryptoObject;
    }

    private static FaceManager getFaceManager(Context context) {
        FaceManager faceManager;
        AppMethodBeat.i(72939);
        try {
            faceManager = (FaceManager) Class.forName(FACEMANAGER_FACTORY_CLASS_NAME).getDeclaredMethod("getFaceManager", new Class[]{Context.class}).invoke(null, new Object[]{context});
        } catch (Exception e) {
            d.e(TAG, "soter: FaceManager init failed, maybe not support." + e.toString(), new Object[0]);
            faceManager = null;
        }
        AppMethodBeat.o(72939);
        return faceManager;
    }

    public static boolean hasEnrolledFaceids(Context context) {
        boolean z = false;
        AppMethodBeat.i(72940);
        try {
            FaceManager faceManager = getFaceManager(context);
            if (faceManager != null) {
                z = faceManager.hasEnrolledFaces();
                AppMethodBeat.o(72940);
            } else {
                d.e(TAG, "soter: facemanager is null in hasEnrolledBiometric! Should never happen", new Object[0]);
                AppMethodBeat.o(72940);
            }
        } catch (Exception e) {
            d.e(TAG, "soter: triggered SecurityException in hasEnrolledBiometric! Make sure you declared USE_FACEID in AndroidManifest.xml", new Object[0]);
            AppMethodBeat.o(72940);
        }
        return z;
    }

    public static boolean isHardwareDetected(Context context) {
        boolean z = false;
        AppMethodBeat.i(72941);
        try {
            FaceManager faceManager = getFaceManager(context);
            if (faceManager != null) {
                z = faceManager.isHardwareDetected();
                AppMethodBeat.o(72941);
            } else {
                d.e(TAG, "soter: facemanager is null in isHardwareDetected! Should never happen", new Object[0]);
                AppMethodBeat.o(72941);
            }
        } catch (Exception e) {
            d.e(TAG, "soter: triggered SecurityException in isHardwareDetected! Make sure you declared USE_FACEID in AndroidManifest.xml", new Object[0]);
            AppMethodBeat.o(72941);
        }
        return z;
    }

    public static void authenticate(Context context, CryptoObject cryptoObject, int i, Object obj, AuthenticationCallback authenticationCallback, Handler handler) {
        AppMethodBeat.i(72942);
        try {
            FaceManager faceManager = getFaceManager(context);
            if (faceManager != null) {
                faceManager.authenticate(wrapCryptoObject(cryptoObject), (CancellationSignal) obj, i, wrapCallback(authenticationCallback), handler);
                AppMethodBeat.o(72942);
                return;
            }
            d.e(TAG, "soter: facemanager is null in authenticate! Should never happen", new Object[0]);
            AppMethodBeat.o(72942);
        } catch (Exception e) {
            d.e(TAG, "soter: triggered SecurityException in authenticate! Make sure you declared USE_FACEID in AndroidManifest.xml", new Object[0]);
            AppMethodBeat.o(72942);
        }
    }

    private static FaceManager$CryptoObject wrapCryptoObject(CryptoObject cryptoObject) {
        AppMethodBeat.i(72943);
        FaceManager$CryptoObject faceManager$CryptoObject;
        if (cryptoObject == null) {
            AppMethodBeat.o(72943);
            return null;
        } else if (cryptoObject.getCipher() != null) {
            faceManager$CryptoObject = new FaceManager$CryptoObject(cryptoObject.getCipher());
            AppMethodBeat.o(72943);
            return faceManager$CryptoObject;
        } else if (cryptoObject.getSignature() != null) {
            faceManager$CryptoObject = new FaceManager$CryptoObject(cryptoObject.getSignature());
            AppMethodBeat.o(72943);
            return faceManager$CryptoObject;
        } else if (cryptoObject.getMac() != null) {
            faceManager$CryptoObject = new FaceManager$CryptoObject(cryptoObject.getMac());
            AppMethodBeat.o(72943);
            return faceManager$CryptoObject;
        } else {
            AppMethodBeat.o(72943);
            return null;
        }
    }

    private static CryptoObject unwrapCryptoObject(FaceManager$CryptoObject faceManager$CryptoObject) {
        AppMethodBeat.i(72944);
        CryptoObject cryptoObject;
        if (faceManager$CryptoObject == null) {
            AppMethodBeat.o(72944);
            return null;
        } else if (faceManager$CryptoObject.getCipher() != null) {
            cryptoObject = new CryptoObject(faceManager$CryptoObject.getCipher());
            AppMethodBeat.o(72944);
            return cryptoObject;
        } else if (faceManager$CryptoObject.getSignature() != null) {
            cryptoObject = new CryptoObject(faceManager$CryptoObject.getSignature());
            AppMethodBeat.o(72944);
            return cryptoObject;
        } else if (faceManager$CryptoObject.getMac() != null) {
            cryptoObject = new CryptoObject(faceManager$CryptoObject.getMac());
            AppMethodBeat.o(72944);
            return cryptoObject;
        } else {
            AppMethodBeat.o(72944);
            return null;
        }
    }

    private static AuthenticationCallback wrapCallback(AuthenticationCallback authenticationCallback) {
        AppMethodBeat.i(72945);
        1 1 = new 1(authenticationCallback);
        AppMethodBeat.o(72945);
        return 1;
    }

    public static String getBiometricName(Context context) {
        String str = null;
        AppMethodBeat.i(72946);
        try {
            FaceManager faceManager = getFaceManager(context);
            if (faceManager != null) {
                str = faceManager.getBiometricName(context);
                AppMethodBeat.o(72946);
            } else {
                d.e(TAG, "soter: faceid manager is null! no biometric name returned.", new Object[0]);
                AppMethodBeat.o(72946);
            }
        } catch (Exception e) {
            d.e(TAG, "soter: triggered SecurityException in getBiometricName! Make sure you declared USE_FACEID in AndroidManifest.xml", new Object[0]);
            AppMethodBeat.o(72946);
        }
        return str;
    }
}
