package com.tencent.tmassistantsdk.openSDK.opensdktomsdk;

import android.content.Context;
import android.os.HandlerThread;
import android.os.Looper;
import android.text.TextUtils;
import android.view.View.OnClickListener;
import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.mm.pluginsdk.model.app.q;
import com.tencent.mm.sdk.platformtools.ab;
import com.tencent.mm.sdk.platformtools.ak;
import com.tencent.smtt.sdk.TbsListener$ErrorCode;
import com.tencent.tmassistantsdk.channel.TMAssistantSDKChannel;
import com.tencent.tmassistantsdk.channel.TMAssistantSDKChannelDataItem;
import com.tencent.tmassistantsdk.downloadclient.ITMAssistantDownloadSDKClientListener;
import com.tencent.tmassistantsdk.downloadclient.TMAssistantDownloadSDKClient;
import com.tencent.tmassistantsdk.downloadclient.TMAssistantDownloadSDKManager;
import com.tencent.tmassistantsdk.logreport.TipsInfoReportManager;
import com.tencent.tmassistantsdk.network.GetAuthorizedHttpRequest;
import com.tencent.tmassistantsdk.network.IGetAuthorizedHttpRequestListenner;
import com.tencent.tmassistantsdk.openSDK.TMQQDownloaderOpenSDK;
import com.tencent.tmassistantsdk.openSDK.opensdktomsdk.component.PopDialog;
import com.tencent.tmassistantsdk.openSDK.opensdktomsdk.data.ActionButton;
import com.tencent.tmassistantsdk.openSDK.opensdktomsdk.data.AuthorizedResult;
import com.tencent.tmassistantsdk.openSDK.opensdktomsdk.data.TipsInfo;
import com.tencent.tmassistantsdk.protocol.jce.TipsInfoLog;
import com.tencent.tmassistantsdk.util.Res;
import com.tencent.tmassistantsdk.util.TMLog;
import java.io.File;
import java.util.ArrayList;
import java.util.Iterator;

public class TMOpenSDKToMsdkManager {
    protected static final String CLIENT_NAME = "downloadSDKClient";
    protected static final String TAG = "OpensdkToMsdkManager";
    protected static TMOpenSDKToMsdkManager mInstance = null;
    protected int authorizedState = 0;
    protected PopDialog dialog = null;
    protected boolean hasNotify = false;
    protected long insertActionId = -1;
    protected boolean isInstallFinished = false;
    protected TMOpenSDKAuthorizedInfo mAuthorizedInfo = null;
    protected TMAssistantDownloadSDKClient mClient = null;
    protected Context mContext = null;
    protected ITMAssistantDownloadSDKClientListener mDownloadSDKListener = new 9(this);
    protected String mDownloadUrl = null;
    protected GetAuthorizedHttpRequest mHttpRequest = null;
    protected ak mMainMessageHandler = null;
    protected TMQQDownloaderOpenSDK mOpenSDK = null;
    protected IGetAuthorizedHttpRequestListenner mRequestListener = new 2(this);
    protected ak mSubMessageHandler = null;
    protected HandlerThread mSubMessagehandlerThread = null;
    protected int mSupportVersionCode = 0;
    protected ITMOpenSDKToMsdkListener mToMsdkListener = null;
    protected OnClickListener negativeBtnListenner = new 5(this);
    protected OnClickListener positiveBtnListener = new 6(this);
    protected OnClickListener retryBtnListener = new 4(this);
    protected TMAssistantSDKChannel sdkChannel = null;

    private TMOpenSDKToMsdkManager(Context context) {
        AppMethodBeat.i(75931);
        this.mContext = context;
        AppMethodBeat.o(75931);
    }

    public static synchronized TMOpenSDKToMsdkManager getInstance(Context context) {
        TMOpenSDKToMsdkManager tMOpenSDKToMsdkManager;
        synchronized (TMOpenSDKToMsdkManager.class) {
            AppMethodBeat.i(75932);
            if (mInstance == null) {
                mInstance = new TMOpenSDKToMsdkManager(context);
            }
            tMOpenSDKToMsdkManager = mInstance;
            AppMethodBeat.o(75932);
        }
        return tMOpenSDKToMsdkManager;
    }

    public void initOpenSDK(ITMOpenSDKToMsdkListener iTMOpenSDKToMsdkListener) {
        AppMethodBeat.i(75933);
        this.mOpenSDK = TMQQDownloaderOpenSDK.getInstance();
        this.mOpenSDK.initQQDownloaderOpenSDK(this.mContext);
        this.mToMsdkListener = iTMOpenSDKToMsdkListener;
        this.sdkChannel = new TMAssistantSDKChannel();
        this.mSubMessagehandlerThread = new HandlerThread("OpenSDKToMsdkManager");
        this.mSubMessagehandlerThread.start();
        this.mSubMessageHandler = new ak(this.mSubMessagehandlerThread.getLooper());
        this.mMainMessageHandler = new ak(Looper.getMainLooper(), new 1(this));
        AppMethodBeat.o(75933);
    }

    public void onDestroy() {
        AppMethodBeat.i(75934);
        if (this.dialog != null && this.dialog.isShowing()) {
            this.dialog.dismiss();
        }
        if (this.mOpenSDK != null) {
            this.mOpenSDK.destroyQQDownloaderOpenSDK();
        }
        this.mToMsdkListener = null;
        this.hasNotify = false;
        this.isInstallFinished = false;
        this.authorizedState = 0;
        this.mHttpRequest = null;
        this.mAuthorizedInfo = null;
        this.sdkChannel = null;
        this.insertActionId = -1;
        if (this.mContext != null) {
            TMAssistantDownloadSDKManager.closeAllService(this.mContext);
        }
        this.mClient = null;
        AppMethodBeat.o(75934);
    }

    public void onResume() {
        AppMethodBeat.i(75935);
        tryToCloseDialog();
        if (this.hasNotify) {
            AppMethodBeat.o(75935);
        } else if (this.authorizedState == 2) {
            AppMethodBeat.o(75935);
        } else {
            if ((this.authorizedState == 3 || this.authorizedState == 0) && this.mContext != null) {
                getUserAuthorizedInfo(this.mAuthorizedInfo, this.mContext);
            }
            AppMethodBeat.o(75935);
        }
    }

    public void getUserAuthorizedInfo(TMOpenSDKAuthorizedInfo tMOpenSDKAuthorizedInfo, Context context) {
        AppMethodBeat.i(75936);
        if (context != null) {
            this.mContext = context;
        }
        TMLog.i(TAG, "getUserAuthorizedInfo method called!");
        this.hasNotify = false;
        if (this.mHttpRequest != null) {
            TMLog.i(TAG, "mHttpRequest != null, request didn't finish!");
            AppMethodBeat.o(75936);
            return;
        }
        if (tMOpenSDKAuthorizedInfo != null) {
            this.mAuthorizedInfo = tMOpenSDKAuthorizedInfo;
            if (this.mHttpRequest == null) {
                this.authorizedState = 1;
                this.mHttpRequest = new GetAuthorizedHttpRequest();
                this.mHttpRequest.setListenner(this.mRequestListener);
                this.mHttpRequest.sendRequest(tMOpenSDKAuthorizedInfo);
                AppMethodBeat.o(75936);
                return;
            }
        }
        TMLog.i(TAG, "AuthorizedInfo object is null!");
        AppMethodBeat.o(75936);
    }

    /* Access modifiers changed, original: protected */
    public void onNetworkFinishedSuccess(AuthorizedResult authorizedResult) {
        AppMethodBeat.i(75937);
        this.mDownloadUrl = authorizedResult.downloadUrl;
        this.mSupportVersionCode = authorizedResult.versionCode;
        this.mHttpRequest = null;
        TMLog.i(TAG, "onNetworkFinishedSuccess! authorizedResult.hasAuthoried=" + authorizedResult.hasAuthoried + "  listenner:" + this.mToMsdkListener + "  authroizedinfo:" + this.mAuthorizedInfo);
        if (authorizedResult.hasAuthoried == 1) {
            this.authorizedState = 2;
            if (authorizedResult.tipsInfo != null) {
                showDialog(authorizedResult.tipsInfo);
                AppMethodBeat.o(75937);
                return;
            }
            notifyAuthorizedFinished(true, this.mAuthorizedInfo);
            AppMethodBeat.o(75937);
            return;
        }
        this.authorizedState = 3;
        if (authorizedResult.tipsInfo != null) {
            showDialog(authorizedResult.tipsInfo);
            AppMethodBeat.o(75937);
            return;
        }
        onServerException(authorizedResult.errorCode);
        TMLog.i(TAG, "not in white list and no tips!");
        AppMethodBeat.o(75937);
    }

    /* Access modifiers changed, original: protected */
    public void onNetworkFinishedFailed(int i) {
        AppMethodBeat.i(75938);
        if (i == 606 || i == 602 || i == 601 || i == TbsListener$ErrorCode.INFO_COOKIE_SWITCH_TRANSFER) {
            onServerException(i);
            AppMethodBeat.o(75938);
            return;
        }
        onNetworkException(i);
        AppMethodBeat.o(75938);
    }

    /* Access modifiers changed, original: protected */
    public void onServerException(int i) {
        AppMethodBeat.i(75939);
        if (this.mContext == null) {
            AppMethodBeat.o(75939);
            return;
        }
        Res res = new Res(this.mContext);
        TipsInfo tipsInfo = new TipsInfo();
        tipsInfo.title = this.mContext.getString(res.string("white_list_dlg_title"));
        if (i == 602 || i == 601) {
            tipsInfo.content = this.mContext.getString(res.string("white_list_network_error"));
        } else {
            tipsInfo.content = this.mContext.getString(res.string("white_list_server_error"));
        }
        ArrayList arrayList = new ArrayList();
        ActionButton actionButton = new ActionButton();
        actionButton.jumpType = 4;
        String string = this.mContext.getString(res.string("white_list_positive_retry_again"));
        actionButton.textInstalled = string;
        actionButton.textUninstalled = string;
        ActionButton actionButton2 = new ActionButton();
        actionButton2.jumpType = 3;
        String string2 = this.mContext.getString(res.string("white_list_negtive"));
        actionButton2.textInstalled = string2;
        actionButton2.textUninstalled = string2;
        arrayList.add(actionButton);
        arrayList.add(actionButton2);
        tipsInfo.actionButton = arrayList;
        showDialog(tipsInfo);
        this.mHttpRequest = null;
        this.mDownloadUrl = "";
        this.authorizedState = 3;
        TipsInfoLog createTipsInfoLog = TipsInfoReportManager.getInstance().createTipsInfoLog(this.mAuthorizedInfo);
        createTipsInfoLog.networkErrorTipsCount++;
        TipsInfoReportManager.getInstance().addLogData(createTipsInfoLog);
        AppMethodBeat.o(75939);
    }

    /* Access modifiers changed, original: protected */
    public void onNetworkException(int i) {
        AppMethodBeat.i(75940);
        if (this.mContext == null) {
            AppMethodBeat.o(75940);
            return;
        }
        String string;
        Res res = new Res(this.mContext);
        if (1 == i) {
            string = this.mContext.getString(res.string("white_list_network_not_connected"));
        } else {
            string = this.mContext.getString(res.string("white_list_network_error"));
        }
        TipsInfo tipsInfo = new TipsInfo();
        tipsInfo.title = this.mContext.getString(res.string("white_list_dlg_title"));
        tipsInfo.content = string;
        ArrayList arrayList = new ArrayList();
        ActionButton actionButton = new ActionButton();
        actionButton.jumpType = 3;
        arrayList.add(actionButton);
        String string2 = this.mContext.getString(res.string("white_list_negtive_known"));
        actionButton.textInstalled = string2;
        actionButton.textUninstalled = string2;
        tipsInfo.actionButton = arrayList;
        showDialog(tipsInfo);
        this.mHttpRequest = null;
        this.mDownloadUrl = "";
        this.authorizedState = 3;
        TMLog.i(TAG, "network error happened!");
        TipsInfoLog createTipsInfoLog = TipsInfoReportManager.getInstance().createTipsInfoLog(this.mAuthorizedInfo);
        createTipsInfoLog.networkErrorTipsCount++;
        TipsInfoReportManager.getInstance().addLogData(createTipsInfoLog);
        AppMethodBeat.o(75940);
    }

    /* Access modifiers changed, original: protected */
    public void notifyAuthorizedFinished(boolean z, TMOpenSDKAuthorizedInfo tMOpenSDKAuthorizedInfo) {
        AppMethodBeat.i(75941);
        TMLog.i(TAG, "before realy notifyAuthorizedFinished: TMOpenSDKAuthorizedInfo:" + this.mAuthorizedInfo);
        if (this.mToMsdkListener == null) {
            TMLog.i(TAG, "before notifyAuthorizedFinished: mToMsdkListener = null !");
        }
        if (!(this.mToMsdkListener == null || this.mAuthorizedInfo == null)) {
            TMLog.i(TAG, "notifyAuthorizedFinished: result:".concat(String.valueOf(z)));
            this.mToMsdkListener.onAuthorizedFinished(z, this.mAuthorizedInfo);
            this.mHttpRequest = null;
            this.hasNotify = true;
        }
        AppMethodBeat.o(75941);
    }

    /* Access modifiers changed, original: protected */
    public void showDialog(com.tencent.tmassistantsdk.openSDK.opensdktomsdk.data.TipsInfo r11) {
        /*
        r10 = this;
        r2 = 0;
        r9 = 75942; // 0x128a6 float:1.06417E-40 double:3.75203E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r9);
        r0 = r10.mContext;
        if (r0 != 0) goto L_0x000f;
    L_0x000b:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r9);
    L_0x000e:
        return;
    L_0x000f:
        r0 = r10.dialog;
        if (r0 == 0) goto L_0x001f;
    L_0x0013:
        r0 = r10.dialog;
        r0 = r0.isShowing();
        if (r0 == 0) goto L_0x001f;
    L_0x001b:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r9);
        goto L_0x000e;
    L_0x001f:
        r0 = r10.mContext;
        r0 = r0 instanceof android.app.Activity;
        if (r0 == 0) goto L_0x004b;
    L_0x0025:
        r0 = r10.mContext;
        r0 = (android.app.Activity) r0;
        r0 = r0.isFinishing();
        if (r0 == 0) goto L_0x004b;
    L_0x002f:
        r0 = "OpensdkToMsdkManager";
        r1 = new java.lang.StringBuilder;
        r2 = "context is finishing!  context";
        r1.<init>(r2);
        r2 = r10.mContext;
        r1 = r1.append(r2);
        r1 = r1.toString();
        com.tencent.tmassistantsdk.util.TMLog.i(r0, r1);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r9);
        goto L_0x000e;
    L_0x004b:
        r4 = new com.tencent.tmassistantsdk.util.Res;
        r0 = r10.mContext;
        r4.<init>(r0);
        if (r11 == 0) goto L_0x0122;
    L_0x0054:
        r5 = r11.actionButton;
        if (r5 == 0) goto L_0x0122;
    L_0x0058:
        r0 = r5.size();
        if (r0 <= 0) goto L_0x0122;
    L_0x005e:
        r0 = new com.tencent.tmassistantsdk.openSDK.opensdktomsdk.component.PopDialog;
        r1 = r10.mContext;
        r3 = "while_list_dialog";
        r3 = r4.style(r3);
        r6 = r5.size();
        r0.<init>(r1, r3, r6);
        r10.dialog = r0;
        r0 = r10.dialog;
        r0.show();
        r0 = r10.dialog;
        r1 = r11.title;
        r0.setTitle(r1);
        r0 = r10.dialog;
        r1 = r11.content;
        r0.setContent(r1);
        r1 = r2;
    L_0x0086:
        r0 = r5.size();
        if (r1 >= r0) goto L_0x0122;
    L_0x008c:
        r0 = r5.get(r1);
        r0 = (com.tencent.tmassistantsdk.openSDK.opensdktomsdk.data.ActionButton) r0;
        r3 = r0.jumpType;
        r6 = 3;
        if (r3 != r6) goto L_0x00a9;
    L_0x0097:
        r3 = r10.dialog;
        r0 = r0.textInstalled;
        r3.setNegativeBtnText(r0);
        r0 = r10.dialog;
        r3 = r10.negativeBtnListenner;
        r0.setNegativeBtnClickListener(r3);
    L_0x00a5:
        r0 = r1 + 1;
        r1 = r0;
        goto L_0x0086;
    L_0x00a9:
        r3 = r0.jumpType;
        r6 = 4;
        if (r3 != r6) goto L_0x00bd;
    L_0x00ae:
        r3 = r10.dialog;
        r0 = r0.textUninstalled;
        r3.setPositiveBtnText(r0);
        r0 = r10.dialog;
        r3 = r10.retryBtnListener;
        r0.setPositiveBtnClickListener(r3);
        goto L_0x00a5;
    L_0x00bd:
        r3 = r10.mOpenSDK;	 Catch:{ Exception -> 0x00f4 }
        r6 = r10.mSupportVersionCode;	 Catch:{ Exception -> 0x00f4 }
        r3 = r3.checkQQDownloaderInstalled(r6);	 Catch:{ Exception -> 0x00f4 }
        switch(r3) {
            case 0: goto L_0x00d5;
            case 1: goto L_0x0117;
            case 2: goto L_0x0101;
            default: goto L_0x00c8;
        };
    L_0x00c8:
        r3 = r10.dialog;
        r3.setPositiveBtnTag(r0);
        r0 = r10.dialog;
        r3 = r10.positiveBtnListener;
        r0.setPositiveBtnClickListener(r3);
        goto L_0x00a5;
    L_0x00d5:
        r3 = r10.dialog;	 Catch:{ Exception -> 0x00f4 }
        r6 = r0.textInstalled;	 Catch:{ Exception -> 0x00f4 }
        r3.setPositiveBtnText(r6);	 Catch:{ Exception -> 0x00f4 }
        r3 = com.tencent.tmassistantsdk.logreport.TipsInfoReportManager.getInstance();	 Catch:{ Exception -> 0x00f4 }
        r6 = r10.mAuthorizedInfo;	 Catch:{ Exception -> 0x00f4 }
        r3 = r3.createTipsInfoLog(r6);	 Catch:{ Exception -> 0x00f4 }
        r6 = r3.authorizedTipsCount;	 Catch:{ Exception -> 0x00f4 }
        r6 = r6 + 1;
        r3.authorizedTipsCount = r6;	 Catch:{ Exception -> 0x00f4 }
        r6 = com.tencent.tmassistantsdk.logreport.TipsInfoReportManager.getInstance();	 Catch:{ Exception -> 0x00f4 }
        r6.addLogData(r3);	 Catch:{ Exception -> 0x00f4 }
        goto L_0x00c8;
    L_0x00f4:
        r3 = move-exception;
        r6 = "OpensdkToMsdkManager";
        r7 = "";
        r8 = new java.lang.Object[r2];
        com.tencent.mm.sdk.platformtools.ab.printErrStackTrace(r6, r3, r7, r8);
        goto L_0x00c8;
    L_0x0101:
        r3 = r10.dialog;	 Catch:{ Exception -> 0x00f4 }
        r6 = r10.mContext;	 Catch:{ Exception -> 0x00f4 }
        r7 = "white_list_positive_update";
        r7 = r4.string(r7);	 Catch:{ Exception -> 0x00f4 }
        r6 = r6.getString(r7);	 Catch:{ Exception -> 0x00f4 }
        r3.setPositiveBtnText(r6);	 Catch:{ Exception -> 0x00f4 }
        r10.continueDownload();	 Catch:{ Exception -> 0x00f4 }
        goto L_0x00c8;
    L_0x0117:
        r3 = r10.dialog;	 Catch:{ Exception -> 0x00f4 }
        r6 = r0.textUninstalled;	 Catch:{ Exception -> 0x00f4 }
        r3.setPositiveBtnText(r6);	 Catch:{ Exception -> 0x00f4 }
        r10.continueDownload();	 Catch:{ Exception -> 0x00f4 }
        goto L_0x00c8;
    L_0x0122:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r9);
        goto L_0x000e;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.tmassistantsdk.openSDK.opensdktomsdk.TMOpenSDKToMsdkManager.showDialog(com.tencent.tmassistantsdk.openSDK.opensdktomsdk.data.TipsInfo):void");
    }

    /* Access modifiers changed, original: protected */
    public void continueDownload() {
        AppMethodBeat.i(75943);
        this.mSubMessageHandler.post(new 3(this));
        AppMethodBeat.o(75943);
    }

    /* Access modifiers changed, original: protected */
    public void tryToCloseDialog() {
        AppMethodBeat.i(75944);
        if (this.mOpenSDK == null) {
            AppMethodBeat.o(75944);
        } else if (this.mContext == null) {
            AppMethodBeat.o(75944);
        } else {
            try {
                int checkQQDownloaderInstalled = this.mOpenSDK.checkQQDownloaderInstalled(this.mSupportVersionCode);
                if (this.isInstallFinished && checkQQDownloaderInstalled == 0) {
                    this.mHttpRequest = null;
                    this.isInstallFinished = false;
                    this.mDownloadUrl = null;
                    if (this.dialog.isShowing()) {
                        this.dialog.dismiss();
                    }
                    TMAssistantDownloadSDKManager.closeAllService(this.mContext);
                    this.mClient = null;
                    if (isExitsAction(this.insertActionId)) {
                        this.mOpenSDK.startQQDownloader(this.mContext);
                    }
                }
                AppMethodBeat.o(75944);
            } catch (Exception e) {
                ab.printErrStackTrace(TAG, e, "", new Object[0]);
                AppMethodBeat.o(75944);
            }
        }
    }

    /* Access modifiers changed, original: protected */
    public boolean isExitsAction(long j) {
        AppMethodBeat.i(75945);
        if (j < 0) {
            AppMethodBeat.o(75945);
            return false;
        } else if (this.sdkChannel == null) {
            AppMethodBeat.o(75945);
            return false;
        } else {
            Iterator it = this.sdkChannel.getChannelDataItemList().iterator();
            while (it.hasNext()) {
                TMAssistantSDKChannelDataItem tMAssistantSDKChannelDataItem = (TMAssistantSDKChannelDataItem) it.next();
                if (((long) tMAssistantSDKChannelDataItem.mDBIdentity) == j && tMAssistantSDKChannelDataItem.mDataItemEndTime - tMAssistantSDKChannelDataItem.mDataItemStartTime <= 300000) {
                    AppMethodBeat.o(75945);
                    return true;
                }
            }
            AppMethodBeat.o(75945);
            return false;
        }
    }

    /* Access modifiers changed, original: protected */
    public void handleInstall(String str, int i) {
        AppMethodBeat.i(75946);
        if (this.mContext == null) {
            AppMethodBeat.o(75946);
            return;
        }
        Res res = new Res(this.mContext);
        this.dialog.setPositiveBtnEnable(true);
        this.dialog.downloadText.setText(this.mContext.getString(res.string("white_list_positive_install")));
        if (this.mContext == null) {
            TMLog.i(TAG, "handleDownloading context = null!");
            AppMethodBeat.o(75946);
            return;
        }
        this.isInstallFinished = true;
        if (i == 1) {
            AppMethodBeat.o(75946);
            return;
        }
        q.a(this.mContext, new File(str), null, false);
        AppMethodBeat.o(75946);
    }

    /* Access modifiers changed, original: protected */
    public void handleDownloadFailed() {
        AppMethodBeat.i(75947);
        if (this.mContext == null) {
            TMLog.i(TAG, "handleDownloading context = null!");
            AppMethodBeat.o(75947);
            return;
        }
        Res res = new Res(this.mContext);
        this.dialog.setPositiveBtnEnable(true);
        this.dialog.downloadText.setText(this.mContext.getString(res.string("white_list_positive_retry")));
        if (this.dialog.downloadProgressBar.getProgress() > 0) {
            this.dialog.setPositiveBtnBgResource(res.drawable("com_tencent_tmassistant_sdk_button_bg"));
        }
        AppMethodBeat.o(75947);
    }

    /* Access modifiers changed, original: protected */
    public void handleDownloading(long j, long j2) {
        AppMethodBeat.i(75948);
        if (this.mContext == null) {
            TMLog.i(TAG, "handleDownloading context = null!");
            AppMethodBeat.o(75948);
            return;
        }
        String string = this.mContext.getString(new Res(this.mContext).string("white_list_positive_downloading"));
        this.dialog.downloadText.setText(string + ("(" + ((int) ((((float) (100 * j)) + 0.0f) / ((float) j2))) + "%)"));
        this.dialog.downloadProgressBar.setProgress((int) (((((float) j) + 0.0f) / ((float) j2)) * ((float) this.dialog.downloadProgressBar.getMax())));
        TMLog.i(TAG, "handleDownloading : receivedlen:" + j + " | totalLen:" + j2);
        AppMethodBeat.o(75948);
    }

    /* Access modifiers changed, original: protected */
    public void handleDownloadContinue(long j, long j2) {
        AppMethodBeat.i(75949);
        if (this.mContext == null) {
            TMLog.i(TAG, "handleDownloading context = null!");
            AppMethodBeat.o(75949);
            return;
        }
        Res res = new Res(this.mContext);
        String string = this.mContext.getString(res.string("white_list_positive_continue"));
        this.dialog.downloadText.setText(string + ("(" + ((int) ((((float) (100 * j)) + 0.0f) / ((float) j2))) + "%)"));
        this.dialog.downloadProgressBar.setProgress((int) (((((float) j) + 0.0f) / ((float) j2)) * ((float) this.dialog.downloadProgressBar.getMax())));
        if (this.dialog.downloadProgressBar.getProgress() > 0) {
            this.dialog.setPositiveBtnBgResource(res.drawable("com_tencent_tmassistant_sdk_button_bg"));
        }
        AppMethodBeat.o(75949);
    }

    /* Access modifiers changed, original: protected */
    public void startToQQDownloaderAuthorized(String str) {
        AppMethodBeat.i(75950);
        if (this.dialog.isShowing()) {
            this.dialog.dismiss();
        }
        this.mHttpRequest = null;
        this.isInstallFinished = false;
        if (TextUtils.isEmpty(str)) {
            AppMethodBeat.o(75950);
            return;
        }
        TipsInfoLog createTipsInfoLog = TipsInfoReportManager.getInstance().createTipsInfoLog(this.mAuthorizedInfo);
        createTipsInfoLog.authorizedBtnClickCount++;
        TipsInfoReportManager.getInstance().addLogData(createTipsInfoLog);
        if (!(this.mContext == null || this.mOpenSDK == null)) {
            this.mOpenSDK.startToAuthorized(this.mContext, str);
        }
        AppMethodBeat.o(75950);
    }

    /* Access modifiers changed, original: protected */
    public void startDownloadTask(String str, String str2) {
        AppMethodBeat.i(75951);
        if (TextUtils.isEmpty(str)) {
            AppMethodBeat.o(75951);
            return;
        }
        this.dialog.setPositiveBtnEnable(false);
        this.mSubMessageHandler.post(new 7(this, str2, str));
        AppMethodBeat.o(75951);
    }

    /* Access modifiers changed, original: protected */
    public void pauseDownloadTask(String str) {
        AppMethodBeat.i(75952);
        if (TextUtils.isEmpty(str)) {
            AppMethodBeat.o(75952);
        } else if (this.mAuthorizedInfo == null) {
            AppMethodBeat.o(75952);
        } else {
            this.mSubMessageHandler.post(new 8(this, str));
            AppMethodBeat.o(75952);
        }
    }

    /* Access modifiers changed, original: protected */
    public TMAssistantDownloadSDKClient getClient() {
        AppMethodBeat.i(75953);
        if (this.mContext != null) {
            TMAssistantDownloadSDKClient downloadSDKClient;
            if (this.mClient == null) {
                downloadSDKClient = TMAssistantDownloadSDKManager.getInstance(this.mContext).getDownloadSDKClient(CLIENT_NAME);
                downloadSDKClient.registerDownloadTaskListener(this.mDownloadSDKListener);
                this.mClient = downloadSDKClient;
            } else {
                downloadSDKClient = this.mClient;
            }
            AppMethodBeat.o(75953);
            return downloadSDKClient;
        }
        AppMethodBeat.o(75953);
        return null;
    }

    public static String about() {
        return "TMOpenSDKToMsdkManager_2014_04_01_19_51_release_25434";
    }
}
