package com.eclipsesource.v8.debug;

import com.eclipsesource.v8.JavaVoidCallback;
import com.eclipsesource.v8.Releasable;
import com.eclipsesource.v8.V8;
import com.eclipsesource.v8.V8Array;
import com.eclipsesource.v8.V8Function;
import com.eclipsesource.v8.V8Object;
import com.facebook.appevents.codeless.internal.Constants;
import com.tencent.matrix.trace.core.AppMethodBeat;
import java.io.IOException;
import java.net.ServerSocket;
import java.net.Socket;
import java.nio.charset.Charset;
import java.util.LinkedList;
import java.util.List;

public class V8DebugServer {
    private static final String DEBUG_BREAK_HANDLER = "__j2v8_debug_handler";
    public static String DEBUG_OBJECT_NAME = "__j2v8_Debug";
    private static final String HEADER_EMBEDDING_HOST = "Embedding-Host: ";
    private static final String HEADER_PROTOCOL_VERSION = "Protocol-Version: ";
    private static final String HEADER_TYPE = "Type: ";
    private static final String HEADER_V8_VERSION = "V8-Version: ";
    private static final String J2V8_VERSION = "4.0.0";
    private static final String MAKE_BREAK_EVENT = "__j2v8_MakeBreakEvent";
    private static final String MAKE_COMPILE_EVENT = "__j2v8_MakeCompileEvent";
    private static final int PROTOCOL_BUFFER_SIZE = 4096;
    private static final Charset PROTOCOL_CHARSET = Charset.forName("UTF-8");
    private static final byte[] PROTOCOL_CONTENT_LENGTH_BYTES = PROTOCOL_CONTENT_LENGTH_HEADER.getBytes(PROTOCOL_CHARSET);
    private static final String PROTOCOL_CONTENT_LENGTH_HEADER = "Content-Length:";
    private static final String PROTOCOL_EOL = "\r\n";
    private static final byte[] PROTOCOL_EOL_BYTES = PROTOCOL_EOL.getBytes(PROTOCOL_CHARSET);
    private static final String PROTOCOL_VERSION = "1";
    private static final String SET_LISTENER = "setListener";
    private static final String V8_DEBUG_OBJECT = "Debug";
    private static final String V8_VERSION = "4.10.253";
    private Socket client;
    private Object clientLock = new Object();
    private V8Object debugObject;
    private List<String> requests = new LinkedList();
    private V8Object runningStateDcp;
    private V8 runtime;
    private ServerSocket server;
    private V8Object stoppedStateDcp;
    private boolean traceCommunication = false;
    private boolean waitForConnection;

    class EventHandler implements JavaVoidCallback {
        private EventHandler() {
        }

        public void invoke(V8Object v8Object, V8Array v8Array) {
            Throwable e;
            AppMethodBeat.i(74927);
            if (v8Array == null || v8Array.isUndefined()) {
                AppMethodBeat.o(74927);
                return;
            }
            Releasable object;
            Releasable object2;
            try {
                int integer = v8Array.getInteger(0);
                object = v8Array.getObject(1);
                try {
                    object2 = v8Array.getObject(2);
                    try {
                        if (V8DebugServer.this.traceCommunication) {
                            Object obj = "unknown";
                            switch (integer) {
                                case 1:
                                    obj = "Break";
                                    break;
                                case 2:
                                    obj = "Exception";
                                    break;
                                case 3:
                                    obj = "NewFunction";
                                    break;
                                case 4:
                                    obj = "BeforeCompile";
                                    break;
                                case 5:
                                    obj = "AfterCompile";
                                    break;
                                case 6:
                                    obj = "CompileError";
                                    break;
                                case 7:
                                    obj = "PromiseEvent";
                                    break;
                                case 8:
                                    obj = "AsyncTaskEvent";
                                    break;
                            }
                            System.out.println("V8 has emmitted an event of type ".concat(String.valueOf(obj)));
                        }
                        if (V8DebugServer.access$300(V8DebugServer.this)) {
                            switch (integer) {
                                case 1:
                                    V8DebugServer.access$400(V8DebugServer.this, object, object2);
                                    break;
                                case 5:
                                case 6:
                                    V8DebugServer.access$500(V8DebugServer.this, object2);
                                    break;
                            }
                            safeRelease(object);
                            safeRelease(object2);
                            AppMethodBeat.o(74927);
                            return;
                        }
                        safeRelease(object);
                        safeRelease(object2);
                        AppMethodBeat.o(74927);
                    } catch (Exception e2) {
                        e = e2;
                    }
                } catch (Exception e3) {
                    e = e3;
                    object2 = null;
                } catch (Throwable th) {
                    e = th;
                    object2 = null;
                    safeRelease(object);
                    safeRelease(object2);
                    AppMethodBeat.o(74927);
                    throw e;
                }
            } catch (Exception e4) {
                e = e4;
                object2 = null;
                object = null;
                try {
                    V8DebugServer.this.logError(e);
                    safeRelease(object);
                    safeRelease(object2);
                    AppMethodBeat.o(74927);
                } catch (Throwable th2) {
                    e = th2;
                    safeRelease(object);
                    safeRelease(object2);
                    AppMethodBeat.o(74927);
                    throw e;
                }
            } catch (Throwable th3) {
                e = th3;
                object2 = null;
                object = null;
                safeRelease(object);
                safeRelease(object2);
                AppMethodBeat.o(74927);
                throw e;
            }
        }

        private void safeRelease(Releasable releasable) {
            AppMethodBeat.i(74928);
            if (releasable != null) {
                releasable.release();
            }
            AppMethodBeat.o(74928);
        }
    }

    static /* synthetic */ void access$1000(V8DebugServer v8DebugServer, String str, String str2) {
        AppMethodBeat.i(74945);
        v8DebugServer.sendMessage(str, str2);
        AppMethodBeat.o(74945);
    }

    static /* synthetic */ boolean access$300(V8DebugServer v8DebugServer) {
        AppMethodBeat.i(74942);
        boolean isConnected = v8DebugServer.isConnected();
        AppMethodBeat.o(74942);
        return isConnected;
    }

    static /* synthetic */ void access$400(V8DebugServer v8DebugServer, V8Object v8Object, V8Object v8Object2) {
        AppMethodBeat.i(74943);
        v8DebugServer.enterBreakLoop(v8Object, v8Object2);
        AppMethodBeat.o(74943);
    }

    static /* synthetic */ void access$500(V8DebugServer v8DebugServer, V8Object v8Object) {
        AppMethodBeat.i(74944);
        v8DebugServer.sendCompileEvent(v8Object);
        AppMethodBeat.o(74944);
    }

    static {
        AppMethodBeat.i(74946);
        AppMethodBeat.o(74946);
    }

    public static void configureV8ForDebugging() {
        AppMethodBeat.i(74929);
        try {
            V8.setFlags("-expose-debug-as=" + DEBUG_OBJECT_NAME);
            AppMethodBeat.o(74929);
        } catch (Throwable th) {
            AppMethodBeat.o(74929);
        }
    }

    public V8DebugServer(V8 v8, int i, boolean z) {
        AppMethodBeat.i(74930);
        this.runtime = v8;
        this.waitForConnection = z;
        V8Object object = v8.getObject(DEBUG_OBJECT_NAME);
        if (object == null) {
            System.err.println("Cannot initialize debugger server - global debug object not found.");
            AppMethodBeat.o(74930);
            return;
        }
        try {
            this.debugObject = object.getObject(V8_DEBUG_OBJECT);
            object.release();
            v8.executeVoidScript("(function() {\n " + DEBUG_OBJECT_NAME + ".Debug. __j2v8_MakeBreakEvent = function (break_id,breakpoints_hit) {\n  return new " + DEBUG_OBJECT_NAME + ".BreakEvent(break_id,breakpoints_hit);\n }\n " + DEBUG_OBJECT_NAME + ".Debug. __j2v8_MakeCompileEvent = function(script,type) {\n  var scripts = " + DEBUG_OBJECT_NAME + ".Debug.scripts()\n  for (var i in scripts) {\n   if (scripts[i].id == script.id()) {\n     return new " + DEBUG_OBJECT_NAME + ".CompileEvent(scripts[i], type);\n   }\n  }\n  return {toJSONProtocol: function() {return ''}}\n }\n})()");
            try {
                this.server = new ServerSocket(i);
                AppMethodBeat.o(74930);
            } catch (Exception e) {
                logError(e);
                AppMethodBeat.o(74930);
            }
        } catch (Throwable th) {
            object.release();
            AppMethodBeat.o(74930);
        }
    }

    public int getPort() {
        AppMethodBeat.i(74931);
        if (this.server == null || !this.server.isBound()) {
            AppMethodBeat.o(74931);
            return -1;
        }
        int localPort = this.server.getLocalPort();
        AppMethodBeat.o(74931);
        return localPort;
    }

    public void setTraceCommunication(boolean z) {
        this.traceCommunication = z;
    }

    public void start() {
        AppMethodBeat.i(74932);
        if (this.server == null) {
            AppMethodBeat.o(74932);
            return;
        }
        boolean z = this.waitForConnection;
        Thread thread = new Thread(new ClientLoop(this, null), "J2V8 Debugger Server");
        thread.setDaemon(true);
        thread.start();
        setupEventHandler();
        this.runningStateDcp = this.runtime.executeObjectScript("(function() {return new " + DEBUG_OBJECT_NAME + ".DebugCommandProcessor(null, true)})()");
        if (z) {
            synchronized (this.clientLock) {
                while (this.waitForConnection) {
                    try {
                        try {
                            this.clientLock.wait();
                        } catch (InterruptedException e) {
                        }
                    } finally {
                        while (true) {
                        }
                        AppMethodBeat.o(74932);
                    }
                }
            }
            try {
                processRequests(100);
                return;
            } catch (InterruptedException e2) {
            }
        }
        AppMethodBeat.o(74932);
    }

    public void stop() {
        AppMethodBeat.i(74933);
        try {
            this.server.close();
            synchronized (this.clientLock) {
                if (this.client != null) {
                    this.client.close();
                    this.client = null;
                }
            }
        } catch (IOException e) {
            logError(e);
        } catch (Throwable th) {
            while (true) {
                AppMethodBeat.o(74933);
            }
        }
        if (this.runningStateDcp != null) {
            this.runningStateDcp.release();
            this.runningStateDcp = null;
        }
        if (this.debugObject != null) {
            this.debugObject.release();
            this.debugObject = null;
        }
        if (this.stoppedStateDcp != null) {
            this.stoppedStateDcp.release();
            this.stoppedStateDcp = null;
        }
        AppMethodBeat.o(74933);
    }

    private void sendJson(String str) {
        AppMethodBeat.i(74934);
        sendMessage("", str.replace("\\/", "/"));
        AppMethodBeat.o(74934);
    }

    /* Access modifiers changed, original: protected */
    public void logError(Throwable th) {
    }

    private void sendMessage(String str, String str2) {
        AppMethodBeat.i(74935);
        synchronized (this.clientLock) {
            try {
                if (isConnected()) {
                    byte[] bytes = str2.getBytes(PROTOCOL_CHARSET);
                    StringBuilder stringBuilder = new StringBuilder();
                    stringBuilder.append(str);
                    stringBuilder.append(PROTOCOL_CONTENT_LENGTH_HEADER);
                    stringBuilder.append(Integer.toString(bytes.length));
                    stringBuilder.append(PROTOCOL_EOL);
                    stringBuilder.append(PROTOCOL_EOL);
                    this.client.getOutputStream().write(stringBuilder.toString().getBytes(PROTOCOL_CHARSET));
                    if (bytes.length > 0) {
                        this.client.getOutputStream().write(bytes);
                    }
                } else {
                    Object iOException = new IOException("There is no connected client.");
                    throw iOException;
                }
            } finally {
                AppMethodBeat.o(74935);
            }
        }
        AppMethodBeat.o(74935);
    }

    private boolean isConnected() {
        boolean z;
        AppMethodBeat.i(74936);
        synchronized (this.clientLock) {
            try {
                z = (this.server == null || this.client == null || !this.client.isConnected()) ? false : true;
            } finally {
                while (true) {
                }
                AppMethodBeat.o(74936);
            }
        }
        return z;
    }

    public void processRequests(long j) {
        AppMethodBeat.i(74937);
        if (this.server == null) {
            AppMethodBeat.o(74937);
            return;
        }
        long currentTimeMillis = System.currentTimeMillis();
        while (true) {
            String[] strArr;
            synchronized (this.requests) {
                try {
                    strArr = (String[]) this.requests.toArray(new String[this.requests.size()]);
                    this.requests.clear();
                } catch (Throwable th) {
                    while (true) {
                        AppMethodBeat.o(74937);
                    }
                }
            }
            for (String processRequest : strArr) {
                try {
                    processRequest(processRequest);
                } catch (Exception e) {
                    logError(e);
                }
            }
            if (strArr.length <= 0) {
                if (j > 0) {
                    Thread.sleep(10);
                }
                if (j <= 0 || currentTimeMillis + j <= System.currentTimeMillis()) {
                    AppMethodBeat.o(74937);
                }
            }
        }
        AppMethodBeat.o(74937);
    }

    private void processRequest(String str) {
        AppMethodBeat.i(74938);
        if (this.traceCommunication) {
            System.out.println("Got message: \n" + str.substring(0, Math.min(str.length(), Constants.APP_INDEXING_SCHEDULE_INTERVAL_MS)));
        }
        V8Array v8Array = new V8Array(this.runtime);
        v8Array.push(str);
        V8Object v8Object = this.stoppedStateDcp != null ? this.stoppedStateDcp : this.runningStateDcp;
        String obj = v8Object.executeFunction("processDebugJSONRequest", v8Array).toString();
        if (this.stoppedStateDcp == null && obj.contains("\"running\":false")) {
            obj = obj.replace("\"running\":false", "\"running\":true").replace("\"success\":true", "\"success\":false").replace("{\"", "{\"message\":\"Client requested suspension is not supported on J2V8.\",\"");
            v8Object.add("running_", true);
        }
        String str2 = obj;
        if (this.traceCommunication) {
            System.out.println("Returning response: \n" + str2.substring(0, Math.min(str2.length(), Constants.APP_INDEXING_SCHEDULE_INTERVAL_MS)));
        }
        sendJson(str2);
        AppMethodBeat.o(74938);
    }

    private void setupEventHandler() {
        Throwable th;
        V8Function v8Function;
        AppMethodBeat.i(74939);
        this.debugObject.registerJavaMethod(new EventHandler(), DEBUG_BREAK_HANDLER);
        V8Array push;
        try {
            V8Function v8Function2 = (V8Function) this.debugObject.getObject(DEBUG_BREAK_HANDLER);
            try {
                push = new V8Array(this.runtime).push(v8Function2);
            } catch (Throwable th2) {
                th = th2;
                push = null;
                v8Function = v8Function2;
            }
            try {
                this.debugObject.executeFunction(SET_LISTENER, push);
                if (!(v8Function2 == null || v8Function2.isReleased())) {
                    v8Function2.release();
                }
                if (push == null || push.isReleased()) {
                    AppMethodBeat.o(74939);
                    return;
                }
                push.release();
                AppMethodBeat.o(74939);
            } catch (Throwable th3) {
                th = th3;
                v8Function = v8Function2;
                if (!(v8Function == null || v8Function.isReleased())) {
                    v8Function.release();
                }
                if (!(push == null || push.isReleased())) {
                    push.release();
                }
                AppMethodBeat.o(74939);
                throw th;
            }
        } catch (Throwable th4) {
            th = th4;
            push = null;
            v8Function = null;
            v8Function.release();
            push.release();
            AppMethodBeat.o(74939);
            throw th;
        }
    }

    private void enterBreakLoop(V8Object v8Object, V8Object v8Object2) {
        Throwable th;
        AppMethodBeat.i(74940);
        V8Array v8Array;
        try {
            v8Array = new V8Array(this.runtime);
            v8Array.push(false);
            this.stoppedStateDcp = v8Object.executeObjectFunction("debugCommandProcessor", v8Array);
            v8Array.release();
            int integer = v8Object.getInteger("break_id");
            V8Array array = v8Object2.getArray("break_points_hit_");
            V8Array v8Array2 = new V8Array(this.runtime);
            V8Object executeObjectFunction;
            try {
                v8Array2.push(integer);
                v8Array2.push(array);
                executeObjectFunction = this.debugObject.executeObjectFunction(MAKE_BREAK_EVENT, v8Array2);
                try {
                    String executeStringFunction = executeObjectFunction.executeStringFunction("toJSONProtocol", null);
                    if (this.traceCommunication) {
                        System.out.println("Sending event (Break):\n".concat(String.valueOf(executeStringFunction)));
                    }
                    sendJson(executeStringFunction);
                    v8Array2.release();
                    array.release();
                    if (executeObjectFunction != null) {
                        executeObjectFunction.release();
                    }
                    while (isConnected() && !this.stoppedStateDcp.executeBooleanFunction("isRunning", null)) {
                        try {
                            processRequests(10);
                        } catch (InterruptedException e) {
                        }
                    }
                    this.stoppedStateDcp.release();
                    this.stoppedStateDcp = null;
                    AppMethodBeat.o(74940);
                } catch (Throwable th2) {
                    th = th2;
                    v8Array2.release();
                    array.release();
                    if (executeObjectFunction != null) {
                        executeObjectFunction.release();
                    }
                    AppMethodBeat.o(74940);
                    throw th;
                }
            } catch (Throwable th3) {
                th = th3;
                executeObjectFunction = null;
            }
        } catch (Throwable th4) {
            this.stoppedStateDcp.release();
            this.stoppedStateDcp = null;
            AppMethodBeat.o(74940);
        }
    }

    private void sendCompileEvent(V8Object v8Object) {
        V8Object v8Object2 = null;
        AppMethodBeat.i(74941);
        if (isConnected()) {
            int integer = v8Object.getInteger("type_");
            V8Object object = v8Object.getObject("script_");
            V8Array v8Array = new V8Array(this.runtime);
            try {
                v8Array.push(object);
                v8Array.push(integer);
                v8Object2 = this.debugObject.executeObjectFunction(MAKE_COMPILE_EVENT, v8Array);
                String executeStringFunction = v8Object2.executeStringFunction("toJSONProtocol", null);
                if (this.traceCommunication) {
                    System.out.println("Sending event (CompileEvent):\n" + executeStringFunction.substring(0, Math.min(executeStringFunction.length(), Constants.APP_INDEXING_SCHEDULE_INTERVAL_MS)));
                }
                if (executeStringFunction.length() > 0) {
                    sendJson(executeStringFunction);
                }
                v8Array.release();
                object.release();
                if (v8Object2 != null) {
                    v8Object2.release();
                    AppMethodBeat.o(74941);
                    return;
                }
                AppMethodBeat.o(74941);
            } catch (Throwable th) {
                v8Array.release();
                object.release();
                if (v8Object2 != null) {
                    v8Object2.release();
                }
                AppMethodBeat.o(74941);
            }
        } else {
            AppMethodBeat.o(74941);
        }
    }
}
