package com.google.android.gms.common.data;

import android.content.Context;
import android.os.Bundle;
import com.google.android.gms.common.data.TextFilterable.StringFilter;
import com.google.android.gms.common.util.VisibleForTesting;
import com.tencent.matrix.trace.core.AppMethodBeat;
import java.util.ArrayList;
import java.util.Iterator;

@VisibleForTesting
public final class ConcatenatedDataBuffer<T> implements DataBuffer<T>, ExclusionFilterable, TextFilterable {
    private Bundle mBundle;
    private final ArrayList<DataBuffer<T>> zznf = new ArrayList();
    private final ArrayList<Integer> zzng = new ArrayList();
    private int zznh;

    public ConcatenatedDataBuffer() {
        AppMethodBeat.i(61020);
        AppMethodBeat.o(61020);
    }

    public ConcatenatedDataBuffer(DataBuffer<T> dataBuffer) {
        AppMethodBeat.i(61021);
        append(dataBuffer);
        AppMethodBeat.o(61021);
    }

    public static <T> ConcatenatedDataBuffer<T> extend(ConcatenatedDataBuffer<T> concatenatedDataBuffer, DataBuffer<T> dataBuffer) {
        AppMethodBeat.i(61029);
        ConcatenatedDataBuffer concatenatedDataBuffer2 = new ConcatenatedDataBuffer();
        ArrayList arrayList = concatenatedDataBuffer.zznf;
        int size = arrayList.size();
        int i = 0;
        while (i < size) {
            Object obj = arrayList.get(i);
            i++;
            concatenatedDataBuffer2.append((DataBuffer) obj);
        }
        concatenatedDataBuffer2.append(dataBuffer);
        AppMethodBeat.o(61029);
        return concatenatedDataBuffer2;
    }

    public final void append(DataBuffer<T> dataBuffer) {
        AppMethodBeat.i(61024);
        if (dataBuffer == null) {
            AppMethodBeat.o(61024);
            return;
        }
        synchronized (this) {
            try {
                Bundle metadata;
                if (this.zznf.isEmpty()) {
                    this.mBundle = new Bundle();
                    metadata = dataBuffer.getMetadata();
                    if (metadata != null) {
                        this.mBundle.putString("prev_page_token", metadata.getString("prev_page_token"));
                    }
                }
                this.zznf.add(dataBuffer);
                computeCounts();
                metadata = dataBuffer.getMetadata();
                if (metadata != null) {
                    this.mBundle.putString("next_page_token", metadata.getString("next_page_token"));
                } else {
                    this.mBundle.remove("next_page_token");
                }
            } finally {
                AppMethodBeat.o(61024);
            }
        }
    }

    public final void clearFilters() {
        AppMethodBeat.i(61032);
        int size = this.zznf.size();
        for (int i = 0; i < size; i++) {
            DataBuffer dataBuffer = (DataBuffer) this.zznf.get(i);
            if (dataBuffer instanceof ExclusionFilterable) {
                ((ExclusionFilterable) dataBuffer).clearFilters();
            }
        }
        computeCounts();
        AppMethodBeat.o(61032);
    }

    @Deprecated
    public final void close() {
        AppMethodBeat.i(61025);
        release();
        AppMethodBeat.o(61025);
    }

    public final void computeCounts() {
        AppMethodBeat.i(61028);
        this.zzng.clear();
        int size = this.zznf.size();
        int i = 0;
        int i2 = 0;
        while (i < size) {
            DataBuffer dataBuffer = (DataBuffer) this.zznf.get(i);
            int count = dataBuffer != null ? dataBuffer.getCount() + i2 : i2;
            this.zzng.add(Integer.valueOf(count));
            i++;
            i2 = count;
        }
        this.zznh = i2;
        AppMethodBeat.o(61028);
    }

    public final void filterOut(String str) {
        AppMethodBeat.i(61030);
        int size = this.zznf.size();
        for (int i = 0; i < size; i++) {
            DataBuffer dataBuffer = (DataBuffer) this.zznf.get(i);
            if (dataBuffer instanceof ExclusionFilterable) {
                ((ExclusionFilterable) dataBuffer).filterOut(str);
            }
        }
        computeCounts();
        AppMethodBeat.o(61030);
    }

    public final T get(int i) {
        T t;
        AppMethodBeat.i(61022);
        synchronized (this) {
            try {
                int size = this.zznf.size();
                for (int i2 = 0; i2 < size; i2++) {
                    int intValue = ((Integer) this.zzng.get(i2)).intValue();
                    if (i < intValue) {
                        DataBuffer dataBuffer = (DataBuffer) this.zznf.get(i2);
                        if (dataBuffer != null) {
                            t = dataBuffer.get((i - intValue) + dataBuffer.getCount());
                            break;
                        }
                    }
                }
                t = null;
                AppMethodBeat.o(61022);
            } finally {
                while (true) {
                }
                AppMethodBeat.o(61022);
            }
        }
        return t;
    }

    public final int getCount() {
        int i;
        synchronized (this) {
            i = this.zznh;
        }
        return i;
    }

    public final Bundle getMetadata() {
        Bundle bundle;
        synchronized (this) {
            bundle = this.mBundle;
        }
        return bundle;
    }

    @Deprecated
    public final boolean isClosed() {
        return false;
    }

    public final Iterator<T> iterator() {
        AppMethodBeat.i(61026);
        DataBufferIterator dataBufferIterator = new DataBufferIterator(this);
        AppMethodBeat.o(61026);
        return dataBufferIterator;
    }

    public final void release() {
        AppMethodBeat.i(61023);
        synchronized (this) {
            try {
                int size = this.zznf.size();
                for (int i = 0; i < size; i++) {
                    DataBuffer dataBuffer = (DataBuffer) this.zznf.get(i);
                    if (dataBuffer != null) {
                        dataBuffer.release();
                    }
                }
                this.zznf.clear();
                this.zzng.clear();
                this.mBundle = null;
            } finally {
                while (true) {
                }
                AppMethodBeat.o(61023);
            }
        }
    }

    public final void setFilterTerm(Context context, StringFilter stringFilter, String str) {
        AppMethodBeat.i(61034);
        int size = this.zznf.size();
        for (int i = 0; i < size; i++) {
            DataBuffer dataBuffer = (DataBuffer) this.zznf.get(i);
            if (dataBuffer instanceof TextFilterable) {
                ((TextFilterable) dataBuffer).setFilterTerm(context, stringFilter, str);
            }
        }
        computeCounts();
        AppMethodBeat.o(61034);
    }

    public final void setFilterTerm(Context context, String str) {
        AppMethodBeat.i(61033);
        int size = this.zznf.size();
        for (int i = 0; i < size; i++) {
            DataBuffer dataBuffer = (DataBuffer) this.zznf.get(i);
            if (dataBuffer instanceof TextFilterable) {
                ((TextFilterable) dataBuffer).setFilterTerm(context, str);
            }
        }
        computeCounts();
        AppMethodBeat.o(61033);
    }

    public final Iterator<T> singleRefIterator() {
        AppMethodBeat.i(61027);
        Iterator it = iterator();
        AppMethodBeat.o(61027);
        return it;
    }

    public final void unfilter(String str) {
        AppMethodBeat.i(61031);
        int size = this.zznf.size();
        for (int i = 0; i < size; i++) {
            DataBuffer dataBuffer = (DataBuffer) this.zznf.get(i);
            if (dataBuffer instanceof ExclusionFilterable) {
                ((ExclusionFilterable) dataBuffer).unfilter(str);
            }
        }
        computeCounts();
        AppMethodBeat.o(61031);
    }
}
