package com.tencent.qqmusic.mediaplayer;

import android.os.Handler;
import android.os.Looper;
import com.eclipsesource.v8.BuildConfig;
import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.qqmusic.mediaplayer.BaseDecodeDataComponent.HandleDecodeDataCallback;
import com.tencent.qqmusic.mediaplayer.audiofx.IAudioListener;
import com.tencent.qqmusic.mediaplayer.codec.BaseDecoder;
import com.tencent.qqmusic.mediaplayer.perf.PerformanceTracer;
import com.tencent.qqmusic.mediaplayer.perf.PrefInfoCollector;
import com.tencent.qqmusic.mediaplayer.seektable.NativeSeekTable;
import com.tencent.qqmusic.mediaplayer.seektable.SeekTable;
import com.tencent.qqmusic.mediaplayer.upstream.IDataSource;
import com.tencent.qqmusic.mediaplayer.upstream.INativeDataSource;
import com.tencent.qqmusic.mediaplayer.util.Logger;
import java.util.concurrent.atomic.AtomicInteger;

class CorePlayer implements HandleDecodeDataCallback, Runnable {
    private static final AtomicInteger PLAYER_ID_CREATOR = new AtomicInteger(0);
    private static final String TAG = "CorePlayer";
    private final PlayerCallback mCallback;
    private IDataSource mDataSource;
    private final BaseDecoder mDecoder;
    private final Handler mEventHandler;
    protected AudioInformation mInformation;
    volatile boolean mIsExit = false;
    private INativeDataSource mNativeDataSource;
    private BaseDecodeDataComponent mPcmCompnent;
    private int mPlayerID = PLAYER_ID_CREATOR.addAndGet(1);
    private int mPlayerMode = 0;
    protected final PrefInfoCollector mPrefInfoCollector = PrefInfoCollector.getInstance();
    private final PlayerStateRunner mStateRunner = new PlayerStateRunner(Integer.valueOf(0));
    private String mThreadName = "Unnamed";
    private final PerformanceTracer performanceTracer = new PerformanceTracer();

    static {
        AppMethodBeat.i(104670);
        AppMethodBeat.o(104670);
    }

    CorePlayer(IDataSource iDataSource, INativeDataSource iNativeDataSource, PlayerCallback playerCallback, Looper looper, BaseDecoder baseDecoder) {
        AppMethodBeat.i(104638);
        IllegalArgumentException illegalArgumentException;
        if (iDataSource != null && iNativeDataSource != null) {
            illegalArgumentException = new IllegalArgumentException("you can't set IDataSource and INativeDataSource at the same time!");
            AppMethodBeat.o(104638);
            throw illegalArgumentException;
        } else if (iDataSource == null && iNativeDataSource == null) {
            illegalArgumentException = new IllegalArgumentException("at least on data source is required!");
            AppMethodBeat.o(104638);
            throw illegalArgumentException;
        } else {
            this.mEventHandler = new Handler(looper);
            this.mDecoder = baseDecoder;
            this.mDataSource = iDataSource;
            this.mNativeDataSource = iNativeDataSource;
            this.mCallback = playerCallback;
            this.mStateRunner.transfer(Integer.valueOf(1));
            AppMethodBeat.o(104638);
        }
    }

    /* Access modifiers changed, original: 0000 */
    public void setThreadName(String str) {
        this.mThreadName = str;
    }

    private void exitNotCallback() {
        AppMethodBeat.i(104639);
        Logger.i(TAG, axiliary("exitNotCallback"));
        this.mIsExit = true;
        AppMethodBeat.o(104639);
    }

    /* Access modifiers changed, original: 0000 */
    public void changePlayThreadPriorityImmediately() {
        AppMethodBeat.i(104640);
        Logger.d(TAG, axiliary("changePlayThreadPriorityImmediately"));
        if (this.mPcmCompnent == null) {
            AppMethodBeat.o(104640);
            return;
        }
        this.mPcmCompnent.changePlayThreadPriorityImmediately();
        AppMethodBeat.o(104640);
    }

    /* JADX WARNING: Removed duplicated region for block: B:63:0x01a5  */
    /* JADX WARNING: Removed duplicated region for block: B:81:0x0219  */
    public void run() {
        /*
        r10 = this;
        r4 = 1;
        r9 = 0;
        r8 = 104641; // 0x198c1 float:1.46633E-40 double:5.16995E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r8);
        com.tencent.qqmusic.mediaplayer.util.CpuInfoUtil.startProcessInfoOutput();
        r0 = "CorePlayer";
        r1 = new java.lang.StringBuilder;
        r2 = "run, thread: ";
        r1.<init>(r2);
        r2 = java.lang.Thread.currentThread();
        r2 = r2.getName();
        r1 = r1.append(r2);
        r1 = r1.toString();
        r1 = r10.axiliary(r1);
        com.tencent.qqmusic.mediaplayer.util.Logger.i(r0, r1);
        r0 = r10.mCallback;	 Catch:{ Throwable -> 0x0141 }
        r0.playThreadStart(r10);	 Catch:{ Throwable -> 0x0141 }
        r0 = r10.mDataSource;	 Catch:{ Throwable -> 0x0141 }
        if (r0 == 0) goto L_0x011e;
    L_0x0036:
        r0 = r10.mDecoder;	 Catch:{ Throwable -> 0x0141 }
        r1 = r10.mDataSource;	 Catch:{ Throwable -> 0x0141 }
        r0 = r0.init(r1);	 Catch:{ Throwable -> 0x0141 }
        r1 = "CorePlayer";
        r2 = "mDecoder init from dataSource: ";
        r3 = java.lang.String.valueOf(r0);	 Catch:{ Throwable -> 0x0141 }
        r2 = r2.concat(r3);	 Catch:{ Throwable -> 0x0141 }
        r2 = r10.axiliary(r2);	 Catch:{ Throwable -> 0x0141 }
        com.tencent.qqmusic.mediaplayer.util.Logger.i(r1, r2);	 Catch:{ Throwable -> 0x0141 }
    L_0x0053:
        r1 = -9;
        if (r0 != r1) goto L_0x0246;
    L_0x0057:
        r0 = "CorePlayer";
        r1 = "empty file, maybe external sdcard or other permission issue";
        r1 = r10.axiliary(r1);	 Catch:{ Throwable -> 0x0141 }
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r0, r1);	 Catch:{ Throwable -> 0x0141 }
        r0 = r10.mStateRunner;	 Catch:{ Throwable -> 0x0141 }
        r1 = 9;
        r1 = java.lang.Integer.valueOf(r1);	 Catch:{ Throwable -> 0x0141 }
        r0.transfer(r1);	 Catch:{ Throwable -> 0x0141 }
        r0 = 91;
        r1 = 100;
        r10.callExceptionCallback(r0, r1);	 Catch:{ Throwable -> 0x0141 }
    L_0x0076:
        r0 = com.tencent.qqmusic.mediaplayer.PlayerConfigManager.getInstance();	 Catch:{ Throwable -> 0x039e }
        r0.setCommonPlayerRef(r10);	 Catch:{ Throwable -> 0x039e }
        r0 = r10.mInformation;	 Catch:{ Throwable -> 0x039e }
        if (r0 == 0) goto L_0x00b3;
    L_0x0081:
        r0 = r10.mIsExit;	 Catch:{ Throwable -> 0x039e }
        if (r0 != 0) goto L_0x00b3;
    L_0x0085:
        r0 = r10.mPcmCompnent;	 Catch:{ Throwable -> 0x039e }
        if (r0 != 0) goto L_0x00b3;
    L_0x0089:
        r0 = r10.mInformation;	 Catch:{ Throwable -> 0x039e }
        r0 = r0.getDuration();	 Catch:{ Throwable -> 0x039e }
        r2 = 2000; // 0x7d0 float:2.803E-42 double:9.88E-321;
        r0 = (r0 > r2 ? 1 : (r0 == r2 ? 0 : -1));
        if (r0 < 0) goto L_0x0099;
    L_0x0095:
        r0 = r10.mPlayerMode;	 Catch:{ Throwable -> 0x039e }
        if (r0 != r4) goto L_0x0389;
    L_0x0099:
        r0 = r10.mPlayerMode;	 Catch:{ Throwable -> 0x039e }
        if (r0 == r4) goto L_0x00a0;
    L_0x009d:
        r0 = 1;
        r10.mPlayerMode = r0;	 Catch:{ Throwable -> 0x039e }
    L_0x00a0:
        r0 = new com.tencent.qqmusic.mediaplayer.StaticDecodeDataComponent;	 Catch:{ Throwable -> 0x039e }
        r2 = r10.mStateRunner;	 Catch:{ Throwable -> 0x039e }
        r3 = r10.mInformation;	 Catch:{ Throwable -> 0x039e }
        r4 = r10.mCallback;	 Catch:{ Throwable -> 0x039e }
        r6 = r10.mEventHandler;	 Catch:{ Throwable -> 0x039e }
        r7 = r10.mPlayerID;	 Catch:{ Throwable -> 0x039e }
        r1 = r10;
        r5 = r10;
        r0.<init>(r1, r2, r3, r4, r5, r6, r7);	 Catch:{ Throwable -> 0x039e }
        r10.mPcmCompnent = r0;	 Catch:{ Throwable -> 0x039e }
    L_0x00b3:
        r0 = r10.mPcmCompnent;	 Catch:{ Throwable -> 0x039e }
        if (r0 == 0) goto L_0x00bc;
    L_0x00b7:
        r0 = r10.mPcmCompnent;	 Catch:{ Throwable -> 0x039e }
        r0.handleDecodeData();	 Catch:{ Throwable -> 0x039e }
    L_0x00bc:
        r0 = r10.mPcmCompnent;
        if (r0 == 0) goto L_0x0408;
    L_0x00c0:
        r0 = "CorePlayer";
        r1 = new java.lang.StringBuilder;
        r2 = "thread finally, mIsExit = ";
        r1.<init>(r2);
        r2 = r10.mIsExit;
        r1 = r1.append(r2);
        r1 = r1.toString();
        r1 = r10.axiliary(r1);
        com.tencent.qqmusic.mediaplayer.util.Logger.i(r0, r1);
    L_0x00dc:
        com.tencent.qqmusic.mediaplayer.util.CpuInfoUtil.stopProcessInfoOutput();
        r0 = r10.mDecoder;	 Catch:{ Throwable -> 0x0417 }
        r0.release();	 Catch:{ Throwable -> 0x0417 }
    L_0x00e4:
        r0 = r10.mDataSource;
        if (r0 == 0) goto L_0x00ed;
    L_0x00e8:
        r0 = r10.mDataSource;	 Catch:{ IOException -> 0x0438 }
        r0.close();	 Catch:{ IOException -> 0x0438 }
    L_0x00ed:
        r0 = r10.mPcmCompnent;
        if (r0 == 0) goto L_0x00f6;
    L_0x00f1:
        r0 = r10.mPcmCompnent;
        r0.release();
    L_0x00f6:
        r10.mPlayerMode = r9;
        r0 = "CorePlayer";
        r1 = new java.lang.StringBuilder;
        r2 = "exit, thread: ";
        r1.<init>(r2);
        r2 = java.lang.Thread.currentThread();
        r2 = r2.getName();
        r1 = r1.append(r2);
        r1 = r1.toString();
        r1 = r10.axiliary(r1);
        com.tencent.qqmusic.mediaplayer.util.Logger.i(r0, r1);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
    L_0x011d:
        return;
    L_0x011e:
        r0 = r10.mNativeDataSource;	 Catch:{ Throwable -> 0x0141 }
        if (r0 == 0) goto L_0x01d3;
    L_0x0122:
        r0 = r10.mDecoder;	 Catch:{ Throwable -> 0x0141 }
        r1 = r10.mNativeDataSource;	 Catch:{ Throwable -> 0x0141 }
        r0 = r0.init(r1);	 Catch:{ Throwable -> 0x0141 }
        r1 = "CorePlayer";
        r2 = "mDecoder init from native dataSource: ";
        r3 = java.lang.String.valueOf(r0);	 Catch:{ Throwable -> 0x0141 }
        r2 = r2.concat(r3);	 Catch:{ Throwable -> 0x0141 }
        r2 = r10.axiliary(r2);	 Catch:{ Throwable -> 0x0141 }
        com.tencent.qqmusic.mediaplayer.util.Logger.i(r1, r2);	 Catch:{ Throwable -> 0x0141 }
        goto L_0x0053;
    L_0x0141:
        r0 = move-exception;
        r1 = 62;
        r2 = r0 instanceof com.tencent.qqmusic.mediaplayer.SoNotFindException;	 Catch:{ Throwable -> 0x039e }
        if (r2 == 0) goto L_0x0330;
    L_0x0148:
        r1 = 69;
    L_0x014a:
        r2 = "CorePlayer";
        r3 = "不留痕迹的退出 时机：初始化时 step = 2";
        r3 = r10.axiliary(r3);	 Catch:{ Throwable -> 0x039e }
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r2, r3);	 Catch:{ Throwable -> 0x039e }
        r2 = r10.mStateRunner;	 Catch:{ Throwable -> 0x039e }
        r3 = 9;
        r3 = java.lang.Integer.valueOf(r3);	 Catch:{ Throwable -> 0x039e }
        r2.transfer(r3);	 Catch:{ Throwable -> 0x039e }
        r2 = 91;
        r10.callExceptionCallback(r2, r1);	 Catch:{ Throwable -> 0x039e }
        r1 = "CorePlayer";
        r2 = "[run] init decoder throws an exception!";
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r1, r2, r0);	 Catch:{ Throwable -> 0x039e }
        r0 = r10.mPcmCompnent;
        if (r0 == 0) goto L_0x0338;
    L_0x0174:
        r0 = "CorePlayer";
        r1 = new java.lang.StringBuilder;
        r2 = "thread finally, mIsExit = ";
        r1.<init>(r2);
        r2 = r10.mIsExit;
        r1 = r1.append(r2);
        r1 = r1.toString();
        r1 = r10.axiliary(r1);
        com.tencent.qqmusic.mediaplayer.util.Logger.i(r0, r1);
    L_0x0190:
        com.tencent.qqmusic.mediaplayer.util.CpuInfoUtil.stopProcessInfoOutput();
        r0 = r10.mDecoder;	 Catch:{ Throwable -> 0x0347 }
        r0.release();	 Catch:{ Throwable -> 0x0347 }
    L_0x0198:
        r0 = r10.mDataSource;
        if (r0 == 0) goto L_0x01a1;
    L_0x019c:
        r0 = r10.mDataSource;	 Catch:{ IOException -> 0x0368 }
        r0.close();	 Catch:{ IOException -> 0x0368 }
    L_0x01a1:
        r0 = r10.mPcmCompnent;
        if (r0 == 0) goto L_0x01aa;
    L_0x01a5:
        r0 = r10.mPcmCompnent;
        r0.release();
    L_0x01aa:
        r10.mPlayerMode = r9;
        r0 = "CorePlayer";
        r1 = new java.lang.StringBuilder;
        r2 = "exit, thread: ";
        r1.<init>(r2);
        r2 = java.lang.Thread.currentThread();
        r2 = r2.getName();
        r1 = r1.append(r2);
        r1 = r1.toString();
        r1 = r10.axiliary(r1);
        com.tencent.qqmusic.mediaplayer.util.Logger.i(r0, r1);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        goto L_0x011d;
    L_0x01d3:
        r0 = -1;
        r1 = "CorePlayer";
        r2 = "[run] no dataSource!";
        r2 = r10.axiliary(r2);	 Catch:{ Throwable -> 0x0141 }
        com.tencent.qqmusic.mediaplayer.util.Logger.i(r1, r2);	 Catch:{ Throwable -> 0x0141 }
        goto L_0x0053;
    L_0x01e3:
        r0 = move-exception;
        r1 = r10.mPcmCompnent;
        if (r1 == 0) goto L_0x04aa;
    L_0x01e8:
        r1 = "CorePlayer";
        r2 = new java.lang.StringBuilder;
        r3 = "thread finally, mIsExit = ";
        r2.<init>(r3);
        r3 = r10.mIsExit;
        r2 = r2.append(r3);
        r2 = r2.toString();
        r2 = r10.axiliary(r2);
        com.tencent.qqmusic.mediaplayer.util.Logger.i(r1, r2);
    L_0x0204:
        com.tencent.qqmusic.mediaplayer.util.CpuInfoUtil.stopProcessInfoOutput();
        r1 = r10.mDecoder;	 Catch:{ Throwable -> 0x04b9 }
        r1.release();	 Catch:{ Throwable -> 0x04b9 }
    L_0x020c:
        r1 = r10.mDataSource;
        if (r1 == 0) goto L_0x0215;
    L_0x0210:
        r1 = r10.mDataSource;	 Catch:{ IOException -> 0x04da }
        r1.close();	 Catch:{ IOException -> 0x04da }
    L_0x0215:
        r1 = r10.mPcmCompnent;
        if (r1 == 0) goto L_0x021e;
    L_0x0219:
        r1 = r10.mPcmCompnent;
        r1.release();
    L_0x021e:
        r10.mPlayerMode = r9;
        r1 = "CorePlayer";
        r2 = new java.lang.StringBuilder;
        r3 = "exit, thread: ";
        r2.<init>(r3);
        r3 = java.lang.Thread.currentThread();
        r3 = r3.getName();
        r2 = r2.append(r3);
        r2 = r2.toString();
        r2 = r10.axiliary(r2);
        com.tencent.qqmusic.mediaplayer.util.Logger.i(r1, r2);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        throw r0;
    L_0x0246:
        if (r0 == 0) goto L_0x0326;
    L_0x0248:
        r1 = "CorePlayer";
        r2 = "不留痕迹的退出 时机：初始化时 step = 1";
        r2 = r10.axiliary(r2);	 Catch:{ Throwable -> 0x0141 }
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r1, r2);	 Catch:{ Throwable -> 0x0141 }
        r1 = r10.mStateRunner;	 Catch:{ Throwable -> 0x0141 }
        r2 = 9;
        r2 = java.lang.Integer.valueOf(r2);	 Catch:{ Throwable -> 0x0141 }
        r1.transfer(r2);	 Catch:{ Throwable -> 0x0141 }
        r1 = -2;
        if (r0 != r1) goto L_0x02d4;
    L_0x0263:
        r0 = 55;
    L_0x0265:
        r1 = 91;
        r10.callExceptionCallback(r1, r0);	 Catch:{ Throwable -> 0x0141 }
        r0 = 91;
        r1 = 62;
        r10.callExceptionCallback(r0, r1);	 Catch:{ Throwable -> 0x0141 }
        r0 = r10.mPcmCompnent;
        if (r0 == 0) goto L_0x02d7;
    L_0x0275:
        r0 = "CorePlayer";
        r1 = new java.lang.StringBuilder;
        r2 = "thread finally, mIsExit = ";
        r1.<init>(r2);
        r2 = r10.mIsExit;
        r1 = r1.append(r2);
        r1 = r1.toString();
        r1 = r10.axiliary(r1);
        com.tencent.qqmusic.mediaplayer.util.Logger.i(r0, r1);
    L_0x0291:
        com.tencent.qqmusic.mediaplayer.util.CpuInfoUtil.stopProcessInfoOutput();
        r0 = r10.mDecoder;	 Catch:{ Throwable -> 0x02e5 }
        r0.release();	 Catch:{ Throwable -> 0x02e5 }
    L_0x0299:
        r0 = r10.mDataSource;
        if (r0 == 0) goto L_0x02a2;
    L_0x029d:
        r0 = r10.mDataSource;	 Catch:{ IOException -> 0x0305 }
        r0.close();	 Catch:{ IOException -> 0x0305 }
    L_0x02a2:
        r0 = r10.mPcmCompnent;
        if (r0 == 0) goto L_0x02ab;
    L_0x02a6:
        r0 = r10.mPcmCompnent;
        r0.release();
    L_0x02ab:
        r10.mPlayerMode = r9;
        r0 = "CorePlayer";
        r1 = new java.lang.StringBuilder;
        r2 = "exit, thread: ";
        r1.<init>(r2);
        r2 = java.lang.Thread.currentThread();
        r2 = r2.getName();
        r1 = r1.append(r2);
        r1 = r1.toString();
        r1 = r10.axiliary(r1);
        com.tencent.qqmusic.mediaplayer.util.Logger.i(r0, r1);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        goto L_0x011d;
    L_0x02d4:
        r0 = 62;
        goto L_0x0265;
    L_0x02d7:
        r0 = "CorePlayer";
        r1 = "thread finally, ERROR!!!, no mPcmCompnent";
        r1 = r10.axiliary(r1);
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r0, r1);
        goto L_0x0291;
    L_0x02e5:
        r0 = move-exception;
        r1 = "CorePlayer";
        r2 = new java.lang.StringBuilder;
        r3 = "release throw a exception = ";
        r2.<init>(r3);
        r3 = r0.getMessage();
        r2 = r2.append(r3);
        r2 = r2.toString();
        r2 = r10.axiliary(r2);
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r1, r2, r0);
        goto L_0x0299;
    L_0x0305:
        r0 = move-exception;
        r1 = "CorePlayer";
        r2 = new java.lang.StringBuilder;
        r3 = "release dataSource throw a exception = ";
        r2.<init>(r3);
        r3 = r0.getMessage();
        r2 = r2.append(r3);
        r2 = r2.toString();
        r2 = r10.axiliary(r2);
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r1, r2, r0);
        goto L_0x02a2;
    L_0x0326:
        r0 = r10.mDecoder;	 Catch:{ Throwable -> 0x0141 }
        r0 = r0.getAudioInformation();	 Catch:{ Throwable -> 0x0141 }
        r10.mInformation = r0;	 Catch:{ Throwable -> 0x0141 }
        goto L_0x0076;
    L_0x0330:
        r2 = r0 instanceof java.lang.UnsatisfiedLinkError;	 Catch:{ Throwable -> 0x039e }
        if (r2 == 0) goto L_0x014a;
    L_0x0334:
        r1 = 60;
        goto L_0x014a;
    L_0x0338:
        r0 = "CorePlayer";
        r1 = "thread finally, ERROR!!!, no mPcmCompnent";
        r1 = r10.axiliary(r1);
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r0, r1);
        goto L_0x0190;
    L_0x0347:
        r0 = move-exception;
        r1 = "CorePlayer";
        r2 = new java.lang.StringBuilder;
        r3 = "release throw a exception = ";
        r2.<init>(r3);
        r3 = r0.getMessage();
        r2 = r2.append(r3);
        r2 = r2.toString();
        r2 = r10.axiliary(r2);
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r1, r2, r0);
        goto L_0x0198;
    L_0x0368:
        r0 = move-exception;
        r1 = "CorePlayer";
        r2 = new java.lang.StringBuilder;
        r3 = "release dataSource throw a exception = ";
        r2.<init>(r3);
        r3 = r0.getMessage();
        r2 = r2.append(r3);
        r2 = r2.toString();
        r2 = r10.axiliary(r2);
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r1, r2, r0);
        goto L_0x01a1;
    L_0x0389:
        r0 = new com.tencent.qqmusic.mediaplayer.StreamDecodeDataComponent;	 Catch:{ Throwable -> 0x039e }
        r2 = r10.mStateRunner;	 Catch:{ Throwable -> 0x039e }
        r3 = r10.mInformation;	 Catch:{ Throwable -> 0x039e }
        r4 = r10.mCallback;	 Catch:{ Throwable -> 0x039e }
        r6 = r10.mEventHandler;	 Catch:{ Throwable -> 0x039e }
        r7 = r10.mPlayerID;	 Catch:{ Throwable -> 0x039e }
        r1 = r10;
        r5 = r10;
        r0.<init>(r1, r2, r3, r4, r5, r6, r7);	 Catch:{ Throwable -> 0x039e }
        r10.mPcmCompnent = r0;	 Catch:{ Throwable -> 0x039e }
        goto L_0x00b3;
    L_0x039e:
        r0 = move-exception;
        r1 = "CorePlayer";
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r1, r0);	 Catch:{ all -> 0x01e3 }
        r0 = r10.mPcmCompnent;
        if (r0 == 0) goto L_0x0459;
    L_0x03a9:
        r0 = "CorePlayer";
        r1 = new java.lang.StringBuilder;
        r2 = "thread finally, mIsExit = ";
        r1.<init>(r2);
        r2 = r10.mIsExit;
        r1 = r1.append(r2);
        r1 = r1.toString();
        r1 = r10.axiliary(r1);
        com.tencent.qqmusic.mediaplayer.util.Logger.i(r0, r1);
    L_0x03c5:
        com.tencent.qqmusic.mediaplayer.util.CpuInfoUtil.stopProcessInfoOutput();
        r0 = r10.mDecoder;	 Catch:{ Throwable -> 0x0468 }
        r0.release();	 Catch:{ Throwable -> 0x0468 }
    L_0x03cd:
        r0 = r10.mDataSource;
        if (r0 == 0) goto L_0x03d6;
    L_0x03d1:
        r0 = r10.mDataSource;	 Catch:{ IOException -> 0x0489 }
        r0.close();	 Catch:{ IOException -> 0x0489 }
    L_0x03d6:
        r0 = r10.mPcmCompnent;
        if (r0 == 0) goto L_0x03df;
    L_0x03da:
        r0 = r10.mPcmCompnent;
        r0.release();
    L_0x03df:
        r10.mPlayerMode = r9;
        r0 = "CorePlayer";
        r1 = new java.lang.StringBuilder;
        r2 = "exit, thread: ";
        r1.<init>(r2);
        r2 = java.lang.Thread.currentThread();
        r2 = r2.getName();
        r1 = r1.append(r2);
        r1 = r1.toString();
        r1 = r10.axiliary(r1);
        com.tencent.qqmusic.mediaplayer.util.Logger.i(r0, r1);
        com.tencent.matrix.trace.core.AppMethodBeat.o(r8);
        goto L_0x011d;
    L_0x0408:
        r0 = "CorePlayer";
        r1 = "thread finally, ERROR!!!, no mPcmCompnent";
        r1 = r10.axiliary(r1);
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r0, r1);
        goto L_0x00dc;
    L_0x0417:
        r0 = move-exception;
        r1 = "CorePlayer";
        r2 = new java.lang.StringBuilder;
        r3 = "release throw a exception = ";
        r2.<init>(r3);
        r3 = r0.getMessage();
        r2 = r2.append(r3);
        r2 = r2.toString();
        r2 = r10.axiliary(r2);
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r1, r2, r0);
        goto L_0x00e4;
    L_0x0438:
        r0 = move-exception;
        r1 = "CorePlayer";
        r2 = new java.lang.StringBuilder;
        r3 = "release dataSource throw a exception = ";
        r2.<init>(r3);
        r3 = r0.getMessage();
        r2 = r2.append(r3);
        r2 = r2.toString();
        r2 = r10.axiliary(r2);
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r1, r2, r0);
        goto L_0x00ed;
    L_0x0459:
        r0 = "CorePlayer";
        r1 = "thread finally, ERROR!!!, no mPcmCompnent";
        r1 = r10.axiliary(r1);
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r0, r1);
        goto L_0x03c5;
    L_0x0468:
        r0 = move-exception;
        r1 = "CorePlayer";
        r2 = new java.lang.StringBuilder;
        r3 = "release throw a exception = ";
        r2.<init>(r3);
        r3 = r0.getMessage();
        r2 = r2.append(r3);
        r2 = r2.toString();
        r2 = r10.axiliary(r2);
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r1, r2, r0);
        goto L_0x03cd;
    L_0x0489:
        r0 = move-exception;
        r1 = "CorePlayer";
        r2 = new java.lang.StringBuilder;
        r3 = "release dataSource throw a exception = ";
        r2.<init>(r3);
        r3 = r0.getMessage();
        r2 = r2.append(r3);
        r2 = r2.toString();
        r2 = r10.axiliary(r2);
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r1, r2, r0);
        goto L_0x03d6;
    L_0x04aa:
        r1 = "CorePlayer";
        r2 = "thread finally, ERROR!!!, no mPcmCompnent";
        r2 = r10.axiliary(r2);
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r1, r2);
        goto L_0x0204;
    L_0x04b9:
        r1 = move-exception;
        r2 = "CorePlayer";
        r3 = new java.lang.StringBuilder;
        r4 = "release throw a exception = ";
        r3.<init>(r4);
        r4 = r1.getMessage();
        r3 = r3.append(r4);
        r3 = r3.toString();
        r3 = r10.axiliary(r3);
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r2, r3, r1);
        goto L_0x020c;
    L_0x04da:
        r1 = move-exception;
        r2 = "CorePlayer";
        r3 = new java.lang.StringBuilder;
        r4 = "release dataSource throw a exception = ";
        r3.<init>(r4);
        r4 = r1.getMessage();
        r3 = r3.append(r4);
        r3 = r3.toString();
        r3 = r10.axiliary(r3);
        com.tencent.qqmusic.mediaplayer.util.Logger.e(r2, r3, r1);
        goto L_0x0215;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.qqmusic.mediaplayer.CorePlayer.run():void");
    }

    private void callExceptionCallback(int i, int i2) {
        AppMethodBeat.i(104642);
        callExceptionCallback(i, i2, 0);
        AppMethodBeat.o(104642);
    }

    private void callExceptionCallback(int i, int i2, int i3) {
        AppMethodBeat.i(104643);
        this.mCallback.playerException(this, i, i2, i3);
        AppMethodBeat.o(104643);
    }

    private String axiliary(String str) {
        AppMethodBeat.i(104644);
        String str2 = "ID: " + this.mPlayerID + ". " + str;
        AppMethodBeat.o(104644);
        return str2;
    }

    private void decodeEndOrFailed(int i, int i2) {
        AppMethodBeat.i(104645);
        Logger.d(TAG, axiliary("decodeEndOrFailed"));
        try {
            if (this.mPcmCompnent == null) {
                Logger.e(TAG, axiliary("mPcmCompnent null! Exiting"));
                AppMethodBeat.o(104645);
                return;
            }
            if (this.mInformation != null) {
                Logger.i(TAG, axiliary(String.format("current: %d, duration: %d, isExit: %b, decodeSucc: %b", new Object[]{Long.valueOf(this.mDecoder.getCurrentTime()), Long.valueOf(this.mInformation.getDuration()), Boolean.valueOf(this.mIsExit), Boolean.valueOf(this.mPcmCompnent.hasDecodeDataSuccess())})));
                i &= this.mDecoder.getErrorCodeMask();
            }
            if (this.mIsExit || !this.mPcmCompnent.hasDecodeDataSuccess()) {
                Logger.i(TAG, axiliary("不留痕迹的退出 时机：解码时退出  step = 4"));
                exitNotCallback();
                this.mStateRunner.transfer(Integer.valueOf(9));
                callExceptionCallback(i2, 67, i);
                AppMethodBeat.o(104645);
            } else if (getCurPositionByDecoder() < getDuration() - 5000) {
                Logger.e(TAG, axiliary("Decode failed! Exiting."));
                callExceptionCallback(i2, 67, i);
                this.mStateRunner.transfer(Integer.valueOf(6));
                AppMethodBeat.o(104645);
            } else {
                if (i2 == 92) {
                    Logger.i(TAG, axiliary("Decode ended! Exiting."));
                    this.mStateRunner.transfer(Integer.valueOf(7));
                }
                AppMethodBeat.o(104645);
            }
        } catch (Throwable th) {
            Logger.e(TAG, th);
            AppMethodBeat.o(104645);
        }
    }

    /* Access modifiers changed, original: 0000 */
    public long getDuration() {
        AppMethodBeat.i(104646);
        if (this.mInformation != null) {
            try {
                long duration = this.mInformation.getDuration();
                AppMethodBeat.o(104646);
                return duration;
            } catch (Throwable th) {
                Logger.e(TAG, th);
            }
        }
        AppMethodBeat.o(104646);
        return 0;
    }

    /* Access modifiers changed, original: 0000 */
    public int getPlayerState() {
        AppMethodBeat.i(104647);
        if (this.mPcmCompnent == null) {
            AppMethodBeat.o(104647);
            return 0;
        }
        int playerState = this.mPcmCompnent.getPlayerState();
        AppMethodBeat.o(104647);
        return playerState;
    }

    /* Access modifiers changed, original: 0000 */
    public long getCurPosition() {
        AppMethodBeat.i(104648);
        if (this.mPcmCompnent == null) {
            AppMethodBeat.o(104648);
            return 0;
        }
        long curPosition = this.mPcmCompnent.getCurPosition();
        AppMethodBeat.o(104648);
        return curPosition;
    }

    /* Access modifiers changed, original: declared_synchronized */
    public synchronized boolean hasDecodeData() {
        boolean z;
        AppMethodBeat.i(104649);
        if (this.mPcmCompnent == null) {
            z = false;
            AppMethodBeat.o(104649);
        } else {
            z = this.mPcmCompnent.hasDecodeData();
            AppMethodBeat.o(104649);
        }
        return z;
    }

    /* Access modifiers changed, original: declared_synchronized */
    public synchronized boolean hasDecodeDataSuccess() {
        boolean z;
        AppMethodBeat.i(104650);
        if (this.mPcmCompnent == null) {
            z = false;
            AppMethodBeat.o(104650);
        } else {
            z = this.mPcmCompnent.hasDecodeDataSuccess();
            AppMethodBeat.o(104650);
        }
        return z;
    }

    /* Access modifiers changed, original: 0000 */
    public boolean isInit() {
        AppMethodBeat.i(104651);
        if (this.mPcmCompnent == null) {
            AppMethodBeat.o(104651);
            return false;
        }
        boolean isInit = this.mPcmCompnent.isInit();
        AppMethodBeat.o(104651);
        return isInit;
    }

    /* Access modifiers changed, original: 0000 */
    public AudioInformation getCurrentAudioInformation() {
        return this.mInformation;
    }

    /* Access modifiers changed, original: 0000 */
    public int getSessionId() {
        AppMethodBeat.i(104652);
        if (this.mPcmCompnent != null) {
            int sessionId = this.mPcmCompnent.getSessionId();
            AppMethodBeat.o(104652);
            return sessionId;
        }
        AppMethodBeat.o(104652);
        return 0;
    }

    /* Access modifiers changed, original: 0000 */
    public void addAudioListener(IAudioListener iAudioListener) {
        AppMethodBeat.i(104653);
        if (this.mPcmCompnent != null) {
            this.mPcmCompnent.addAudioListener(iAudioListener);
        }
        AppMethodBeat.o(104653);
    }

    /* Access modifiers changed, original: 0000 */
    public void removeAudioListener(IAudioListener iAudioListener) {
        AppMethodBeat.i(104654);
        if (this.mPcmCompnent != null) {
            this.mPcmCompnent.removeAudioListener(iAudioListener);
        }
        AppMethodBeat.o(104654);
    }

    public void prepare() {
        AppMethodBeat.i(104655);
        Logger.i(TAG, axiliary("prepare"));
        this.mStateRunner.transfer(Integer.valueOf(3));
        new Thread(this, "decoder-" + this.mThreadName).start();
        AppMethodBeat.o(104655);
    }

    /* Access modifiers changed, original: 0000 */
    public void play() {
        AppMethodBeat.i(104656);
        Logger.i(TAG, axiliary("play"));
        if (this.mPcmCompnent == null) {
            AppMethodBeat.o(104656);
            return;
        }
        this.mPcmCompnent.play();
        AppMethodBeat.o(104656);
    }

    /* Access modifiers changed, original: 0000 */
    public void pause() {
        AppMethodBeat.i(104657);
        Logger.i(TAG, axiliary("pause"));
        if (this.mPcmCompnent == null) {
            AppMethodBeat.o(104657);
            return;
        }
        this.mPcmCompnent.pause();
        AppMethodBeat.o(104657);
    }

    /* Access modifiers changed, original: 0000 */
    public void stop() {
        AppMethodBeat.i(104658);
        Logger.i(TAG, axiliary("stop"));
        if (this.mPcmCompnent == null) {
            AppMethodBeat.o(104658);
            return;
        }
        this.mPcmCompnent.stop();
        AppMethodBeat.o(104658);
    }

    public void release() {
        AppMethodBeat.i(104659);
        Logger.i(TAG, axiliary(BuildConfig.BUILD_TYPE));
        this.mEventHandler.removeCallbacksAndMessages(null);
        exitNotCallback();
        if (this.mPcmCompnent != null) {
            this.mPcmCompnent.releaseNotify();
        }
        this.mStateRunner.transfer(Integer.valueOf(8));
        AppMethodBeat.o(104659);
    }

    /* Access modifiers changed, original: 0000 */
    public void setVolume(float f, float f2) {
        AppMethodBeat.i(104660);
        if (this.mPcmCompnent != null) {
            this.mPcmCompnent.setVolume(f, f2);
        }
        AppMethodBeat.o(104660);
    }

    /* Access modifiers changed, original: 0000 */
    public void flush() {
        AppMethodBeat.i(104661);
        if (this.mPcmCompnent != null) {
            this.mPcmCompnent.flush();
        }
        AppMethodBeat.o(104661);
    }

    /* Access modifiers changed, original: 0000 */
    public void setAudioStreamType(int i) {
        AppMethodBeat.i(104662);
        if (this.mPcmCompnent != null) {
            this.mPcmCompnent.setAudioStreamType(i);
        }
        AppMethodBeat.o(104662);
    }

    /* Access modifiers changed, original: 0000 */
    public void setPlayerMode(int i) {
        this.mPlayerMode = i;
    }

    /* Access modifiers changed, original: 0000 */
    public int getPlayerMode() {
        return this.mPlayerMode;
    }

    public void seek(int i) {
        AppMethodBeat.i(104663);
        if (this.mPcmCompnent != null) {
            this.mPcmCompnent.seek(i);
        }
        AppMethodBeat.o(104663);
    }

    /* Access modifiers changed, original: 0000 */
    public SeekTable createSeekTable() {
        AppMethodBeat.i(104664);
        if (this.mDecoder == null) {
            IllegalStateException illegalStateException = new IllegalStateException("please setDataSource before creating seek table!");
            AppMethodBeat.o(104664);
            throw illegalStateException;
        }
        NativeSeekTable nativeSeekTable = new NativeSeekTable(this.mDecoder);
        AppMethodBeat.o(104664);
        return nativeSeekTable;
    }

    public int seekTo(int i) {
        AppMethodBeat.i(104665);
        int seekTo = this.mDecoder.seekTo(i);
        AppMethodBeat.o(104665);
        return seekTo;
    }

    public long getCurPositionByDecoder() {
        AppMethodBeat.i(104666);
        try {
            long currentTime = this.mDecoder.getCurrentTime();
            AppMethodBeat.o(104666);
            return currentTime;
        } catch (SoNotFindException e) {
            Logger.e(TAG, e);
            AppMethodBeat.o(104666);
            return 0;
        } catch (Throwable th) {
            Logger.e(TAG, "Strange Exception!", th);
            AppMethodBeat.o(104666);
            return 0;
        }
    }

    public long getMinPcmBufferSize() {
        AppMethodBeat.i(104667);
        long minBufferSize = this.mDecoder.getMinBufferSize();
        AppMethodBeat.o(104667);
        return minBufferSize;
    }

    public int pullDecodeData(int i, byte[] bArr) {
        AppMethodBeat.i(104668);
        int decodeData = this.mDecoder.decodeData(i, bArr);
        AppMethodBeat.o(104668);
        return decodeData;
    }

    public void onPullDecodeDataEndOrFailed(int i, int i2) {
        AppMethodBeat.i(104669);
        decodeEndOrFailed(i, i2);
        AppMethodBeat.o(104669);
    }
}
