package com.tencent.tmassistantsdk.storage.table;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.text.TextUtils;
import com.tencent.matrix.trace.core.AppMethodBeat;
import com.tencent.mm.sdk.platformtools.ab;
import com.tencent.tmassistantsdk.storage.helper.AstSDKDBHelper_V2;
import com.tencent.tmassistantsdk.storage.helper.SqliteHelper;
import com.tencent.tmassistantsdk.storage.model.ClientInfo;

public class ClientInfoTable implements ITableBase {
    public static final String CREATE_TABLE_SQL = "CREATE TABLE if not exists clientinfo( _id INTEGER PRIMARY KEY AUTOINCREMENT, clientId TEXT , taskId INTEGER, taskUrl TEXT);";
    public static final String QUERY_CLIENTINFO = "select * from clientinfo where clientId = ?";
    public static final String QUERY_CLIENTINFO_ALL = "select * from clientinfo";
    public static final String TABLE_NAME = "clientinfo";
    private static final String TAG = "ClientInfoTable";

    private static void fillValues(ContentValues contentValues, ClientInfo clientInfo) {
        AppMethodBeat.i(76184);
        if (clientInfo != null) {
            contentValues.put("clientId", clientInfo.clientId);
            contentValues.put("taskId", Integer.valueOf(clientInfo.taskId));
            contentValues.put("taskUrl", clientInfo.taskUrl);
        }
        AppMethodBeat.o(76184);
    }

    private static ClientInfo cursor2object(Cursor cursor) {
        AppMethodBeat.i(76185);
        ClientInfo clientInfo = new ClientInfo();
        clientInfo.clientId = cursor.getString(cursor.getColumnIndex("clientId"));
        clientInfo.taskId = cursor.getInt(cursor.getColumnIndex("taskId"));
        clientInfo.taskUrl = cursor.getString(cursor.getColumnIndex("taskUrl"));
        AppMethodBeat.o(76185);
        return clientInfo;
    }

    public static void save(ClientInfo clientInfo) {
        AppMethodBeat.i(76186);
        if (clientInfo != null) {
            try {
                SQLiteDatabase writableDatabase = AstSDKDBHelper_V2.getInstance().getWritableDatabase();
                if (update(clientInfo, writableDatabase) <= 0) {
                    ContentValues contentValues = new ContentValues();
                    fillValues(contentValues, clientInfo);
                    writableDatabase.insert(TABLE_NAME, null, contentValues);
                }
                AppMethodBeat.o(76186);
                return;
            } catch (Exception e) {
                ab.printErrStackTrace(TAG, e, "", new Object[0]);
            }
        }
        AppMethodBeat.o(76186);
    }

    public static void save(String str, String str2) {
        AppMethodBeat.i(76187);
        ClientInfo clientInfo = new ClientInfo();
        clientInfo.clientId = str;
        clientInfo.taskUrl = str2;
        save(clientInfo);
        AppMethodBeat.o(76187);
    }

    private static int update(ClientInfo clientInfo, SQLiteDatabase sQLiteDatabase) {
        AppMethodBeat.i(76188);
        if (clientInfo == null) {
            AppMethodBeat.o(76188);
            return -1;
        }
        try {
            ContentValues contentValues = new ContentValues();
            fillValues(contentValues, clientInfo);
            int update = sQLiteDatabase.update(TABLE_NAME, contentValues, "clientId = ? and taskUrl = ?", new String[]{clientInfo.clientId, clientInfo.taskUrl});
            if (update > 0) {
                AppMethodBeat.o(76188);
                return update;
            }
            AppMethodBeat.o(76188);
            return 0;
        } catch (Exception e) {
            ab.printErrStackTrace(TAG, e, "", new Object[0]);
            AppMethodBeat.o(76188);
            return -2;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:24:0x005d  */
    public static java.util.ArrayList<com.tencent.tmassistantsdk.storage.model.ClientInfo> query(java.lang.String r7) {
        /*
        r1 = 0;
        r6 = 76189; // 0x1299d float:1.06764E-40 double:3.76424E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r6);
        if (r7 == 0) goto L_0x0054;
    L_0x0009:
        r0 = new java.util.ArrayList;
        r0.<init>();
        r2 = com.tencent.tmassistantsdk.storage.helper.AstSDKDBHelper_V2.getInstance();
        r2 = r2.getReadableDatabase();
        r3 = "select * from clientinfo where clientId = ?";
        r4 = 1;
        r4 = new java.lang.String[r4];	 Catch:{ Exception -> 0x0041, all -> 0x0059 }
        r5 = 0;
        r4[r5] = r7;	 Catch:{ Exception -> 0x0041, all -> 0x0059 }
        r2 = r2.rawQuery(r3, r4);	 Catch:{ Exception -> 0x0041, all -> 0x0059 }
        if (r2 == 0) goto L_0x0038;
    L_0x0025:
        r3 = r2.moveToFirst();	 Catch:{ Exception -> 0x0066 }
        if (r3 == 0) goto L_0x0038;
    L_0x002b:
        r3 = cursor2object(r2);	 Catch:{ Exception -> 0x0066 }
        r0.add(r3);	 Catch:{ Exception -> 0x0066 }
        r3 = r2.moveToNext();	 Catch:{ Exception -> 0x0066 }
        if (r3 != 0) goto L_0x002b;
    L_0x0038:
        if (r2 == 0) goto L_0x003d;
    L_0x003a:
        r2.close();
    L_0x003d:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r6);
    L_0x0040:
        return r0;
    L_0x0041:
        r0 = move-exception;
        r2 = r1;
    L_0x0043:
        r3 = "ClientInfoTable";
        r4 = "";
        r5 = 0;
        r5 = new java.lang.Object[r5];	 Catch:{ all -> 0x0064 }
        com.tencent.mm.sdk.platformtools.ab.printErrStackTrace(r3, r0, r4, r5);	 Catch:{ all -> 0x0064 }
        if (r2 == 0) goto L_0x0054;
    L_0x0051:
        r2.close();
    L_0x0054:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r6);
        r0 = r1;
        goto L_0x0040;
    L_0x0059:
        r0 = move-exception;
        r2 = r1;
    L_0x005b:
        if (r2 == 0) goto L_0x0060;
    L_0x005d:
        r2.close();
    L_0x0060:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r6);
        throw r0;
    L_0x0064:
        r0 = move-exception;
        goto L_0x005b;
    L_0x0066:
        r0 = move-exception;
        goto L_0x0043;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.tmassistantsdk.storage.table.ClientInfoTable.query(java.lang.String):java.util.ArrayList");
    }

    public static void delete(String str, String str2) {
        AppMethodBeat.i(76190);
        if (!(str == null || str2 == null)) {
            try {
                AstSDKDBHelper_V2.getInstance().getWritableDatabase().delete(TABLE_NAME, "clientId = ? and taskUrl = ?", new String[]{str, str2});
                AppMethodBeat.o(76190);
                return;
            } catch (Exception e) {
                ab.printErrStackTrace(TAG, e, "", new Object[0]);
            }
        }
        AppMethodBeat.o(76190);
    }

    public static void deleteItemsByURL(String str) {
        AppMethodBeat.i(76191);
        if (!TextUtils.isEmpty(str)) {
            try {
                AstSDKDBHelper_V2.getInstance().getWritableDatabase().delete(TABLE_NAME, "taskUrl = ?", new String[]{str});
                AppMethodBeat.o(76191);
                return;
            } catch (Exception e) {
                ab.printErrStackTrace(TAG, e, "", new Object[0]);
            }
        }
        AppMethodBeat.o(76191);
    }

    public String tableName() {
        return TABLE_NAME;
    }

    public String createTableSQL() {
        return CREATE_TABLE_SQL;
    }

    public String[] getAlterSQL(int i, int i2) {
        return null;
    }

    public SqliteHelper getHelper() {
        AppMethodBeat.i(76192);
        SqliteHelper instance = AstSDKDBHelper_V2.getInstance();
        AppMethodBeat.o(76192);
        return instance;
    }

    /* JADX WARNING: Removed duplicated region for block: B:12:0x0039  */
    public void dataMovement(android.database.sqlite.SQLiteDatabase r7, android.database.sqlite.SQLiteDatabase r8) {
        /*
        r6 = this;
        r1 = 0;
        r5 = 76193; // 0x129a1 float:1.06769E-40 double:3.76443E-319;
        com.tencent.matrix.trace.core.AppMethodBeat.i(r5);
        if (r8 == 0) goto L_0x0042;
    L_0x0009:
        if (r7 == 0) goto L_0x0042;
    L_0x000b:
        r8.beginTransaction();
        r0 = "select * from clientinfo";
        r2 = 0;
        r1 = r7.rawQuery(r0, r2);	 Catch:{ Exception -> 0x0046 }
        if (r1 == 0) goto L_0x0037;
    L_0x0018:
        r0 = r1.moveToFirst();	 Catch:{ Exception -> 0x0046 }
        if (r0 == 0) goto L_0x0037;
    L_0x001e:
        r0 = new android.content.ContentValues;	 Catch:{ Exception -> 0x0046 }
        r0.<init>();	 Catch:{ Exception -> 0x0046 }
        r2 = cursor2object(r1);	 Catch:{ Exception -> 0x0046 }
        fillValues(r0, r2);	 Catch:{ Exception -> 0x0046 }
        r2 = "clientinfo";
        r3 = 0;
        r8.insert(r2, r3, r0);	 Catch:{ Exception -> 0x0046 }
        r0 = r1.moveToNext();	 Catch:{ Exception -> 0x0046 }
        if (r0 != 0) goto L_0x001e;
    L_0x0037:
        if (r1 == 0) goto L_0x003c;
    L_0x0039:
        r1.close();
    L_0x003c:
        r8.setTransactionSuccessful();
        r8.endTransaction();
    L_0x0042:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
        return;
    L_0x0046:
        r0 = move-exception;
        r2 = "ClientInfoTable";
        r3 = "";
        r4 = 0;
        r4 = new java.lang.Object[r4];	 Catch:{ all -> 0x0059 }
        com.tencent.mm.sdk.platformtools.ab.printErrStackTrace(r2, r0, r3, r4);	 Catch:{ all -> 0x0059 }
        if (r1 == 0) goto L_0x003c;
    L_0x0055:
        r1.close();
        goto L_0x003c;
    L_0x0059:
        r0 = move-exception;
        if (r1 == 0) goto L_0x005f;
    L_0x005c:
        r1.close();
    L_0x005f:
        com.tencent.matrix.trace.core.AppMethodBeat.o(r5);
        throw r0;
        */
        throw new UnsupportedOperationException("Method not decompiled: com.tencent.tmassistantsdk.storage.table.ClientInfoTable.dataMovement(android.database.sqlite.SQLiteDatabase, android.database.sqlite.SQLiteDatabase):void");
    }
}
